@@ -21,8 +21,7 @@ import 'dart:collection';
 import 'dart:convert' hide Codec;
 import 'dart:developer' as developer;
 import 'dart:js_util' as js_util;
-import 'dart:_js_annotations';
-import 'dart:js_interop' hide JS;
+import 'dart:js_interop';
 import 'dart:js_interop_unsafe';
 import 'dart:math' as math;
 import 'dart:typed_data';
@@ -37,7 +36,6 @@ import 'dart:_web_locale_keymap' as locale_keymap;
 part 'engine/alarm_clock.dart';
 part 'engine/app_bootstrap.dart';
 part 'engine/browser_detection.dart';
-part 'engine/canvas_pool.dart';
 part 'engine/canvaskit/canvas.dart';
 part 'engine/canvaskit/canvaskit_api.dart';
 part 'engine/canvaskit/canvaskit_canvas.dart';
@@ -52,6 +50,7 @@ part 'engine/canvaskit/image_web_codecs.dart';
 part 'engine/canvaskit/layer.dart';
 part 'engine/canvaskit/layer_scene_builder.dart';
 part 'engine/canvaskit/layer_tree.dart';
+part 'engine/canvaskit/layer_visitor.dart';
 part 'engine/canvaskit/mask_filter.dart';
 part 'engine/canvaskit/multi_surface_rasterizer.dart';
 part 'engine/canvaskit/n_way_canvas.dart';
@@ -78,55 +77,16 @@ part 'engine/color_filter.dart';
 part 'engine/configuration.dart';
 part 'engine/display.dart';
 part 'engine/dom.dart';
-part 'engine/engine_canvas.dart';
 part 'engine/font_change_util.dart';
 part 'engine/font_fallback_data.dart';
 part 'engine/font_fallbacks.dart';
 part 'engine/fonts.dart';
-part 'engine/frame_reference.dart';
+part 'engine/frame_service.dart';
 part 'engine/frame_timing_recorder.dart';
-part 'engine/html/backdrop_filter.dart';
-part 'engine/html/bitmap_canvas.dart';
-part 'engine/html/canvas.dart';
-part 'engine/html/clip.dart';
-part 'engine/html/color_filter.dart';
-part 'engine/html/debug_canvas_reuse_overlay.dart';
-part 'engine/html/dom_canvas.dart';
-part 'engine/html/image.dart';
-part 'engine/html/image_filter.dart';
-part 'engine/html/offset.dart';
-part 'engine/html/opacity.dart';
-part 'engine/html/painting.dart';
-part 'engine/html/path/conic.dart';
-part 'engine/html/path/cubic.dart';
-part 'engine/html/path/path.dart';
-part 'engine/html/path/path_iterator.dart';
-part 'engine/html/path/path_metrics.dart';
-part 'engine/html/path/path_ref.dart';
-part 'engine/html/path/path_to_svg.dart';
-part 'engine/html/path/path_utils.dart';
-part 'engine/html/path/path_windings.dart';
-part 'engine/html/path/tangent.dart';
-part 'engine/html/path_to_svg_clip.dart';
-part 'engine/html/picture.dart';
-part 'engine/html/platform_view.dart';
-part 'engine/html/recording_canvas.dart';
-part 'engine/html/render_vertices.dart';
-part 'engine/html/renderer.dart';
-part 'engine/html/resource_manager.dart';
-part 'engine/html/scene.dart';
-part 'engine/html/scene_builder.dart';
-part 'engine/html/shader_mask.dart';
-part 'engine/html/shaders/image_shader.dart';
-part 'engine/html/shaders/normalized_gradient.dart';
-part 'engine/html/shaders/shader.dart';
-part 'engine/html/shaders/shader_builder.dart';
-part 'engine/html/shaders/vertex_shaders.dart';
-part 'engine/html/surface.dart';
-part 'engine/html/surface_stats.dart';
-part 'engine/html/transform.dart';
+part 'engine/high_contrast.dart';
 part 'engine/html_image_element_codec.dart';
 part 'engine/image_decoder.dart';
+part 'engine/image_format_detector.dart';
 part 'engine/initialization.dart';
 part 'engine/js_interop/js_app.dart';
 part 'engine/js_interop/js_loader.dart';
@@ -162,19 +122,28 @@ part 'engine/scene_builder.dart';
 part 'engine/scene_painting.dart';
 part 'engine/scene_view.dart';
 part 'engine/semantics/accessibility.dart';
+part 'engine/semantics/alert.dart';
 part 'engine/semantics/checkable.dart';
-part 'engine/semantics/dialog.dart';
+part 'engine/semantics/disable.dart';
+part 'engine/semantics/expandable.dart';
 part 'engine/semantics/focusable.dart';
+part 'engine/semantics/header.dart';
 part 'engine/semantics/heading.dart';
 part 'engine/semantics/image.dart';
 part 'engine/semantics/incrementable.dart';
 part 'engine/semantics/label_and_value.dart';
 part 'engine/semantics/link.dart';
+part 'engine/semantics/list.dart';
 part 'engine/semantics/live_region.dart';
+part 'engine/semantics/menus.dart';
 part 'engine/semantics/platform_view.dart';
+part 'engine/semantics/requirable.dart';
+part 'engine/semantics/route.dart';
 part 'engine/semantics/scrollable.dart';
 part 'engine/semantics/semantics.dart';
 part 'engine/semantics/semantics_helper.dart';
+part 'engine/semantics/table.dart';
+part 'engine/semantics/tabs.dart';
 part 'engine/semantics/tappable.dart';
 part 'engine/semantics/text_field.dart';
 part 'engine/services/buffers.dart';
@@ -185,21 +154,8 @@ part 'engine/shader_data.dart';
 part 'engine/shadow.dart';
 part 'engine/svg.dart';
 part 'engine/test_embedding.dart';
-part 'engine/text/canvas_paragraph.dart';
-part 'engine/text/font_collection.dart';
-part 'engine/text/fragmenter.dart';
-part 'engine/text/layout_fragmenter.dart';
-part 'engine/text/layout_service.dart';
-part 'engine/text/line_break_properties.dart';
 part 'engine/text/line_breaker.dart';
-part 'engine/text/measurement.dart';
-part 'engine/text/paint_service.dart';
 part 'engine/text/paragraph.dart';
-part 'engine/text/ruler.dart';
-part 'engine/text/text_direction.dart';
-part 'engine/text/unicode_range.dart';
-part 'engine/text/word_break_properties.dart';
-part 'engine/text/word_breaker.dart';
 part 'engine/text_editing/autofill_hint.dart';
 part 'engine/text_editing/composition_aware_mixin.dart';
 part 'engine/text_editing/input_action.dart';
