@@ -21,26 +21,9 @@ class CkBrowserImageDecoder extends BrowserImageDecoder {
 
   static Future<CkBrowserImageDecoder> create({
     required Uint8List data,
+    required String contentType,
     required String debugSource,
   }) async {
-    // ImageDecoder does not detect image type automatically. It requires us to
-    // tell it what the image type is.
-    final String? contentType = detectContentType(data);
-
-    if (contentType == null) {
-      final String fileHeader;
-      if (data.isNotEmpty) {
-        fileHeader = '[${bytesToHexString(data.sublist(0, math.min(10, data.length)))}]';
-      } else {
-        fileHeader = 'empty';
-      }
-      throw ImageCodecException(
-        'Failed to detect image file format using the file header.\n'
-        'File header was $fileHeader.\n'
-        'Image source: $debugSource'
-      );
-    }
-
     final CkBrowserImageDecoder decoder = CkBrowserImageDecoder._(
       contentType: contentType,
       dataSource: data.toJS,
@@ -70,13 +53,17 @@ class CkBrowserImageDecoder extends BrowserImageDecoder {
       );
     }
 
-    return CkImage(skImage, videoFrame: frame);
+    return CkImage(skImage, imageSource: VideoFrameImageSource(frame));
   }
 }
 
 Future<ByteData> readPixelsFromVideoFrame(VideoFrame videoFrame, ui.ImageByteFormat format) async {
   if (format == ui.ImageByteFormat.png) {
-    final Uint8List png = await encodeVideoFrameAsPng(videoFrame);
+    final Uint8List png = await encodeDomImageSourceAsPng(
+      videoFrame,
+      videoFrame.displayWidth.toInt(),
+      videoFrame.displayHeight.toInt(),
+    );
     return png.buffer.asByteData();
   }
 
@@ -106,6 +93,21 @@ Future<ByteData> readPixelsFromVideoFrame(VideoFrame videoFrame, ui.ImageByteFor
   return pixels.asByteData();
 }
 
+Future<ByteData> readPixelsFromDomImageSource(
+  DomCanvasImageSource imageSource,
+  ui.ImageByteFormat format,
+  int width,
+  int height,
+) async {
+  if (format == ui.ImageByteFormat.png) {
+    final Uint8List png = await encodeDomImageSourceAsPng(imageSource, width, height);
+    return png.buffer.asByteData();
+  }
+
+  final ByteBuffer pixels = readDomImageSourcePixelsUnmodified(imageSource, width, height);
+  return pixels.asByteData();
+}
+
 /// Mutates the [pixels], converting them from BGRX/BGRA to RGBA.
 void _bgrToStraightRgba(ByteBuffer pixels, bool isBgrx) {
   final Uint8List pixelBytes = pixels.asUint8List();
@@ -169,7 +171,7 @@ Future<ByteBuffer> readVideoFramePixelsUnmodified(VideoFrame videoFrame) async {
 
   // In dart2wasm, Uint8List is not the same as a JS Uint8Array. So we
   // explicitly construct the JS object here.
-  final JSUint8Array destination = createUint8ArrayFromLength(size);
+  final JSUint8Array destination = JSUint8Array.withLength(size);
   final JSPromise<JSAny?> copyPromise = videoFrame.copyTo(destination);
   await promiseToFuture<void>(copyPromise);
 
@@ -178,13 +180,35 @@ Future<ByteBuffer> readVideoFramePixelsUnmodified(VideoFrame videoFrame) async {
   return destination.toDart.buffer;
 }
 
-Future<Uint8List> encodeVideoFrameAsPng(VideoFrame videoFrame) async {
-  final int width = videoFrame.displayWidth.toInt();
-  final int height = videoFrame.displayHeight.toInt();
-  final DomCanvasElement canvas = createDomCanvasElement(width: width, height:
-      height);
+ByteBuffer readDomImageSourcePixelsUnmodified(
+  DomCanvasImageSource imageSource,
+  int width,
+  int height,
+) {
+  final DomHTMLCanvasElement htmlCanvas = createDomCanvasElement(width: width, height: height);
+  final DomCanvasRenderingContext2D ctx =
+      htmlCanvas.getContext('2d')! as DomCanvasRenderingContext2D;
+  ctx.drawImage(imageSource, 0, 0);
+  final DomImageData imageData = ctx.getImageData(0, 0, width, height);
+  // Resize the canvas to 0x0 to cause the browser to reclaim its memory
+  // eagerly.
+  htmlCanvas.width = 0;
+  htmlCanvas.height = 0;
+  return imageData.data.buffer;
+}
+
+Future<Uint8List> encodeDomImageSourceAsPng(
+  DomCanvasImageSource imageSource,
+  int width,
+  int height,
+) async {
+  final DomHTMLCanvasElement canvas = createDomCanvasElement(width: width, height: height);
   final DomCanvasRenderingContext2D ctx = canvas.context2D;
-  ctx.drawImage(videoFrame, 0, 0);
+  ctx.drawImage(imageSource, 0, 0);
   final String pngBase64 = canvas.toDataURL().substring('data:image/png;base64,'.length);
+  // Resize the canvas to 0x0 to cause the browser to reclaim its memory
+  // eagerly.
+  canvas.width = 0;
+  canvas.height = 0;
   return base64.decode(pngBase64);
 }
