@@ -100,6 +100,13 @@ class CkPath implements ScenePath {
     skiaObject.addRRect(toSkRRect(rrect), false);
   }
 
+  @override
+  void addRSuperellipse(ui.RSuperellipse rsuperellipse) {
+    // TODO(dkwingsmt): Properly implement RSuperellipse on Web instead of falling
+    // back to RRect.  https://github.com/flutter/flutter/issues/163718
+    addRRect(rsuperellipse.toApproximateRRect());
+  }
+
   @override
   void addRect(ui.Rect rect) {
     skiaObject.addRect(toSkRect(rect));
