@@ -7,12 +7,10 @@ part of dart._engine;
 
 
 class CkPictureRecorder implements ui.PictureRecorder {
-  ui.Rect? _cullRect;
   SkPictureRecorder? _skRecorder;
   CkCanvas? _recordingCanvas;
 
   CkCanvas beginRecording(ui.Rect bounds) {
-    _cullRect = bounds;
     final SkPictureRecorder recorder = _skRecorder = SkPictureRecorder();
     final Float32List skRect = toSkRect(bounds);
     final SkCanvas skCanvas = recorder.beginRecording(skRect);
@@ -32,7 +30,7 @@ class CkPictureRecorder implements ui.PictureRecorder {
     final SkPicture skPicture = recorder.finishRecordingAsPicture();
     recorder.delete();
     _skRecorder = null;
-    final CkPicture result = CkPicture(skPicture, _cullRect);
+    final CkPicture result = CkPicture(skPicture);
     // We invoke the handler here, not in the picture constructor, because we want
     // [result.approximateBytesUsed] to be available for the handler.
     ui.Picture.onCreate?.call(result);
