@@ -39,12 +39,31 @@ class CanvasKitRenderer implements Renderer {
   DomElement? _sceneHost;
   DomElement? get sceneHost => _sceneHost;
 
-  /// This is an SkSurface backed by an OffScreenCanvas. This single Surface is
-  /// used to render to many RenderCanvases to produce the rendered scene.
-  final Surface offscreenSurface = Surface();
+  Rasterizer _rasterizer = _createRasterizer();
 
-  set resourceCacheMaxBytes(int bytes) =>
-      offscreenSurface.setSkiaResourceCacheMaxBytes(bytes);
+  static Rasterizer _createRasterizer() {
+    if (configuration.canvasKitForceMultiSurfaceRasterizer || isSafari || isFirefox) {
+      return MultiSurfaceRasterizer();
+    }
+    return OffscreenCanvasRasterizer();
+  }
+
+  /// Resets the [Rasterizer] to the default value. Used in tests.
+  void debugResetRasterizer() {
+    _rasterizer = _createRasterizer();
+  }
+
+  /// Override the rasterizer with the given [_rasterizer]. Used in tests.
+  void debugOverrideRasterizer(Rasterizer testRasterizer) {
+    _rasterizer = testRasterizer;
+  }
+
+  /// Returns the current [Rasterizer]. Used in tests.
+  Rasterizer debugGetRasterizer() {
+    return _rasterizer;
+  }
+
+  set resourceCacheMaxBytes(int bytes) => _rasterizer.setResourceCacheMaxBytes(bytes);
 
   /// A surface used specifically for `Picture.toImage` when software rendering
   /// is supported.
@@ -60,6 +79,9 @@ class CanvasKitRenderer implements Renderer {
     _initialized ??= () async {
       if (windowFlutterCanvasKit != null) {
         canvasKit = windowFlutterCanvasKit!;
+      } else if (windowFlutterCanvasKitLoaded != null) {
+        // CanvasKit is being preloaded by flutter.js. Wait for it to complete.
+        canvasKit = await promiseToFuture<CanvasKit>(windowFlutterCanvasKitLoaded!);
       } else {
         canvasKit = await downloadCanvasKit();
         windowFlutterCanvasKit = canvasKit;
@@ -67,27 +89,19 @@ class CanvasKitRenderer implements Renderer {
       // Views may have been registered before this renderer was initialized.
       // Create rasterizers for them and then start listening for new view
       // creation/disposal events.
-      final FlutterViewManager viewManager =
-          EnginePlatformDispatcher.instance.viewManager;
+      final FlutterViewManager viewManager = EnginePlatformDispatcher.instance.viewManager;
       if (_onViewCreatedListener == null) {
         for (final EngineFlutterView view in viewManager.views) {
           _onViewCreated(view.viewId);
         }
       }
-      _onViewCreatedListener ??=
-          viewManager.onViewCreated.listen(_onViewCreated);
-      _onViewDisposedListener ??=
-          viewManager.onViewDisposed.listen(_onViewDisposed);
+      _onViewCreatedListener ??= viewManager.onViewCreated.listen(_onViewCreated);
+      _onViewDisposedListener ??= viewManager.onViewDisposed.listen(_onViewDisposed);
       _instance = this;
     }();
     return _initialized;
   }
 
-  @override
-  void reset(FlutterViewEmbedder embedder) {
-    // No work required.
-  }
-
   @override
   ui.Paint createPaint() => CkPaint();
 
@@ -103,7 +117,8 @@ class CanvasKitRenderer implements Renderer {
     positions,
     textureCoordinates: textureCoordinates,
     colors: colors,
-    indices: indices);
+    indices: indices,
+  );
 
   @override
   ui.Vertices createVerticesRaw(
@@ -117,11 +132,12 @@ class CanvasKitRenderer implements Renderer {
     positions,
     textureCoordinates: textureCoordinates,
     colors: colors,
-    indices: indices);
+    indices: indices,
+  );
 
   @override
   ui.Canvas createCanvas(ui.PictureRecorder recorder, [ui.Rect? cullRect]) =>
-    CanvasKitCanvas(recorder, cullRect);
+      CanvasKitCanvas(recorder, cullRect);
 
   @override
   ui.Gradient createLinearGradient(
@@ -130,7 +146,7 @@ class CanvasKitRenderer implements Renderer {
     List<ui.Color> colors, [
     List<double>? colorStops,
     ui.TileMode tileMode = ui.TileMode.clamp,
-    Float32List? matrix4
+    Float32List? matrix4,
   ]) => CkGradientLinear(from, to, colors, colorStops, tileMode, matrix4);
 
   @override
@@ -149,19 +165,11 @@ class CanvasKitRenderer implements Renderer {
     double focalRadius,
     ui.Offset center,
     double radius,
-    List<ui.Color> colors,
-    [List<double>? colorStops,
+    List<ui.Color> colors, [
+    List<double>? colorStops,
     ui.TileMode tileMode = ui.TileMode.clamp,
-    Float32List? matrix]
-  ) => CkGradientConical(
-    focal,
-    focalRadius,
-    center,
-    radius,
-    colors,
-    colorStops,
-    tileMode,
-    matrix);
+    Float32List? matrix,
+  ]) => CkGradientConical(focal, focalRadius, center, radius, colors, colorStops, tileMode, matrix);
 
   @override
   ui.Gradient createSweepGradient(
@@ -171,7 +179,7 @@ class CanvasKitRenderer implements Renderer {
     ui.TileMode tileMode = ui.TileMode.clamp,
     double startAngle = 0.0,
     double endAngle = math.pi * 2,
-    Float32List? matrix4
+    Float32List? matrix4,
   ]) => CkGradientSweep(center, colors, colorStops, tileMode, startAngle, endAngle, matrix4);
 
   @override
@@ -184,30 +192,28 @@ class CanvasKitRenderer implements Renderer {
   ui.ImageFilter createBlurImageFilter({
     double sigmaX = 0.0,
     double sigmaY = 0.0,
-    ui.TileMode tileMode = ui.TileMode.clamp
+    ui.TileMode? tileMode,
   }) => CkImageFilter.blur(sigmaX: sigmaX, sigmaY: sigmaY, tileMode: tileMode);
 
   @override
-  ui.ImageFilter createDilateImageFilter({double radiusX = 0.0, double radiusY = 0.0}) {
-    // TODO(fzyzcjy): implement dilate. https://github.com/flutter/flutter/issues/101085
-    throw UnimplementedError('ImageFilter.dilate not implemented for CanvasKit.');
-  }
+  ui.ImageFilter createDilateImageFilter({double radiusX = 0.0, double radiusY = 0.0}) =>
+      CkImageFilter.dilate(radiusX: radiusX, radiusY: radiusY);
 
   @override
-  ui.ImageFilter createErodeImageFilter({double radiusX = 0.0, double radiusY = 0.0}) {
-    // TODO(fzyzcjy): implement erode. https://github.com/flutter/flutter/issues/101085
-    throw UnimplementedError('ImageFilter.erode not implemented for CanvasKit.');
-  }
+  ui.ImageFilter createErodeImageFilter({double radiusX = 0.0, double radiusY = 0.0}) =>
+      CkImageFilter.erode(radiusX: radiusX, radiusY: radiusY);
 
   @override
   ui.ImageFilter createMatrixImageFilter(
     Float64List matrix4, {
-    ui.FilterQuality filterQuality = ui.FilterQuality.low
+    ui.FilterQuality filterQuality = ui.FilterQuality.low,
   }) => CkImageFilter.matrix(matrix: matrix4, filterQuality: filterQuality);
 
   @override
-  ui.ImageFilter composeImageFilters(
-      {required ui.ImageFilter outer, required ui.ImageFilter inner}) {
+  ui.ImageFilter composeImageFilters({
+    required ui.ImageFilter outer,
+    required ui.ImageFilter inner,
+  }) {
     if (outer is EngineColorFilter) {
       final CkColorFilter colorFilter = createCkColorFilter(outer)!;
       outer = CkColorFilterImageFilter(colorFilter: colorFilter);
@@ -216,8 +222,7 @@ class CanvasKitRenderer implements Renderer {
       final CkColorFilter colorFilter = createCkColorFilter(inner)!;
       inner = CkColorFilterImageFilter(colorFilter: colorFilter);
     }
-    return CkImageFilter.compose(
-          outer: outer as CkImageFilter, inner: inner as CkImageFilter);
+    return CkImageFilter.compose(outer: outer as CkImageFilter, inner: inner as CkImageFilter);
   }
 
   @override
@@ -225,25 +230,51 @@ class CanvasKitRenderer implements Renderer {
     Uint8List list, {
     int? targetWidth,
     int? targetHeight,
-    bool allowUpscaling = true
-  }) async => skiaInstantiateImageCodec(
-    list,
-    targetWidth,
-    targetHeight
-  );
+    bool allowUpscaling = true,
+  }) async => skiaInstantiateImageCodec(list, targetWidth, targetHeight, allowUpscaling);
 
   @override
   Future<ui.Codec> instantiateImageCodecFromUrl(
     Uri uri, {
-    ui_web.ImageCodecChunkCallback? chunkCallback
+    ui_web.ImageCodecChunkCallback? chunkCallback,
   }) => skiaInstantiateWebImageCodec(uri.toString(), chunkCallback);
 
   @override
   ui.Image createImageFromImageBitmap(DomImageBitmap imageBitmap) {
-    final SkImage? skImage = canvasKit.MakeLazyImageFromImageBitmap(
-      imageBitmap,
-      true
+    final SkImage? skImage = canvasKit.MakeLazyImageFromImageBitmap(imageBitmap, true);
+    if (skImage == null) {
+      throw Exception('Failed to convert image bitmap to an SkImage.');
+    }
+    return CkImage(skImage, imageSource: ImageBitmapImageSource(imageBitmap));
+  }
+
+  @override
+  FutureOr<ui.Image> createImageFromTextureSource(
+    JSAny object, {
+    required int width,
+    required int height,
+    required bool transferOwnership,
+  }) async {
+    if (!transferOwnership) {
+      final DomImageBitmap bitmap = await createImageBitmap(object, (
+        x: 0,
+        y: 0,
+        width: width,
+        height: height,
+      ));
+      return createImageFromImageBitmap(bitmap);
+    }
+    final SkImage? skImage = canvasKit.MakeLazyImageFromTextureSourceWithInfo(
+      object,
+      SkPartialImageInfo(
+        width: width.toDouble(),
+        height: height.toDouble(),
+        alphaType: canvasKit.AlphaType.Premul,
+        colorType: canvasKit.ColorType.RGBA_8888,
+        colorSpace: SkColorSpaceSRGB,
+      ),
     );
+
     if (skImage == null) {
       throw Exception('Failed to convert image bitmap to an SkImage.');
     }
@@ -260,7 +291,7 @@ class CanvasKitRenderer implements Renderer {
     int? rowBytes,
     int? targetWidth,
     int? targetHeight,
-    bool allowUpscaling = true
+    bool allowUpscaling = true,
   }) => skiaDecodeImageFromPixels(
     pixels,
     width,
@@ -270,7 +301,7 @@ class CanvasKitRenderer implements Renderer {
     rowBytes: rowBytes,
     targetWidth: targetWidth,
     targetHeight: targetHeight,
-    allowUpscaling: allowUpscaling
+    allowUpscaling: allowUpscaling,
   );
 
   @override
@@ -279,7 +310,7 @@ class CanvasKitRenderer implements Renderer {
     ui.TileMode tmx,
     ui.TileMode tmy,
     Float64List matrix4,
-    ui.FilterQuality? filterQuality
+    ui.FilterQuality? filterQuality,
   ) => CkImageShader(image, tmx, tmy, matrix4, filterQuality);
 
   @override
@@ -290,7 +321,7 @@ class CanvasKitRenderer implements Renderer {
 
   @override
   ui.Path combinePaths(ui.PathOperation op, ui.Path path1, ui.Path path2) =>
-    CkPath.combine(op, path1, path2);
+      CkPath.combine(op, path1, path2);
 
   @override
   ui.TextStyle createTextStyle({
@@ -314,7 +345,7 @@ class CanvasKitRenderer implements Renderer {
     ui.Paint? foreground,
     List<ui.Shadow>? shadows,
     List<ui.FontFeature>? fontFeatures,
-    List<ui.FontVariation>? fontVariations
+    List<ui.FontVariation>? fontVariations,
   }) => CkTextStyle(
     color: color,
     decoration: decoration,
@@ -352,7 +383,7 @@ class CanvasKitRenderer implements Renderer {
     ui.FontStyle? fontStyle,
     ui.StrutStyle? strutStyle,
     String? ellipsis,
-    ui.Locale? locale
+    ui.Locale? locale,
   }) => CkParagraphStyle(
     textAlign: textAlign,
     textDirection: textDirection,
@@ -366,7 +397,6 @@ class CanvasKitRenderer implements Renderer {
     strutStyle: strutStyle,
     ellipsis: ellipsis,
     locale: locale,
-    applyRoundingHack: !ui.ParagraphBuilder.shouldDisableRoundingHack,
   );
 
   @override
@@ -379,7 +409,7 @@ class CanvasKitRenderer implements Renderer {
     double? leading,
     ui.FontWeight? fontWeight,
     ui.FontStyle? fontStyle,
-    bool? forceStrutHeight
+    bool? forceStrutHeight,
   }) => CkStrutStyle(
     fontFamily: fontFamily,
     fontFamilyFallback: fontFamilyFallback,
@@ -393,11 +423,57 @@ class CanvasKitRenderer implements Renderer {
   );
 
   @override
-  ui.ParagraphBuilder createParagraphBuilder(ui.ParagraphStyle style) =>
-    CkParagraphBuilder(style);
+  ui.ParagraphBuilder createParagraphBuilder(ui.ParagraphStyle style) => CkParagraphBuilder(style);
 
+  // TODO(harryterkelsen): Merge this logic with the async logic in
+  // [EngineScene], https://github.com/flutter/flutter/issues/142072.
   @override
-  Future<void> renderScene(ui.Scene scene, ui.FlutterView view) async {
+  Future<void> renderScene(ui.Scene scene, EngineFlutterView view) async {
+    assert(
+      _rasterizers.containsKey(view.viewId),
+      "Unable to render to a view which hasn't been registered",
+    );
+    final ViewRasterizer rasterizer = _rasterizers[view.viewId]!;
+    final RenderQueue renderQueue = rasterizer.queue;
+    final FrameTimingRecorder? recorder =
+        FrameTimingRecorder.frameTimingsEnabled ? FrameTimingRecorder() : null;
+    if (renderQueue.current != null) {
+      // If a scene is already queued up, drop it and queue this one up instead
+      // so that the scene view always displays the most recently requested scene.
+      renderQueue.next?.completer.complete();
+      final Completer<void> completer = Completer<void>();
+      renderQueue.next = (scene: scene, completer: completer, recorder: recorder);
+      return completer.future;
+    }
+    final Completer<void> completer = Completer<void>();
+    renderQueue.current = (scene: scene, completer: completer, recorder: recorder);
+    unawaited(_kickRenderLoop(rasterizer));
+    return completer.future;
+  }
+
+  Future<void> _kickRenderLoop(ViewRasterizer rasterizer) async {
+    final RenderQueue renderQueue = rasterizer.queue;
+    final RenderRequest current = renderQueue.current!;
+    try {
+      await _renderScene(current.scene, rasterizer, current.recorder);
+      current.completer.complete();
+    } catch (error, stackTrace) {
+      current.completer.completeError(error, stackTrace);
+    }
+    renderQueue.current = renderQueue.next;
+    renderQueue.next = null;
+    if (renderQueue.current == null) {
+      return;
+    } else {
+      return _kickRenderLoop(rasterizer);
+    }
+  }
+
+  Future<void> _renderScene(
+    ui.Scene scene,
+    ViewRasterizer rasterizer,
+    FrameTimingRecorder? recorder,
+  ) async {
     // "Build finish" and "raster start" happen back-to-back because we
     // render on the same thread, so there's no overhead from hopping to
     // another thread.
@@ -405,24 +481,20 @@ class CanvasKitRenderer implements Renderer {
     // CanvasKit works differently from the HTML renderer in that in HTML
     // we update the DOM in SceneBuilder.build, which is these function calls
     // here are CanvasKit-only.
-    frameTimingsOnBuildFinish();
-    frameTimingsOnRasterStart();
-
-    assert(_rasterizers.containsKey(view.viewId),
-        "Unable to render to a view which hasn't been registered");
-    final Rasterizer rasterizer = _rasterizers[view.viewId]!;
+    recorder?.recordBuildFinish();
+    recorder?.recordRasterStart();
 
     await rasterizer.draw((scene as LayerScene).layerTree);
-    frameTimingsOnRasterFinish();
+    recorder?.recordRasterFinish();
+    recorder?.submitTimings();
   }
 
   // Map from view id to the associated Rasterizer for that view.
-  final Map<int, Rasterizer> _rasterizers = <int, Rasterizer>{};
+  final Map<int, ViewRasterizer> _rasterizers = <int, ViewRasterizer>{};
 
   void _onViewCreated(int viewId) {
-    final EngineFlutterView view =
-        EnginePlatformDispatcher.instance.viewManager[viewId]!;
-    _rasterizers[view.viewId] = Rasterizer(view);
+    final EngineFlutterView view = EnginePlatformDispatcher.instance.viewManager[viewId]!;
+    _rasterizers[view.viewId] = _rasterizer.createViewRasterizer(view);
   }
 
   void _onViewDisposed(int viewId) {
@@ -430,11 +502,11 @@ class CanvasKitRenderer implements Renderer {
     if (!_rasterizers.containsKey(viewId)) {
       return;
     }
-    final Rasterizer rasterizer = _rasterizers.remove(viewId)!;
+    final ViewRasterizer rasterizer = _rasterizers.remove(viewId)!;
     rasterizer.dispose();
   }
 
-  Rasterizer? debugGetRasterizerForView(EngineFlutterView view) {
+  ViewRasterizer? debugGetRasterizerForView(EngineFlutterView view) {
     return _rasterizers[view.viewId];
   }
 
@@ -442,18 +514,26 @@ class CanvasKitRenderer implements Renderer {
   void dispose() {
     _onViewCreatedListener?.cancel();
     _onViewDisposedListener?.cancel();
-    for (final Rasterizer rasterizer in _rasterizers.values) {
+    for (final ViewRasterizer rasterizer in _rasterizers.values) {
       rasterizer.dispose();
     }
     _rasterizers.clear();
   }
 
+  /// Clears the state of this renderer. Used in tests.
+  void debugClear() {
+    for (final ViewRasterizer rasterizer in _rasterizers.values) {
+      rasterizer.debugClear();
+    }
+  }
+
   @override
   void clearFragmentProgramCache() {
     _programs.clear();
   }
 
-  static final Map<String, Future<ui.FragmentProgram>> _programs = <String, Future<ui.FragmentProgram>>{};
+  static final Map<String, Future<ui.FragmentProgram>> _programs =
+      <String, Future<ui.FragmentProgram>>{};
 
   @override
   Future<ui.FragmentProgram> createFragmentProgram(String assetKey) {
@@ -475,7 +555,7 @@ class CanvasKitRenderer implements Renderer {
     required double width,
     required double left,
     required double baseline,
-    required int lineNumber
+    required int lineNumber,
   }) => EngineLineMetrics(
     hardBreak: hardBreak,
     ascent: ascent,
@@ -485,6 +565,9 @@ class CanvasKitRenderer implements Renderer {
     width: width,
     left: left,
     baseline: baseline,
-    lineNumber: lineNumber
+    lineNumber: lineNumber,
   );
+
+  @override
+  void dumpDebugInfo() {}
 }
