@@ -10,27 +10,6 @@ part of dart._engine;
 // removes the ability for disabling AA on Paint objects.
 const bool _kUsingMSAA = bool.fromEnvironment('flutter.canvaskit.msaa');
 
-typedef SubmitCallback = bool Function(SurfaceFrame, CkCanvas);
-
-/// A frame which contains a canvas to be drawn into.
-class SurfaceFrame {
-  SurfaceFrame(this.skiaSurface, this.submitCallback) : _submitted = false;
-
-  final CkSurface skiaSurface;
-  final SubmitCallback submitCallback;
-  final bool _submitted;
-
-  /// Submit this frame to be drawn.
-  bool submit() {
-    if (_submitted) {
-      return false;
-    }
-    return submitCallback(this, skiaCanvas);
-  }
-
-  CkCanvas get skiaCanvas => skiaSurface.getCanvas();
-}
-
 /// A surface which can be drawn into by the compositor.
 ///
 /// The underlying representation is a [CkSurface], which can be reused by
@@ -42,6 +21,19 @@ class Surface extends DisplayCanvas {
 
   CkSurface? _surface;
 
+  /// Returns the underlying CanvasKit Surface. Should only be used in tests.
+  CkSurface? debugGetCkSurface() {
+    bool assertsEnabled = false;
+    assert(() {
+      assertsEnabled = true;
+      return true;
+    }());
+    if (!assertsEnabled) {
+      throw StateError('debugGetCkSurface() can only be used in tests');
+    }
+    return _surface;
+  }
+
   /// Whether or not to use an `OffscreenCanvas` to back this [Surface].
   final bool useOffscreenCanvas;
 
@@ -98,7 +90,7 @@ class Surface extends DisplayCanvas {
 
   /// The <canvas> backing this Surface in the case that OffscreenCanvas isn't
   /// supported.
-  DomCanvasElement? _canvasElement;
+  DomHTMLCanvasElement? _canvasElement;
 
   /// Note, if this getter is called, then this Surface is being used as an
   /// overlay and must be backed by an onscreen <canvas> element.
@@ -148,7 +140,7 @@ class Surface extends DisplayCanvas {
       if (useOffscreenCanvas) {
         bitmap = _offscreenCanvas!.transferToImageBitmap();
       } else {
-        bitmapSource = _canvasElement! as JSObject;
+        bitmapSource = _canvasElement!;
         bitmap = await createImageBitmap(bitmapSource, (
           x: 0,
           y: _pixelHeight - bitmapSize.height,
@@ -170,20 +162,6 @@ class Surface extends DisplayCanvas {
     }
   }
 
-  /// Acquire a frame of the given [size] containing a drawable canvas.
-  ///
-  /// The given [size] is in physical pixels.
-  SurfaceFrame acquireFrame(ui.Size size) {
-    final CkSurface surface = createOrUpdateSurface(BitmapSize.fromSize(size));
-
-    // ignore: prefer_function_declarations_over_variables
-    final SubmitCallback submitCallback = (SurfaceFrame surfaceFrame, CkCanvas canvas) {
-      return _presentSurface();
-    };
-
-    return SurfaceFrame(surface, submitCallback);
-  }
-
   BitmapSize? _currentCanvasPhysicalSize;
 
   /// Sets the CSS size of the canvas so that canvas pixels are 1:1 with device
@@ -281,9 +259,9 @@ class Surface extends DisplayCanvas {
       }
     }
 
-    // If we reached here, then either we are forcing a new context, or
-    // the size of the surface has changed so we need to make a new one.
-
+    // If we reached here, then this is the first frame and we haven't made a
+    // surface yet, we are forcing a new context, or the size of the surface
+    // has changed and we need to make a new one.
     _surface?.dispose();
     _surface = null;
 
@@ -300,7 +278,7 @@ class Surface extends DisplayCanvas {
     return _surface = _createNewSurface(size);
   }
 
-  JSVoid _contextRestoredListener(DomEvent event) {
+  void _contextRestoredListener(DomEvent event) {
     assert(
       _contextLost,
       'Received "webglcontextrestored" event but never received '
@@ -313,7 +291,7 @@ class Surface extends DisplayCanvas {
     event.preventDefault();
   }
 
-  JSVoid _contextLostListener(DomEvent event) {
+  void _contextLostListener(DomEvent event) {
     assert(
       event.target == _offscreenCanvas || event.target == _canvasElement,
       'Received a context lost event for a disposed canvas',
@@ -332,9 +310,13 @@ class Surface extends DisplayCanvas {
       _offscreenCanvas!.removeEventListener(
         'webglcontextrestored',
         _cachedContextRestoredListener,
-        false,
+        false.toJS,
+      );
+      _offscreenCanvas!.removeEventListener(
+        'webglcontextlost',
+        _cachedContextLostListener,
+        false.toJS,
       );
-      _offscreenCanvas!.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
       _offscreenCanvas = null;
       _cachedContextRestoredListener = null;
       _cachedContextLostListener = null;
@@ -342,9 +324,13 @@ class Surface extends DisplayCanvas {
       _canvasElement!.removeEventListener(
         'webglcontextrestored',
         _cachedContextRestoredListener,
-        false,
+        false.toJS,
+      );
+      _canvasElement!.removeEventListener(
+        'webglcontextlost',
+        _cachedContextLostListener,
+        false.toJS,
       );
-      _canvasElement!.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
       _canvasElement!.remove();
       _canvasElement = null;
       _cachedContextRestoredListener = null;
@@ -365,7 +351,7 @@ class Surface extends DisplayCanvas {
       _offscreenCanvas = offscreenCanvas;
       _canvasElement = null;
     } else {
-      final DomCanvasElement canvas = createDomCanvasElement(
+      final DomHTMLCanvasElement canvas = createDomCanvasElement(
         width: _pixelWidth,
         height: _pixelHeight,
       );
@@ -388,8 +374,8 @@ class Surface extends DisplayCanvas {
     // See also: https://www.khronos.org/webgl/wiki/HandlingContextLost
     _cachedContextRestoredListener = createDomEventListener(_contextRestoredListener);
     _cachedContextLostListener = createDomEventListener(_contextLostListener);
-    htmlCanvas.addEventListener('webglcontextlost', _cachedContextLostListener, false);
-    htmlCanvas.addEventListener('webglcontextrestored', _cachedContextRestoredListener, false);
+    htmlCanvas.addEventListener('webglcontextlost', _cachedContextLostListener, false.toJS);
+    htmlCanvas.addEventListener('webglcontextrestored', _cachedContextRestoredListener, false.toJS);
     _forceNewContext = false;
     _contextLost = false;
 
@@ -412,6 +398,8 @@ class Surface extends DisplayCanvas {
       if (_glContext != 0) {
         _grContext = canvasKit.MakeGrContext(glContext.toDouble());
         if (_grContext == null) {
+          // TODO(harryterkelsen): Make this error message more descriptive by
+          // reporting the number of currently live Surfaces, https://github.com/flutter/flutter/issues/162868.
           throw CanvasKitError(
             'Failed to initialize CanvasKit. '
             'CanvasKit.MakeGrContext returned null.',
@@ -487,11 +475,6 @@ class Surface extends DisplayCanvas {
     }
   }
 
-  bool _presentSurface() {
-    _surface!.flush();
-    return true;
-  }
-
   @override
   bool get isConnected => _canvasElement!.isConnected!;
 
@@ -502,11 +485,15 @@ class Surface extends DisplayCanvas {
 
   @override
   void dispose() {
-    _offscreenCanvas?.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
+    _offscreenCanvas?.removeEventListener(
+      'webglcontextlost',
+      _cachedContextLostListener,
+      false.toJS,
+    );
     _offscreenCanvas?.removeEventListener(
       'webglcontextrestored',
       _cachedContextRestoredListener,
-      false,
+      false.toJS,
     );
     _cachedContextLostListener = null;
     _cachedContextRestoredListener = null;
