@@ -11,8 +11,8 @@ final bool _ckRequiresClientICU = canvasKit.ParagraphBuilder.RequiresClientICU()
 final List<String> _testFonts = <String>['FlutterTest', 'Ahem'];
 String? _computeEffectiveFontFamily(String? fontFamily) {
   return ui_web.debugEmulateFlutterTesterEnvironment && !_testFonts.contains(fontFamily)
-    ? _testFonts.first
-    : fontFamily;
+      ? _testFonts.first
+      : fontFamily;
 }
 
 
@@ -30,34 +30,33 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     ui.StrutStyle? strutStyle,
     String? ellipsis,
     ui.Locale? locale,
-  })  : skParagraphStyle = toSkParagraphStyle(
-          textAlign,
-          textDirection,
-          maxLines,
-          _computeEffectiveFontFamily(fontFamily),
-          fontSize,
-          height == ui.kTextHeightNone ? null : height,
-          textHeightBehavior,
-          fontWeight,
-          fontStyle,
-          strutStyle,
-          ellipsis,
-          locale,
-        ),
-        _textAlign = textAlign,
-        _textDirection = textDirection,
-        _fontWeight = fontWeight,
-        _fontStyle = fontStyle,
-        _maxLines = maxLines,
-        _originalFontFamily = fontFamily,
-        _effectiveFontFamily = _computeEffectiveFontFamily(fontFamily),
-        _fontSize = fontSize,
-        _height = height == ui.kTextHeightNone ? null : height,
-        _textHeightBehavior = textHeightBehavior,
-        _strutStyle = strutStyle,
-        _ellipsis = ellipsis,
-        _locale = locale;
-
+  }) : skParagraphStyle = toSkParagraphStyle(
+         textAlign,
+         textDirection,
+         maxLines,
+         _computeEffectiveFontFamily(fontFamily),
+         fontSize,
+         height == ui.kTextHeightNone ? null : height,
+         textHeightBehavior,
+         fontWeight,
+         fontStyle,
+         strutStyle,
+         ellipsis,
+         locale,
+       ),
+       _textAlign = textAlign,
+       _textDirection = textDirection,
+       _fontWeight = fontWeight,
+       _fontStyle = fontStyle,
+       _maxLines = maxLines,
+       _originalFontFamily = fontFamily,
+       _effectiveFontFamily = _computeEffectiveFontFamily(fontFamily),
+       _fontSize = fontSize,
+       _height = height == ui.kTextHeightNone ? null : height,
+       _textHeightBehavior = textHeightBehavior,
+       _strutStyle = strutStyle,
+       _ellipsis = ellipsis,
+       _locale = locale;
 
   final SkParagraphStyle skParagraphStyle;
 
@@ -101,11 +100,15 @@ class CkParagraphStyle implements ui.ParagraphStyle {
   }
 
   static SkStrutStyleProperties toSkStrutStyleProperties(
-      ui.StrutStyle value, ui.TextHeightBehavior? paragraphHeightBehavior) {
+    ui.StrutStyle value,
+    ui.TextHeightBehavior? paragraphHeightBehavior,
+  ) {
     final CkStrutStyle style = value as CkStrutStyle;
     final SkStrutStyleProperties skStrutStyle = SkStrutStyleProperties();
-    skStrutStyle.fontFamilies =
-        _computeCombinedFontFamilies(style._fontFamily, style._fontFamilyFallback);
+    skStrutStyle.fontFamilies = _computeCombinedFontFamilies(
+      style._fontFamily,
+      style._fontFamilyFallback,
+    );
 
     if (style._fontSize != null) {
       skStrutStyle.fontSize = style._fontSize;
@@ -116,8 +119,7 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     }
 
     final ui.TextLeadingDistribution? effectiveLeadingDistribution =
-        style._leadingDistribution ??
-            paragraphHeightBehavior?.leadingDistribution;
+        style._leadingDistribution ?? paragraphHeightBehavior?.leadingDistribution;
     switch (effectiveLeadingDistribution) {
       case null:
         break;
@@ -132,8 +134,7 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     }
 
     if (style._fontWeight != null || style._fontStyle != null) {
-      skStrutStyle.fontStyle =
-          toSkFontStyle(style._fontWeight, style._fontStyle);
+      skStrutStyle.fontStyle = toSkFontStyle(style._fontWeight, style._fontStyle);
     }
 
     if (style._forceStrutHeight != null) {
@@ -178,8 +179,7 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     }
 
     if (textHeightBehavior != null) {
-      properties.textHeightBehavior =
-          toSkTextHeightBehavior(textHeightBehavior);
+      properties.textHeightBehavior = toSkTextHeightBehavior(textHeightBehavior);
     }
 
     if (ellipsis != null) {
@@ -187,13 +187,17 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     }
 
     if (strutStyle != null) {
-      properties.strutStyle =
-          toSkStrutStyleProperties(strutStyle, textHeightBehavior);
+      properties.strutStyle = toSkStrutStyleProperties(strutStyle, textHeightBehavior);
     }
 
     properties.replaceTabCharacters = true;
     properties.textStyle = toSkTextStyleProperties(
-        fontFamily, fontSize, height, fontWeight, fontStyle);
+      fontFamily,
+      fontSize,
+      height,
+      fontWeight,
+      fontStyle,
+    );
     properties.applyRoundingHack = false;
 
     return canvasKit.ParagraphStyle(properties);
@@ -278,7 +282,8 @@ class CkParagraphStyle implements ui.ParagraphStyle {
     assert(() {
       final double? fontSize = _fontSize;
       final double? height = _height;
-      result = 'ParagraphStyle('
+      result =
+          'ParagraphStyle('
           'textAlign: ${_textAlign ?? "unspecified"}, '
           'textDirection: ${_textDirection ?? "unspecified"}, '
           'fontWeight: ${_fontWeight ?? "unspecified"}, '
@@ -340,7 +345,8 @@ class CkTextStyle implements ui.TextStyle {
       originalFontFamily: fontFamily,
       effectiveFontFamily: _computeEffectiveFontFamily(fontFamily),
       originalFontFamilyFallback: fontFamilyFallback,
-      effectiveFontFamilyFallback: ui_web.debugEmulateFlutterTesterEnvironment ? null : fontFamilyFallback,
+      effectiveFontFamilyFallback:
+          ui_web.debugEmulateFlutterTesterEnvironment ? null : fontFamilyFallback,
       fontSize: fontSize,
       letterSpacing: letterSpacing,
       wordSpacing: wordSpacing,
@@ -410,9 +416,7 @@ class CkTextStyle implements ui.TextStyle {
   /// The values in this text style are used unless [other] specifically
   /// overrides it.
   CkTextStyle mergeWith(CkTextStyle other) {
-    final double? textHeight = other.height == ui.kTextHeightNone
-      ? null
-      : (other.height ?? height);
+    final double? textHeight = other.height == ui.kTextHeightNone ? null : (other.height ?? height);
     return CkTextStyle._(
       color: other.color ?? color,
       decoration: other.decoration ?? decoration,
@@ -441,8 +445,10 @@ class CkTextStyle implements ui.TextStyle {
   }
 
   /// Lazy-initialized combination of font family and font family fallback sent to Skia.
-  late final List<String> combinedFontFamilies =
-      _computeCombinedFontFamilies(effectiveFontFamily, effectiveFontFamilyFallback);
+  late final List<String> combinedFontFamilies = _computeCombinedFontFamilies(
+    effectiveFontFamily,
+    effectiveFontFamilyFallback,
+  );
 
   /// Lazy-initialized Skia style used to pass the style to Skia.
   ///
@@ -590,28 +596,28 @@ class CkTextStyle implements ui.TextStyle {
     if (identical(this, other)) {
       return true;
     }
-    return other is CkTextStyle
-        && other.color == color
-        && other.decoration == decoration
-        && other.decorationColor == decorationColor
-        && other.decorationStyle == decorationStyle
-        && other.fontWeight == fontWeight
-        && other.fontStyle == fontStyle
-        && other.textBaseline == textBaseline
-        && other.leadingDistribution == leadingDistribution
-        && other.originalFontFamily == originalFontFamily
-        && other.fontSize == fontSize
-        && other.letterSpacing == letterSpacing
-        && other.wordSpacing == wordSpacing
-        && other.height == height
-        && other.decorationThickness == decorationThickness
-        && other.locale == locale
-        && other.background == background
-        && other.foreground == foreground
-        && listEquals<ui.Shadow>(other.shadows, shadows)
-        && listEquals<String>(other.originalFontFamilyFallback, originalFontFamilyFallback)
-        && listEquals<ui.FontFeature>(other.fontFeatures, fontFeatures)
-        && listEquals<ui.FontVariation>(other.fontVariations, fontVariations);
+    return other is CkTextStyle &&
+        other.color == color &&
+        other.decoration == decoration &&
+        other.decorationColor == decorationColor &&
+        other.decorationStyle == decorationStyle &&
+        other.fontWeight == fontWeight &&
+        other.fontStyle == fontStyle &&
+        other.textBaseline == textBaseline &&
+        other.leadingDistribution == leadingDistribution &&
+        other.originalFontFamily == originalFontFamily &&
+        other.fontSize == fontSize &&
+        other.letterSpacing == letterSpacing &&
+        other.wordSpacing == wordSpacing &&
+        other.height == height &&
+        other.decorationThickness == decorationThickness &&
+        other.locale == locale &&
+        other.background == background &&
+        other.foreground == foreground &&
+        listEquals<ui.Shadow>(other.shadows, shadows) &&
+        listEquals<String>(other.originalFontFamilyFallback, originalFontFamilyFallback) &&
+        listEquals<ui.FontFeature>(other.fontFeatures, fontFeatures) &&
+        listEquals<ui.FontVariation>(other.fontVariations, fontVariations);
   }
 
   @override
@@ -644,7 +650,7 @@ class CkTextStyle implements ui.TextStyle {
       Object.hash(
         fontFeatures == null ? null : Object.hashAll(fontFeatures),
         fontVariations == null ? null : Object.hashAll(fontVariations),
-      )
+      ),
     );
   }
 
@@ -655,7 +661,8 @@ class CkTextStyle implements ui.TextStyle {
       final List<String>? fontFamilyFallback = originalFontFamilyFallback;
       final double? fontSize = this.fontSize;
       final double? height = this.height;
-      result = 'TextStyle('
+      result =
+          'TextStyle('
           'color: ${color ?? "unspecified"}, '
           'decoration: ${decoration ?? "unspecified"}, '
           'decorationColor: ${decorationColor ?? "unspecified"}, '
@@ -696,15 +703,16 @@ class CkStrutStyle implements ui.StrutStyle {
     ui.FontWeight? fontWeight,
     ui.FontStyle? fontStyle,
     bool? forceStrutHeight,
-  })  : _fontFamily = _computeEffectiveFontFamily(fontFamily),
-        _fontFamilyFallback = ui_web.debugEmulateFlutterTesterEnvironment ? null : fontFamilyFallback,
-        _fontSize = fontSize,
-        _height = height == ui.kTextHeightNone ? null : height,
-        _leadingDistribution = leadingDistribution,
-        _leading = leading,
-        _fontWeight = fontWeight,
-        _fontStyle = fontStyle,
-        _forceStrutHeight = forceStrutHeight;
+  }) : _fontFamily = _computeEffectiveFontFamily(fontFamily),
+       _fontFamilyFallback =
+           ui_web.debugEmulateFlutterTesterEnvironment ? null : fontFamilyFallback,
+       _fontSize = fontSize,
+       _height = height == ui.kTextHeightNone ? null : height,
+       _leadingDistribution = leadingDistribution,
+       _leading = leading,
+       _fontWeight = fontWeight,
+       _fontStyle = fontStyle,
+       _forceStrutHeight = forceStrutHeight;
 
   final String? _fontFamily;
   final List<String>? _fontFamilyFallback;
@@ -737,16 +745,16 @@ class CkStrutStyle implements ui.StrutStyle {
   int get hashCode {
     final List<String>? fontFamilyFallback = _fontFamilyFallback;
     return Object.hash(
-        _fontFamily,
-        fontFamilyFallback != null ? Object.hashAll(fontFamilyFallback) : null,
-        _fontSize,
-        _height,
-        _leading,
-        _leadingDistribution,
-        _fontWeight,
-        _fontStyle,
-        _forceStrutHeight,
-      );
+      _fontFamily,
+      fontFamilyFallback != null ? Object.hashAll(fontFamilyFallback) : null,
+      _fontSize,
+      _height,
+      _leading,
+      _leadingDistribution,
+      _fontWeight,
+      _fontStyle,
+      _forceStrutHeight,
+    );
   }
 }
 
@@ -783,7 +791,6 @@ class CkParagraph implements ui.Paragraph {
   /// is deleted.
   final CkParagraphStyle _paragraphStyle;
 
-
   @override
   double get alphabeticBaseline => _alphabeticBaseline;
   double _alphabeticBaseline = 0;
@@ -850,13 +857,15 @@ class CkParagraph implements ui.Paragraph {
       final SkRectWithDirection skRect = skRects[i];
       final Float32List rect = skRect.rect;
       final int skTextDirection = skRect.dir.value.toInt();
-      result.add(ui.TextBox.fromLTRBD(
-        rect[0],
-        rect[1],
-        rect[2],
-        rect[3],
-        ui.TextDirection.values[skTextDirection],
-      ));
+      result.add(
+        ui.TextBox.fromLTRBD(
+          rect[0],
+          rect[1],
+          rect[2],
+          rect[3],
+          ui.TextDirection.values[skTextDirection],
+        ),
+      );
     }
 
     return result;
@@ -887,13 +896,10 @@ class CkParagraph implements ui.Paragraph {
   @override
   ui.TextRange getWordBoundary(ui.TextPosition position) {
     assert(!_disposed, 'Paragraph has been disposed.');
-    final int characterPosition;
-    switch (position.affinity) {
-      case ui.TextAffinity.upstream:
-        characterPosition = position.offset - 1;
-      case ui.TextAffinity.downstream:
-        characterPosition = position.offset;
-    }
+    final int characterPosition = switch (position.affinity) {
+      ui.TextAffinity.upstream => position.offset - 1,
+      ui.TextAffinity.downstream => position.offset,
+    };
     final SkTextRange skRange = skiaObject.getWordBoundary(characterPosition.toDouble());
     return ui.TextRange(start: skRange.start.toInt(), end: skRange.end.toInt());
   }
@@ -920,8 +926,7 @@ class CkParagraph implements ui.Paragraph {
       _maxIntrinsicWidth = paragraph.getMaxIntrinsicWidth();
       _minIntrinsicWidth = paragraph.getMinIntrinsicWidth();
       _width = paragraph.getMaxWidth();
-      _boxesForPlaceholders =
-          skRectsToTextBoxes(paragraph.getRectsForPlaceholders());
+      _boxesForPlaceholders = skRectsToTextBoxes(paragraph.getRectsForPlaceholders());
     } catch (e) {
       printWarning(
         'CanvasKit threw an exception while laying '
@@ -1023,8 +1028,7 @@ class CkLineMetrics implements ui.LineMetrics {
   double get baseline => skLineMetrics.baseline;
 
   @override
-  double get height =>
-      (skLineMetrics.ascent + skLineMetrics.descent).round().toDouble();
+  double get height => (skLineMetrics.ascent + skLineMetrics.descent).round().toDouble();
 
   @override
   double get left => skLineMetrics.left;
@@ -1038,14 +1042,14 @@ class CkLineMetrics implements ui.LineMetrics {
 
 class CkParagraphBuilder implements ui.ParagraphBuilder {
   CkParagraphBuilder(ui.ParagraphStyle style)
-      : _style = style as CkParagraphStyle,
-        _placeholderCount = 0,
-        _placeholderScales = <double>[],
-        _styleStack = <CkTextStyle>[],
-        _paragraphBuilder = canvasKit.ParagraphBuilder.MakeFromFontCollection(
-          style.skParagraphStyle,
-          CanvasKitRenderer.instance.fontCollection.skFontCollection,
-        ) {
+    : _style = style as CkParagraphStyle,
+      _placeholderCount = 0,
+      _placeholderScales = <double>[],
+      _styleStack = <CkTextStyle>[],
+      _paragraphBuilder = canvasKit.ParagraphBuilder.MakeFromFontCollection(
+        style.skParagraphStyle,
+        CanvasKitRenderer.instance.fontCollection.skFontCollection,
+      ) {
     _styleStack.add(_style.getTextStyle());
   }
 
@@ -1065,13 +1069,16 @@ class CkParagraphBuilder implements ui.ParagraphBuilder {
     ui.TextBaseline? baseline,
   }) {
     // Require a baseline to be specified if using a baseline-based alignment.
-    assert(!(alignment == ui.PlaceholderAlignment.aboveBaseline ||
-            alignment == ui.PlaceholderAlignment.belowBaseline ||
-            alignment == ui.PlaceholderAlignment.baseline) || baseline != null);
+    assert(
+      !(alignment == ui.PlaceholderAlignment.aboveBaseline ||
+              alignment == ui.PlaceholderAlignment.belowBaseline ||
+              alignment == ui.PlaceholderAlignment.baseline) ||
+          baseline != null,
+    );
 
     _placeholderCount++;
     _placeholderScales.add(scale);
-    final _CkParagraphPlaceholder placeholderStyle = toSkPlaceholderStyle(
+    final _CkParagraphPlaceholder placeholderStyle = _toSkPlaceholderStyle(
       width * scale,
       height * scale,
       alignment,
@@ -1091,7 +1098,7 @@ class CkParagraphBuilder implements ui.ParagraphBuilder {
     );
   }
 
-  static _CkParagraphPlaceholder toSkPlaceholderStyle(
+  static _CkParagraphPlaceholder _toSkPlaceholderStyle(
     double width,
     double height,
     ui.PlaceholderAlignment alignment,
@@ -1166,38 +1173,43 @@ class CkParagraphBuilder implements ui.ParagraphBuilder {
     return _styleStack.last;
   }
 
-  // Used as the paint for background or foreground in the text style when
-  // the other one is not specified. CanvasKit either both background and
-  // foreground paints specified, or neither, but Flutter allows one of them
-  // to go unspecified.
-  //
-  // This object is never deleted. It is effectively a static global constant.
-  // Therefore it doesn't need to be wrapped in CkPaint.
-  static final SkPaint _defaultTextForeground = SkPaint();
-  static final SkPaint _defaultTextBackground = SkPaint()
-    ..setColorInt(0x00000000);
+  static SkPaint createForegroundPaint(CkTextStyle style) {
+    final SkPaint foreground;
+    if (style.foreground != null) {
+      foreground = style.foreground!.toSkPaint();
+    } else {
+      foreground = SkPaint();
+      foreground.setColorInt(style.color?.value ?? 0xFF000000);
+    }
+    return foreground;
+  }
+
+  static SkPaint createBackgroundPaint(CkTextStyle style) {
+    final SkPaint background;
+    if (style.background != null) {
+      background = style.background!.toSkPaint();
+    } else {
+      background = SkPaint()..setColorInt(0x00000000);
+    }
+    return background;
+  }
 
   @override
-  void pushStyle(ui.TextStyle style) {
-    final CkTextStyle baseStyle = _peekStyle();
-    final CkTextStyle ckStyle = style as CkTextStyle;
-    final CkTextStyle skStyle = baseStyle.mergeWith(ckStyle);
-    _styleStack.add(skStyle);
-    if (skStyle.foreground != null || skStyle.background != null) {
-      SkPaint? foreground = skStyle.foreground?.skiaObject;
-      if (foreground == null) {
-        _defaultTextForeground.setColorInt(
-          skStyle.color?.value ?? 0xFF000000,
-        );
-        foreground = _defaultTextForeground;
-      }
+  void pushStyle(ui.TextStyle leafStyle) {
+    leafStyle as CkTextStyle;
 
-      final SkPaint background =
-          skStyle.background?.skiaObject ?? _defaultTextBackground;
-      _paragraphBuilder.pushPaintStyle(
-          skStyle.skTextStyle, foreground, background);
+    final CkTextStyle baseStyle = _peekStyle();
+    final CkTextStyle mergedStyle = baseStyle.mergeWith(leafStyle);
+    _styleStack.add(mergedStyle);
+
+    if (mergedStyle.foreground != null || mergedStyle.background != null) {
+      final foreground = createForegroundPaint(mergedStyle);
+      final background = createBackgroundPaint(mergedStyle);
+      _paragraphBuilder.pushPaintStyle(mergedStyle.skTextStyle, foreground, background);
+      foreground.delete();
+      background.delete();
     } else {
-      _paragraphBuilder.pushStyle(skStyle.skTextStyle);
+      _paragraphBuilder.pushStyle(mergedStyle.skTextStyle);
     }
   }
 }
@@ -1218,8 +1230,7 @@ class _CkParagraphPlaceholder {
   final double offset;
 }
 
-List<String> _computeCombinedFontFamilies(String? fontFamily,
-    [List<String>? fontFamilyFallback]) {
+List<String> _computeCombinedFontFamilies(String? fontFamily, [List<String>? fontFamilyFallback]) {
   final List<String> fontFamilies = <String>[];
   if (fontFamily != null) {
     fontFamilies.add(fontFamily);
@@ -1228,8 +1239,6 @@ List<String> _computeCombinedFontFamilies(String? fontFamily,
       !fontFamilyFallback.every((String font) => fontFamily == font)) {
     fontFamilies.addAll(fontFamilyFallback);
   }
-  fontFamilies.addAll(
-    renderer.fontCollection.fontFallbackManager!.globalFontFallbacks
-  );
+  fontFamilies.addAll(renderer.fontCollection.fontFallbackManager!.globalFontFallbacks);
   return fontFamilies;
 }
