@@ -38,6 +38,11 @@ class NoopOperation implements LayerOperation {
 
   @override
   String toString() => 'NoopOperation()';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{'type': 'noop'};
+  }
 }
 
 class BackdropFilterLayer with PictureEngineLayer implements ui.BackdropFilterEngineLayer {
@@ -77,6 +82,15 @@ class BackdropFilterOperation implements LayerOperation {
 
   @override
   String toString() => 'BackdropFilterOperation(filter: $filter, mode: $mode)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'backdropFilter',
+      'filter': filter.toString(),
+      'mode': mode.toString(),
+    };
+  }
 }
 
 class ClipPathLayer with PictureEngineLayer implements ui.ClipPathEngineLayer {
@@ -125,6 +139,21 @@ class ClipPathOperation implements LayerOperation {
 
   @override
   String toString() => 'ClipPathOperation(path: $path, clip: $clip)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    final ui.Rect bounds = path.getBounds();
+    return <String, Object>{
+      'type': 'clipPath',
+      'pathBounds': {
+        'left': bounds.left,
+        'top': bounds.top,
+        'right': bounds.right,
+        'bottom': bounds.bottom,
+      },
+      'clip': clip.name,
+    };
+  }
 }
 
 class ClipRectLayer with PictureEngineLayer implements ui.ClipRectEngineLayer {
@@ -173,6 +202,15 @@ class ClipRectOperation implements LayerOperation {
 
   @override
   String toString() => 'ClipRectOperation(rect: $rect, clip: $clip)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'clipRect',
+      'rect': {'left': rect.left, 'top': rect.top, 'right': rect.right, 'bottom': rect.bottom},
+      'clip': clip.name,
+    };
+  }
 }
 
 class ClipRRectLayer with PictureEngineLayer implements ui.ClipRRectEngineLayer {
@@ -221,6 +259,100 @@ class ClipRRectOperation implements LayerOperation {
 
   @override
   String toString() => 'ClipRRectOperation(rrect: $rrect, clip: $clip)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'clipRRect',
+      'rrect': {
+        'left': rrect.left,
+        'top': rrect.top,
+        'right': rrect.right,
+        'bottom': rrect.bottom,
+        'tlRadiusX': rrect.tlRadiusX,
+        'tlRadiusY': rrect.tlRadiusY,
+        'trRadiusX': rrect.trRadiusX,
+        'trRadiusY': rrect.trRadiusY,
+        'brRadiusX': rrect.brRadiusX,
+        'brRadiusY': rrect.brRadiusY,
+        'blRadiusX': rrect.blRadiusX,
+        'blRadiusY': rrect.blRadiusY,
+      },
+      'clip': clip.name,
+    };
+  }
+}
+
+class ClipRSuperellipseLayer with PictureEngineLayer implements ui.ClipRSuperellipseEngineLayer {
+  ClipRSuperellipseLayer(this.operation);
+
+  @override
+  final ClipRSuperellipseOperation operation;
+
+  @override
+  ClipRSuperellipseLayer emptyClone() => ClipRSuperellipseLayer(operation);
+}
+
+class ClipRSuperellipseOperation implements LayerOperation {
+  const ClipRSuperellipseOperation(this.rsuperellipse, this.clip);
+
+  final ui.RSuperellipse rsuperellipse;
+  final ui.Clip clip;
+
+  @override
+  ui.Rect mapRect(ui.Rect contentRect) => contentRect.intersect(rsuperellipse.outerRect);
+
+  @override
+  void pre(SceneCanvas canvas) {
+    canvas.save();
+    canvas.clipRSuperellipse(rsuperellipse, doAntiAlias: clip != ui.Clip.hardEdge);
+    if (clip == ui.Clip.antiAliasWithSaveLayer) {
+      canvas.saveLayer(rsuperellipse.outerRect, ui.Paint());
+    }
+  }
+
+  @override
+  void post(SceneCanvas canvas) {
+    if (clip == ui.Clip.antiAliasWithSaveLayer) {
+      canvas.restore();
+    }
+    canvas.restore();
+  }
+
+  @override
+  PlatformViewStyling createPlatformViewStyling() {
+    // TODO(dkwingsmt): Properly implement RSuperellipse on Web instead of falling
+    // back to RRect.  https://github.com/flutter/flutter/issues/163718
+    return PlatformViewStyling(clip: PlatformViewRRectClip(rsuperellipse.toApproximateRRect()));
+  }
+
+  @override
+  bool get affectsBackdrop => false;
+
+  @override
+  String toString() => 'ClipRSuperellipseOperation(rsuperellipse: $rsuperellipse, clip: $clip)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'clipRSuperEllipse',
+      'rsuperellipse': {
+        'left': rsuperellipse.left,
+        'top': rsuperellipse.top,
+        'right': rsuperellipse.right,
+        'bottom': rsuperellipse.bottom,
+        'tlRadiusX': rsuperellipse.tlRadiusX,
+        'tlRadiusY': rsuperellipse.tlRadiusY,
+        'trRadiusX': rsuperellipse.trRadiusX,
+        'trRadiusY': rsuperellipse.trRadiusY,
+        'brRadiusX': rsuperellipse.brRadiusX,
+        'brRadiusY': rsuperellipse.brRadiusY,
+        'blRadiusX': rsuperellipse.blRadiusX,
+        'blRadiusY': rsuperellipse.blRadiusY,
+      },
+      'clip': clip.name,
+    };
+  }
 }
 
 class ColorFilterLayer with PictureEngineLayer implements ui.ColorFilterEngineLayer {
@@ -259,6 +391,11 @@ class ColorFilterOperation implements LayerOperation {
 
   @override
   String toString() => 'ColorFilterOperation(filter: $filter)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{'type': 'colorFilter', 'filter': filter.toString()};
+  }
 }
 
 class ImageFilterLayer with PictureEngineLayer implements ui.ImageFilterEngineLayer {
@@ -318,6 +455,15 @@ class ImageFilterOperation implements LayerOperation {
 
   @override
   String toString() => 'ImageFilterOperation(filter: $filter)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'imageFilter',
+      'filter': filter.toString(),
+      'offset': {'x': offset.dx, 'y': offset.dy},
+    };
+  }
 }
 
 class OffsetLayer with PictureEngineLayer implements ui.OffsetEngineLayer {
@@ -359,6 +505,14 @@ class OffsetOperation implements LayerOperation {
 
   @override
   String toString() => 'OffsetOperation(dx: $dx, dy: $dy)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'offset',
+      'offset': {'x': dx, 'y': dy},
+    };
+  }
 }
 
 class OpacityLayer with PictureEngineLayer implements ui.OpacityEngineLayer {
@@ -411,6 +565,15 @@ class OpacityOperation implements LayerOperation {
 
   @override
   String toString() => 'OpacityOperation(offset: $offset, alpha: $alpha)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'opacity',
+      'alpha': alpha,
+      'offset': {'x': offset.dx, 'y': offset.dy},
+    };
+  }
 }
 
 class TransformLayer with PictureEngineLayer implements ui.TransformEngineLayer {
@@ -455,6 +618,11 @@ class TransformOperation implements LayerOperation {
 
   @override
   String toString() => 'TransformOperation(matrix: $matrix)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{'type': 'transform', 'matrix': transform.toList()};
+  }
 }
 
 class ShaderMaskLayer with PictureEngineLayer implements ui.ShaderMaskEngineLayer {
@@ -505,6 +673,20 @@ class ShaderMaskOperation implements LayerOperation {
   @override
   String toString() =>
       'ShaderMaskOperation(shader: $shader, maskRect: $maskRect, blendMode: $blendMode)';
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'shaderMask',
+      'shader': shader.toString(),
+      'maskRect': {
+        'left': maskRect.left,
+        'top': maskRect.top,
+        'right': maskRect.right,
+        'bottom': maskRect.bottom,
+      },
+    };
+  }
 }
 
 class PlatformView {
@@ -561,6 +743,13 @@ mixin PictureEngineLayer implements ui.EngineLayer {
     return 'PictureEngineLayer($operation)';
   }
 
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'operation': operation.debugJsonDescription,
+      'commands': drawCommands.map((c) => c.debugJsonDescription).toList(),
+    };
+  }
+
   bool get isSimple {
     if (slices.length > 1) {
       return false;
@@ -590,9 +779,13 @@ abstract class LayerOperation {
   /// invoked even if it contains no pictures. (Most operations don't need to
   /// actually be performed at all if they don't contain any pictures.)
   bool get affectsBackdrop;
+
+  Map<String, Object> get debugJsonDescription;
 }
 
-sealed class LayerDrawCommand {}
+sealed class LayerDrawCommand {
+  Map<String, Object> get debugJsonDescription;
+}
 
 class PictureDrawCommand extends LayerDrawCommand {
   PictureDrawCommand(this.offset, this.picture, this.sliceIndex);
@@ -600,6 +793,22 @@ class PictureDrawCommand extends LayerDrawCommand {
   final int sliceIndex;
   final ui.Offset offset;
   final ScenePicture picture;
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    final bounds = picture.cullRect;
+    return <String, Object>{
+      'type': 'picture',
+      'sliceIndex': sliceIndex,
+      'offset': <String, Object>{'x': offset.dx, 'y': offset.dy},
+      'localBounds': <String, Object>{
+        'left': bounds.left,
+        'top': bounds.top,
+        'right': bounds.right,
+        'bottom': bounds.bottom,
+      },
+    };
+  }
 }
 
 class PlatformViewDrawCommand extends LayerDrawCommand {
@@ -608,12 +817,32 @@ class PlatformViewDrawCommand extends LayerDrawCommand {
   final int sliceIndex;
   final int viewId;
   final ui.Rect bounds;
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{
+      'type': 'platformView',
+      'sliceIndex': sliceIndex,
+      'viewId': viewId,
+      'localBounds': <String, Object>{
+        'left': bounds.left,
+        'top': bounds.top,
+        'right': bounds.right,
+        'bottom': bounds.bottom,
+      },
+    };
+  }
 }
 
 class RetainedLayerDrawCommand extends LayerDrawCommand {
   RetainedLayerDrawCommand(this.layer);
 
   final PictureEngineLayer layer;
+
+  @override
+  Map<String, Object> get debugJsonDescription {
+    return <String, Object>{'type': 'layer', 'layer': layer.debugJsonDescription};
+  }
 }
 
 // Represents how a platform view should be positioned in the scene.
@@ -724,7 +953,7 @@ class PlatformViewStyling {
   final PlatformViewClip clip;
 
   ui.Rect mapLocalToGlobal(ui.Rect rect) {
-    return position.mapLocalToGlobal(rect.intersect(clip.outerRect));
+    return position.mapLocalToGlobal(rect).intersect(clip.outerRect);
   }
 
   static PlatformViewStyling combine(PlatformViewStyling outer, PlatformViewStyling inner) {
@@ -830,10 +1059,15 @@ class PlatformViewNoClip implements PlatformViewClip {
 
   @override
   ui.Rect get outerRect => ui.Rect.largest;
+
+  @override
+  String toString() {
+    return 'PlatformViewClip(none)';
+  }
 }
 
 class PlatformViewRectClip implements PlatformViewClip {
-  PlatformViewRectClip(this.rect);
+  const PlatformViewRectClip(this.rect);
 
   final ui.Rect rect;
 
@@ -869,10 +1103,15 @@ class PlatformViewRectClip implements PlatformViewClip {
 
   @override
   ui.Rect get outerRect => rect;
+
+  @override
+  String toString() {
+    return 'PlatformViewRectClip($rect)';
+  }
 }
 
 class PlatformViewRRectClip implements PlatformViewClip {
-  PlatformViewRRectClip(this.rrect);
+  const PlatformViewRRectClip(this.rrect);
 
   final ui.RRect rrect;
 
@@ -908,6 +1147,11 @@ class PlatformViewRRectClip implements PlatformViewClip {
 
   @override
   ui.Rect get outerRect => rrect.outerRect;
+
+  @override
+  String toString() {
+    return 'PlatformViewRRectClip($rrect)';
+  }
 }
 
 class PlatformViewPathClip implements PlatformViewClip {
@@ -948,6 +1192,11 @@ class PlatformViewPathClip implements PlatformViewClip {
 
   @override
   ui.Rect get outerRect => path.getBounds();
+
+  @override
+  String toString() {
+    return 'PlatformViewPathClip($path)';
+  }
 }
 
 class LayerSliceBuilder {
