@@ -22,10 +22,7 @@ part of dart._engine;
 class PlatformViewManager {
   PlatformViewManager() {
     // Register some default factories.
-    registerFactory(
-      ui_web.PlatformViewRegistry.defaultVisibleViewType,
-      _defaultFactory,
-    );
+    registerFactory(ui_web.PlatformViewRegistry.defaultVisibleViewType, _defaultFactory);
     registerFactory(
       ui_web.PlatformViewRegistry.defaultInvisibleViewType,
       _defaultFactory,
@@ -92,8 +89,7 @@ class PlatformViewManager {
   /// it's been set.
   ///
   /// `factoryFunction` needs to be a [PlatformViewFactory].
-  bool registerFactory(String viewType, Function factoryFunction,
-      {bool isVisible = true}) {
+  bool registerFactory(String viewType, Function factoryFunction, {bool isVisible = true}) {
     assert(
       factoryFunction is ui_web.PlatformViewFactory ||
           factoryFunction is ui_web.ParameterizedPlatformViewFactory,
@@ -132,20 +128,18 @@ class PlatformViewManager {
   /// a place where to attach the `slot` property, that will tell the browser
   /// what `slot` tag will reveal this `contents`, **without modifying the returned
   /// html from the `factory` function**.
-  DomElement renderContent(
-    String viewType,
-    int viewId,
-    Object? params,
-  ) {
-    assert(knowsViewType(viewType),
-        'Attempted to render contents of unregistered viewType: $viewType');
+  DomElement renderContent(String viewType, int viewId, Object? params) {
+    assert(
+      knowsViewType(viewType),
+      'Attempted to render contents of unregistered viewType: $viewType',
+    );
 
     final String slotName = getPlatformViewSlotName(viewId);
     _viewIdToType[viewId] = viewType;
 
     return _contents.putIfAbsent(viewId, () {
-      final DomElement wrapper = domDocument
-          .createElement('flt-platform-view')
+      final DomElement wrapper =
+          domDocument.createElement('flt-platform-view')
             ..id = getPlatformViewDomId(viewId)
             ..setAttribute('slot', slotName);
 
@@ -183,17 +177,21 @@ class PlatformViewManager {
     // Note there's also no getContent(viewId) function anymore, to prevent
     // from later modifications too.
     if (content.style.height.isEmpty) {
-      printWarning('Height of Platform View type: [$viewType] may not be set.'
-          ' Defaulting to `height: 100%`.\n'
-          'Set `style.height` to any appropriate value to stop this message.');
+      printWarning(
+        'Height of Platform View type: [$viewType] may not be set.'
+        ' Defaulting to `height: 100%`.\n'
+        'Set `style.height` to any appropriate value to stop this message.',
+      );
 
       content.style.height = '100%';
     }
 
     if (content.style.width.isEmpty) {
-      printWarning('Width of Platform View type: [$viewType] may not be set.'
-          ' Defaulting to `width: 100%`.\n'
-          'Set `style.width` to any appropriate value to stop this message.');
+      printWarning(
+        'Width of Platform View type: [$viewType] may not be set.'
+        ' Defaulting to `width: 100%`.\n'
+        'Set `style.width` to any appropriate value to stop this message.',
+      );
 
       content.style.width = '100%';
     }
@@ -210,23 +208,16 @@ class PlatformViewManager {
   bool isVisible(int viewId) => !isInvisible(viewId);
 
   /// Clears the state. Used in tests.
-  ///
-  /// Returns the set of know view ids, so they can be cleaned up.
-  Set<int> debugClear() {
-    final Set<int> result = _contents.keys.toSet();
-    result.forEach(clearPlatformView);
+  void debugClear() {
+    _contents.keys.toList().forEach(clearPlatformView);
     _factories.clear();
     _contents.clear();
     _invisibleViews.clear();
     _viewIdToType.clear();
-    return result;
   }
 }
 
-DomElement _defaultFactory(
-  int viewId, {
-  Object? params,
-}) {
+DomElement _defaultFactory(int viewId, {Object? params}) {
   params!;
   params as Map<Object?, Object?>;
   return domDocument.createElement(params.readString('tagName'))
