@@ -17,21 +17,13 @@ abstract class Renderer {
   factory Renderer._internal() {
     if (FlutterConfiguration.flutterWebUseSkwasm) {
       return SkwasmRenderer();
+    } else if (FlutterConfiguration.useSkia) {
+      return CanvasKitRenderer();
     } else {
-      bool useCanvasKit;
-      if (FlutterConfiguration.flutterWebAutoDetect) {
-        if (configuration.requestedRendererType != null) {
-          useCanvasKit = configuration.requestedRendererType == 'canvaskit';
-        } else {
-          // If requestedRendererType is not specified, use CanvasKit for desktop and
-          // html for mobile.
-          useCanvasKit = isDesktop;
-        }
-      } else {
-        useCanvasKit = FlutterConfiguration.useSkia;
-      }
-
-      return useCanvasKit ? CanvasKitRenderer() : HtmlRenderer();
+      throw StateError(
+        'Wrong combination of configuration flags. Was expecting either CanvasKit or Skwasm to be '
+        'selected.',
+      );
     }
   }
 
@@ -39,7 +31,6 @@ abstract class Renderer {
   FlutterFontCollection get fontCollection;
 
   FutureOr<void> initialize();
-  void reset(FlutterViewEmbedder embedder);
 
   ui.Paint createPaint();
 
@@ -101,14 +92,18 @@ abstract class Renderer {
   ui.ImageFilter createBlurImageFilter({
     double sigmaX = 0.0,
     double sigmaY = 0.0,
-    ui.TileMode tileMode = ui.TileMode.clamp});
-  ui.ImageFilter createDilateImageFilter({ double radiusX = 0.0, double radiusY = 0.0});
-  ui.ImageFilter createErodeImageFilter({ double radiusX = 0.0, double radiusY = 0.0});
+    ui.TileMode? tileMode,
+  });
+  ui.ImageFilter createDilateImageFilter({double radiusX = 0.0, double radiusY = 0.0});
+  ui.ImageFilter createErodeImageFilter({double radiusX = 0.0, double radiusY = 0.0});
   ui.ImageFilter createMatrixImageFilter(
     Float64List matrix4, {
-    ui.FilterQuality filterQuality = ui.FilterQuality.low
+    ui.FilterQuality filterQuality = ui.FilterQuality.low,
+  });
+  ui.ImageFilter composeImageFilters({
+    required ui.ImageFilter outer,
+    required ui.ImageFilter inner,
   });
-  ui.ImageFilter composeImageFilters({required ui.ImageFilter outer, required ui.ImageFilter inner});
 
   Future<ui.Codec> instantiateImageCodec(
     Uint8List list, {
@@ -124,6 +119,13 @@ abstract class Renderer {
 
   FutureOr<ui.Image> createImageFromImageBitmap(DomImageBitmap imageSource);
 
+  FutureOr<ui.Image> createImageFromTextureSource(
+    JSAny object, {
+    required int width,
+    required int height,
+    required bool transferOwnership,
+  });
+
   void decodeImageFromPixels(
     Uint8List pixels,
     int width,
@@ -133,7 +135,7 @@ abstract class Renderer {
     int? rowBytes,
     int? targetWidth,
     int? targetHeight,
-    bool allowUpscaling = true
+    bool allowUpscaling = true,
   });
 
   ui.ImageShader createImageShader(
@@ -216,5 +218,7 @@ abstract class Renderer {
 
   ui.ParagraphBuilder createParagraphBuilder(ui.ParagraphStyle style);
 
-  Future<void> renderScene(ui.Scene scene, ui.FlutterView view);
+  Future<void> renderScene(ui.Scene scene, EngineFlutterView view);
+
+  void dumpDebugInfo();
 }
