@@ -13,8 +13,6 @@ part of dart._engine;
 
 
 
-
-
 /// Returns true if [object] has property [name], false otherwise.
 ///
 /// This is equivalent to writing `name in object` in plain JavaScript.
@@ -29,10 +27,7 @@ T getJsProperty<T>(Object object, String name) {
   return js_util.getProperty<T>(object, name);
 }
 
-const Set<String> _safeJsProperties = <String>{
-  'decoding',
-  '__flutter_state',
-};
+const Set<String> _safeJsProperties = <String>{'decoding', '__flutter_state'};
 
 /// Sets the value of property [name] on a JavaScript [object].
 ///
@@ -54,9 +49,6 @@ Future<T> promiseToFuture<T>(Object jsPromise) {
   return js_util.promiseToFuture<T>(jsPromise);
 }
 
-/// A function that receives a benchmark [value] labeleb by [name].
-typedef OnBenchmark = void Function(String name, double value);
-
 /// Parses a string [source] into a double.
 ///
 /// Uses the JavaScript `parseFloat` function instead of Dart's [double.parse]
@@ -82,8 +74,7 @@ num? parseFloat(String source) {
 /// This getter calls the `hasFocus` method of the `Document` interface.
 /// See for more details:
 /// https://developer.mozilla.org/en-US/docs/Web/API/Document/hasFocus
-bool get windowHasFocus =>
-    js_util.callMethod<bool>(domDocument, 'hasFocus', <dynamic>[]);
+bool get windowHasFocus => js_util.callMethod<bool>(domDocument, 'hasFocus', <dynamic>[]);
 
 /// Parses the font size of [element] and returns the value without a unit.
 num? parseFontSize(DomElement element) {
@@ -91,11 +82,15 @@ num? parseFontSize(DomElement element) {
 
   if (hasJsProperty(element, 'computedStyleMap')) {
     // Use the newer `computedStyleMap` API available on some browsers.
-    final Object? computedStyleMap =
-        js_util.callMethod<Object?>(element, 'computedStyleMap', const <Object?>[]);
+    final Object? computedStyleMap = js_util.callMethod<Object?>(
+      element,
+      'computedStyleMap',
+      const <Object?>[],
+    );
     if (computedStyleMap is Object) {
-      final Object? fontSizeObject =
-          js_util.callMethod<Object?>(computedStyleMap, 'get', <Object?>['font-size']);
+      final Object? fontSizeObject = js_util.callMethod<Object?>(computedStyleMap, 'get', <Object?>[
+        'font-size',
+      ]);
       if (fontSizeObject is Object) {
         fontSize = js_util.getProperty<num>(fontSizeObject, 'value');
       }
@@ -104,8 +99,7 @@ num? parseFontSize(DomElement element) {
 
   if (fontSize == null) {
     // Fallback to `getComputedStyle`.
-    final String fontSizeString =
-        domWindow.getComputedStyle(element).getPropertyValue('font-size');
+    final String fontSizeString = domWindow.getComputedStyle(element).getPropertyValue('font-size');
     fontSize = parseFloat(fontSizeString);
   }
 
@@ -125,8 +119,8 @@ void vibrate(int durationMs) {
 /// The [DomCanvasElement] factory assumes that element allocation will
 /// succeed and will return a non-null element. This is not always true. For
 /// example, when Safari on iOS runs out of memory it returns null.
-DomCanvasElement? tryCreateCanvasElement(int width, int height) {
-  final DomCanvasElement? canvas = js_util.callMethod<DomCanvasElement?>(
+DomHTMLCanvasElement? tryCreateCanvasElement(int width, int height) {
+  final DomHTMLCanvasElement? canvas = js_util.callMethod<DomHTMLCanvasElement?>(
     domDocument,
     'createElement',
     <dynamic>['CANVAS'],
@@ -149,8 +143,7 @@ DomCanvasElement? tryCreateCanvasElement(int width, int height) {
 
 @JS('window.ImageDecoder')
 external JSAny? get __imageDecoderConstructor;
-Object? get _imageDecoderConstructor =>
-    __imageDecoderConstructor?.toObjectShallow;
+Object? get _imageDecoderConstructor => __imageDecoderConstructor?.toObjectShallow;
 
 /// Environment variable that allows the developer to opt out of using browser's
 /// `ImageDecoder` API, and use the WASM codecs bundled with CanvasKit.
@@ -182,24 +175,10 @@ bool get _defaultBrowserSupportsImageDecoder =>
 // Frequently, when a browser launches an API that other browsers already
 // support, there are subtle incompatibilities that may cause apps to crash if,
 // we blindly adopt the new implementation. This variable prevents us from
-// picking up potentially incompatible implementations of ImagdeDecoder API.
+// picking up potentially incompatible implementations of ImageDecoder API.
 // Instead, when a new browser engine launches the API, we'll evaluate it and
 // enable it explicitly.
-bool get _isBrowserImageDecoderStable => browserEngine == BrowserEngine.blink;
-
-/// The signature of the function passed to the constructor of JavaScript `Promise`.
-typedef JsPromiseCallback = void Function(void Function(Object? value) resolve, void Function(Object? error) reject);
-
-/// Corresponds to JavaScript's `Promise`.
-///
-/// This type doesn't need any members. Instead, it should be first converted
-/// to Dart's [Future] using [promiseToFuture] then interacted with through the
-/// [Future] API.
-@JS('window.Promise')
-@staticInterop
-class JsPromise {
-  external factory JsPromise(JsPromiseCallback callback);
-}
+bool get _isBrowserImageDecoderStable => ui_web.browser.browserEngine == ui_web.BrowserEngine.blink;
 
 /// Corresponds to the browser's `ImageDecoder` type.
 ///
@@ -207,20 +186,13 @@ class JsPromise {
 ///
 ///  * https://www.w3.org/TR/webcodecs/#imagedecoder-interface
 @JS('window.ImageDecoder')
-@staticInterop
-class ImageDecoder {
-  external factory ImageDecoder(ImageDecoderOptions options);
-}
+extension type ImageDecoder._(JSObject _) implements JSObject {
+  external ImageDecoder(ImageDecoderOptions options);
 
-extension ImageDecoderExtension on ImageDecoder {
   external ImageTrackList get tracks;
-
-  @JS('complete')
-  external JSBoolean get _complete;
-  bool get complete => _complete.toDart;
-
-  external JsPromise decode(DecodeOptions options);
-  external JSVoid close();
+  external bool get complete;
+  external JSPromise<JSAny?> decode(DecodeOptions options);
+  external void close();
 }
 
 /// Options passed to the `ImageDecoder` constructor.
@@ -228,18 +200,15 @@ extension ImageDecoderExtension on ImageDecoder {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#imagedecoderinit-interface
-@JS()
-@anonymous
-@staticInterop
-class ImageDecoderOptions {
-  external factory ImageDecoderOptions({
-    required JSString type,
+extension type ImageDecoderOptions._(JSObject _) implements JSObject {
+  external ImageDecoderOptions({
+    required String type,
     required JSAny data,
-    required JSString premultiplyAlpha,
-    JSNumber? desiredWidth,
-    JSNumber? desiredHeight,
-    required JSString colorSpaceConversion,
-    required JSBoolean preferAnimation,
+    required String premultiplyAlpha,
+    double? desiredWidth,
+    double? desiredHeight,
+    required String colorSpaceConversion,
+    required bool preferAnimation,
   });
 }
 
@@ -248,17 +217,9 @@ class ImageDecoderOptions {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#imagedecoderesult-interface
-@JS()
-@anonymous
-@staticInterop
-class DecodeResult {}
-
-extension DecodeResultExtension on DecodeResult {
+extension type DecodeResult(JSObject _) implements JSObject {
   external VideoFrame get image;
-
-  @JS('complete')
-  external JSBoolean get _complete;
-  bool get complete => _complete.toDart;
+  external bool get complete;
 }
 
 /// Options passed to [ImageDecoder.decode].
@@ -266,13 +227,8 @@ extension DecodeResultExtension on DecodeResult {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#dictdef-imagedecodeoptions
-@JS()
-@anonymous
-@staticInterop
-class DecodeOptions {
-  external factory DecodeOptions({
-    required JSNumber frameIndex,
-  });
+extension type DecodeOptions._(JSObject _) implements JSObject {
+  external DecodeOptions({required int frameIndex});
 }
 
 /// The only frame in a static image, or one of the frames in an animated one.
@@ -282,46 +238,21 @@ class DecodeOptions {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#videoframe-interface
-@JS()
-@anonymous
-@staticInterop
-class VideoFrame implements DomCanvasImageSource {}
-
-extension VideoFrameExtension on VideoFrame {
-  @JS('allocationSize')
-  external JSNumber _allocationSize();
-  double allocationSize() => _allocationSize().toDart;
+extension type VideoFrame(JSObject _) implements JSObject, DomCanvasImageSource {
+  external double allocationSize();
 
   @JS('copyTo')
-  external JsPromise _copyTo(JSAny destination);
-  JsPromise copyTo(Object destination) => _copyTo(destination.toJSAnyShallow);
-
-  @JS('format')
-  external JSString? get _format;
-  String? get format => _format?.toDart;
-
-  @JS('codedWidth')
-  external JSNumber get _codedWidth;
-  double get codedWidth => _codedWidth.toDart;
-
-  @JS('codedHeight')
-  external JSNumber get _codedHeight;
-  double get codedHeight => _codedHeight.toDart;
-
-  @JS('displayWidth')
-  external JSNumber get _displayWidth;
-  double get displayWidth => _displayWidth.toDart;
-
-  @JS('displayHeight')
-  external JSNumber get _displayHeight;
-  double get displayHeight => _displayHeight.toDart;
-
-  @JS('duration')
-  external JSNumber? get _duration;
-  double? get duration => _duration?.toDart;
+  external JSPromise<JSAny?> _copyTo(JSAny destination);
+  JSPromise<JSAny?> copyTo(Object destination) => _copyTo(destination.toJSAnyShallow);
 
+  external String? get format;
+  external double get codedWidth;
+  external double get codedHeight;
+  external double get displayWidth;
+  external double get displayHeight;
+  external double? get duration;
   external VideoFrame clone();
-  external JSVoid close();
+  external void close();
 }
 
 /// Corresponds to the browser's `ImageTrackList` type.
@@ -329,13 +260,8 @@ extension VideoFrameExtension on VideoFrame {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#imagetracklist-interface
-@JS()
-@anonymous
-@staticInterop
-class ImageTrackList {}
-
-extension ImageTrackListExtension on ImageTrackList {
-  external JsPromise get ready;
+extension type ImageTrackList(JSObject _) implements JSObject {
+  external JSPromise<JSAny?> get ready;
   external ImageTrack? get selectedTrack;
 }
 
@@ -344,19 +270,9 @@ extension ImageTrackListExtension on ImageTrackList {
 /// See also:
 ///
 ///  * https://www.w3.org/TR/webcodecs/#imagetrack
-@JS()
-@anonymous
-@staticInterop
-class ImageTrack {}
-
-extension ImageTrackExtension on ImageTrack {
-  @JS('repetitionCount')
-  external JSNumber get _repetitionCount;
-  double get repetitionCount => _repetitionCount.toDart;
-
-  @JS('frameCount')
-  external JSNumber get _frameCount;
-  double get frameCount => _frameCount.toDart;
+extension type ImageTrack(JSObject _) implements JSObject {
+  external double get repetitionCount;
+  external double get frameCount;
 }
 
 void scaleCanvas2D(Object context2d, num x, num y) {
@@ -364,11 +280,7 @@ void scaleCanvas2D(Object context2d, num x, num y) {
 }
 
 void drawImageCanvas2D(Object context2d, Object imageSource, num width, num height) {
-  js_util.callMethod<void>(context2d, 'drawImage', <dynamic>[
-    imageSource,
-    width,
-    height,
-  ]);
+  js_util.callMethod<void>(context2d, 'drawImage', <dynamic>[imageSource, width, height]);
 }
 
 void vertexAttribPointerGlContext(
@@ -402,20 +314,24 @@ class GlContext {
     return OffScreenCanvas.supported
         ? GlContext._fromOffscreenCanvas(offScreenCanvas.offScreenCanvas!)
         : GlContext._fromCanvasElement(
-        offScreenCanvas.canvasElement!, webGLVersion == WebGLVersion.webgl1);
+          offScreenCanvas.canvasElement!,
+          webGLVersion == WebGLVersion.webgl1,
+        );
   }
 
   GlContext._fromOffscreenCanvas(DomOffscreenCanvas canvas)
-      : glContext = canvas.getContext('webgl2', <String, dynamic>{'premultipliedAlpha': false})!,
-        isOffscreen = true {
+    : glContext = canvas.getContext('webgl2', <String, dynamic>{'premultipliedAlpha': false})!,
+      isOffscreen = true {
     _programCache = <String, GlProgram?>{};
     _canvas = canvas;
   }
 
-  GlContext._fromCanvasElement(DomCanvasElement canvas, bool useWebGl1)
-      : glContext = canvas.getContext(useWebGl1 ? 'webgl' : 'webgl2',
-      <String, dynamic>{'premultipliedAlpha': false})!,
-        isOffscreen = false {
+  GlContext._fromCanvasElement(DomHTMLCanvasElement canvas, bool useWebGl1)
+    : glContext =
+          canvas.getContext(useWebGl1 ? 'webgl' : 'webgl2', <String, dynamic>{
+            'premultipliedAlpha': false,
+          })!,
+      isOffscreen = false {
     _programCache = <String, GlProgram?>{};
     _canvas = canvas;
   }
@@ -454,24 +370,29 @@ class GlContext {
   }
 
   /// Draws Gl context contents to canvas context.
-  void drawImage(DomCanvasRenderingContext2D context,
-      double left, double top) {
+  void drawImage(DomCanvasRenderingContext2D context, double left, double top) {
     // Actual size of canvas may be larger than viewport size. Use
     // source/destination to draw part of the image data.
-    js_util.callMethod<void>(context, 'drawImage',
-        <dynamic>[_canvas, 0, 0, _widthInPixels, _heightInPixels,
-          left, top, _widthInPixels, _heightInPixels]);
+    js_util.callMethod<void>(context, 'drawImage', <dynamic>[
+      _canvas,
+      0,
+      0,
+      _widthInPixels,
+      _heightInPixels,
+      left,
+      top,
+      _widthInPixels,
+      _heightInPixels,
+    ]);
   }
 
-  GlProgram cacheProgram(
-      String vertexShaderSource, String fragmentShaderSource) {
+  GlProgram cacheProgram(String vertexShaderSource, String fragmentShaderSource) {
     final String cacheKey = '$vertexShaderSource||$fragmentShaderSource';
     GlProgram? cachedProgram = _programCache[cacheKey];
     if (cachedProgram == null) {
       // Create and compile shaders.
       final Object vertexShader = compileShader('VERTEX_SHADER', vertexShaderSource);
-      final Object fragmentShader =
-      compileShader('FRAGMENT_SHADER', fragmentShaderSource);
+      final Object fragmentShader = compileShader('FRAGMENT_SHADER', fragmentShaderSource);
       // Create a gl program and link shaders.
       final Object program = createProgram();
       attachShader(program, vertexShader);
@@ -490,16 +411,16 @@ class GlContext {
     }
     js_util.callMethod<void>(glContext, 'shaderSource', <dynamic>[shader, source]);
     js_util.callMethod<void>(glContext, 'compileShader', <dynamic>[shader]);
-    final bool shaderStatus = js_util.callMethod<bool>(
-      glContext,
-      'getShaderParameter',
-      <dynamic>[shader, compileStatus],
-    );
+    final bool shaderStatus = js_util.callMethod<bool>(glContext, 'getShaderParameter', <dynamic>[
+      shader,
+      compileStatus,
+    ]);
     if (!shaderStatus) {
       throw Exception('Shader compilation failed: ${getShaderInfoLog(shader)}');
     }
     return shader;
   }
+
   Object createProgram() =>
       js_util.callMethod<Object>(glContext, 'createProgram', const <dynamic>[]);
 
@@ -509,11 +430,10 @@ class GlContext {
 
   void linkProgram(Object program) {
     js_util.callMethod<void>(glContext, 'linkProgram', <dynamic>[program]);
-    final bool programStatus = js_util.callMethod<bool>(
-      glContext,
-      'getProgramParameter',
-      <dynamic>[program, kLinkStatus],
-    );
+    final bool programStatus = js_util.callMethod<bool>(glContext, 'getProgramParameter', <dynamic>[
+      program,
+      kLinkStatus,
+    ]);
     if (!programStatus) {
       throw Exception(getProgramInfoLog(program));
     }
@@ -523,8 +443,7 @@ class GlContext {
     js_util.callMethod<void>(glContext, 'useProgram', <dynamic>[program.program]);
   }
 
-  Object? createBuffer() =>
-      js_util.callMethod(glContext, 'createBuffer', const <dynamic>[]);
+  Object? createBuffer() => js_util.callMethod(glContext, 'createBuffer', const <dynamic>[]);
 
   void bindArrayBuffer(Object? buffer) {
     js_util.callMethod<void>(glContext, 'bindBuffer', <dynamic>[kArrayBuffer, buffer]);
@@ -534,21 +453,18 @@ class GlContext {
       js_util.callMethod(glContext, 'createVertexArray', const <dynamic>[]);
 
   void bindVertexArray(Object vertexObjectArray) {
-    js_util.callMethod<void>(glContext, 'bindVertexArray',
-        <dynamic>[vertexObjectArray]);
+    js_util.callMethod<void>(glContext, 'bindVertexArray', <dynamic>[vertexObjectArray]);
   }
 
   void unbindVertexArray() {
-    js_util.callMethod<void>(glContext, 'bindVertexArray',
-        <dynamic>[null]);
+    js_util.callMethod<void>(glContext, 'bindVertexArray', <dynamic>[null]);
   }
 
   void bindElementArrayBuffer(Object? buffer) {
     js_util.callMethod<void>(glContext, 'bindBuffer', <dynamic>[kElementArrayBuffer, buffer]);
   }
 
-  Object? createTexture() =>
-      js_util.callMethod(glContext, 'createTexture', const <dynamic>[]);
+  Object? createTexture() => js_util.callMethod(glContext, 'createTexture', const <dynamic>[]);
 
   void generateMipmap(dynamic target) =>
       js_util.callMethod(glContext, 'generateMipmap', <dynamic>[target]);
@@ -561,22 +477,43 @@ class GlContext {
     js_util.callMethod<void>(glContext, 'activeTexture', <dynamic>[textureUnit]);
   }
 
-  void texImage2D(dynamic target, int level, dynamic internalFormat,
-      dynamic format, dynamic dataType,
-      dynamic pixels, {int? width, int? height, int border = 0}) {
+  void texImage2D(
+    dynamic target,
+    int level,
+    dynamic internalFormat,
+    dynamic format,
+    dynamic dataType,
+    dynamic pixels, {
+    int? width,
+    int? height,
+    int border = 0,
+  }) {
     if (width == null) {
       js_util.callMethod<void>(glContext, 'texImage2D', <dynamic>[
-        target, level, internalFormat, format, dataType, pixels]);
+        target,
+        level,
+        internalFormat,
+        format,
+        dataType,
+        pixels,
+      ]);
     } else {
       js_util.callMethod<void>(glContext, 'texImage2D', <dynamic>[
-        target, level, internalFormat, width, height, border, format, dataType,
-        pixels]);
+        target,
+        level,
+        internalFormat,
+        width,
+        height,
+        border,
+        format,
+        dataType,
+        pixels,
+      ]);
     }
   }
 
   void texParameteri(dynamic target, dynamic parameterName, dynamic value) {
-    js_util.callMethod<void>(glContext, 'texParameteri', <dynamic>[
-      target, parameterName, value]);
+    js_util.callMethod<void>(glContext, 'texParameteri', <dynamic>[target, parameterName, value]);
   }
 
   void deleteBuffer(Object buffer) {
@@ -604,11 +541,7 @@ class GlContext {
   void dispose() {
     final Object? loseContextExtension = _getExtension('WEBGL_lose_context');
     if (loseContextExtension != null) {
-      js_util.callMethod<void>(
-        loseContextExtension,
-        'loseContext',
-        const <dynamic>[],
-      );
+      js_util.callMethod<void>(loseContextExtension, 'loseContext', const <dynamic>[]);
     }
   }
 
@@ -650,25 +583,24 @@ class GlContext {
   }
 
   Object? _createShader(String shaderType) => js_util.callMethod(
-      glContext, 'createShader', <Object?>[js_util.getProperty<Object?>(glContext, shaderType)]);
+    glContext,
+    'createShader',
+    <Object?>[js_util.getProperty<Object?>(glContext, shaderType)],
+  );
 
   /// Error state of gl context.
   Object? get error => js_util.callMethod(glContext, 'getError', const <dynamic>[]);
 
   /// Shader compiler error, if this returns [kFalse], to get details use
   /// [getShaderInfoLog].
-  Object? get compileStatus =>
-      _kCompileStatus ??= js_util.getProperty(glContext, 'COMPILE_STATUS');
+  Object? get compileStatus => _kCompileStatus ??= js_util.getProperty(glContext, 'COMPILE_STATUS');
 
-  Object? get kArrayBuffer =>
-      _kArrayBuffer ??= js_util.getProperty(glContext, 'ARRAY_BUFFER');
+  Object? get kArrayBuffer => _kArrayBuffer ??= js_util.getProperty(glContext, 'ARRAY_BUFFER');
 
   Object? get kElementArrayBuffer =>
-      _kElementArrayBuffer ??= js_util.getProperty(glContext,
-          'ELEMENT_ARRAY_BUFFER');
+      _kElementArrayBuffer ??= js_util.getProperty(glContext, 'ELEMENT_ARRAY_BUFFER');
 
-  Object get kLinkStatus =>
-      _kLinkStatus ??= js_util.getProperty<Object>(glContext, 'LINK_STATUS');
+  Object get kLinkStatus => _kLinkStatus ??= js_util.getProperty<Object>(glContext, 'LINK_STATUS');
 
   Object get kFloat => _kFloat ??= js_util.getProperty<Object>(glContext, 'FLOAT');
 
@@ -680,14 +612,11 @@ class GlContext {
   Object? get kUnsignedShort =>
       _kUnsignedShort ??= js_util.getProperty(glContext, 'UNSIGNED_SHORT');
 
-  Object? get kStaticDraw =>
-      _kStaticDraw ??= js_util.getProperty(glContext, 'STATIC_DRAW');
+  Object? get kStaticDraw => _kStaticDraw ??= js_util.getProperty(glContext, 'STATIC_DRAW');
 
-  Object get kTriangles =>
-      _kTriangles ??= js_util.getProperty<Object>(glContext, 'TRIANGLES');
+  Object get kTriangles => _kTriangles ??= js_util.getProperty<Object>(glContext, 'TRIANGLES');
 
-  Object get kTriangleFan =>
-      _kTriangles ??= js_util.getProperty<Object>(glContext, 'TRIANGLE_FAN');
+  Object get kTriangleFan => _kTriangles ??= js_util.getProperty<Object>(glContext, 'TRIANGLE_FAN');
 
   Object get kTriangleStrip =>
       _kTriangles ??= js_util.getProperty<Object>(glContext, 'TRIANGLE_STRIP');
@@ -695,38 +624,32 @@ class GlContext {
   Object? get kColorBufferBit =>
       _kColorBufferBit ??= js_util.getProperty(glContext, 'COLOR_BUFFER_BIT');
 
-  Object? get kTexture2D =>
-      _kTexture2D ??= js_util.getProperty(glContext, 'TEXTURE_2D');
+  Object? get kTexture2D => _kTexture2D ??= js_util.getProperty(glContext, 'TEXTURE_2D');
 
-  double get kTexture0 =>
-      _kTexture0 ??= js_util.getProperty<double>(glContext, 'TEXTURE0');
+  double get kTexture0 => _kTexture0 ??= js_util.getProperty<double>(glContext, 'TEXTURE0');
 
-  Object? get kTextureWrapS =>
-      _kTextureWrapS ??= js_util.getProperty(glContext, 'TEXTURE_WRAP_S');
+  Object? get kTextureWrapS => _kTextureWrapS ??= js_util.getProperty(glContext, 'TEXTURE_WRAP_S');
 
-  Object? get kTextureWrapT =>
-      _kTextureWrapT ??= js_util.getProperty(glContext, 'TEXTURE_WRAP_T');
+  Object? get kTextureWrapT => _kTextureWrapT ??= js_util.getProperty(glContext, 'TEXTURE_WRAP_T');
 
-  Object? get kRepeat =>
-      _kRepeat ??= js_util.getProperty(glContext, 'REPEAT');
+  Object? get kRepeat => _kRepeat ??= js_util.getProperty(glContext, 'REPEAT');
 
-  Object? get kClampToEdge =>
-      _kClampToEdge ??= js_util.getProperty(glContext, 'CLAMP_TO_EDGE');
+  Object? get kClampToEdge => _kClampToEdge ??= js_util.getProperty(glContext, 'CLAMP_TO_EDGE');
 
   Object? get kMirroredRepeat =>
       _kMirroredRepeat ??= js_util.getProperty(glContext, 'MIRRORED_REPEAT');
 
-  Object? get kLinear =>
-      _kLinear ??= js_util.getProperty(glContext, 'LINEAR');
+  Object? get kLinear => _kLinear ??= js_util.getProperty(glContext, 'LINEAR');
 
   Object? get kTextureMinFilter =>
-      _kTextureMinFilter ??= js_util.getProperty(glContext,
-          'TEXTURE_MIN_FILTER');
+      _kTextureMinFilter ??= js_util.getProperty(glContext, 'TEXTURE_MIN_FILTER');
 
   /// Returns reference to uniform in program.
   Object getUniformLocation(Object program, String uniformName) {
-    final Object? res = js_util
-        .callMethod(glContext, 'getUniformLocation', <dynamic>[program, uniformName]);
+    final Object? res = js_util.callMethod(glContext, 'getUniformLocation', <dynamic>[
+      program,
+      uniformName,
+    ]);
     if (res == null) {
       throw Exception('$uniformName not found');
     } else {
@@ -736,15 +659,19 @@ class GlContext {
 
   /// Returns true if uniform exists.
   bool containsUniform(Object program, String uniformName) {
-    final Object? res = js_util
-        .callMethod(glContext, 'getUniformLocation', <dynamic>[program, uniformName]);
+    final Object? res = js_util.callMethod(glContext, 'getUniformLocation', <dynamic>[
+      program,
+      uniformName,
+    ]);
     return res != null;
   }
 
   /// Returns reference to uniform in program.
   Object getAttributeLocation(Object program, String attribName) {
-    final Object? res = js_util
-        .callMethod(glContext, 'getAttribLocation', <dynamic>[program, attribName]);
+    final Object? res = js_util.callMethod(glContext, 'getAttribLocation', <dynamic>[
+      program,
+      attribName,
+    ]);
     if (res == null) {
       throw Exception('$attribName not found');
     } else {
@@ -763,16 +690,19 @@ class GlContext {
   }
 
   /// Sets vec4 uniform values.
-  void setUniform4f(Object uniform, double value1, double value2, double value3,
-      double value4) {
-    js_util.callMethod<void>(
-        glContext, 'uniform4f', <dynamic>[uniform, value1, value2, value3, value4]);
+  void setUniform4f(Object uniform, double value1, double value2, double value3, double value4) {
+    js_util.callMethod<void>(glContext, 'uniform4f', <dynamic>[
+      uniform,
+      value1,
+      value2,
+      value3,
+      value4,
+    ]);
   }
 
   /// Sets mat4 uniform values.
   void setUniformMatrix4fv(Object uniform, bool transpose, Float32List value) {
-    js_util.callMethod<void>(
-        glContext, 'uniformMatrix4fv', <dynamic>[uniform, transpose, value]);
+    js_util.callMethod<void>(glContext, 'uniformMatrix4fv', <dynamic>[uniform, transpose, value]);
   }
 
   /// Shader compile error log.
@@ -786,10 +716,8 @@ class GlContext {
     return js_util.callMethod<String?>(glContext, 'getProgramInfoLog', <dynamic>[glProgram]);
   }
 
-  int? get drawingBufferWidth =>
-      js_util.getProperty<int?>(glContext, 'drawingBufferWidth');
-  int? get drawingBufferHeight =>
-      js_util.getProperty<int?>(glContext, 'drawingBufferWidth');
+  int? get drawingBufferWidth => js_util.getProperty<int?>(glContext, 'drawingBufferWidth');
+  int? get drawingBufferHeight => js_util.getProperty<int?>(glContext, 'drawingBufferWidth');
 
   /// Reads gl contents as image data.
   ///
@@ -798,19 +726,30 @@ class GlContext {
     const int kBytesPerPixel = 4;
     final int bufferWidth = _widthInPixels!;
     final int bufferHeight = _heightInPixels!;
-    if (browserEngine == BrowserEngine.webkit ||
-        browserEngine == BrowserEngine.firefox) {
-      final Uint8List pixels =
-      Uint8List(bufferWidth * bufferHeight * kBytesPerPixel);
-      js_util.callMethod<void>(glContext, 'readPixels',
-          <dynamic>[0, 0, bufferWidth, bufferHeight, kRGBA, kUnsignedByte, pixels]);
-      return createDomImageData(
-          Uint8ClampedList.fromList(pixels), bufferWidth, bufferHeight);
+    if (ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit ||
+        ui_web.browser.browserEngine == ui_web.BrowserEngine.firefox) {
+      final Uint8List pixels = Uint8List(bufferWidth * bufferHeight * kBytesPerPixel);
+      js_util.callMethod<void>(glContext, 'readPixels', <dynamic>[
+        0,
+        0,
+        bufferWidth,
+        bufferHeight,
+        kRGBA,
+        kUnsignedByte,
+        pixels,
+      ]);
+      return createDomImageData(Uint8ClampedList.fromList(pixels), bufferWidth, bufferHeight);
     } else {
-      final Uint8ClampedList pixels =
-      Uint8ClampedList(bufferWidth * bufferHeight * kBytesPerPixel);
-      js_util.callMethod<void>(glContext, 'readPixels',
-          <dynamic>[0, 0, bufferWidth, bufferHeight, kRGBA, kUnsignedByte, pixels]);
+      final Uint8ClampedList pixels = Uint8ClampedList(bufferWidth * bufferHeight * kBytesPerPixel);
+      js_util.callMethod<void>(glContext, 'readPixels', <dynamic>[
+        0,
+        0,
+        bufferWidth,
+        bufferHeight,
+        kRGBA,
+        kUnsignedByte,
+        pixels,
+      ]);
       return createDomImageData(pixels, bufferWidth, bufferHeight);
     }
   }
@@ -822,16 +761,20 @@ class GlContext {
     // browser create ImageBitmap otherwise use more expensive canvas
     // allocation. However, transferToImageBitmap does not properly preserve
     // the alpha channel, so only use it if the pattern is opaque.
-    if (_canvas != null &&
-        js_util.hasProperty(_canvas!, 'transferToImageBitmap') &&
-        isOpaque) {
+    if (_canvas != null && js_util.hasProperty(_canvas!, 'transferToImageBitmap') && isOpaque) {
       // TODO(yjbanov): find out why we need to call getContext and ignore the return value.
       js_util.callMethod<void>(_canvas!, 'getContext', <dynamic>['webgl2']);
-      final Object? imageBitmap = js_util.callMethod(_canvas!, 'transferToImageBitmap',
-          <dynamic>[]);
+      final Object? imageBitmap = js_util.callMethod(
+        _canvas!,
+        'transferToImageBitmap',
+        <dynamic>[],
+      );
       return imageBitmap;
     } else {
-      final DomCanvasElement canvas = createDomCanvasElement(width: _widthInPixels, height: _heightInPixels);
+      final DomHTMLCanvasElement canvas = createDomCanvasElement(
+        width: _widthInPixels,
+        height: _heightInPixels,
+      );
       final DomCanvasRenderingContext2D ctx = canvas.context2D;
       drawImage(ctx, 0, 0);
       return canvas;
@@ -840,7 +783,10 @@ class GlContext {
 
   /// Returns image data in data url format.
   String toImageUrl() {
-    final DomCanvasElement canvas = createDomCanvasElement(width: _widthInPixels, height: _heightInPixels);
+    final DomHTMLCanvasElement canvas = createDomCanvasElement(
+      width: _widthInPixels,
+      height: _heightInPixels,
+    );
     final DomCanvasRenderingContext2D ctx = canvas.context2D;
     drawImage(ctx, 0, 0);
     final String dataUrl = canvas.toDataURL();
@@ -850,7 +796,6 @@ class GlContext {
   }
 }
 
-// ignore: avoid_classes_with_only_static_members
 /// Creates gl context from cached OffscreenCanvas for webgl rendering to image.
 class GlContextCache {
   static int _maxPixelWidth = 0;
@@ -881,36 +826,39 @@ class GlContextCache {
 }
 
 void setupVertexTransforms(
-    GlContext gl,
-    GlProgram glProgram,
-    double offsetX,
-    double offsetY,
-    double widthInPixels,
-    double heightInPixels,
-    Matrix4 transform) {
-  final Object transformUniform =
-      gl.getUniformLocation(glProgram.program, 'u_ctransform');
-  final Matrix4 transformAtOffset = transform.clone()
-    ..translate(-offsetX, -offsetY);
+  GlContext gl,
+  GlProgram glProgram,
+  double offsetX,
+  double offsetY,
+  double widthInPixels,
+  double heightInPixels,
+  Matrix4 transform,
+) {
+  final Object transformUniform = gl.getUniformLocation(glProgram.program, 'u_ctransform');
+  final Matrix4 transformAtOffset = transform.clone()..translate(-offsetX, -offsetY);
   gl.setUniformMatrix4fv(transformUniform, false, transformAtOffset.storage);
 
   // Set uniform to scale 0..width/height pixels coordinates to -1..1
   // clipspace range and flip the Y axis.
   final Object resolution = gl.getUniformLocation(glProgram.program, 'u_scale');
-  gl.setUniform4f(resolution, 2.0 / widthInPixels,
-      -2.0 / heightInPixels, 1, 1);
+  gl.setUniform4f(resolution, 2.0 / widthInPixels, -2.0 / heightInPixels, 1, 1);
   final Object shift = gl.getUniformLocation(glProgram.program, 'u_shift');
   gl.setUniform4f(shift, -1, 1, 0, 0);
 }
 
 void setupTextureTransform(
-    GlContext gl, GlProgram glProgram, double offsetx, double offsety, double sx, double sy) {
+  GlContext gl,
+  GlProgram glProgram,
+  double offsetx,
+  double offsety,
+  double sx,
+  double sy,
+) {
   final Object scalar = gl.getUniformLocation(glProgram.program, 'u_textransform');
   gl.setUniform4f(scalar, sx, sy, offsetx, offsety);
 }
 
-void bufferVertexData(GlContext gl, Float32List positions,
-    double devicePixelRatio) {
+void bufferVertexData(GlContext gl, Float32List positions, double devicePixelRatio) {
   if (devicePixelRatio == 1.0) {
     gl.bufferData(positions, gl.kStaticDraw);
   } else {
@@ -926,13 +874,13 @@ void bufferVertexData(GlContext gl, Float32List positions,
 dynamic tileModeToGlWrapping(GlContext gl, ui.TileMode tileMode) {
   switch (tileMode) {
     case ui.TileMode.clamp:
-    return gl.kClampToEdge;
+      return gl.kClampToEdge;
     case ui.TileMode.decal:
-    return gl.kClampToEdge;
+      return gl.kClampToEdge;
     case ui.TileMode.mirror:
-    return gl.kMirroredRepeat;
+      return gl.kMirroredRepeat;
     case ui.TileMode.repeated:
-    return gl.kRepeat;
+      return gl.kRepeat;
   }
 }
 
@@ -942,24 +890,21 @@ class OffScreenCanvas {
     if (OffScreenCanvas.supported) {
       offScreenCanvas = createDomOffscreenCanvas(width, height);
     } else {
-      canvasElement = createDomCanvasElement(
-        width: width,
-        height: height,
-      );
+      canvasElement = createDomCanvasElement(width: width, height: height);
       canvasElement!.className = 'gl-canvas';
       _updateCanvasCssSize(canvasElement!);
     }
   }
 
   DomOffscreenCanvas? offScreenCanvas;
-  DomCanvasElement? canvasElement;
+  DomHTMLCanvasElement? canvasElement;
   int width;
   int height;
   static bool? _supported;
 
-  void _updateCanvasCssSize(DomCanvasElement element) {
-    final double cssWidth = width / EnginePlatformDispatcher.browserDevicePixelRatio;
-    final double cssHeight = height / EnginePlatformDispatcher.browserDevicePixelRatio;
+  void _updateCanvasCssSize(DomHTMLCanvasElement element) {
+    final double cssWidth = width / EngineFlutterDisplay.instance.browserDevicePixelRatio;
+    final double cssHeight = height / EngineFlutterDisplay.instance.browserDevicePixelRatio;
     element.style
       ..position = 'absolute'
       ..width = '${cssWidth}px'
@@ -967,10 +912,10 @@ class OffScreenCanvas {
   }
 
   void resize(int requestedWidth, int requestedHeight) {
-    if(requestedWidth != width && requestedHeight != height) {
+    if (requestedWidth != width || requestedHeight != height) {
       width = requestedWidth;
       height = requestedHeight;
-      if(offScreenCanvas != null) {
+      if (offScreenCanvas != null) {
         offScreenCanvas!.width = requestedWidth.toDouble();
         offScreenCanvas!.height = requestedHeight.toDouble();
       } else if (canvasElement != null) {
@@ -994,6 +939,13 @@ class OffScreenCanvas {
         : canvasElement!.getContext('2d');
   }
 
+  DomImageBitmapRenderingContext? getBitmapRendererContext() {
+    return (offScreenCanvas != null
+            ? offScreenCanvas!.getContext('bitmaprenderer')
+            : canvasElement!.getContext('bitmaprenderer'))
+        as DomImageBitmapRenderingContext?;
+  }
+
   /// Feature detection for transferToImageBitmap on OffscreenCanvas.
   bool get transferToImageBitmapSupported =>
       js_util.hasProperty(offScreenCanvas!, 'transferToImageBitmap');
@@ -1003,17 +955,24 @@ class OffScreenCanvas {
   ///
   /// !Warning API still in experimental status, feature detect before using.
   Object? transferToImageBitmap() {
-    return js_util.callMethod(offScreenCanvas!, 'transferToImageBitmap',
-        <dynamic>[]);
+    return js_util.callMethod(offScreenCanvas!, 'transferToImageBitmap', <dynamic>[]);
   }
 
   /// Draws canvas contents to a rendering context.
   void transferImage(Object targetContext) {
     // Actual size of canvas may be larger than viewport size. Use
     // source/destination to draw part of the image data.
-    js_util.callMethod<void>(targetContext, 'drawImage',
-        <dynamic>[offScreenCanvas ?? canvasElement!, 0, 0, width, height,
-          0, 0, width, height]);
+    js_util.callMethod<void>(targetContext, 'drawImage', <dynamic>[
+      offScreenCanvas ?? canvasElement!,
+      0,
+      0,
+      width,
+      height,
+      0,
+      0,
+      width,
+      height,
+    ]);
   }
 
   /// Converts canvas contents to an image and returns as data URL.
@@ -1022,11 +981,14 @@ class OffScreenCanvas {
     if (offScreenCanvas != null) {
       offScreenCanvas!.convertToBlob().then((DomBlob value) {
         final DomFileReader fileReader = createDomFileReader();
-        fileReader.addEventListener('load', createDomEventListener((DomEvent event) {
-          completer.complete(
-            js_util.getProperty<String>(js_util.getProperty<Object>(event, 'target'), 'result'),
-          );
-        }));
+        fileReader.addEventListener(
+          'load',
+          createDomEventListener((DomEvent event) {
+            completer.complete(
+              js_util.getProperty<String>(js_util.getProperty<Object>(event, 'target'), 'result'),
+            );
+          }),
+        );
         fileReader.readAsDataURL(value);
       });
       return completer.future;
@@ -1037,14 +999,13 @@ class OffScreenCanvas {
 
   /// Draws an image to canvas for both offscreen canvas context2d.
   void drawImage(Object image, int x, int y, int width, int height) {
-    js_util.callMethod<void>(
-        getContext2d()!, 'drawImage', <dynamic>[image, x, y, width, height]);
+    js_util.callMethod<void>(getContext2d()!, 'drawImage', <dynamic>[image, x, y, width, height]);
   }
 
   /// Feature detects OffscreenCanvas.
-  static bool get supported => _supported ??=
-      // Safari 16.4 implements OffscreenCanvas, but without WebGL support. So
-      // it's not really supported in a way that is useful to us.
-      !isSafari
-      && js_util.hasProperty(domWindow, 'OffscreenCanvas');
+  static bool get supported =>
+      _supported ??=
+          // Safari 16.4 implements OffscreenCanvas, but without WebGL support. So
+          // it's not really supported in a way that is useful to us.
+          !ui_web.browser.isSafari && js_util.hasProperty(domWindow, 'OffscreenCanvas');
 }
