@@ -46,7 +46,7 @@ enum LabelRepresentation {
   sizedSpan;
 
   /// Creates the behavior for this label representation.
-  LabelRepresentationBehavior createBehavior(PrimaryRoleManager owner) {
+  LabelRepresentationBehavior createBehavior(SemanticRole owner) {
     return switch (this) {
       ariaLabel => AriaLabelRepresentation._(owner),
       domText => DomTextRepresentation._(owner),
@@ -61,8 +61,8 @@ abstract final class LabelRepresentationBehavior {
 
   final LabelRepresentation kind;
 
-  /// The role manager that this label representation is attached to.
-  final PrimaryRoleManager owner;
+  /// The role that this label representation is attached to.
+  final SemanticRole owner;
 
   /// Convenience getter for the corresponding semantics object.
   SemanticsObject get semanticsObject => owner.semanticsObject;
@@ -97,7 +97,7 @@ abstract final class LabelRepresentationBehavior {
   /// https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/tabindex
   void focusAsRouteDefault() {
     focusTarget.tabIndex = -1;
-    focusTarget.focus();
+    focusTarget.focusWithoutScroll();
   }
 }
 
@@ -107,7 +107,7 @@ abstract final class LabelRepresentationBehavior {
 ///
 ///     <flt-semantics aria-label="Hello, World!"></flt-semantics>
 final class AriaLabelRepresentation extends LabelRepresentationBehavior {
-  AriaLabelRepresentation._(PrimaryRoleManager owner) : super(LabelRepresentation.ariaLabel, owner);
+  AriaLabelRepresentation._(SemanticRole owner) : super(LabelRepresentation.ariaLabel, owner);
 
   String? _previousLabel;
 
@@ -141,7 +141,7 @@ final class AriaLabelRepresentation extends LabelRepresentationBehavior {
 /// no ARIA role set, or the role does not size the element, then the
 /// [SizedSpanRepresentation] representation can be used.
 final class DomTextRepresentation extends LabelRepresentationBehavior {
-  DomTextRepresentation._(PrimaryRoleManager owner) : super(LabelRepresentation.domText, owner);
+  DomTextRepresentation._(SemanticRole owner) : super(LabelRepresentation.domText, owner);
 
   DomText? _domText;
   String? _previousLabel;
@@ -170,26 +170,28 @@ final class DomTextRepresentation extends LabelRepresentationBehavior {
 }
 
 /// A span queue for a size update.
-typedef _QueuedSizeUpdate = ({
-  // The span to be sized.
-  SizedSpanRepresentation representation,
+typedef _QueuedSizeUpdate =
+    ({
+      // The span to be sized.
+      SizedSpanRepresentation representation,
 
-  // The desired size.
-  ui.Size targetSize,
-});
+      // The desired size.
+      ui.Size targetSize,
+    });
 
 /// The size of a span as measured in the DOM.
-typedef _Measurement = ({
-  // The span that was measured.
-  SizedSpanRepresentation representation,
+typedef _Measurement =
+    ({
+      // The span that was measured.
+      SizedSpanRepresentation representation,
 
-  // The measured size of the DOM element before the size adjustment.
-  ui.Size domSize,
+      // The measured size of the DOM element before the size adjustment.
+      ui.Size domSize,
 
-  // The size of the element that the screen reader should observe after the
-  // size adjustment.
-  ui.Size targetSize,
-});
+      // The size of the element that the screen reader should observe after the
+      // size adjustment.
+      ui.Size targetSize,
+    });
 
 /// Sets the label as the text of a `<span>` child element.
 ///
@@ -231,7 +233,7 @@ typedef _Measurement = ({
 /// * Use an existing non-text role, e.g. "heading". Sizes correctly, but breaks
 ///   the message (reads "heading").
 final class SizedSpanRepresentation extends LabelRepresentationBehavior {
-  SizedSpanRepresentation._(PrimaryRoleManager owner) : super(LabelRepresentation.sizedSpan, owner) {
+  SizedSpanRepresentation._(SemanticRole owner) : super(LabelRepresentation.sizedSpan, owner) {
     _domText.style
       // `inline-block` is needed for two reasons:
       // - It supports measuring the true size of the text. Pure `block` would
@@ -239,14 +241,19 @@ final class SizedSpanRepresentation extends LabelRepresentationBehavior {
       // - It supports the `transform` and `transform-origin` properties. Pure
       //   `inline` does not support them.
       ..display = 'inline-block'
-
       // Do not wrap text based on parent constraints. Instead, to fit in the
       // parent's box the text will be scaled.
       ..whiteSpace = 'nowrap'
-
       // The origin of the coordinate system is the top-left corner of the
       // parent element.
-      ..transformOrigin = '0 0 0';
+      ..transformOrigin = '0 0 0'
+      // The node may be tappable without having a more concrete role set on it,
+      // such as "button". It will just have a tap handler. This could lead to
+      // sized span to be chosen as the label representation strategy. However,
+      // when pointer events land on the span the DOM `target` becomes the span
+      // rather than the tappable element, and that breaks the debouncing logic
+      // in `pointer_binding.dart`.
+      ..pointerEvents = 'none';
     semanticsObject.element.appendChild(_domText);
   }
 
@@ -310,10 +317,7 @@ final class SizedSpanRepresentation extends LabelRepresentationBehavior {
       // corresponding to the semantic node may still be detached.
       semanticsObject.owner.addOneTimePostUpdateCallback(_updateSizes);
     }
-    _resizeQueue!.add((
-      representation: this,
-      targetSize: size,
-    ));
+    _resizeQueue!.add((representation: this, targetSize: size));
   }
 
   @override
@@ -423,14 +427,13 @@ final class SizedSpanRepresentation extends LabelRepresentationBehavior {
   DomElement get focusTarget => _domText;
 }
 
-/// Renders [SemanticsObject.label] and/or [SemanticsObject.value] to the semantics DOM.
+/// Renders the label for a [SemanticsObject] that can be scanned by screen
+/// readers, web crawlers, and other automated agents.
 ///
-/// The value is not always rendered. Some semantics nodes correspond to
-/// interactive controls. In such case the value is reported via that element's
-/// `value` attribute rather than rendering it separately.
-class LabelAndValue extends RoleManager {
-  LabelAndValue(SemanticsObject semanticsObject, PrimaryRoleManager owner, { required this.preferredRepresentation })
-      : super(Role.labelAndValue, semanticsObject, owner);
+/// See [computeDomSemanticsLabel] for the exact logic that constructs the label
+/// of a semantic node.
+class LabelAndValue extends SemanticBehavior {
+  LabelAndValue(super.semanticsObject, super.owner, {required this.preferredRepresentation});
 
   /// The preferred representation of the label in the DOM.
   ///
@@ -461,11 +464,10 @@ class LabelAndValue extends RoleManager {
   /// If the node has children always use an `aria-label`. Using extra child
   /// nodes to represent the label will cause layout shifts and confuse the
   /// screen reader. If the are no children, use the representation preferred
-  /// by the primary role manager.
+  /// by the role.
   LabelRepresentationBehavior _getEffectiveRepresentation() {
-    final LabelRepresentation effectiveRepresentation = semanticsObject.hasChildren
-      ? LabelRepresentation.ariaLabel
-      : preferredRepresentation;
+    final LabelRepresentation effectiveRepresentation =
+        semanticsObject.hasChildren ? LabelRepresentation.ariaLabel : preferredRepresentation;
 
     LabelRepresentationBehavior? representation = _representation;
     if (representation == null || representation.kind != effectiveRepresentation) {
@@ -481,7 +483,7 @@ class LabelAndValue extends RoleManager {
   /// combination is present.
   String? _computeLabel() {
     // If the node is incrementable the value is reported to the browser via
-    // the respective role manager. We do not need to also render it again here.
+    // the respective role. We do not need to also render it again here.
     final bool shouldDisplayValue = !semanticsObject.isIncrementable && semanticsObject.hasValue;
 
     return computeDomSemanticsLabel(
@@ -515,12 +517,7 @@ class LabelAndValue extends RoleManager {
   }
 }
 
-String? computeDomSemanticsLabel({
-  String? tooltip,
-  String? label,
-  String? hint,
-  String? value,
-}) {
+String? computeDomSemanticsLabel({String? tooltip, String? label, String? hint, String? value}) {
   final String? labelHintValue = _computeLabelHintValue(label: label, hint: hint, value: value);
 
   if (tooltip == null && labelHintValue == null) {
@@ -544,14 +541,10 @@ String? computeDomSemanticsLabel({
   return combinedValue.isNotEmpty ? combinedValue.toString() : null;
 }
 
-String? _computeLabelHintValue({
-  String? label,
-  String? hint,
-  String? value,
-}) {
+String? _computeLabelHintValue({String? label, String? hint, String? value}) {
   final String combinedValue = <String?>[label, hint, value]
-    .whereType<String>() // poor man's null filter
-    .where((String element) => element.trim().isNotEmpty)
-    .join(' ');
+      .whereType<String>() // poor man's null filter
+      .where((String element) => element.trim().isNotEmpty)
+      .join(' ');
   return combinedValue.isNotEmpty ? combinedValue : null;
 }
