@@ -5,24 +5,36 @@ part of dart._engine;
 
 
 /// Provides accessibility for links.
-class Link extends PrimaryRoleManager {
-  Link(SemanticsObject semanticsObject) : super.withBasics(
-    PrimaryRole.link,
-    semanticsObject,
-    preferredLabelRepresentation: LabelRepresentation.domText,
-  ) {
+class SemanticLink extends SemanticRole {
+  SemanticLink(SemanticsObject semanticsObject)
+    : super.withBasics(
+        EngineSemanticsRole.link,
+        semanticsObject,
+        preferredLabelRepresentation: LabelRepresentation.domText,
+      ) {
     addTappable();
   }
 
   @override
   DomElement createElement() {
     final DomElement element = domDocument.createElement('a');
-    // TODO(mdebbar): Fill in the real link once the framework sends entire uri.
-    // https://github.com/flutter/flutter/issues/150263.
     element.style.display = 'block';
     return element;
   }
 
+  @override
+  void update() {
+    super.update();
+
+    if (semanticsObject.isLinkUrlDirty) {
+      if (semanticsObject.hasLinkUrl) {
+        element.setAttribute('href', semanticsObject.linkUrl!);
+      } else {
+        element.removeAttribute('href');
+      }
+    }
+  }
+
   @override
   bool focusAsRouteDefault() => focusable?.focusAsRouteDefault() ?? false;
 }
