@@ -181,7 +181,7 @@ class DesktopSemanticsEnabler extends SemanticsEnabler {
       createDomEventListener((DomEvent event) {
         tryEnableSemantics(event);
       }),
-      true,
+      true.toJS,
     );
 
     // Adding roles to semantics placeholder. 'aria-live' will make sure that
@@ -379,7 +379,7 @@ class MobileSemanticsEnabler extends SemanticsEnabler {
       createDomEventListener((DomEvent event) {
         tryEnableSemantics(event);
       }),
-      true,
+      true.toJS,
     );
 
     placeholder
