@@ -33,17 +33,17 @@ enum TextCapitalization {
 /// https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/autocapitalize
 class TextCapitalizationConfig {
   const TextCapitalizationConfig.defaultCapitalization()
-      : textCapitalization = TextCapitalization.none;
+    : textCapitalization = TextCapitalization.none;
 
   const TextCapitalizationConfig.fromInputConfiguration(String inputConfiguration)
-      : textCapitalization =
-            inputConfiguration == 'TextCapitalization.words'
-                ? TextCapitalization.words
-                : inputConfiguration == 'TextCapitalization.characters'
-                    ? TextCapitalization.characters
-                    : inputConfiguration == 'TextCapitalization.sentences'
-                        ? TextCapitalization.sentences
-                        : TextCapitalization.none;
+    : textCapitalization =
+          inputConfiguration == 'TextCapitalization.words'
+              ? TextCapitalization.words
+              : inputConfiguration == 'TextCapitalization.characters'
+              ? TextCapitalization.characters
+              : inputConfiguration == 'TextCapitalization.sentences'
+              ? TextCapitalization.sentences
+              : TextCapitalization.none;
 
   final TextCapitalization textCapitalization;
 
@@ -61,29 +61,19 @@ class TextCapitalizationConfig {
     String autocapitalize = '';
     switch (textCapitalization) {
       case TextCapitalization.words:
-        // TODO(mdebbar): There is a bug for `words` level capitalization in IOS now.
-        // For now go back to default. Remove the check after bug is resolved.
-        // https://bugs.webkit.org/show_bug.cgi?id=148504
-        if (ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit) {
-          autocapitalize = 'sentences';
-        } else {
-          autocapitalize = 'words';
-        }
+        autocapitalize = 'words';
       case TextCapitalization.characters:
         autocapitalize = 'characters';
       case TextCapitalization.sentences:
         autocapitalize = 'sentences';
       case TextCapitalization.none:
-      default:
         autocapitalize = 'off';
-        break;
     }
-    if (domInstanceOfString(domElement, 'HTMLInputElement')) {
+    if (domElement.isA<DomHTMLInputElement>()) {
       final DomHTMLInputElement element = domElement as DomHTMLInputElement;
       element.setAttribute('autocapitalize', autocapitalize);
-    } else if (domInstanceOfString(domElement, 'HTMLTextAreaElement')) {
-      final DomHTMLTextAreaElement element = domElement as
-          DomHTMLTextAreaElement;
+    } else if (domElement.isA<DomHTMLTextAreaElement>()) {
+      final DomHTMLTextAreaElement element = domElement as DomHTMLTextAreaElement;
       element.setAttribute('autocapitalize', autocapitalize);
     }
   }
