@@ -21,7 +21,7 @@ int _nextViewId = kImplicitViewId + 1;
 ///
 /// In addition to everything defined in [ui.FlutterView], this class adds
 /// a few web-specific properties.
-base class EngineFlutterView implements ui.FlutterView {
+class EngineFlutterView implements ui.FlutterView {
   /// Creates a [ui.FlutterView] that can be used in multi-view mode.
   ///
   /// The [hostElement] parameter specifies the container in the DOM into which
@@ -29,9 +29,8 @@ base class EngineFlutterView implements ui.FlutterView {
   factory EngineFlutterView(
     EnginePlatformDispatcher platformDispatcher,
     DomElement hostElement, {
-      JsViewConstraints? viewConstraints,
-    }
-  ) = _EngineFlutterViewImpl;
+    JsViewConstraints? viewConstraints,
+  }) = _EngineFlutterViewImpl;
 
   EngineFlutterView._(
     this.viewId,
@@ -40,11 +39,10 @@ base class EngineFlutterView implements ui.FlutterView {
     // multi-view mode, the host element is required for each view (as reflected
     // by the public `EngineFlutterView` constructor).
     DomElement? hostElement, {
-      JsViewConstraints? viewConstraints,
-    }
-  )   : _jsViewConstraints = viewConstraints,
-        embeddingStrategy = EmbeddingStrategy.create(hostElement: hostElement),
-        dimensionsProvider = DimensionsProvider.create(hostElement: hostElement) {
+    JsViewConstraints? viewConstraints,
+  }) : _jsViewConstraints = viewConstraints,
+       embeddingStrategy = EmbeddingStrategy.create(hostElement: hostElement),
+       dimensionsProvider = DimensionsProvider.create(hostElement: hostElement) {
     // The embeddingStrategy will take care of cleaning up the rootElement on
     // hot restart.
     embeddingStrategy.attachViewRoot(dom.rootElement);
@@ -52,7 +50,6 @@ base class EngineFlutterView implements ui.FlutterView {
     _resizeSubscription = onResize.listen(_didResize);
     _globalHtmlAttributes.applyAttributes(
       viewId: viewId,
-      autoDetectRenderer: FlutterConfiguration.flutterWebAutoDetect,
       rendererTag: renderer.rendererTag,
       buildMode: buildMode,
     );
@@ -134,7 +131,7 @@ base class EngineFlutterView implements ui.FlutterView {
 
   final JsViewConstraints? _jsViewConstraints;
 
-  late final EngineSemanticsOwner semantics = EngineSemanticsOwner(dom.semanticsHost);
+  late final EngineSemanticsOwner semantics = EngineSemanticsOwner(viewId, dom.semanticsHost);
 
   @override
   ui.Size get physicalSize {
@@ -287,11 +284,14 @@ base class EngineFlutterView implements ui.FlutterView {
     // Return false if the previous dimensions are not set.
     if (_physicalSize != null) {
       // First confirm both height and width are effected.
-      if (_physicalSize!.height != newPhysicalSize.height && _physicalSize!.width != newPhysicalSize.width) {
+      if (_physicalSize!.height != newPhysicalSize.height &&
+          _physicalSize!.width != newPhysicalSize.width) {
         // If prior to rotation height is bigger than width it should be the
         // opposite after the rotation and vice versa.
-        if ((_physicalSize!.height > _physicalSize!.width && newPhysicalSize.height < newPhysicalSize.width) ||
-            (_physicalSize!.width > _physicalSize!.height && newPhysicalSize.width < newPhysicalSize.height)) {
+        if ((_physicalSize!.height > _physicalSize!.width &&
+                newPhysicalSize.height < newPhysicalSize.width) ||
+            (_physicalSize!.width > _physicalSize!.height &&
+                newPhysicalSize.width < newPhysicalSize.height)) {
           // Rotation detected
           return true;
         }
@@ -312,17 +312,14 @@ final class _EngineFlutterViewImpl extends EngineFlutterView {
   _EngineFlutterViewImpl(
     EnginePlatformDispatcher platformDispatcher,
     DomElement hostElement, {
-      JsViewConstraints? viewConstraints,
-    }
-  ) : super._(_nextViewId++, platformDispatcher, hostElement, viewConstraints: viewConstraints);
+    JsViewConstraints? viewConstraints,
+  }) : super._(_nextViewId++, platformDispatcher, hostElement, viewConstraints: viewConstraints);
 }
 
 /// The Web implementation of [ui.SingletonFlutterWindow].
 final class EngineFlutterWindow extends EngineFlutterView implements ui.SingletonFlutterWindow {
-  EngineFlutterWindow._(
-    EnginePlatformDispatcher platformDispatcher,
-    DomElement? hostElement,
-  ) : super._(kImplicitViewId, platformDispatcher, hostElement) {
+  EngineFlutterWindow._(EnginePlatformDispatcher platformDispatcher, DomElement? hostElement)
+    : super._(kImplicitViewId, platformDispatcher, hostElement) {
     if (ui_web.isCustomUrlStrategySet) {
       _browserHistory = createHistoryForExistingState(ui_web.urlStrategy);
     }
@@ -387,7 +384,8 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
   ui.Brightness get platformBrightness => platformDispatcher.platformBrightness;
 
   @override
-  ui.VoidCallback? get onPlatformBrightnessChanged => platformDispatcher.onPlatformBrightnessChanged;
+  ui.VoidCallback? get onPlatformBrightnessChanged =>
+      platformDispatcher.onPlatformBrightnessChanged;
   @override
   set onPlatformBrightnessChanged(ui.VoidCallback? callback) {
     platformDispatcher.onPlatformBrightnessChanged = callback;
@@ -495,8 +493,7 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
   /// Handles the browser history integration to allow users to use the back
   /// button, etc.
   BrowserHistory get browserHistory {
-    return _browserHistory ??=
-        createHistoryForExistingState(_urlStrategyForInitialization);
+    return _browserHistory ??= createHistoryForExistingState(_urlStrategyForInitialization);
   }
 
   ui_web.UrlStrategy? get _urlStrategyForInitialization {
@@ -506,7 +503,7 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
   }
 
   BrowserHistory?
-      _browserHistory; // Must be either SingleEntryBrowserHistory or MultiEntriesBrowserHistory.
+  _browserHistory; // Must be either SingleEntryBrowserHistory or MultiEntriesBrowserHistory.
 
   Future<void> _useSingleEntryBrowserHistory() async {
     // Recreate the browser history mode that's appropriate for the existing
@@ -518,8 +515,7 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
     // with a single-entry history.
     //
     // See: https://github.com/flutter/flutter/issues/79241
-    _browserHistory ??=
-        createHistoryForExistingState(_urlStrategyForInitialization);
+    _browserHistory ??= createHistoryForExistingState(_urlStrategyForInitialization);
 
     if (_browserHistory is SingleEntryBrowserHistory) {
       return;
@@ -542,8 +538,7 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
     // with a multi-entry history.
     //
     // See: https://github.com/flutter/flutter/issues/79241
-    _browserHistory ??=
-        createHistoryForExistingState(_urlStrategyForInitialization);
+    _browserHistory ??= createHistoryForExistingState(_urlStrategyForInitialization);
 
     if (_browserHistory is MultiEntriesBrowserHistory) {
       return;
@@ -637,50 +632,6 @@ final class EngineFlutterWindow extends EngineFlutterView implements ui.Singleto
       return false;
     });
   }
-
-  // TODO(mdebbar): Deprecate this and remove it.
-  // https://github.com/flutter/flutter/issues/127395
-  void debugOverrideDevicePixelRatio(double? value) {
-    assert(() {
-      printWarning(
-        'The window.debugOverrideDevicePixelRatio API is deprecated and will '
-        'be removed in a future release. Please use '
-        '`debugOverrideDevicePixelRatio` from `dart:ui_web` instead.',
-      );
-      return true;
-    }());
-    display.debugOverrideDevicePixelRatio(value);
-  }
-
-  // TODO(mdebbar): Deprecate this and remove it.
-  // https://github.com/flutter/flutter/issues/127395
-  ui.Size? get webOnlyDebugPhysicalSizeOverride {
-    assert(() {
-      printWarning(
-        'The webOnlyDebugPhysicalSizeOverride API is deprecated and will be '
-        'removed in a future release. Please use '
-        '`SingletonFlutterWindow.debugPhysicalSizeOverride` from `dart:ui_web` '
-        'instead.',
-      );
-      return true;
-    }());
-    return debugPhysicalSizeOverride;
-  }
-
-  // TODO(mdebbar): Deprecate this and remove it.
-  // https://github.com/flutter/flutter/issues/127395
-  set webOnlyDebugPhysicalSizeOverride(ui.Size? value) {
-    assert(() {
-      printWarning(
-        'The webOnlyDebugPhysicalSizeOverride API is deprecated and will be '
-        'removed in a future release. Please use '
-        '`SingletonFlutterWindow.debugPhysicalSizeOverride` from `dart:ui_web` '
-        'instead.',
-      );
-      return true;
-    }());
-    debugPhysicalSizeOverride = value;
-  }
 }
 
 /// The window singleton.
@@ -696,18 +647,14 @@ EngineFlutterWindow get window {
   );
   return _window!;
 }
+
 EngineFlutterWindow? _window;
 
 /// Initializes the [window] (aka the implicit view), if it's not already
 /// initialized.
-EngineFlutterWindow ensureImplicitViewInitialized({
-  DomElement? hostElement,
-}) {
+EngineFlutterWindow ensureImplicitViewInitialized({DomElement? hostElement}) {
   if (_window == null) {
-    _window = EngineFlutterView.implicit(
-      EnginePlatformDispatcher.instance,
-      hostElement,
-    );
+    _window = EngineFlutterView.implicit(EnginePlatformDispatcher.instance, hostElement);
     EnginePlatformDispatcher.instance.viewManager.registerView(_window!);
   }
   return _window!;
@@ -754,8 +701,7 @@ class ViewConstraints implements ui.ViewConstraints {
   /// The resulting ViewConstraints object will be multiplied by devicePixelRatio
   /// later to compute the physicalViewConstraints, which is what the framework
   /// uses.
-  factory ViewConstraints.fromJs(
-    JsViewConstraints? constraints, ui.Size currentLogicalSize) {
+  factory ViewConstraints.fromJs(JsViewConstraints? constraints, ui.Size currentLogicalSize) {
     if (constraints == null) {
       return ViewConstraints.tight(currentLogicalSize);
     }
@@ -778,14 +724,16 @@ class ViewConstraints implements ui.ViewConstraints {
 
   @override
   bool isSatisfiedBy(ui.Size size) {
-    return (minWidth <= size.width) && (size.width <= maxWidth) &&
-           (minHeight <= size.height) && (size.height <= maxHeight);
+    return (minWidth <= size.width) &&
+        (size.width <= maxWidth) &&
+        (minHeight <= size.height) &&
+        (size.height <= maxHeight);
   }
 
   @override
   bool get isTight => minWidth >= maxWidth && minHeight >= maxHeight;
 
-  ViewConstraints operator*(double factor) {
+  ViewConstraints operator *(double factor) {
     return ViewConstraints(
       minWidth: minWidth * factor,
       maxWidth: maxWidth * factor,
@@ -795,7 +743,7 @@ class ViewConstraints implements ui.ViewConstraints {
   }
 
   @override
-  ViewConstraints operator/(double factor) {
+  ViewConstraints operator /(double factor) {
     return ViewConstraints(
       minWidth: minWidth / factor,
       maxWidth: maxWidth / factor,
@@ -812,11 +760,11 @@ class ViewConstraints implements ui.ViewConstraints {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is ViewConstraints
-        && other.minWidth == minWidth
-        && other.maxWidth == maxWidth
-        && other.minHeight == minHeight
-        && other.maxHeight == maxHeight;
+    return other is ViewConstraints &&
+        other.minWidth == minWidth &&
+        other.maxWidth == maxWidth &&
+        other.minHeight == minHeight &&
+        other.maxHeight == maxHeight;
   }
 
   @override
@@ -827,8 +775,10 @@ class ViewConstraints implements ui.ViewConstraints {
     if (minWidth == double.infinity && minHeight == double.infinity) {
       return 'ViewConstraints(biggest)';
     }
-    if (minWidth == 0 && maxWidth == double.infinity &&
-        minHeight == 0 && maxHeight == double.infinity) {
+    if (minWidth == 0 &&
+        maxWidth == double.infinity &&
+        minHeight == 0 &&
+        maxHeight == double.infinity) {
       return 'ViewConstraints(unconstrained)';
     }
     String describe(double min, double max, String dim) {
@@ -837,6 +787,7 @@ class ViewConstraints implements ui.ViewConstraints {
       }
       return '${min.toStringAsFixed(1)}<=$dim<=${max.toStringAsFixed(1)}';
     }
+
     final String width = describe(minWidth, maxWidth, 'w');
     final String height = describe(minHeight, maxHeight, 'h');
     return 'ViewConstraints($width, $height)';
