@@ -4,7 +4,6 @@ part of dart._skwasm_impl;
 // found in the LICENSE file.
 
 
-
 class SkwasmImageDecoder extends BrowserImageDecoder {
   SkwasmImageDecoder({
     required super.contentType,
@@ -17,8 +16,6 @@ class SkwasmImageDecoder extends BrowserImageDecoder {
     final int width = frame.displayWidth.toInt();
     final int height = frame.displayHeight.toInt();
     final SkwasmSurface surface = (renderer as SkwasmRenderer).surface;
-    return SkwasmImage(
-      imageCreateFromTextureSource(frame as JSObject, width, height, surface.handle),
-    );
+    return SkwasmImage(imageCreateFromTextureSource(frame, width, height, surface.handle));
   }
 }
