@@ -26,18 +26,18 @@ typedef DisposeFunction<T extends NativeType> = void Function(Pointer<T>);
 
 class SkwasmFinalizationRegistry<T extends NativeType> {
   SkwasmFinalizationRegistry(this.dispose)
-    : registry = DomFinalizationRegistry(((ExternalDartReference address) =>
-      // ignore: cast_nullable_to_non_nullable
-      dispose(Pointer<T>.fromAddress(address.toDartObject as int))
-    ).toJS);
+    : registry = DomFinalizationRegistry(
+        ((ExternalDartReference<int> address) =>
+                dispose(Pointer<T>.fromAddress(address.toDartObject)))
+            .toJS,
+      );
 
   final DomFinalizationRegistry registry;
   final DisposeFunction<T> dispose;
 
   void register(SkwasmObjectWrapper<T> wrapper) {
     final ExternalDartReference jsWrapper = wrapper.toExternalReference;
-    registry.registerWithToken(
-        jsWrapper, wrapper.handle.address.toExternalReference, jsWrapper);
+    registry.registerWithToken(jsWrapper, wrapper.handle.address.toExternalReference, jsWrapper);
   }
 
   void evict(SkwasmObjectWrapper<T> wrapper) {
