@@ -28,22 +28,26 @@ class SkwasmLineMetrics extends SkwasmObjectWrapper<RawLineMetrics> implements u
     required double left,
     required double baseline,
     required int lineNumber,
-  }) => SkwasmLineMetrics._(lineMetricsCreate(
-    hardBreak,
-    ascent,
-    descent,
-    unscaledAscent,
-    height,
-    width,
-    left,
-    baseline,
-    lineNumber,
-  ));
+  }) => SkwasmLineMetrics._(
+    lineMetricsCreate(
+      hardBreak,
+      ascent,
+      descent,
+      unscaledAscent,
+      height,
+      width,
+      left,
+      baseline,
+      lineNumber,
+    ),
+  );
 
   SkwasmLineMetrics._(LineMetricsHandle handle) : super(handle, _registry);
 
   static final SkwasmFinalizationRegistry<RawLineMetrics> _registry =
-    SkwasmFinalizationRegistry<RawLineMetrics>(lineMetricsDispose);
+      SkwasmFinalizationRegistry<RawLineMetrics>(
+        (LineMetricsHandle handle) => lineMetricsDispose(handle),
+      );
 
   @override
   bool get hardBreak => lineMetricsGetHardBreak(handle);
@@ -80,7 +84,9 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
   SkwasmParagraph(ParagraphHandle handle) : super(handle, _registry);
 
   static final SkwasmFinalizationRegistry<RawParagraph> _registry =
-    SkwasmFinalizationRegistry<RawParagraph>(paragraphDispose);
+      SkwasmFinalizationRegistry<RawParagraph>(
+        (ParagraphHandle handle) => paragraphDispose(handle),
+      );
 
   bool _hasCheckedForMissingCodePoints = false;
 
@@ -129,14 +135,11 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
           final int returnedCodePointCount = paragraphGetUnresolvedCodePoints(
             handle,
             codePointBuffer,
-            missingCodePointCount
+            missingCodePointCount,
           );
           assert(missingCodePointCount == returnedCodePointCount);
           renderer.fontCollection.fontFallbackManager!.addMissingCodePoints(
-            List<int>.generate(
-              missingCodePointCount,
-              (int index) => codePointBuffer[index]
-            )
+            List<int>.generate(missingCodePointCount, (int index) => codePointBuffer[index]),
           );
         });
       }
@@ -148,8 +151,7 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
     return withStackScope((StackScope scope) {
       final RawRect tempRect = scope.allocFloatArray(4);
       return List<ui.TextBox>.generate(length, (int index) {
-        final int textDirectionIndex =
-          textBoxListGetBoxAtIndex(listHandle, index, tempRect);
+        final int textDirectionIndex = textBoxListGetBoxAtIndex(listHandle, index, tempRect);
         return ui.TextBox.fromLTRBD(
           tempRect[0],
           tempRect[1],
@@ -166,14 +168,14 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
     int start,
     int end, {
     ui.BoxHeightStyle boxHeightStyle = ui.BoxHeightStyle.tight,
-    ui.BoxWidthStyle boxWidthStyle = ui.BoxWidthStyle.tight
+    ui.BoxWidthStyle boxWidthStyle = ui.BoxWidthStyle.tight,
   }) {
     final TextBoxListHandle listHandle = paragraphGetBoxesForRange(
       handle,
       start,
       end,
       boxHeightStyle.index,
-      boxWidthStyle.index
+      boxWidthStyle.index,
     );
     final List<ui.TextBox> boxes = _convertTextBoxList(listHandle);
     textBoxListDispose(listHandle);
@@ -183,16 +185,8 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
   @override
   ui.TextPosition getPositionForOffset(ui.Offset offset) => withStackScope((StackScope scope) {
     final Pointer<Int32> outAffinity = scope.allocInt32Array(1);
-    final int position = paragraphGetPositionForOffset(
-      handle,
-      offset.dx,
-      offset.dy,
-      outAffinity
-    );
-    return ui.TextPosition(
-      offset: position,
-      affinity: ui.TextAffinity.values[outAffinity[0]],
-    );
+    final int position = paragraphGetPositionForOffset(handle, offset.dx, offset.dy, outAffinity);
+    return ui.TextPosition(offset: position, affinity: ui.TextAffinity.values[outAffinity[0]]);
   });
 
   @override
@@ -202,12 +196,12 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
       final Pointer<Uint32> outRange = scope.allocUint32Array(2);
       final Pointer<Bool> outBooleanFlags = scope.allocBoolArray(1);
       return paragraphGetGlyphInfoAt(handle, codeUnitOffset, outRect, outRange, outBooleanFlags)
-        ? ui.GlyphInfo(
-          scope.convertRectFromNative(outRect),
-          ui.TextRange(start: outRange[0], end: outRange[1]),
-          outBooleanFlags[0] ? ui.TextDirection.ltr : ui.TextDirection.rtl,
-        )
-        : null;
+          ? ui.GlyphInfo(
+            scope.convertRectFromNative(outRect),
+            ui.TextRange(start: outRange[0], end: outRange[1]),
+            outBooleanFlags[0] ? ui.TextDirection.ltr : ui.TextDirection.rtl,
+          )
+          : null;
     });
   }
 
@@ -217,13 +211,20 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
       final Pointer<Float> outRect = scope.allocFloatArray(4);
       final Pointer<Uint32> outRange = scope.allocUint32Array(2);
       final Pointer<Bool> outBooleanFlags = scope.allocBoolArray(1);
-      return paragraphGetClosestGlyphInfoAtCoordinate(handle, offset.dx, offset.dy, outRect, outRange, outBooleanFlags)
-        ? ui.GlyphInfo(
-          scope.convertRectFromNative(outRect),
-          ui.TextRange(start: outRange[0], end: outRange[1]),
-          outBooleanFlags[0] ? ui.TextDirection.ltr : ui.TextDirection.rtl,
-        )
-        : null;
+      return paragraphGetClosestGlyphInfoAtCoordinate(
+            handle,
+            offset.dx,
+            offset.dy,
+            outRect,
+            outRange,
+            outBooleanFlags,
+          )
+          ? ui.GlyphInfo(
+            scope.convertRectFromNative(outRect),
+            ui.TextRange(start: outRange[0], end: outRange[1]),
+            outBooleanFlags[0] ? ui.TextDirection.ltr : ui.TextDirection.rtl,
+          )
+          : null;
     });
   }
 
@@ -260,8 +261,9 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
   @override
   List<SkwasmLineMetrics> computeLineMetrics() {
     final int lineCount = paragraphGetLineCount(handle);
-    return List<SkwasmLineMetrics>.generate(lineCount,
-      (int index) => SkwasmLineMetrics._(paragraphGetLineMetricsAtIndex(handle, index))
+    return List<SkwasmLineMetrics>.generate(
+      lineCount,
+      (int index) => SkwasmLineMetrics._(paragraphGetLineMetricsAtIndex(handle, index)),
     );
   }
 
@@ -273,11 +275,12 @@ class SkwasmParagraph extends SkwasmObjectWrapper<RawParagraph> implements ui.Pa
 }
 
 void withScopedFontList(
-    List<String> fontFamilies,
-  void Function(Pointer<SkStringHandle>, int) callback) {
+  List<String> fontFamilies,
+  void Function(Pointer<SkStringHandle>, int) callback,
+) {
   withStackScope((StackScope scope) {
     final Pointer<SkStringHandle> familiesPtr =
-      scope.allocPointerArray(fontFamilies.length).cast<SkStringHandle>();
+        scope.allocPointerArray(fontFamilies.length).cast<SkStringHandle>();
     int nativeIndex = 0;
     for (int i = 0; i < fontFamilies.length; i++) {
       familiesPtr[nativeIndex] = skStringFromDartString(fontFamilies[i]);
@@ -296,7 +299,9 @@ class SkwasmNativeTextStyle extends SkwasmObjectWrapper<RawTextStyle> {
   factory SkwasmNativeTextStyle.defaultTextStyle() => SkwasmNativeTextStyle(textStyleCreate());
 
   static final SkwasmFinalizationRegistry<RawTextStyle> _registry =
-    SkwasmFinalizationRegistry<RawTextStyle>(textStyleDispose);
+      SkwasmFinalizationRegistry<RawTextStyle>(
+        (TextStyleHandle handle) => textStyleDispose(handle),
+      );
 
   SkwasmNativeTextStyle copy() {
     return SkwasmNativeTextStyle(textStyleCopy(handle));
@@ -327,9 +332,9 @@ class SkwasmTextStyle implements ui.TextStyle {
     this.fontFeatures,
     this.fontVariations,
   }) : assert(
-        color == null || foreground == null,
-        'Cannot provide both a color and a foreground\n'
-        'The color argument is just a shorthand for "foreground: Paint()..color = color".',
+         color == null || foreground == null,
+         'Cannot provide both a color and a foreground\n'
+         'The color argument is just a shorthand for "foreground: Paint()..color = color".',
        );
 
   void applyToNative(SkwasmNativeTextStyle style) {
@@ -353,7 +358,7 @@ class SkwasmTextStyle implements ui.TextStyle {
       textStyleSetFontStyle(
         handle,
         (fontWeight ?? ui.FontWeight.normal).value,
-        (fontStyle ?? ui.FontStyle.normal).index
+        (fontStyle ?? ui.FontStyle.normal).index,
       );
     }
     if (textBaseline != null) {
@@ -362,9 +367,11 @@ class SkwasmTextStyle implements ui.TextStyle {
 
     final List<String> effectiveFontFamilies = _computeEffectiveFontFamilies(fontFamilies);
     if (effectiveFontFamilies.isNotEmpty) {
-      withScopedFontList(effectiveFontFamilies,
+      withScopedFontList(
+        effectiveFontFamilies,
         (Pointer<SkStringHandle> families, int count) =>
-          textStyleAddFontFamilies(handle, families, count));
+            textStyleAddFontFamilies(handle, families, count),
+      );
     }
 
     if (fontSize != null) {
@@ -380,22 +387,22 @@ class SkwasmTextStyle implements ui.TextStyle {
       textStyleSetHeight(handle, height!);
     }
     if (leadingDistribution != null) {
-      textStyleSetHalfLeading(
-        handle,
-        leadingDistribution == ui.TextLeadingDistribution.even
-      );
+      textStyleSetHalfLeading(handle, leadingDistribution == ui.TextLeadingDistribution.even);
     }
     if (locale != null) {
-      final SkStringHandle localeHandle =
-        skStringFromDartString(locale!.toLanguageTag());
+      final SkStringHandle localeHandle = skStringFromDartString(locale!.toLanguageTag());
       textStyleSetLocale(handle, localeHandle);
       skStringFree(localeHandle);
     }
     if (background != null) {
-      textStyleSetBackground(handle, (background! as SkwasmPaint).handle);
+      final backgroundPaint = (background! as SkwasmPaint).toRawPaint();
+      textStyleSetBackground(handle, backgroundPaint);
+      paintDispose(backgroundPaint);
     }
     if (foreground != null) {
-      textStyleSetForeground(handle, (foreground! as SkwasmPaint).handle);
+      final foregroundPaint = (foreground! as SkwasmPaint).toRawPaint();
+      textStyleSetForeground(handle, foregroundPaint);
+      paintDispose(foregroundPaint);
     }
     if (shadows != null) {
       for (final ui.Shadow shadow in shadows!) {
@@ -426,10 +433,10 @@ class SkwasmTextStyle implements ui.TextStyle {
           final String axis = variation.axis;
           assert(axis.length == 4); // 4 byte code
           final int axisNumber =
-            axis.codeUnitAt(0) << 24 |
-            axis.codeUnitAt(1) << 16 |
-            axis.codeUnitAt(2) << 8 |
-            axis.codeUnitAt(3);
+              axis.codeUnitAt(0) << 24 |
+              axis.codeUnitAt(1) << 16 |
+              axis.codeUnitAt(2) << 8 |
+              axis.codeUnitAt(3);
           axisBuffer[i] = axisNumber;
           valueBuffer[i] = variation.value;
         }
@@ -470,28 +477,28 @@ class SkwasmTextStyle implements ui.TextStyle {
     if (identical(this, other)) {
       return true;
     }
-    return other is SkwasmTextStyle
-        && other.color == color
-        && other.decoration == decoration
-        && other.decorationColor == decorationColor
-        && other.decorationStyle == decorationStyle
-        && other.fontWeight == fontWeight
-        && other.fontStyle == fontStyle
-        && other.textBaseline == textBaseline
-        && other.leadingDistribution == leadingDistribution
-        && other.fontFamily == fontFamily
-        && other.fontSize == fontSize
-        && other.letterSpacing == letterSpacing
-        && other.wordSpacing == wordSpacing
-        && other.height == height
-        && other.decorationThickness == decorationThickness
-        && other.locale == locale
-        && other.background == background
-        && other.foreground == foreground
-        && listEquals<ui.Shadow>(other.shadows, shadows)
-        && listEquals<String>(other.fontFamilyFallback, fontFamilyFallback)
-        && listEquals<ui.FontFeature>(other.fontFeatures, fontFeatures)
-        && listEquals<ui.FontVariation>(other.fontVariations, fontVariations);
+    return other is SkwasmTextStyle &&
+        other.color == color &&
+        other.decoration == decoration &&
+        other.decorationColor == decorationColor &&
+        other.decorationStyle == decorationStyle &&
+        other.fontWeight == fontWeight &&
+        other.fontStyle == fontStyle &&
+        other.textBaseline == textBaseline &&
+        other.leadingDistribution == leadingDistribution &&
+        other.fontFamily == fontFamily &&
+        other.fontSize == fontSize &&
+        other.letterSpacing == letterSpacing &&
+        other.wordSpacing == wordSpacing &&
+        other.height == height &&
+        other.decorationThickness == decorationThickness &&
+        other.locale == locale &&
+        other.background == background &&
+        other.foreground == foreground &&
+        listEquals<ui.Shadow>(other.shadows, shadows) &&
+        listEquals<String>(other.fontFamilyFallback, fontFamilyFallback) &&
+        listEquals<ui.FontFeature>(other.fontFeatures, fontFeatures) &&
+        listEquals<ui.FontVariation>(other.fontVariations, fontVariations);
   }
 
   @override
@@ -524,7 +531,7 @@ class SkwasmTextStyle implements ui.TextStyle {
       Object.hash(
         fontFeatures == null ? null : Object.hashAll(fontFeatures),
         fontVariations == null ? null : Object.hashAll(fontVariations),
-      )
+      ),
     );
   }
 
@@ -535,7 +542,8 @@ class SkwasmTextStyle implements ui.TextStyle {
       final List<String>? fontFamilyFallback = this.fontFamilyFallback;
       final double? fontSize = this.fontSize;
       final double? height = this.height;
-      result = 'TextStyle('
+      result =
+          'TextStyle('
           'color: ${color ?? "unspecified"}, '
           'decoration: ${decoration ?? "unspecified"}, '
           'decorationColor: ${decorationColor ?? "unspecified"}, '
@@ -582,8 +590,11 @@ final class SkwasmStrutStyle extends SkwasmObjectWrapper<RawStrutStyle> implemen
       if (fontFamilyFallback != null) ...fontFamilyFallback,
     ]);
     if (effectiveFontFamilies.isNotEmpty) {
-      withScopedFontList(effectiveFontFamilies, (Pointer<SkStringHandle> families, int count) =>
-          strutStyleSetFontFamilies(handle, families, count));
+      withScopedFontList(
+        effectiveFontFamilies,
+        (Pointer<SkStringHandle> families, int count) =>
+            strutStyleSetFontFamilies(handle, families, count),
+      );
     }
     if (fontSize != null) {
       strutStyleSetFontSize(handle, fontSize);
@@ -592,9 +603,7 @@ final class SkwasmStrutStyle extends SkwasmObjectWrapper<RawStrutStyle> implemen
       strutStyleSetHeight(handle, height);
     }
     if (leadingDistribution != null) {
-      strutStyleSetHalfLeading(
-        handle,
-        leadingDistribution == ui.TextLeadingDistribution.even);
+      strutStyleSetHalfLeading(handle, leadingDistribution == ui.TextLeadingDistribution.even);
     }
     if (leading != null) {
       strutStyleSetLeading(handle, leading);
@@ -635,7 +644,9 @@ final class SkwasmStrutStyle extends SkwasmObjectWrapper<RawStrutStyle> implemen
   ) : super(handle, _registry);
 
   static final SkwasmFinalizationRegistry<RawStrutStyle> _registry =
-    SkwasmFinalizationRegistry<RawStrutStyle>(strutStyleDispose);
+      SkwasmFinalizationRegistry<RawStrutStyle>(
+        (StrutStyleHandle handle) => strutStyleDispose(handle),
+      );
 
   final String? _fontFamily;
   final List<String>? _fontFamilyFallback;
@@ -685,7 +696,8 @@ final class SkwasmStrutStyle extends SkwasmObjectWrapper<RawStrutStyle> implemen
       final double? fontSize = _fontSize;
       final double? height = _height;
       final double? leading = _leading;
-      result = 'StrutStyle('
+      result =
+          'StrutStyle('
           'fontFamily: ${_fontFamily ?? "unspecified"}, '
           'fontFamilyFallback: ${_fontFamilyFallback ?? "unspecified"}, '
           'fontFamilyFallback: ${fontFamilyFallback != null && fontFamilyFallback.isNotEmpty ? fontFamilyFallback : "unspecified"}, '
@@ -703,7 +715,8 @@ final class SkwasmStrutStyle extends SkwasmObjectWrapper<RawStrutStyle> implemen
   }
 }
 
-class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implements ui.ParagraphStyle {
+class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle>
+    implements ui.ParagraphStyle {
   factory SkwasmParagraphStyle({
     ui.TextAlign? textAlign,
     ui.TextDirection? textDirection,
@@ -748,15 +761,18 @@ class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implem
       paragraphStyleSetStrutStyle(handle, strutStyle.handle);
     }
     final SkwasmNativeTextStyle textStyle =
-      (renderer.fontCollection as SkwasmFontCollection).defaultTextStyle.copy();
+        (renderer.fontCollection as SkwasmFontCollection).defaultTextStyle.copy();
     final TextStyleHandle textStyleHandle = textStyle.handle;
 
     final List<String> effectiveFontFamilies = _computeEffectiveFontFamilies(<String>[
-      if (fontFamily != null) fontFamily
+      if (fontFamily != null) fontFamily,
     ]);
     if (effectiveFontFamilies.isNotEmpty) {
-      withScopedFontList(effectiveFontFamilies, (Pointer<SkStringHandle> families, int count) =>
-          textStyleAddFontFamilies(textStyleHandle, families, count));
+      withScopedFontList(
+        effectiveFontFamilies,
+        (Pointer<SkStringHandle> families, int count) =>
+            textStyleAddFontFamilies(textStyleHandle, families, count),
+      );
     }
     if (fontSize != null) {
       textStyleSetFontSize(textStyleHandle, fontSize);
@@ -776,8 +792,7 @@ class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implem
       );
     }
     if (locale != null) {
-      final SkStringHandle localeHandle =
-      skStringFromDartString(locale.toLanguageTag());
+      final SkStringHandle localeHandle = skStringFromDartString(locale.toLanguageTag());
       textStyleSetLocale(textStyleHandle, localeHandle);
       skStringFree(localeHandle);
     }
@@ -822,7 +837,9 @@ class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implem
   ) : super(handle, _registry);
 
   static final SkwasmFinalizationRegistry<RawParagraphStyle> _registry =
-    SkwasmFinalizationRegistry<RawParagraphStyle>(paragraphStyleDispose);
+      SkwasmFinalizationRegistry<RawParagraphStyle>(
+        (ParagraphStyleHandle handle) => paragraphStyleDispose(handle),
+      );
 
   final SkwasmNativeTextStyle textStyle;
   final String? defaultFontFamily;
@@ -887,7 +904,8 @@ class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implem
     assert(() {
       final double? fontSize = _fontSize;
       final double? height = _height;
-      result = 'ParagraphStyle('
+      result =
+          'ParagraphStyle('
           'textAlign: ${_textAlign ?? "unspecified"}, '
           'textDirection: ${_textDirection ?? "unspecified"}, '
           'fontWeight: ${_fontWeight ?? "unspecified"}, '
@@ -907,19 +925,17 @@ class SkwasmParagraphStyle extends SkwasmObjectWrapper<RawParagraphStyle> implem
   }
 }
 
-class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> implements ui.ParagraphBuilder {
-  factory SkwasmParagraphBuilder(
-    SkwasmParagraphStyle style,
-    SkwasmFontCollection collection,
-  ) => SkwasmParagraphBuilder._(paragraphBuilderCreate(
-      style.handle,
-      collection.handle,
-    ), style);
+class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder>
+    implements ui.ParagraphBuilder {
+  factory SkwasmParagraphBuilder(SkwasmParagraphStyle style, SkwasmFontCollection collection) =>
+      SkwasmParagraphBuilder._(paragraphBuilderCreate(style.handle, collection.handle), style);
 
   SkwasmParagraphBuilder._(ParagraphBuilderHandle handle, this.style) : super(handle, _registry);
 
   static final SkwasmFinalizationRegistry<RawParagraphBuilder> _registry =
-    SkwasmFinalizationRegistry<RawParagraphBuilder>(paragraphBuilderDispose);
+      SkwasmFinalizationRegistry<RawParagraphBuilder>(
+        (ParagraphBuilderHandle handle) => paragraphBuilderDispose(handle),
+      );
 
   final SkwasmParagraphStyle style;
   final List<SkwasmNativeTextStyle> textStyleStack = <SkwasmNativeTextStyle>[];
@@ -934,7 +950,7 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
     ui.PlaceholderAlignment alignment, {
     double scale = 1.0,
     double? baselineOffset,
-    ui.TextBaseline? baseline
+    ui.TextBaseline? baseline,
   }) {
     paragraphBuilderAddPlaceholder(
       handle,
@@ -976,7 +992,7 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
     } else {
       final List<int> codeUnitList = List<int>.generate(
         outSize.value,
-        (int index) => utf8Data[index]
+        (int index) => utf8Data[index],
       );
       text = utf8.decode(codeUnitList);
       jsText = _utf8Decoder.decode(
@@ -984,10 +1000,10 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
         // than a slice, but the TextDecoder API doesn't work on shared buffer
         // sources yet.
         // See https://bugs.chromium.org/p/chromium/issues/detail?id=1012656
-        createUint8ArrayFromBuffer(skwasmInstance.wasmMemory.buffer).slice(
-          utf8Data.address.toJS,
-          (utf8Data.address + outSize.value).toJS
-        ));
+        JSUint8Array(
+          skwasmInstance.wasmMemory.buffer,
+        ).slice(utf8Data.address, utf8Data.address + outSize.value),
+      );
     }
 
     _addGraphemeBreakData(text, jsText);
@@ -995,7 +1011,11 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
     _addLineBreakData(text, jsText);
   });
 
-  UnicodePositionBufferHandle _createBreakPositionBuffer(String text, JSString jsText, DomSegmenter segmenter) {
+  UnicodePositionBufferHandle _createBreakPositionBuffer(
+    String text,
+    JSString jsText,
+    DomSegmenter segmenter,
+  ) {
     final DomIteratorWrapper<DomSegment> iterator = segmenter.segmentRaw(jsText).iterator();
     final List<int> breaks = <int>[];
     while (iterator.moveNext()) {
@@ -1012,21 +1032,31 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
   }
 
   void _addGraphemeBreakData(String text, JSString jsText) {
-    final UnicodePositionBufferHandle positionBuffer =
-      _createBreakPositionBuffer(text, jsText, _graphemeSegmenter);
+    final UnicodePositionBufferHandle positionBuffer = _createBreakPositionBuffer(
+      text,
+      jsText,
+      _graphemeSegmenter,
+    );
     paragraphBuilderSetGraphemeBreaksUtf16(handle, positionBuffer);
     unicodePositionBufferFree(positionBuffer);
   }
 
   void _addWordBreakData(String text, JSString jsText) {
-    final UnicodePositionBufferHandle positionBuffer =
-      _createBreakPositionBuffer(text, jsText, _wordSegmenter);
+    final UnicodePositionBufferHandle positionBuffer = _createBreakPositionBuffer(
+      text,
+      jsText,
+      _wordSegmenter,
+    );
     paragraphBuilderSetWordBreaksUtf16(handle, positionBuffer);
     unicodePositionBufferFree(positionBuffer);
   }
 
   void _addLineBreakData(String text, JSString jsText) {
-    final List<LineBreakFragment> lineBreaks = breakLinesUsingV8BreakIterator(text, jsText, _v8BreakIterator);
+    final List<LineBreakFragment> lineBreaks = breakLinesUsingV8BreakIterator(
+      text,
+      jsText,
+      _v8BreakIterator,
+    );
     final LineBreakBufferHandle lineBreakBuffer = lineBreakBufferCreate(lineBreaks.length + 1);
     final Pointer<LineBreak> lineBreakPointer = lineBreakBufferGetDataPointer(lineBreakBuffer);
 
@@ -1035,9 +1065,8 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
     for (int i = 0; i < lineBreaks.length; i++) {
       final LineBreakFragment fragment = lineBreaks[i];
       lineBreakPointer[i + 1].position = fragment.end;
-      lineBreakPointer[i + 1].lineBreakType = fragment.type == LineBreakType.mandatory
-        ? _kHardLineBreak
-        : _kSoftLineBreak;
+      lineBreakPointer[i + 1].lineBreakType =
+          fragment.type == LineBreakType.mandatory ? _kHardLineBreak : _kSoftLineBreak;
     }
     paragraphBuilderSetLineBreaksUtf16(handle, lineBreakBuffer);
     lineBreakBufferFree(lineBreakBuffer);
@@ -1062,9 +1091,8 @@ class SkwasmParagraphBuilder extends SkwasmObjectWrapper<RawParagraphBuilder> im
   @override
   void pushStyle(ui.TextStyle textStyle) {
     textStyle as SkwasmTextStyle;
-    final SkwasmNativeTextStyle baseStyle = textStyleStack.isNotEmpty
-      ? textStyleStack.last
-      : style.textStyle;
+    final SkwasmNativeTextStyle baseStyle =
+        textStyleStack.isNotEmpty ? textStyleStack.last : style.textStyle;
     final SkwasmNativeTextStyle nativeStyle = baseStyle.copy();
     textStyle.applyToNative(nativeStyle);
     textStyleStack.add(nativeStyle);
