@@ -11,8 +11,7 @@ import 'dart:collection';
 import 'dart:convert' hide Codec;
 import 'dart:developer' as developer;
 import 'dart:js_util' as js_util;
-import 'dart:_js_annotations';
-import 'dart:js_interop' hide JS;
+import 'dart:js_interop';
 import 'dart:js_interop_unsafe';
 import 'dart:math' as math;
 import 'dart:typed_data';
