@@ -90,7 +90,7 @@ class Size extends OffsetBase {
   const Size(super.width, super.height);
   // Used by the rendering library's _DebugSize hack.
   Size.copy(Size source) : super(source.width, source.height);
-  const Size.square(double dimension) : super(dimension, dimension); // ignore: use_super_parameters
+  const Size.square(double dimension) : super(dimension, dimension);
   const Size.fromWidth(double width) : super(width, double.infinity);
   const Size.fromHeight(double height) : super(double.infinity, height);
   const Size.fromRadius(double radius) : super(radius * 2.0, radius * 2.0);
@@ -405,7 +405,337 @@ class Radius {
   }
 }
 
-class RRect {
+abstract class _RRectLike<T extends _RRectLike<T>> {
+  const _RRectLike({
+    required this.left,
+    required this.top,
+    required this.right,
+    required this.bottom,
+    required this.tlRadiusX,
+    required this.tlRadiusY,
+    required this.trRadiusX,
+    required this.trRadiusY,
+    required this.brRadiusX,
+    required this.brRadiusY,
+    required this.blRadiusX,
+    required this.blRadiusY,
+    required bool uniformRadii,
+  }) : assert(tlRadiusX >= 0),
+       assert(tlRadiusY >= 0),
+       assert(trRadiusX >= 0),
+       assert(trRadiusY >= 0),
+       assert(brRadiusX >= 0),
+       assert(brRadiusY >= 0),
+       assert(blRadiusX >= 0),
+       assert(blRadiusY >= 0),
+       webOnlyUniformRadii = uniformRadii;
+
+  T _create({
+    required double left,
+    required double top,
+    required double right,
+    required double bottom,
+    required double tlRadiusX,
+    required double tlRadiusY,
+    required double trRadiusX,
+    required double trRadiusY,
+    required double brRadiusX,
+    required double brRadiusY,
+    required double blRadiusX,
+    required double blRadiusY,
+  });
+
+  final double left;
+  final double top;
+  final double right;
+  final double bottom;
+  final double tlRadiusX;
+  final double tlRadiusY;
+  Radius get tlRadius => Radius.elliptical(tlRadiusX, tlRadiusY);
+  final double trRadiusX;
+  final double trRadiusY;
+  Radius get trRadius => Radius.elliptical(trRadiusX, trRadiusY);
+  final double brRadiusX;
+  final double brRadiusY;
+  Radius get brRadius => Radius.elliptical(brRadiusX, brRadiusY);
+  final double blRadiusX;
+  final double blRadiusY;
+  // webOnly
+  final bool webOnlyUniformRadii;
+  Radius get blRadius => Radius.elliptical(blRadiusX, blRadiusY);
+
+  T shift(Offset offset) {
+    return _create(
+      left: left + offset.dx,
+      top: top + offset.dy,
+      right: right + offset.dx,
+      bottom: bottom + offset.dy,
+      tlRadiusX: tlRadiusX,
+      tlRadiusY: tlRadiusY,
+      trRadiusX: trRadiusX,
+      trRadiusY: trRadiusY,
+      blRadiusX: blRadiusX,
+      blRadiusY: blRadiusY,
+      brRadiusX: brRadiusX,
+      brRadiusY: brRadiusY,
+    );
+  }
+
+  T inflate(double delta) {
+    return _create(
+      left: left - delta,
+      top: top - delta,
+      right: right + delta,
+      bottom: bottom + delta,
+      tlRadiusX: math.max(0, tlRadiusX + delta),
+      tlRadiusY: math.max(0, tlRadiusY + delta),
+      trRadiusX: math.max(0, trRadiusX + delta),
+      trRadiusY: math.max(0, trRadiusY + delta),
+      blRadiusX: math.max(0, blRadiusX + delta),
+      blRadiusY: math.max(0, blRadiusY + delta),
+      brRadiusX: math.max(0, brRadiusX + delta),
+      brRadiusY: math.max(0, brRadiusY + delta),
+    );
+  }
+
+  T deflate(double delta) => inflate(-delta);
+  double get width => right - left;
+  double get height => bottom - top;
+  Rect get outerRect => Rect.fromLTRB(left, top, right, bottom);
+  Rect get safeInnerRect {
+    const double kInsetFactor = 0.29289321881; // 1-cos(pi/4)
+
+    final double leftRadius = math.max(blRadiusX, tlRadiusX);
+    final double topRadius = math.max(tlRadiusY, trRadiusY);
+    final double rightRadius = math.max(trRadiusX, brRadiusX);
+    final double bottomRadius = math.max(brRadiusY, blRadiusY);
+
+    return Rect.fromLTRB(
+      left + leftRadius * kInsetFactor,
+      top + topRadius * kInsetFactor,
+      right - rightRadius * kInsetFactor,
+      bottom - bottomRadius * kInsetFactor,
+    );
+  }
+
+  Rect get middleRect {
+    final double leftRadius = math.max(blRadiusX, tlRadiusX);
+    final double topRadius = math.max(tlRadiusY, trRadiusY);
+    final double rightRadius = math.max(trRadiusX, brRadiusX);
+    final double bottomRadius = math.max(brRadiusY, blRadiusY);
+    return Rect.fromLTRB(
+      left + leftRadius,
+      top + topRadius,
+      right - rightRadius,
+      bottom - bottomRadius,
+    );
+  }
+
+  Rect get wideMiddleRect {
+    final double topRadius = math.max(tlRadiusY, trRadiusY);
+    final double bottomRadius = math.max(brRadiusY, blRadiusY);
+    return Rect.fromLTRB(left, top + topRadius, right, bottom - bottomRadius);
+  }
+
+  Rect get tallMiddleRect {
+    final double leftRadius = math.max(blRadiusX, tlRadiusX);
+    final double rightRadius = math.max(trRadiusX, brRadiusX);
+    return Rect.fromLTRB(left + leftRadius, top, right - rightRadius, bottom);
+  }
+
+  bool get isEmpty => left >= right || top >= bottom;
+  bool get isFinite => left.isFinite && top.isFinite && right.isFinite && bottom.isFinite;
+  bool get isRect {
+    return (tlRadiusX == 0.0 || tlRadiusY == 0.0) &&
+        (trRadiusX == 0.0 || trRadiusY == 0.0) &&
+        (blRadiusX == 0.0 || blRadiusY == 0.0) &&
+        (brRadiusX == 0.0 || brRadiusY == 0.0);
+  }
+
+  bool get isStadium {
+    return tlRadius == trRadius &&
+        trRadius == brRadius &&
+        brRadius == blRadius &&
+        (width <= 2.0 * tlRadiusX || height <= 2.0 * tlRadiusY);
+  }
+
+  bool get isEllipse {
+    return tlRadius == trRadius &&
+        trRadius == brRadius &&
+        brRadius == blRadius &&
+        width <= 2.0 * tlRadiusX &&
+        height <= 2.0 * tlRadiusY;
+  }
+
+  bool get isCircle => width == height && isEllipse;
+  double get shortestSide => math.min(width.abs(), height.abs());
+  double get longestSide => math.max(width.abs(), height.abs());
+  bool get hasNaN =>
+      left.isNaN ||
+      top.isNaN ||
+      right.isNaN ||
+      bottom.isNaN ||
+      trRadiusX.isNaN ||
+      trRadiusY.isNaN ||
+      tlRadiusX.isNaN ||
+      tlRadiusY.isNaN ||
+      brRadiusX.isNaN ||
+      brRadiusY.isNaN ||
+      blRadiusX.isNaN ||
+      blRadiusY.isNaN;
+  Offset get center => Offset(left + width / 2.0, top + height / 2.0);
+
+  // Returns the minimum between min and scale to which radius1 and radius2
+  // should be scaled with in order not to exceed the limit.
+  double _getMin(double min, double radius1, double radius2, double limit) {
+    final double sum = radius1 + radius2;
+    if (sum > limit && sum != 0.0) {
+      return math.min(min, limit / sum);
+    }
+    return min;
+  }
+
+  T scaleRadii() {
+    double scale = 1.0;
+    final double absWidth = width.abs();
+    final double absHeight = height.abs();
+    scale = _getMin(scale, blRadiusY, tlRadiusY, absHeight);
+    scale = _getMin(scale, tlRadiusX, trRadiusX, absWidth);
+    scale = _getMin(scale, trRadiusY, brRadiusY, absHeight);
+    scale = _getMin(scale, brRadiusX, blRadiusX, absWidth);
+
+    if (scale < 1.0) {
+      return _create(
+        top: top,
+        left: left,
+        right: right,
+        bottom: bottom,
+        tlRadiusX: tlRadiusX * scale,
+        tlRadiusY: tlRadiusY * scale,
+        trRadiusX: trRadiusX * scale,
+        trRadiusY: trRadiusY * scale,
+        blRadiusX: blRadiusX * scale,
+        blRadiusY: blRadiusY * scale,
+        brRadiusX: brRadiusX * scale,
+        brRadiusY: brRadiusY * scale,
+      );
+    }
+
+    return _create(
+      top: top,
+      left: left,
+      right: right,
+      bottom: bottom,
+      tlRadiusX: tlRadiusX,
+      tlRadiusY: tlRadiusY,
+      trRadiusX: trRadiusX,
+      trRadiusY: trRadiusY,
+      blRadiusX: blRadiusX,
+      blRadiusY: blRadiusY,
+      brRadiusX: brRadiusX,
+      brRadiusY: brRadiusY,
+    );
+  }
+
+  // Linearly interpolate between this object and another of the same shape.
+  T _lerpTo(T? b, double t) {
+    assert(runtimeType == T);
+    if (b == null) {
+      final double k = 1.0 - t;
+      return _create(
+        left: left * k,
+        top: top * k,
+        right: right * k,
+        bottom: bottom * k,
+        tlRadiusX: math.max(0, tlRadiusX * k),
+        tlRadiusY: math.max(0, tlRadiusY * k),
+        trRadiusX: math.max(0, trRadiusX * k),
+        trRadiusY: math.max(0, trRadiusY * k),
+        brRadiusX: math.max(0, brRadiusX * k),
+        brRadiusY: math.max(0, brRadiusY * k),
+        blRadiusX: math.max(0, blRadiusX * k),
+        blRadiusY: math.max(0, blRadiusY * k),
+      );
+    } else {
+      return _create(
+        left: _lerpDouble(left, b.left, t),
+        top: _lerpDouble(top, b.top, t),
+        right: _lerpDouble(right, b.right, t),
+        bottom: _lerpDouble(bottom, b.bottom, t),
+        tlRadiusX: math.max(0, _lerpDouble(tlRadiusX, b.tlRadiusX, t)),
+        tlRadiusY: math.max(0, _lerpDouble(tlRadiusY, b.tlRadiusY, t)),
+        trRadiusX: math.max(0, _lerpDouble(trRadiusX, b.trRadiusX, t)),
+        trRadiusY: math.max(0, _lerpDouble(trRadiusY, b.trRadiusY, t)),
+        brRadiusX: math.max(0, _lerpDouble(brRadiusX, b.brRadiusX, t)),
+        brRadiusY: math.max(0, _lerpDouble(brRadiusY, b.brRadiusY, t)),
+        blRadiusX: math.max(0, _lerpDouble(blRadiusX, b.blRadiusX, t)),
+        blRadiusY: math.max(0, _lerpDouble(blRadiusY, b.blRadiusY, t)),
+      );
+    }
+  }
+
+  @override
+  bool operator ==(Object other) {
+    if (identical(this, other)) {
+      return true;
+    }
+    if (runtimeType != other.runtimeType) {
+      return false;
+    }
+    return other is _RRectLike &&
+        other.left == left &&
+        other.top == top &&
+        other.right == right &&
+        other.bottom == bottom &&
+        other.tlRadiusX == tlRadiusX &&
+        other.tlRadiusY == tlRadiusY &&
+        other.trRadiusX == trRadiusX &&
+        other.trRadiusY == trRadiusY &&
+        other.blRadiusX == blRadiusX &&
+        other.blRadiusY == blRadiusY &&
+        other.brRadiusX == brRadiusX &&
+        other.brRadiusY == brRadiusY;
+  }
+
+  @override
+  int get hashCode => Object.hash(
+    left,
+    top,
+    right,
+    bottom,
+    tlRadiusX,
+    tlRadiusY,
+    trRadiusX,
+    trRadiusY,
+    blRadiusX,
+    blRadiusY,
+    brRadiusX,
+    brRadiusY,
+  );
+
+  String _toString({required String className}) {
+    final String rect =
+        '${left.toStringAsFixed(1)}, '
+        '${top.toStringAsFixed(1)}, '
+        '${right.toStringAsFixed(1)}, '
+        '${bottom.toStringAsFixed(1)}';
+    if (tlRadius == trRadius && trRadius == brRadius && brRadius == blRadius) {
+      if (tlRadius.x == tlRadius.y) {
+        return '$className.fromLTRBR($rect, ${tlRadius.x.toStringAsFixed(1)})';
+      }
+      return '$className.fromLTRBXY($rect, ${tlRadius.x.toStringAsFixed(1)}, ${tlRadius.y.toStringAsFixed(1)})';
+    }
+    return '$className.fromLTRBAndCorners('
+        '$rect, '
+        'topLeft: $tlRadius, '
+        'topRight: $trRadius, '
+        'bottomRight: $brRadius, '
+        'bottomLeft: $blRadius'
+        ')';
+  }
+}
+
+class RRect extends _RRectLike<RRect> {
   const RRect.fromLTRBXY(
     double left,
     double top,
@@ -542,222 +872,52 @@ class RRect {
        );
 
   const RRect._raw({
-    this.left = 0.0,
-    this.top = 0.0,
-    this.right = 0.0,
-    this.bottom = 0.0,
-    this.tlRadiusX = 0.0,
-    this.tlRadiusY = 0.0,
-    this.trRadiusX = 0.0,
-    this.trRadiusY = 0.0,
-    this.brRadiusX = 0.0,
-    this.brRadiusY = 0.0,
-    this.blRadiusX = 0.0,
-    this.blRadiusY = 0.0,
-    bool uniformRadii = false,
-  }) : assert(tlRadiusX >= 0),
-       assert(tlRadiusY >= 0),
-       assert(trRadiusX >= 0),
-       assert(trRadiusY >= 0),
-       assert(brRadiusX >= 0),
-       assert(brRadiusY >= 0),
-       assert(blRadiusX >= 0),
-       assert(blRadiusY >= 0),
-       webOnlyUniformRadii = uniformRadii;
+    super.left = 0.0,
+    super.top = 0.0,
+    super.right = 0.0,
+    super.bottom = 0.0,
+    super.tlRadiusX = 0.0,
+    super.tlRadiusY = 0.0,
+    super.trRadiusX = 0.0,
+    super.trRadiusY = 0.0,
+    super.brRadiusX = 0.0,
+    super.brRadiusY = 0.0,
+    super.blRadiusX = 0.0,
+    super.blRadiusY = 0.0,
+    super.uniformRadii = false,
+  });
+
+  @override
+  RRect _create({
+    required double left,
+    required double top,
+    required double right,
+    required double bottom,
+    required double tlRadiusX,
+    required double tlRadiusY,
+    required double trRadiusX,
+    required double trRadiusY,
+    required double brRadiusX,
+    required double brRadiusY,
+    required double blRadiusX,
+    required double blRadiusY,
+  }) => RRect._raw(
+    top: top,
+    left: left,
+    right: right,
+    bottom: bottom,
+    tlRadiusX: tlRadiusX,
+    tlRadiusY: tlRadiusY,
+    trRadiusX: trRadiusX,
+    trRadiusY: trRadiusY,
+    blRadiusX: blRadiusX,
+    blRadiusY: blRadiusY,
+    brRadiusX: brRadiusX,
+    brRadiusY: brRadiusY,
+  );
 
-  final double left;
-  final double top;
-  final double right;
-  final double bottom;
-  final double tlRadiusX;
-  final double tlRadiusY;
-  Radius get tlRadius => Radius.elliptical(tlRadiusX, tlRadiusY);
-  final double trRadiusX;
-  final double trRadiusY;
-  Radius get trRadius => Radius.elliptical(trRadiusX, trRadiusY);
-  final double brRadiusX;
-  final double brRadiusY;
-  Radius get brRadius => Radius.elliptical(brRadiusX, brRadiusY);
-  final double blRadiusX;
-  final double blRadiusY;
-  // webOnly
-  final bool webOnlyUniformRadii;
-  Radius get blRadius => Radius.elliptical(blRadiusX, blRadiusY);
   static const RRect zero = RRect._raw();
 
-  RRect shift(Offset offset) {
-    return RRect._raw(
-      left: left + offset.dx,
-      top: top + offset.dy,
-      right: right + offset.dx,
-      bottom: bottom + offset.dy,
-      tlRadiusX: tlRadiusX,
-      tlRadiusY: tlRadiusY,
-      trRadiusX: trRadiusX,
-      trRadiusY: trRadiusY,
-      blRadiusX: blRadiusX,
-      blRadiusY: blRadiusY,
-      brRadiusX: brRadiusX,
-      brRadiusY: brRadiusY,
-    );
-  }
-
-  RRect inflate(double delta) {
-    return RRect._raw(
-      left: left - delta,
-      top: top - delta,
-      right: right + delta,
-      bottom: bottom + delta,
-      tlRadiusX: math.max(0, tlRadiusX + delta),
-      tlRadiusY: math.max(0, tlRadiusY + delta),
-      trRadiusX: math.max(0, trRadiusX + delta),
-      trRadiusY: math.max(0, trRadiusY + delta),
-      blRadiusX: math.max(0, blRadiusX + delta),
-      blRadiusY: math.max(0, blRadiusY + delta),
-      brRadiusX: math.max(0, brRadiusX + delta),
-      brRadiusY: math.max(0, brRadiusY + delta),
-    );
-  }
-
-  RRect deflate(double delta) => inflate(-delta);
-  double get width => right - left;
-  double get height => bottom - top;
-  Rect get outerRect => Rect.fromLTRB(left, top, right, bottom);
-  Rect get safeInnerRect {
-    const double kInsetFactor = 0.29289321881; // 1-cos(pi/4)
-
-    final double leftRadius = math.max(blRadiusX, tlRadiusX);
-    final double topRadius = math.max(tlRadiusY, trRadiusY);
-    final double rightRadius = math.max(trRadiusX, brRadiusX);
-    final double bottomRadius = math.max(brRadiusY, blRadiusY);
-
-    return Rect.fromLTRB(
-      left + leftRadius * kInsetFactor,
-      top + topRadius * kInsetFactor,
-      right - rightRadius * kInsetFactor,
-      bottom - bottomRadius * kInsetFactor,
-    );
-  }
-
-  Rect get middleRect {
-    final double leftRadius = math.max(blRadiusX, tlRadiusX);
-    final double topRadius = math.max(tlRadiusY, trRadiusY);
-    final double rightRadius = math.max(trRadiusX, brRadiusX);
-    final double bottomRadius = math.max(brRadiusY, blRadiusY);
-    return Rect.fromLTRB(
-      left + leftRadius,
-      top + topRadius,
-      right - rightRadius,
-      bottom - bottomRadius,
-    );
-  }
-
-  Rect get wideMiddleRect {
-    final double topRadius = math.max(tlRadiusY, trRadiusY);
-    final double bottomRadius = math.max(brRadiusY, blRadiusY);
-    return Rect.fromLTRB(left, top + topRadius, right, bottom - bottomRadius);
-  }
-
-  Rect get tallMiddleRect {
-    final double leftRadius = math.max(blRadiusX, tlRadiusX);
-    final double rightRadius = math.max(trRadiusX, brRadiusX);
-    return Rect.fromLTRB(left + leftRadius, top, right - rightRadius, bottom);
-  }
-
-  bool get isEmpty => left >= right || top >= bottom;
-  bool get isFinite => left.isFinite && top.isFinite && right.isFinite && bottom.isFinite;
-  bool get isRect {
-    return (tlRadiusX == 0.0 || tlRadiusY == 0.0) &&
-        (trRadiusX == 0.0 || trRadiusY == 0.0) &&
-        (blRadiusX == 0.0 || blRadiusY == 0.0) &&
-        (brRadiusX == 0.0 || brRadiusY == 0.0);
-  }
-
-  bool get isStadium {
-    return tlRadius == trRadius &&
-        trRadius == brRadius &&
-        brRadius == blRadius &&
-        (width <= 2.0 * tlRadiusX || height <= 2.0 * tlRadiusY);
-  }
-
-  bool get isEllipse {
-    return tlRadius == trRadius &&
-        trRadius == brRadius &&
-        brRadius == blRadius &&
-        width <= 2.0 * tlRadiusX &&
-        height <= 2.0 * tlRadiusY;
-  }
-
-  bool get isCircle => width == height && isEllipse;
-  double get shortestSide => math.min(width.abs(), height.abs());
-  double get longestSide => math.max(width.abs(), height.abs());
-  bool get hasNaN =>
-      left.isNaN ||
-      top.isNaN ||
-      right.isNaN ||
-      bottom.isNaN ||
-      trRadiusX.isNaN ||
-      trRadiusY.isNaN ||
-      tlRadiusX.isNaN ||
-      tlRadiusY.isNaN ||
-      brRadiusX.isNaN ||
-      brRadiusY.isNaN ||
-      blRadiusX.isNaN ||
-      blRadiusY.isNaN;
-  Offset get center => Offset(left + width / 2.0, top + height / 2.0);
-
-  // Returns the minimum between min and scale to which radius1 and radius2
-  // should be scaled with in order not to exceed the limit.
-  double _getMin(double min, double radius1, double radius2, double limit) {
-    final double sum = radius1 + radius2;
-    if (sum > limit && sum != 0.0) {
-      return math.min(min, limit / sum);
-    }
-    return min;
-  }
-
-  RRect scaleRadii() {
-    double scale = 1.0;
-    final double absWidth = width.abs();
-    final double absHeight = height.abs();
-    scale = _getMin(scale, blRadiusY, tlRadiusY, absHeight);
-    scale = _getMin(scale, tlRadiusX, trRadiusX, absWidth);
-    scale = _getMin(scale, trRadiusY, brRadiusY, absHeight);
-    scale = _getMin(scale, brRadiusX, blRadiusX, absWidth);
-
-    if (scale < 1.0) {
-      return RRect._raw(
-        top: top,
-        left: left,
-        right: right,
-        bottom: bottom,
-        tlRadiusX: tlRadiusX * scale,
-        tlRadiusY: tlRadiusY * scale,
-        trRadiusX: trRadiusX * scale,
-        trRadiusY: trRadiusY * scale,
-        blRadiusX: blRadiusX * scale,
-        blRadiusY: blRadiusY * scale,
-        brRadiusX: brRadiusX * scale,
-        brRadiusY: brRadiusY * scale,
-      );
-    }
-
-    return RRect._raw(
-      top: top,
-      left: left,
-      right: right,
-      bottom: bottom,
-      tlRadiusX: tlRadiusX,
-      tlRadiusY: tlRadiusY,
-      trRadiusX: trRadiusX,
-      trRadiusY: trRadiusY,
-      blRadiusX: blRadiusX,
-      blRadiusY: blRadiusY,
-      brRadiusX: brRadiusX,
-      brRadiusY: brRadiusY,
-    );
-  }
-
   bool contains(Offset point) {
     if (point.dx < left || point.dx >= right || point.dy < top || point.dy >= bottom) {
       return false;
@@ -805,120 +965,251 @@ class RRect {
   }
 
   static RRect? lerp(RRect? a, RRect? b, double t) {
-    if (b == null) {
-      if (a == null) {
+    if (a == null) {
+      if (b == null) {
         return null;
-      } else {
-        final double k = 1.0 - t;
-        return RRect._raw(
-          left: a.left * k,
-          top: a.top * k,
-          right: a.right * k,
-          bottom: a.bottom * k,
-          tlRadiusX: math.max(0, a.tlRadiusX * k),
-          tlRadiusY: math.max(0, a.tlRadiusY * k),
-          trRadiusX: math.max(0, a.trRadiusX * k),
-          trRadiusY: math.max(0, a.trRadiusY * k),
-          brRadiusX: math.max(0, a.brRadiusX * k),
-          brRadiusY: math.max(0, a.brRadiusY * k),
-          blRadiusX: math.max(0, a.blRadiusX * k),
-          blRadiusY: math.max(0, a.blRadiusY * k),
-        );
-      }
-    } else {
-      if (a == null) {
-        return RRect._raw(
-          left: b.left * t,
-          top: b.top * t,
-          right: b.right * t,
-          bottom: b.bottom * t,
-          tlRadiusX: math.max(0, b.tlRadiusX * t),
-          tlRadiusY: math.max(0, b.tlRadiusY * t),
-          trRadiusX: math.max(0, b.trRadiusX * t),
-          trRadiusY: math.max(0, b.trRadiusY * t),
-          brRadiusX: math.max(0, b.brRadiusX * t),
-          brRadiusY: math.max(0, b.brRadiusY * t),
-          blRadiusX: math.max(0, b.blRadiusX * t),
-          blRadiusY: math.max(0, b.blRadiusY * t),
-        );
-      } else {
-        return RRect._raw(
-          left: _lerpDouble(a.left, b.left, t),
-          top: _lerpDouble(a.top, b.top, t),
-          right: _lerpDouble(a.right, b.right, t),
-          bottom: _lerpDouble(a.bottom, b.bottom, t),
-          tlRadiusX: math.max(0, _lerpDouble(a.tlRadiusX, b.tlRadiusX, t)),
-          tlRadiusY: math.max(0, _lerpDouble(a.tlRadiusY, b.tlRadiusY, t)),
-          trRadiusX: math.max(0, _lerpDouble(a.trRadiusX, b.trRadiusX, t)),
-          trRadiusY: math.max(0, _lerpDouble(a.trRadiusY, b.trRadiusY, t)),
-          brRadiusX: math.max(0, _lerpDouble(a.brRadiusX, b.brRadiusX, t)),
-          brRadiusY: math.max(0, _lerpDouble(a.brRadiusY, b.brRadiusY, t)),
-          blRadiusX: math.max(0, _lerpDouble(a.blRadiusX, b.blRadiusX, t)),
-          blRadiusY: math.max(0, _lerpDouble(a.blRadiusY, b.blRadiusY, t)),
-        );
       }
+      return b._lerpTo(null, 1 - t);
     }
+    return a._lerpTo(b, t);
   }
 
-  @override
-  bool operator ==(Object other) {
-    if (identical(this, other)) {
-      return true;
-    }
-    if (runtimeType != other.runtimeType) {
-      return false;
-    }
-    return other is RRect &&
-        other.left == left &&
-        other.top == top &&
-        other.right == right &&
-        other.bottom == bottom &&
-        other.tlRadiusX == tlRadiusX &&
-        other.tlRadiusY == tlRadiusY &&
-        other.trRadiusX == trRadiusX &&
-        other.trRadiusY == trRadiusY &&
-        other.blRadiusX == blRadiusX &&
-        other.blRadiusY == blRadiusY &&
-        other.brRadiusX == brRadiusX &&
-        other.brRadiusY == brRadiusY;
-  }
-
-  @override
-  int get hashCode => Object.hash(
-    left,
-    top,
-    right,
-    bottom,
-    tlRadiusX,
-    tlRadiusY,
-    trRadiusX,
-    trRadiusY,
-    blRadiusX,
-    blRadiusY,
-    brRadiusX,
-    brRadiusY,
-  );
-
   @override
   String toString() {
-    final String rect =
-        '${left.toStringAsFixed(1)}, '
-        '${top.toStringAsFixed(1)}, '
-        '${right.toStringAsFixed(1)}, '
-        '${bottom.toStringAsFixed(1)}';
-    if (tlRadius == trRadius && trRadius == brRadius && brRadius == blRadius) {
-      if (tlRadius.x == tlRadius.y) {
-        return 'RRect.fromLTRBR($rect, ${tlRadius.x.toStringAsFixed(1)})';
+    return _toString(className: 'RRect');
+  }
+}
+
+class RSuperellipse extends _RRectLike<RSuperellipse> {
+  const RSuperellipse.fromLTRBXY(
+    double left,
+    double top,
+    double right,
+    double bottom,
+    double radiusX,
+    double radiusY,
+  ) : this._raw(
+        top: top,
+        left: left,
+        right: right,
+        bottom: bottom,
+        tlRadiusX: radiusX,
+        tlRadiusY: radiusY,
+        trRadiusX: radiusX,
+        trRadiusY: radiusY,
+        blRadiusX: radiusX,
+        blRadiusY: radiusY,
+        brRadiusX: radiusX,
+        brRadiusY: radiusY,
+        uniformRadii: radiusX == radiusY,
+      );
+
+  RSuperellipse.fromLTRBR(double left, double top, double right, double bottom, Radius radius)
+    : this._raw(
+        top: top,
+        left: left,
+        right: right,
+        bottom: bottom,
+        tlRadiusX: radius.x,
+        tlRadiusY: radius.y,
+        trRadiusX: radius.x,
+        trRadiusY: radius.y,
+        blRadiusX: radius.x,
+        blRadiusY: radius.y,
+        brRadiusX: radius.x,
+        brRadiusY: radius.y,
+        uniformRadii: radius.x == radius.y,
+      );
+
+  RSuperellipse.fromRectXY(Rect rect, double radiusX, double radiusY)
+    : this._raw(
+        top: rect.top,
+        left: rect.left,
+        right: rect.right,
+        bottom: rect.bottom,
+        tlRadiusX: radiusX,
+        tlRadiusY: radiusY,
+        trRadiusX: radiusX,
+        trRadiusY: radiusY,
+        blRadiusX: radiusX,
+        blRadiusY: radiusY,
+        brRadiusX: radiusX,
+        brRadiusY: radiusY,
+        uniformRadii: radiusX == radiusY,
+      );
+
+  RSuperellipse.fromRectAndRadius(Rect rect, Radius radius)
+    : this._raw(
+        top: rect.top,
+        left: rect.left,
+        right: rect.right,
+        bottom: rect.bottom,
+        tlRadiusX: radius.x,
+        tlRadiusY: radius.y,
+        trRadiusX: radius.x,
+        trRadiusY: radius.y,
+        blRadiusX: radius.x,
+        blRadiusY: radius.y,
+        brRadiusX: radius.x,
+        brRadiusY: radius.y,
+        uniformRadii: radius.x == radius.y,
+      );
+
+  RSuperellipse.fromLTRBAndCorners(
+    double left,
+    double top,
+    double right,
+    double bottom, {
+    Radius topLeft = Radius.zero,
+    Radius topRight = Radius.zero,
+    Radius bottomRight = Radius.zero,
+    Radius bottomLeft = Radius.zero,
+  }) : this._raw(
+         top: top,
+         left: left,
+         right: right,
+         bottom: bottom,
+         tlRadiusX: topLeft.x,
+         tlRadiusY: topLeft.y,
+         trRadiusX: topRight.x,
+         trRadiusY: topRight.y,
+         blRadiusX: bottomLeft.x,
+         blRadiusY: bottomLeft.y,
+         brRadiusX: bottomRight.x,
+         brRadiusY: bottomRight.y,
+         uniformRadii:
+             topLeft.x == topLeft.y &&
+             topLeft.x == topRight.x &&
+             topLeft.x == topRight.y &&
+             topLeft.x == bottomLeft.x &&
+             topLeft.x == bottomLeft.y &&
+             topLeft.x == bottomRight.x &&
+             topLeft.x == bottomRight.y,
+       );
+
+  RSuperellipse.fromRectAndCorners(
+    Rect rect, {
+    Radius topLeft = Radius.zero,
+    Radius topRight = Radius.zero,
+    Radius bottomRight = Radius.zero,
+    Radius bottomLeft = Radius.zero,
+  }) : this._raw(
+         top: rect.top,
+         left: rect.left,
+         right: rect.right,
+         bottom: rect.bottom,
+         tlRadiusX: topLeft.x,
+         tlRadiusY: topLeft.y,
+         trRadiusX: topRight.x,
+         trRadiusY: topRight.y,
+         blRadiusX: bottomLeft.x,
+         blRadiusY: bottomLeft.y,
+         brRadiusX: bottomRight.x,
+         brRadiusY: bottomRight.y,
+         uniformRadii:
+             topLeft.x == topLeft.y &&
+             topLeft.x == topRight.x &&
+             topLeft.x == topRight.y &&
+             topLeft.x == bottomLeft.x &&
+             topLeft.x == bottomLeft.y &&
+             topLeft.x == bottomRight.x &&
+             topLeft.x == bottomRight.y,
+       );
+
+  const RSuperellipse._raw({
+    super.left = 0.0,
+    super.top = 0.0,
+    super.right = 0.0,
+    super.bottom = 0.0,
+    super.tlRadiusX = 0.0,
+    super.tlRadiusY = 0.0,
+    super.trRadiusX = 0.0,
+    super.trRadiusY = 0.0,
+    super.brRadiusX = 0.0,
+    super.brRadiusY = 0.0,
+    super.blRadiusX = 0.0,
+    super.blRadiusY = 0.0,
+    super.uniformRadii = false,
+  });
+
+  @override
+  RSuperellipse _create({
+    required double left,
+    required double top,
+    required double right,
+    required double bottom,
+    required double tlRadiusX,
+    required double tlRadiusY,
+    required double trRadiusX,
+    required double trRadiusY,
+    required double brRadiusX,
+    required double brRadiusY,
+    required double blRadiusX,
+    required double blRadiusY,
+  }) => RSuperellipse._raw(
+    top: top,
+    left: left,
+    right: right,
+    bottom: bottom,
+    tlRadiusX: tlRadiusX,
+    tlRadiusY: tlRadiusY,
+    trRadiusX: trRadiusX,
+    trRadiusY: trRadiusY,
+    blRadiusX: blRadiusX,
+    blRadiusY: blRadiusY,
+    brRadiusX: brRadiusX,
+    brRadiusY: brRadiusY,
+  );
+
+  // Approximates a rounded superellipse with a round rectangle to the
+  // best practical accuracy.
+  //
+  // This workaround is needed until the rounded superellipse is implemented on
+  // Web. https://github.com/flutter/flutter/issues/163718
+  RRect toApproximateRRect() {
+    // Experiments have shown that using the same corner radii for the RRect
+    // provides an approximation that is close to optimal, as achieving a perfect
+    // match is not feasible.
+    return RRect._raw(
+      top: top,
+      left: left,
+      right: right,
+      bottom: bottom,
+      tlRadiusX: tlRadiusX,
+      tlRadiusY: tlRadiusY,
+      trRadiusX: trRadiusX,
+      trRadiusY: trRadiusY,
+      blRadiusX: blRadiusX,
+      blRadiusY: blRadiusY,
+      brRadiusX: brRadiusX,
+      brRadiusY: brRadiusY,
+    );
+  }
+
+  static const RSuperellipse zero = RSuperellipse._raw();
+
+  bool contains(Offset point) {
+    // Web doesn't support RSuperellipse, but falls back to RRect in all use
+    // cases. Therefore this `contains` is implemented as RRect. Once Web
+    // supports RSuperellipse this method should be changed to the correct shape.
+    // TODO(dkwingsmt): Properly implement the shape on Web instead of
+    // falling back to RRect.  https://github.com/flutter/flutter/issues/163718
+    return toApproximateRRect().contains(point);
+  }
+
+  static RSuperellipse? lerp(RSuperellipse? a, RSuperellipse? b, double t) {
+    if (a == null) {
+      if (b == null) {
+        return null;
       }
-      return 'RRect.fromLTRBXY($rect, ${tlRadius.x.toStringAsFixed(1)}, ${tlRadius.y.toStringAsFixed(1)})';
+      return b._lerpTo(null, 1 - t);
     }
-    return 'RRect.fromLTRBAndCorners('
-        '$rect, '
-        'topLeft: $tlRadius, '
-        'topRight: $trRadius, '
-        'bottomRight: $brRadius, '
-        'bottomLeft: $blRadius'
-        ')';
+    return a._lerpTo(b, t);
+  }
+
+  @override
+  String toString() {
+    return _toString(className: 'RSuperellipse');
   }
 }
 // Modeled after Skia's SkRSXform.
