@@ -5,18 +5,6 @@
 // For documentation see https://github.com/flutter/engine/blob/main/lib/ui/painting.dart
 part of dart.ui;
 
-// ignore: unused_element, Used in Shader assert.
-bool _offsetIsValid(Offset offset) {
-  assert(!offset.dx.isNaN && !offset.dy.isNaN, 'Offset argument contained a NaN value.');
-  return true;
-}
-
-// ignore: unused_element, Used in Shader assert.
-bool _matrix4IsValid(Float32List matrix4) {
-  assert(matrix4.length == 16, 'Matrix4 must have 16 entries.');
-  return true;
-}
-
 void _validateColorStops(List<Color> colors, List<double>? colorStops) {
   if (colorStops == null) {
     if (colors.length != 2) {
@@ -29,30 +17,97 @@ void _validateColorStops(List<Color> colors, List<double>? colorStops) {
   }
 }
 
-Color _scaleAlpha(Color a, double factor) {
-  return a.withAlpha(engine.clampInt((a.alpha * factor).round(), 0, 255));
+Color _scaleAlpha(Color x, double factor) {
+  return x.withValues(alpha: (x.a * factor).clamp(0, 1));
 }
 
 class Color {
-  const Color(int value) : value = value & 0xFFFFFFFF;
-  const Color.fromARGB(int a, int r, int g, int b)
-      : value = (((a & 0xff) << 24) |
-                ((r & 0xff) << 16) |
-                ((g & 0xff) << 8) |
-                ((b & 0xff) << 0)) &
-            0xFFFFFFFF;
+  const Color(int value)
+    : this._fromARGBC(value >> 24, value >> 16, value >> 8, value, ColorSpace.sRGB);
+
+  const Color.from({
+    required double alpha,
+    required double red,
+    required double green,
+    required double blue,
+    this.colorSpace = ColorSpace.sRGB,
+  }) : a = alpha,
+       r = red,
+       g = green,
+       b = blue;
+
+  const Color.fromARGB(int a, int r, int g, int b) : this._fromARGBC(a, r, g, b, ColorSpace.sRGB);
+
+  const Color._fromARGBC(int alpha, int red, int green, int blue, ColorSpace colorSpace)
+    : this._fromRGBOC(red, green, blue, (alpha & 0xff) / 255, colorSpace);
+
   const Color.fromRGBO(int r, int g, int b, double opacity)
-      : value = ((((opacity * 0xff ~/ 1) & 0xff) << 24) |
-                ((r & 0xff) << 16) |
-                ((g & 0xff) << 8) |
-                ((b & 0xff) << 0)) &
-            0xFFFFFFFF;
-  final int value;
+    : this._fromRGBOC(r, g, b, opacity, ColorSpace.sRGB);
+
+  const Color._fromRGBOC(int r, int g, int b, double opacity, this.colorSpace)
+    : a = opacity,
+      r = (r & 0xff) / 255,
+      g = (g & 0xff) / 255,
+      b = (b & 0xff) / 255;
+
+  final double a;
+
+  final double r;
+
+  final double g;
+
+  final double b;
+
+  final ColorSpace colorSpace;
+
+  static int _floatToInt8(double x) {
+    return (x * 255.0).round() & 0xff;
+  }
+
+  int get value => toARGB32();
+
+  int toARGB32() {
+    return _floatToInt8(a) << 24 |
+        _floatToInt8(r) << 16 |
+        _floatToInt8(g) << 8 |
+        _floatToInt8(b) << 0;
+  }
+
   int get alpha => (0xff000000 & value) >> 24;
+
   double get opacity => alpha / 0xFF;
+
   int get red => (0x00ff0000 & value) >> 16;
+
   int get green => (0x0000ff00 & value) >> 8;
+
   int get blue => (0x000000ff & value) >> 0;
+
+  Color withValues({
+    double? alpha,
+    double? red,
+    double? green,
+    double? blue,
+    ColorSpace? colorSpace,
+  }) {
+    Color? updatedComponents;
+    if (alpha != null || red != null || green != null || blue != null) {
+      updatedComponents = Color.from(
+        alpha: alpha ?? a,
+        red: red ?? r,
+        green: green ?? g,
+        blue: blue ?? b,
+        colorSpace: this.colorSpace,
+      );
+    }
+    if (colorSpace != null && colorSpace != this.colorSpace) {
+      final _ColorTransform transform = _getColorTransform(this.colorSpace, colorSpace);
+      return transform.transform(updatedComponents ?? this, colorSpace);
+    } else {
+      return updatedComponents ?? this;
+    }
+  }
+
   Color withAlpha(int a) {
     return Color.fromARGB(a, red, green, blue);
   }
@@ -84,59 +139,67 @@ class Color {
 
   double computeLuminance() {
     // See <https://www.w3.org/TR/WCAG20/#relativeluminancedef>
-    final double R = _linearizeColorComponent(red / 0xFF);
-    final double G = _linearizeColorComponent(green / 0xFF);
-    final double B = _linearizeColorComponent(blue / 0xFF);
+    final double R = _linearizeColorComponent(r);
+    final double G = _linearizeColorComponent(g);
+    final double B = _linearizeColorComponent(b);
     return 0.2126 * R + 0.7152 * G + 0.0722 * B;
   }
 
-  static Color? lerp(Color? a, Color? b, double t) {
-    if (b == null) {
-      if (a == null) {
+  static Color? lerp(Color? x, Color? y, double t) {
+    assert(x?.colorSpace != ColorSpace.extendedSRGB);
+    assert(y?.colorSpace != ColorSpace.extendedSRGB);
+    if (y == null) {
+      if (x == null) {
         return null;
       } else {
-        return _scaleAlpha(a, 1.0 - t);
+        return _scaleAlpha(x, 1.0 - t);
       }
     } else {
-      if (a == null) {
-        return _scaleAlpha(b, t);
+      if (x == null) {
+        return _scaleAlpha(y, t);
       } else {
-        return Color.fromARGB(
-          engine.clampInt(_lerpInt(a.alpha, b.alpha, t).toInt(), 0, 255),
-          engine.clampInt(_lerpInt(a.red, b.red, t).toInt(), 0, 255),
-          engine.clampInt(_lerpInt(a.green, b.green, t).toInt(), 0, 255),
-          engine.clampInt(_lerpInt(a.blue, b.blue, t).toInt(), 0, 255),
+        assert(x.colorSpace == y.colorSpace);
+        return Color.from(
+          alpha: _lerpDouble(x.a, y.a, t).clamp(0, 1),
+          red: _lerpDouble(x.r, y.r, t).clamp(0, 1),
+          green: _lerpDouble(x.g, y.g, t).clamp(0, 1),
+          blue: _lerpDouble(x.b, y.b, t).clamp(0, 1),
+          colorSpace: x.colorSpace,
         );
       }
     }
   }
 
   static Color alphaBlend(Color foreground, Color background) {
-    final int alpha = foreground.alpha;
-    if (alpha == 0x00) {
+    assert(foreground.colorSpace == background.colorSpace);
+    assert(foreground.colorSpace != ColorSpace.extendedSRGB);
+    final double alpha = foreground.a;
+    if (alpha == 0) {
       // Foreground completely transparent.
       return background;
     }
-    final int invAlpha = 0xff - alpha;
-    int backAlpha = background.alpha;
-    if (backAlpha == 0xff) {
+    final double invAlpha = 1 - alpha;
+    double backAlpha = background.a;
+    if (backAlpha == 1) {
       // Opaque background case
-      return Color.fromARGB(
-        0xff,
-        (alpha * foreground.red + invAlpha * background.red) ~/ 0xff,
-        (alpha * foreground.green + invAlpha * background.green) ~/ 0xff,
-        (alpha * foreground.blue + invAlpha * background.blue) ~/ 0xff,
+      return Color.from(
+        alpha: 1,
+        red: alpha * foreground.r + invAlpha * background.r,
+        green: alpha * foreground.g + invAlpha * background.g,
+        blue: alpha * foreground.b + invAlpha * background.b,
+        colorSpace: foreground.colorSpace,
       );
     } else {
       // General case
-      backAlpha = (backAlpha * invAlpha) ~/ 0xff;
-      final int outAlpha = alpha + backAlpha;
-      assert(outAlpha != 0x00);
-      return Color.fromARGB(
-        outAlpha,
-        (foreground.red * alpha + background.red * backAlpha) ~/ outAlpha,
-        (foreground.green * alpha + background.green * backAlpha) ~/ outAlpha,
-        (foreground.blue * alpha + background.blue * backAlpha) ~/ outAlpha,
+      backAlpha = backAlpha * invAlpha;
+      final double outAlpha = alpha + backAlpha;
+      assert(outAlpha != 0);
+      return Color.from(
+        alpha: outAlpha,
+        red: (foreground.r * alpha + background.r * backAlpha) / outAlpha,
+        green: (foreground.g * alpha + background.g * backAlpha) / outAlpha,
+        blue: (foreground.b * alpha + background.b * backAlpha) / outAlpha,
+        colorSpace: foreground.colorSpace,
       );
     }
   }
@@ -153,35 +216,28 @@ class Color {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is Color && other.value == value;
+    return other is Color &&
+        other.a == a &&
+        other.r == r &&
+        other.g == g &&
+        other.b == b &&
+        other.colorSpace == colorSpace;
   }
 
   @override
-  int get hashCode => value.hashCode;
+  int get hashCode => Object.hash(a, r, g, b, colorSpace);
 
   @override
-  String toString() {
-    return 'Color(0x${value.toRadixString(16).padLeft(8, '0')})';
-  }
+  String toString() =>
+      'Color(alpha: ${a.toStringAsFixed(4)}, red: ${r.toStringAsFixed(4)}, green: ${g.toStringAsFixed(4)}, blue: ${b.toStringAsFixed(4)}, colorSpace: $colorSpace)';
 }
 
-enum StrokeCap {
-  butt,
-  round,
-  square,
-}
+enum StrokeCap { butt, round, square }
 
 // These enum values must be kept in sync with SkPaint::Join.
-enum StrokeJoin {
-  miter,
-  round,
-  bevel,
-}
+enum StrokeJoin { miter, round, bevel }
 
-enum PaintingStyle {
-  fill,
-  stroke,
-}
+enum PaintingStyle { fill, stroke }
 
 enum BlendMode {
   // This list comes from Skia's SkXfermode.h and the values (order) should be
@@ -220,16 +276,31 @@ enum BlendMode {
   luminosity,
 }
 
-enum Clip {
-  none,
-  hardEdge,
-  antiAlias,
-  antiAliasWithSaveLayer,
-}
+enum Clip { none, hardEdge, antiAlias, antiAliasWithSaveLayer }
 
 abstract class Paint {
   factory Paint() => engine.renderer.createPaint();
-  static bool enableDithering = false;
+
+  factory Paint.from(Paint other) {
+    final Paint paint = Paint();
+    paint
+      ..blendMode = other.blendMode
+      ..color = other.color
+      ..colorFilter = other.colorFilter
+      ..filterQuality = other.filterQuality
+      ..imageFilter = other.imageFilter
+      ..invertColors = other.invertColors
+      ..isAntiAlias = other.isAntiAlias
+      ..maskFilter = other.maskFilter
+      ..shader = other.shader
+      ..strokeCap = other.strokeCap
+      ..strokeJoin = other.strokeJoin
+      ..strokeMiterLimit = other.strokeMiterLimit
+      ..strokeWidth = other.strokeWidth
+      ..style = other.style;
+    return paint;
+  }
+
   BlendMode get blendMode;
   set blendMode(BlendMode value);
   PaintingStyle get style;
@@ -282,13 +353,7 @@ abstract class Gradient implements Shader {
     Float64List? matrix4,
   ]) {
     final Float32List? matrix = matrix4 == null ? null : engine.toMatrix32(matrix4);
-    return engine.renderer.createLinearGradient(
-      from,
-      to,
-      colors,
-      colorStops,
-      tileMode,
-      matrix);
+    return engine.renderer.createLinearGradient(from, to, colors, colorStops, tileMode, matrix);
   }
 
   factory Gradient.radial(
@@ -307,12 +372,27 @@ abstract class Gradient implements Shader {
     final Float32List? matrix32 = matrix4 != null ? engine.toMatrix32(matrix4) : null;
     if (focal == null || (focal == center && focalRadius == 0.0)) {
       return engine.renderer.createRadialGradient(
-        center, radius, colors, colorStops, tileMode, matrix32);
+        center,
+        radius,
+        colors,
+        colorStops,
+        tileMode,
+        matrix32,
+      );
     } else {
-      assert(center != Offset.zero ||
-          focal != Offset.zero); // will result in exception(s) in Skia side
+      assert(
+        center != Offset.zero || focal != Offset.zero,
+      ); // will result in exception(s) in Skia side
       return engine.renderer.createConicalGradient(
-        focal, focalRadius, center, radius, colors, colorStops, tileMode, matrix32);
+        focal,
+        focalRadius,
+        center,
+        radius,
+        colors,
+        colorStops,
+        tileMode,
+        matrix32,
+      );
     }
   }
   factory Gradient.sweep(
@@ -330,7 +410,8 @@ abstract class Gradient implements Shader {
     tileMode,
     startAngle,
     endAngle,
-    matrix4 != null ? engine.toMatrix32(matrix4) : null);
+    matrix4 != null ? engine.toMatrix32(matrix4) : null,
+  );
 }
 
 typedef ImageEventCallback = void Function(Image image);
@@ -374,10 +455,7 @@ enum BlurStyle {
 }
 
 class MaskFilter {
-  const MaskFilter.blur(
-    this._style,
-    this._sigma,
-  );
+  const MaskFilter.blur(this._style, this._sigma);
 
   final BlurStyle _style;
   final double _sigma;
@@ -386,9 +464,7 @@ class MaskFilter {
 
   @override
   bool operator ==(Object other) {
-    return other is MaskFilter
-        && other._style == _style
-        && other._sigma == _sigma;
+    return other is MaskFilter && other._style == _style && other._sigma == _sigma;
   }
 
   @override
@@ -398,32 +474,111 @@ class MaskFilter {
   String toString() => 'MaskFilter.blur($_style, ${_sigma.toStringAsFixed(1)})';
 }
 
-// This needs to be kept in sync with the "_FilterQuality" enum in skwasm's canvas.cpp
-enum FilterQuality {
-  none,
-  low,
-  medium,
-  high,
+abstract class _ColorTransform {
+  Color transform(Color color, ColorSpace resultColorSpace);
 }
 
+class _IdentityColorTransform implements _ColorTransform {
+  const _IdentityColorTransform();
+  @override
+  Color transform(Color color, ColorSpace resultColorSpace) => color;
+}
+
+class _ClampTransform implements _ColorTransform {
+  const _ClampTransform(this.child);
+  final _ColorTransform child;
+  @override
+  Color transform(Color color, ColorSpace resultColorSpace) {
+    return Color.from(
+      alpha: clampDouble(color.a, 0, 1),
+      red: clampDouble(color.r, 0, 1),
+      green: clampDouble(color.g, 0, 1),
+      blue: clampDouble(color.b, 0, 1),
+      colorSpace: resultColorSpace,
+    );
+  }
+}
+
+class _MatrixColorTransform implements _ColorTransform {
+  const _MatrixColorTransform(this.values);
+
+  final List<double> values;
+
+  @override
+  Color transform(Color color, ColorSpace resultColorSpace) {
+    return Color.from(
+      alpha: color.a,
+      red: values[0] * color.r + values[1] * color.g + values[2] * color.b + values[3],
+      green: values[4] * color.r + values[5] * color.g + values[6] * color.b + values[7],
+      blue: values[8] * color.r + values[9] * color.g + values[10] * color.b + values[11],
+      colorSpace: resultColorSpace,
+    );
+  }
+}
+
+_ColorTransform _getColorTransform(ColorSpace source, ColorSpace destination) {
+  const _MatrixColorTransform srgbToP3 = _MatrixColorTransform(<double>[
+    0.808052267214446, 0.220292047628890, -0.139648846160100,
+    0.145738111193222, //
+    0.096480880462996, 0.916386732581291, -0.086093928394828,
+    0.089490172325882, //
+    -0.127099563510240, -0.068983484963878, 0.735426667591299, 0.233655661600230,
+  ]);
+  const _ColorTransform p3ToSrgb = _MatrixColorTransform(<double>[
+    1.306671048092539, -0.298061942172353, 0.213228303487995,
+    -0.213580156254466, //
+    -0.117390025596251, 1.127722006101976, 0.109727644608938,
+    -0.109450321455370, //
+    0.214813187718391, 0.054268702864647, 1.406898424029350, -0.364892765879631,
+  ]);
+  switch (source) {
+    case ColorSpace.sRGB:
+      switch (destination) {
+        case ColorSpace.sRGB:
+          return const _IdentityColorTransform();
+        case ColorSpace.extendedSRGB:
+          return const _IdentityColorTransform();
+        case ColorSpace.displayP3:
+          return srgbToP3;
+      }
+    case ColorSpace.extendedSRGB:
+      switch (destination) {
+        case ColorSpace.sRGB:
+          return const _ClampTransform(_IdentityColorTransform());
+        case ColorSpace.extendedSRGB:
+          return const _IdentityColorTransform();
+        case ColorSpace.displayP3:
+          return const _ClampTransform(srgbToP3);
+      }
+    case ColorSpace.displayP3:
+      switch (destination) {
+        case ColorSpace.sRGB:
+          return const _ClampTransform(p3ToSrgb);
+        case ColorSpace.extendedSRGB:
+          return p3ToSrgb;
+        case ColorSpace.displayP3:
+          return const _IdentityColorTransform();
+      }
+  }
+}
+
+// This needs to be kept in sync with the "_FilterQuality" enum in skwasm's canvas.cpp
+enum FilterQuality { none, low, medium, high }
+
 class ImageFilter {
-  factory ImageFilter.blur({
-    double sigmaX = 0.0,
-    double sigmaY = 0.0,
-    TileMode tileMode = TileMode.clamp
-  }) => engine.renderer.createBlurImageFilter(
-    sigmaX: sigmaX,
-    sigmaY: sigmaY,
-    tileMode: tileMode
-  );
+  factory ImageFilter.blur({double sigmaX = 0.0, double sigmaY = 0.0, TileMode? tileMode}) =>
+      engine.renderer.createBlurImageFilter(sigmaX: sigmaX, sigmaY: sigmaY, tileMode: tileMode);
 
-  factory ImageFilter.dilate({ double radiusX = 0.0, double radiusY = 0.0 }) =>
-    engine.renderer.createDilateImageFilter(radiusX: radiusX, radiusY: radiusY);
+  factory ImageFilter.dilate({double radiusX = 0.0, double radiusY = 0.0}) =>
+      engine.renderer.createDilateImageFilter(radiusX: radiusX, radiusY: radiusY);
 
-  factory ImageFilter.erode({ double radiusX = 0.0, double radiusY = 0.0 }) =>
-    engine.renderer.createErodeImageFilter(radiusX: radiusX, radiusY: radiusY);
+  factory ImageFilter.erode({double radiusX = 0.0, double radiusY = 0.0}) =>
+      engine.renderer.createErodeImageFilter(radiusX: radiusX, radiusY: radiusY);
 
-  factory ImageFilter.matrix(Float64List matrix4, {FilterQuality filterQuality = FilterQuality.low}) {
+  factory ImageFilter.matrix(
+    Float64List matrix4, {
+    FilterQuality filterQuality = FilterQuality.medium,
+  }) {
     if (matrix4.length != 16) {
       throw ArgumentError('"matrix4" must have 16 entries.');
     }
@@ -431,28 +586,23 @@ class ImageFilter {
   }
 
   factory ImageFilter.compose({required ImageFilter outer, required ImageFilter inner}) =>
-    engine.renderer.composeImageFilters(outer: outer, inner: inner);
+      engine.renderer.composeImageFilters(outer: outer, inner: inner);
+
+  // ignore: avoid_unused_constructor_parameters
+  factory ImageFilter.shader(FragmentShader shader) {
+    throw UnsupportedError('ImageFilter.shader only supported with Impeller rendering engine.');
+  }
+
+  static bool get isShaderFilterSupported => false;
 }
 
-enum ColorSpace {
-  sRGB,
-  extendedSRGB,
-}
+enum ColorSpace { sRGB, extendedSRGB, displayP3 }
 
 // This must be kept in sync with the `ImageByteFormat` enum in Skwasm's surface.cpp.
-enum ImageByteFormat {
-  rawRgba,
-  rawStraightRgba,
-  rawUnmodified,
-  png,
-}
+enum ImageByteFormat { rawRgba, rawStraightRgba, rawUnmodified, png }
 
 // This must be kept in sync with the `PixelFormat` enum in Skwasm's image.cpp.
-enum PixelFormat {
-  rgba8888,
-  bgra8888,
-  rgbaFloat32,
-}
+enum PixelFormat { rgba8888, bgra8888, rgbaFloat32 }
 
 typedef ImageDecoderCallback = void Function(Image result);
 
@@ -484,7 +634,8 @@ Future<Codec> instantiateImageCodec(
   list,
   targetWidth: targetWidth,
   targetHeight: targetHeight,
-  allowUpscaling: allowUpscaling);
+  allowUpscaling: allowUpscaling,
+);
 
 Future<Codec> instantiateImageCodecFromBuffer(
   ImmutableBuffer buffer, {
@@ -495,7 +646,8 @@ Future<Codec> instantiateImageCodecFromBuffer(
   buffer._list!,
   targetWidth: targetWidth,
   targetHeight: targetHeight,
-  allowUpscaling: allowUpscaling);
+  allowUpscaling: allowUpscaling,
+);
 
 Future<Codec> instantiateImageCodecWithSize(
   ImmutableBuffer buffer, {
@@ -511,8 +663,12 @@ Future<Codec> instantiateImageCodecWithSize(
         final int width = info.image.width;
         final int height = info.image.height;
         final TargetImageSize targetSize = getTargetSize(width, height);
-        return engine.renderer.instantiateImageCodec(buffer._list!,
-            targetWidth: targetSize.width, targetHeight: targetSize.height, allowUpscaling: false);
+        return engine.renderer.instantiateImageCodec(
+          buffer._list!,
+          targetWidth: targetSize.width,
+          targetHeight: targetSize.height,
+          allowUpscaling: false,
+        );
       } finally {
         info.image.dispose();
       }
@@ -526,24 +682,25 @@ typedef TargetImageSizeCallback = TargetImageSize Function(int intrinsicWidth, i
 
 class TargetImageSize {
   const TargetImageSize({this.width, this.height})
-      : assert(width == null || width > 0),
-        assert(height == null || height > 0);
+    : assert(width == null || width > 0),
+      assert(height == null || height > 0);
 
   final int? width;
   final int? height;
 }
 
-Future<Codec> webOnlyInstantiateImageCodecFromUrl(Uri uri,
-  {engine.WebOnlyImageCodecChunkCallback? chunkCallback}) =>
-  engine.renderer.instantiateImageCodecFromUrl(uri, chunkCallback: chunkCallback);
-
 void decodeImageFromList(Uint8List list, ImageDecoderCallback callback) {
   _decodeImageFromListAsync(list, callback);
 }
 
 Future<void> _decodeImageFromListAsync(Uint8List list, ImageDecoderCallback callback) async {
   final Codec codec = await instantiateImageCodec(list);
-  final FrameInfo frameInfo = await codec.getNextFrame();
+  final FrameInfo frameInfo;
+  try {
+    frameInfo = await codec.getNextFrame();
+  } finally {
+    codec.dispose();
+  }
   callback(frameInfo.image);
 }
 
@@ -552,22 +709,13 @@ Future<void> _decodeImageFromListAsync(Uint8List list, ImageDecoderCallback call
 // The `pixels` should be the scanlined raw pixels, 4 bytes per pixel, from left
 // to right, then from top to down. The order of the 4 bytes of pixels is
 // decided by `format`.
-Future<Codec> createBmp(
-  Uint8List pixels,
-  int width,
-  int height,
-  int rowBytes,
-  PixelFormat format,
-) {
-  late bool swapRedBlue;
-  switch (format) {
-    case PixelFormat.bgra8888:
-      swapRedBlue = true;
-    case PixelFormat.rgba8888:
-      swapRedBlue = false;
-    case PixelFormat.rgbaFloat32:
-      throw UnimplementedError('RGB conversion from rgbaFloat32 data is not implemented');
-  }
+Future<Codec> createBmp(Uint8List pixels, int width, int height, int rowBytes, PixelFormat format) {
+  final bool swapRedBlue = switch (format) {
+    PixelFormat.bgra8888 => true,
+    PixelFormat.rgba8888 => false,
+    PixelFormat.rgbaFloat32 =>
+      throw UnimplementedError('RGB conversion from rgbaFloat32 data is not implemented'),
+  };
 
   // See https://en.wikipedia.org/wiki/BMP_file_format for format examples.
   // The header is in the 108-byte BITMAPV4HEADER format, or as called by
@@ -626,9 +774,7 @@ Future<Codec> createBmp(
     }
   }
 
-  return instantiateImageCodec(
-    bmpData.buffer.asUint8List(),
-  );
+  return instantiateImageCodec(bmpData.buffer.asUint8List());
 }
 
 void decodeImageFromPixels(
@@ -650,14 +796,15 @@ void decodeImageFromPixels(
   rowBytes: rowBytes,
   targetWidth: targetWidth,
   targetHeight: targetHeight,
-  allowUpscaling: allowUpscaling);
+  allowUpscaling: allowUpscaling,
+);
 
 class Shadow {
   const Shadow({
     this.color = const Color(_kColorDefault),
     this.offset = Offset.zero,
     this.blurRadius = 0.0,
-  })  : assert(blurRadius >= 0.0, 'Text shadow blur radius should be non-negative.');
+  }) : assert(blurRadius >= 0.0, 'Text shadow blur radius should be non-negative.');
 
   static const int _kColorDefault = 0xFF000000;
   final Color color;
@@ -677,11 +824,7 @@ class Shadow {
   }
 
   Shadow scale(double factor) {
-    return Shadow(
-      color: color,
-      offset: offset * factor,
-      blurRadius: blurRadius * factor,
-    );
+    return Shadow(color: color, offset: offset * factor, blurRadius: blurRadius * factor);
   }
 
   static Shadow? lerp(Shadow? a, Shadow? b, double t) {
@@ -749,13 +892,7 @@ abstract class ImageShader implements Shader {
     TileMode tmy,
     Float64List matrix4, {
     FilterQuality? filterQuality,
-  }) => engine.renderer.createImageShader(
-    image,
-    tmx,
-    tmy,
-    matrix4,
-    filterQuality
-  );
+  }) => engine.renderer.createImageShader(image, tmx, tmy, matrix4, filterQuality);
 
   @override
   void dispose();
@@ -793,6 +930,7 @@ class ImmutableBuffer {
     }());
     return disposed;
   }
+
   void dispose() => _list = null;
 }
 
@@ -804,18 +942,14 @@ class ImageDescriptor {
     required int height,
     int? rowBytes,
     required PixelFormat pixelFormat,
-  })   : _width = width,
-        _height = height,
-        _rowBytes = rowBytes,
-        _format = pixelFormat {
+  }) : _width = width,
+       _height = height,
+       _rowBytes = rowBytes,
+       _format = pixelFormat {
     _data = buffer._list;
   }
 
-  ImageDescriptor._()
-      : _width = null,
-        _height = null,
-        _rowBytes = null,
-        _format = null;
+  ImageDescriptor._() : _width = null, _height = null, _rowBytes = null, _format = null;
 
   static Future<ImageDescriptor> encoded(ImmutableBuffer buffer) async {
     final ImageDescriptor descriptor = ImageDescriptor._();
