@@ -14,15 +14,12 @@ import 'dart:math' as math;
 import 'dart:typed_data';
 
 import 'dart:_engine' as engine;
-import 'dart:ui_web' as ui_web;
 
 part 'annotations.dart';
 part 'canvas.dart';
 part 'channel_buffers.dart';
 part 'compositing.dart';
 part 'geometry.dart';
-part 'hash_codes.dart';
-part 'initialization.dart';
 part 'key.dart';
 part 'lerp.dart';
 part 'math.dart';
@@ -31,6 +28,7 @@ part 'painting.dart';
 part 'path.dart';
 part 'path_metrics.dart';
 part 'platform_dispatcher.dart';
+part 'platform_isolate.dart';
 part 'pointer.dart';
 part 'semantics.dart';
 part 'text.dart';
