@@ -10,6 +10,7 @@ import 'dart:_internal'
         Since,
         valueOfNonNullableParamWithDefault,
         HttpStatus;
+import 'dart:async' as dart_async show runZoned;
 import 'dart:async';
 import 'dart:collection'
     show
@@ -186,9 +187,13 @@ abstract class HttpServer implements Stream<HttpRequest> {
   /// isolates are bound to the port, then the incoming connections will be
   /// distributed among all the bound `HttpServer`s. Connections can be
   /// distributed over multiple isolates this way.
-  static Future<HttpServer> bind(address, int port,
-          {int backlog = 0, bool v6Only = false, bool shared = false}) =>
-      _HttpServer.bind(address, port, backlog, v6Only, shared);
+  static Future<HttpServer> bind(
+    address,
+    int port, {
+    int backlog = 0,
+    bool v6Only = false,
+    bool shared = false,
+  }) => _HttpServer.bind(address, port, backlog, v6Only, shared);
 
   /// The [address] can either be a [String] or an
   /// [InternetAddress]. If [address] is a [String], [bind] will
@@ -229,13 +234,22 @@ abstract class HttpServer implements Stream<HttpRequest> {
   /// distributed over multiple isolates this way.
 
   static Future<HttpServer> bindSecure(
-          address, int port, SecurityContext context,
-          {int backlog = 0,
-          bool v6Only = false,
-          bool requestClientCertificate = false,
-          bool shared = false}) =>
-      _HttpServer.bindSecure(address, port, context, backlog, v6Only,
-          requestClientCertificate, shared);
+    address,
+    int port,
+    SecurityContext context, {
+    int backlog = 0,
+    bool v6Only = false,
+    bool requestClientCertificate = false,
+    bool shared = false,
+  }) => _HttpServer.bindSecure(
+    address,
+    port,
+    context,
+    backlog,
+    v6Only,
+    requestClientCertificate,
+    shared,
+  );
 
   /// Attaches the HTTP server to an existing [ServerSocket]. When the
   /// [HttpServer] is closed, the [HttpServer] will just detach itself,
@@ -388,6 +402,7 @@ abstract interface class HttpHeaders {
   static const viaHeader = "via";
   static const warningHeader = "warning";
   static const wwwAuthenticateHeader = "www-authenticate";
+  static const contentDisposition = "content-disposition";
 
   // Cookie headers from RFC 6265.
   static const cookieHeader = "cookie";
@@ -403,7 +418,7 @@ abstract interface class HttpHeaders {
     transferEncodingHeader,
     upgradeHeader,
     viaHeader,
-    warningHeader
+    warningHeader,
   ];
 
   static const entityHeaders = [
@@ -416,7 +431,7 @@ abstract interface class HttpHeaders {
     contentRangeHeader,
     contentTypeHeader,
     expiresHeader,
-    lastModifiedHeader
+    lastModifiedHeader,
   ];
 
   static const responseHeaders = [
@@ -428,7 +443,8 @@ abstract interface class HttpHeaders {
     retryAfterHeader,
     serverHeader,
     varyHeader,
-    wwwAuthenticateHeader
+    wwwAuthenticateHeader,
+    contentDisposition,
   ];
 
   static const requestHeaders = [
@@ -450,7 +466,7 @@ abstract interface class HttpHeaders {
     rangeHeader,
     refererHeader,
     teHeader,
-    userAgentHeader
+    userAgentHeader,
   ];
 
   /// The date specified by the [dateHeader] header, if any.
@@ -516,15 +532,13 @@ abstract interface class HttpHeaders {
   ///
   /// The current case of the a header name is that of the name used by
   /// the last [set] or [add] call for that header.
-  void add(String name, Object value,
-      {@Since("2.8") bool preserveHeaderCase = false});
+  void add(String name, Object value, {bool preserveHeaderCase = false});
 
   /// Sets the header [name] to [value].
   ///
   /// Removes all existing values for the header named [name] and
   /// then [add]s [value] to it.
-  void set(String name, Object value,
-      {@Since("2.8") bool preserveHeaderCase = false});
+  void set(String name, Object value, {bool preserveHeaderCase = false});
 
   /// Removes a specific value for a header name.
   ///
@@ -605,21 +619,27 @@ abstract interface class HttpHeaders {
 /// An instance of [HeaderValue] is immutable.
 abstract interface class HeaderValue {
   /// Creates a new header value object setting the value and parameters.
-  factory HeaderValue(
-      [String value = "", Map<String, String?> parameters = const {}]) {
+  factory HeaderValue([
+    String value = "",
+    Map<String, String?> parameters = const {},
+  ]) {
     return _HeaderValue(value, parameters);
   }
 
   /// Creates a new header value object from parsing a header value
   /// string with both value and optional parameters.
-  static HeaderValue parse(String value,
-      {String parameterSeparator = ";",
-      String? valueSeparator,
-      bool preserveBackslash = false}) {
-    return _HeaderValue.parse(value,
-        parameterSeparator: parameterSeparator,
-        valueSeparator: valueSeparator,
-        preserveBackslash: preserveBackslash);
+  static HeaderValue parse(
+    String value, {
+    String parameterSeparator = ";",
+    String? valueSeparator,
+    bool preserveBackslash = false,
+  }) {
+    return _HeaderValue.parse(
+      value,
+      parameterSeparator: parameterSeparator,
+      valueSeparator: valueSeparator,
+      preserveBackslash: preserveBackslash,
+    );
   }
 
   /// The value of the header.
@@ -638,6 +658,33 @@ abstract interface class HeaderValue {
 }
 
 /// The [session][HttpRequest.session] of an [HttpRequest].
+///
+/// Stores arbitrary information about a browser session on the server. This
+/// information is stored in memory so it will be lost when the server exits.
+///
+/// A cookie named "DARTSESSID" is stored on the browser to associate the
+/// `HttpSession` with a particular client.
+///
+/// ```dart
+/// import 'dart:io';
+///
+/// void main() async {
+///   HttpServer.bind("localhost", 8080).then((server) {
+///     server.listen((request) {
+///       final session = request.session;
+///       if (session.isNew) {
+///         session["cart"] = [];
+///       }
+///       if (request.uri.queryParameters['buy'] != null) {
+///         final item = request.uri.queryParameters['buy'];
+///         session["cart"].add(item);
+///       }
+///       session["cart"].cast<String>().forEach(request.response.writeln);
+///       request.response.close();
+///     });
+///   });
+/// }
+/// ```
 abstract interface class HttpSession implements Map {
   /// The id of the current session.
   String get id;
@@ -689,8 +736,12 @@ abstract interface class ContentType implements HeaderValue {
   /// override the value in parameters. Keys passed in parameters will be
   /// converted to lower case. The `charset` entry, whether passed as `charset`
   /// or in `parameters`, will have its value converted to lower-case.
-  factory ContentType(String primaryType, String subType,
-      {String? charset, Map<String, String?> parameters = const {}}) {
+  factory ContentType(
+    String primaryType,
+    String subType, {
+    String? charset,
+    Map<String, String?> parameters = const {},
+  }) {
     return _ContentType(primaryType, subType, charset, parameters);
   }
 
@@ -981,6 +1032,10 @@ abstract interface class HttpRequest implements Stream<Uint8List> {
 /// first time, the request header is sent. Calling any methods that
 /// change the header after it is sent throws an exception.
 ///
+/// If no "Content-Type" header is set then a default of
+/// "text/plain; charset=utf-8" is used and string data written to the IOSink
+/// will be encoded using UTF-8.
+///
 /// ## Setting the headers
 ///
 /// The HttpResponse object has a number of properties for setting up
@@ -1001,8 +1056,9 @@ abstract interface class HttpRequest implements Stream<Uint8List> {
 ///     response.headers.add(HttpHeaders.contentTypeHeader, "text/plain");
 ///     response.write(...);  // Strings written will be ISO-8859-1 encoded.
 ///
-/// An exception is thrown if you use the `write()` method
-/// while an unsupported content-type is set.
+/// If a charset is provided but it is not recognized, then the "Content-Type"
+/// header will include that charset but string data will be encoded using
+/// ISO-8859-1 (Latin 1).
 abstract interface class HttpResponse implements IOSink {
   // TODO(ajohnsen): Add documentation of how to pipe a file to the response.
   /// Gets and sets the content length of the response. If the size of
@@ -1080,7 +1136,7 @@ abstract interface class HttpResponse implements IOSink {
   /// socket is detached the HTTP server will no longer perform any
   /// operations on it.
   ///
-  /// This is normally used when a HTTP upgrade request is received
+  /// This is normally used when an HTTP upgrade request is received
   /// and the communication should continue with a different protocol.
   ///
   /// If [writeHeaders] is `true`, the status line and [headers] will be written
@@ -1095,14 +1151,24 @@ abstract interface class HttpResponse implements IOSink {
 
 /// An HTTP client for communicating with an HTTP server.
 ///
+/// > **Note:** You should avoid directly using `HttpClient` to make HTTP
+/// > requests. You can use `HttpClient` indirectly through the
+/// > [`IOClient`](https://pub.dev/documentation/http/latest/io_client/IOClient-class.html)
+/// > adapter in [`package:http`](https://pub.dev/packages/http).
+/// >
+/// > Using a higher-level library,
+/// > like [`package:http`](https://pub.dev/packages/http), allows you to
+/// > switch implementations with minimal changes to your code. For example,
+/// > `package:http`
+/// > [`Client`](https://pub.dev/documentation/http/latest/http/Client-class.html)
+/// > has implementations for the browser and implementations that use
+/// > platform native HTTP clients on Android and iOS. Unlike `HttpClient`,
+/// > these native implementations work with the proxies, VPNs, etc.
+///
 /// Sends HTTP requests to an HTTP server and receives responses.
 /// Maintains state, including session cookies and other cookies,
 /// between multiple requests to the same server.
 ///
-/// Note: [HttpClient] provides low-level HTTP functionality.
-/// We recommend users start with more developer-friendly and composable APIs
-/// found in [`package:http`](https://pub.dev/packages/http).
-///
 /// HttpClient contains a number of methods to send an [HttpClientRequest]
 /// to an Http server and receive an [HttpClientResponse] back.
 /// For example, you can use the [get], [getUrl], [post], and [postUrl] methods
@@ -1285,7 +1351,7 @@ abstract interface class HttpClient {
     return overrides.createHttpClient(context);
   }
 
-  /// Opens a HTTP connection.
+  /// Opens an HTTP connection.
   ///
   /// The HTTP method to use is specified in [method], the server is
   /// specified using [host] and [port], and the path (including
@@ -1301,9 +1367,13 @@ abstract interface class HttpClient {
   /// HTTP transaction, and the objects returned by the futures, see
   /// the overall documentation for the class [HttpClient].
   Future<HttpClientRequest> open(
-      String method, String host, int port, String path);
+    String method,
+    String host,
+    int port,
+    String path,
+  );
 
-  /// Opens a HTTP connection.
+  /// Opens an HTTP connection.
   ///
   /// The HTTP method is specified in [method] and the URL to use in
   /// [url].
@@ -1318,7 +1388,7 @@ abstract interface class HttpClient {
   /// the overall documentation for the class [HttpClient].
   Future<HttpClientRequest> openUrl(String method, Uri url);
 
-  /// Opens a HTTP connection using the GET method.
+  /// Opens an HTTP connection using the GET method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using
@@ -1327,14 +1397,14 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> get(String host, int port, String path);
 
-  /// Opens a HTTP connection using the GET method.
+  /// Opens an HTTP connection using the GET method.
   ///
   /// The URL to use is specified in [url].
   ///
   /// See [openUrl] for details.
   Future<HttpClientRequest> getUrl(Uri url);
 
-  /// Opens a HTTP connection using the POST method.
+  /// Opens an HTTP connection using the POST method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using
@@ -1343,14 +1413,14 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> post(String host, int port, String path);
 
-  /// Opens a HTTP connection using the POST method.
+  /// Opens an HTTP connection using the POST method.
   ///
   /// The URL to use is specified in [url].
   ///
   /// See [openUrl] for details.
   Future<HttpClientRequest> postUrl(Uri url);
 
-  /// Opens a HTTP connection using the PUT method.
+  /// Opens an HTTP connection using the PUT method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using [path].
@@ -1358,14 +1428,14 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> put(String host, int port, String path);
 
-  /// Opens a HTTP connection using the PUT method.
+  /// Opens an HTTP connection using the PUT method.
   ///
   /// The URL to use is specified in [url].
   ///
   /// See [openUrl] for details.
   Future<HttpClientRequest> putUrl(Uri url);
 
-  /// Opens a HTTP connection using the DELETE method.
+  /// Opens an HTTP connection using the DELETE method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using [path].
@@ -1373,14 +1443,14 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> delete(String host, int port, String path);
 
-  /// Opens a HTTP connection using the DELETE method.
+  /// Opens an HTTP connection using the DELETE method.
   ///
   /// The URL to use is specified in [url].
   ///
   /// See [openUrl] for details.
   Future<HttpClientRequest> deleteUrl(Uri url);
 
-  /// Opens a HTTP connection using the PATCH method.
+  /// Opens an HTTP connection using the PATCH method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using [path].
@@ -1388,14 +1458,14 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> patch(String host, int port, String path);
 
-  /// Opens a HTTP connection using the PATCH method.
+  /// Opens an HTTP connection using the PATCH method.
   ///
   /// The URL to use is specified in [url].
   ///
   /// See [openUrl] for details.
   Future<HttpClientRequest> patchUrl(Uri url);
 
-  /// Opens a HTTP connection using the HEAD method.
+  /// Opens an HTTP connection using the HEAD method.
   ///
   /// The server is specified using [host] and [port], and the path
   /// (including a possible query) is specified using [path].
@@ -1403,7 +1473,7 @@ abstract interface class HttpClient {
   /// See [open] for details.
   Future<HttpClientRequest> head(String host, int port, String path);
 
-  /// Opens a HTTP connection using the HEAD method.
+  /// Opens an HTTP connection using the HEAD method.
   ///
   /// The URL to use is specified in [url].
   ///
@@ -1414,8 +1484,8 @@ abstract interface class HttpClient {
   /// authentication.
   ///
   /// The URL requested, the authentication scheme and the security realm
-  /// from the server are passed in the arguments [f.url], [f.scheme] and
-  /// [f.realm].
+  /// from the server are passed in the arguments `f.url`, `f.scheme` and
+  /// `f.realm`.
   ///
   /// The function returns a [Future] which should complete when the
   /// authentication has been resolved. If credentials cannot be
@@ -1435,7 +1505,8 @@ abstract interface class HttpClient {
   /// of a failed request, or issues due to missing request payload on retried
   /// request.
   void set authenticate(
-      Future<bool> Function(Uri url, String scheme, String? realm)? f);
+    Future<bool> Function(Uri url, String scheme, String? realm)? f,
+  );
 
   /// Add credentials to be used for authorizing HTTP requests.
   void addCredentials(Uri url, String realm, HttpClientCredentials credentials);
@@ -1443,12 +1514,12 @@ abstract interface class HttpClient {
   /// Sets the function used to create socket connections.
   ///
   /// The URL requested (e.g. through [getUrl]) and proxy configuration
-  /// ([f.proxyHost] and [f.proxyPort]) are passed as arguments. [f.proxyHost]
-  /// and [f.proxyPort] will be `null` if the connection is not made through
+  /// (`f.proxyHost` and `f.proxyPort`) are passed as arguments. `f.proxyHost`
+  /// and `f.proxyPort` will be `null` if the connection is not made through
   /// a proxy.
   ///
   /// Since connections may be reused based on host and port, it is important
-  /// that the function not ignore [f.proxyHost] and [f.proxyPort] if they are
+  /// that the function not ignore `f.proxyHost` and `f.proxyPort` if they are
   /// not `null`. If proxies are not meaningful for the returned [Socket], you
   /// can set [findProxy] to use a direct connection.
   ///
@@ -1476,12 +1547,16 @@ abstract interface class HttpClient {
   /// }
   /// ```
   void set connectionFactory(
-      Future<ConnectionTask<Socket>> Function(
-              Uri url, String? proxyHost, int? proxyPort)?
-          f);
+    Future<ConnectionTask<Socket>> Function(
+      Uri url,
+      String? proxyHost,
+      int? proxyPort,
+    )?
+    f,
+  );
 
   /// Sets the function used to resolve the proxy server to be used for
-  /// opening a HTTP connection to the specified [url]. If this
+  /// opening an HTTP connection to the specified `url`. If this
   /// function is not set, direct connections will always be used.
   ///
   /// The string returned by [f] must be in the format used by browser
@@ -1505,7 +1580,7 @@ abstract interface class HttpClient {
   /// variables.
   void set findProxy(String Function(Uri url)? f);
 
-  /// Function for resolving the proxy server to be used for a HTTP
+  /// Function for resolving the proxy server to be used for an HTTP
   /// connection from the proxy configuration specified through
   /// environment variables.
   ///
@@ -1554,8 +1629,10 @@ abstract interface class HttpClient {
   /// [:username:password@hostname:port:] to include the username and
   /// password. Alternatively the API [addProxyCredentials] can be used
   /// to set credentials for proxies which require authentication.
-  static String findProxyFromEnvironment(Uri url,
-      {Map<String, String>? environment}) {
+  static String findProxyFromEnvironment(
+    Uri url, {
+    Map<String, String>? environment,
+  }) {
     HttpOverrides? overrides = HttpOverrides.current;
     if (overrides == null) {
       return _HttpClient._findProxyFromEnvironment(url, environment);
@@ -1568,7 +1645,7 @@ abstract interface class HttpClient {
   ///
   /// Information on the proxy in use, the authentication scheme
   /// and the security realm for the authentication
-  /// are passed in the arguments [f.host], [f.port], [f.scheme] and [f.realm].
+  /// are passed in the arguments `f.host`, `f.port`, `f.scheme` and `f.realm`.
   ///
   /// The function returns a [Future] which should complete when the
   /// authentication has been resolved. If credentials cannot be
@@ -1581,19 +1658,23 @@ abstract interface class HttpClient {
   /// using the updated credentials. Otherwise response processing will
   /// continue normally.
   void set authenticateProxy(
-      Future<bool> Function(
-              String host, int port, String scheme, String? realm)?
-          f);
+    Future<bool> Function(String host, int port, String scheme, String? realm)?
+    f,
+  );
 
   /// Add credentials to be used for authorizing HTTP proxies.
   void addProxyCredentials(
-      String host, int port, String realm, HttpClientCredentials credentials);
+    String host,
+    int port,
+    String realm,
+    HttpClientCredentials credentials,
+  );
 
   /// Sets a callback that will decide whether to accept a secure connection
   /// with a server certificate that cannot be authenticated by any of our
   /// trusted root certificates.
   ///
-  /// When an secure HTTP request if made, using this HttpClient, and the
+  /// When a secure HTTP request is made, using this HttpClient, and the
   /// server returns a server certificate that cannot be authenticated, the
   /// callback is called asynchronously with the [X509Certificate] object and
   /// the server's hostname and port.  If the value of [badCertificateCallback]
@@ -1610,7 +1691,8 @@ abstract interface class HttpClient {
   /// the request is made, even if the value of badCertificateCallback
   /// has changed since then.
   void set badCertificateCallback(
-      bool Function(X509Certificate cert, String host, int port)? callback);
+    bool Function(X509Certificate cert, String host, int port)? callback,
+  );
 
   /// Sets a callback that will be called when new TLS keys are exchanged with
   /// the server. It will receive one line of text in
@@ -1807,7 +1889,6 @@ abstract interface class HttpClientRequest implements IOSink {
   ///   // If abort() called before response is available, onError will fire.
   /// });
   /// ```
-  @Since("2.10")
   void abort([Object? exception, StackTrace? stackTrace]);
 }
 
@@ -1856,7 +1937,6 @@ abstract interface class HttpClientResponse implements Stream<List<int>> {
   /// This specifies whether the response bytes were compressed when they were
   /// received across the wire and whether callers will receive compressed
   /// or uncompressed bytes when they listed to this response's byte stream.
-  @Since("2.4")
   HttpClientResponseCompressionState get compressionState;
 
   /// Gets the persistent connection state returned by the server.
@@ -1892,8 +1972,11 @@ abstract interface class HttpClientResponse implements Stream<List<int>> {
   ///
   /// The method will ignore [HttpClientRequest.maxRedirects]
   /// and will always perform the redirect.
-  Future<HttpClientResponse> redirect(
-      [String? method, Uri? url, bool? followLoops]);
+  Future<HttpClientResponse> redirect([
+    String? method,
+    Uri? url,
+    bool? followLoops,
+  ]);
 
   /// Returns the client response headers.
   ///
@@ -1904,7 +1987,7 @@ abstract interface class HttpClientResponse implements Stream<List<int>> {
   /// socket is detached the HTTP client will no longer perform any
   /// operations on it.
   ///
-  /// This is normally used when a HTTP upgrade is negotiated and the
+  /// This is normally used when an HTTP upgrade is negotiated and the
   /// communication should continue with a different protocol.
   Future<Socket> detachSocket();
 
@@ -1930,7 +2013,6 @@ abstract interface class HttpClientResponse implements Stream<List<int>> {
 ///  * Does the caller need to manually decompress the response's byte stream?
 ///
 /// This enum is accessed via the [HttpClientResponse.compressionState] value.
-@Since("2.4")
 enum HttpClientResponseCompressionState {
   /// The body of the HTTP response was received and remains in an uncompressed
   /// state.
@@ -1963,19 +2045,36 @@ enum HttpClientResponseCompressionState {
   compressed,
 }
 
+/// Represents credentials for authentication in [HttpClient].
+///
+/// Subtypes of [HttpClientCredentials] can be passed to
+/// [HttpClient.addCredentials] or [HttpClient.addProxyCredentials].
 abstract interface class HttpClientCredentials {}
 
 /// Represents credentials for basic authentication.
+///
+/// See https://datatracker.ietf.org/doc/html/rfc7617
 abstract final class HttpClientBasicCredentials
     implements HttpClientCredentials {
   factory HttpClientBasicCredentials(String username, String password) =>
       _HttpClientBasicCredentials(username, password);
 }
 
-/// Represents credentials for digest authentication. Digest
-/// authentication is only supported for servers using the MD5
-/// algorithm and quality of protection (qop) of either "none" or
-/// "auth".
+/// Represents credentials for bearer token authentication.
+///
+/// See https://datatracker.ietf.org/doc/html/rfc6750
+abstract final class HttpClientBearerCredentials
+    implements HttpClientCredentials {
+  factory HttpClientBearerCredentials(String token) =>
+      _HttpClientBearerCredentials(token);
+}
+
+/// Represents credentials for digest authentication.
+///
+/// Digest authentication is only supported for servers using the MD5 algorithm
+/// and quality of protection (qop) of either "none" or "auth".
+///
+/// See https://datatracker.ietf.org/doc/html/rfc7616
 abstract final class HttpClientDigestCredentials
     implements HttpClientCredentials {
   factory HttpClientDigestCredentials(String username, String password) =>
@@ -2009,9 +2108,10 @@ class HttpException implements IOException {
   const HttpException(this.message, {this.uri});
 
   String toString() {
-    var b = StringBuffer()
-      ..write('HttpException: ')
-      ..write(message);
+    var b =
+        StringBuffer()
+          ..write('HttpException: ')
+          ..write(message);
     var uri = this.uri;
     if (uri != null) {
       b.write(', uri = $uri');
