@@ -8,7 +8,9 @@ import 'package:flutter_test/flutter_test.dart';
 class TestTestBinding extends AutomatedTestWidgetsFlutterBinding {
   @override
   DebugPrintCallback get debugPrintOverride => testPrint;
-  static void testPrint(String? message, { int? wrapWidth }) { print(message); }
+  static void testPrint(String? message, {int? wrapWidth}) {
+    print(message);
+  }
 }
 
 Future<void> helperFunction(WidgetTester tester) async {
@@ -17,7 +19,9 @@ Future<void> helperFunction(WidgetTester tester) async {
 
 void main() {
   TestTestBinding();
-  testWidgets('TestAsyncUtils - handling unguarded async helper functions', (WidgetTester tester) async {
+  testWidgets('TestAsyncUtils - handling unguarded async helper functions', (
+    WidgetTester tester,
+  ) async {
     helperFunction(tester);
     helperFunction(tester);
     // this should fail
