@@ -6,7 +6,5 @@ import 'package:flutter/widgets.dart';
 import 'src/app.dart';
 
 void main() {
-  runApp(
-    const ComplexLayoutApp()
-  );
+  runApp(const ComplexLayoutApp());
 }
