@@ -23,10 +23,7 @@ class _NestedMouseRegion extends StatelessWidget {
   Widget build(BuildContext context) {
     Widget current = child;
     for (int i = 0; i < nests; i++) {
-      current = MouseRegion(
-        onEnter: (_) {},
-        child: child,
-      );
+      current = MouseRegion(onEnter: (_) {}, child: child);
     }
     return current;
   }
@@ -90,25 +87,26 @@ class BenchMouseRegionGridHover extends WidgetRecorder {
             itemCount: rowsCount,
             cacheExtent: rowsCount * containerSize,
             physics: const ClampingScrollPhysics(),
-            itemBuilder: (BuildContext context, int rowIndex) => _NestedMouseRegion(
-              nests: 10,
-              child: Row(
-                children: List<Widget>.generate(
-                  columnsCount,
-                  (int columnIndex) => _NestedMouseRegion(
-                    nests: 10,
-                    child: Container(
-                      decoration: BoxDecoration(
-                        border: _getBorder(columnIndex, rowIndex),
-                        color: Color.fromARGB(255, rowIndex * 20 % 256, 127, 127),
+            itemBuilder:
+                (BuildContext context, int rowIndex) => _NestedMouseRegion(
+                  nests: 10,
+                  child: Row(
+                    children: List<Widget>.generate(
+                      columnsCount,
+                      (int columnIndex) => _NestedMouseRegion(
+                        nests: 10,
+                        child: Container(
+                          decoration: BoxDecoration(
+                            border: _getBorder(columnIndex, rowIndex),
+                            color: Color.fromARGB(255, rowIndex * 20 % 256, 127, 127),
+                          ),
+                          width: containerSize,
+                          height: containerSize,
+                        ),
                       ),
-                      width: containerSize,
-                      height: containerSize,
                     ),
                   ),
                 ),
-              ),
-            ),
           ),
         ),
       ),
@@ -123,7 +121,7 @@ abstract final class _UntilNextFrame {
     if (_UntilNextFrame._completer == null) {
       _UntilNextFrame._completer = Completer<void>();
       SchedulerBinding.instance.addPostFrameCallback((_) {
-        _UntilNextFrame._completer!.complete(null);
+        _UntilNextFrame._completer!.complete();
         _UntilNextFrame._completer = null;
       });
     }
@@ -148,6 +146,7 @@ class _Tester {
       kind: PointerDeviceKind.mouse,
     );
   }
+
   TestGesture? _gesture;
 
   Duration currentTime = Duration.zero;
