@@ -19,11 +19,10 @@ class Data {
 }
 
 List<Data> test(int length) {
-  return List<Data>.generate(length,
-      (int index) => Data(index * index));
+  return List<Data>.generate(length, (int index) => Data(index * index));
 }
 
-Future<void> main() async {
+Future<void> execute() async {
   assert(false, "Don't run benchmarks in debug mode! Use 'flutter run --release'.");
 
   // Warm up lap
