@@ -10,23 +10,22 @@ import 'package:flutter_devicelab/framework/task_result.dart';
 import 'package:flutter_devicelab/framework/utils.dart';
 import 'package:path/path.dart' as path;
 
-final String platformLineSep = Platform.isWindows ? '\r\n': '\n';
-
-
-final String gradlew = Platform.isWindows ? 'gradlew.bat' : 'gradlew';
-final String gradlewExecutable = Platform.isWindows ? '.\\$gradlew' : './$gradlew';
-
 /// Tests that AARs can be built on module projects.
 Future<void> main() async {
   await task(() async {
-
     section('Find Java');
 
     final String? javaHome = await findJavaHome();
-    if (javaHome == null)
+    if (javaHome == null) {
       return TaskResult.failure('Could not find Java');
+    }
     print('\nUsing JAVA_HOME=$javaHome');
 
+    // TODO(matanlurey): Remove after default.
+    // https://github.com/flutter/flutter/issues/160257
+    section('Opt-in to --explicit-package-dependencies');
+    await flutter('config', options: <String>['--explicit-package-dependencies']);
+
     final Directory tempDir = Directory.systemTemp.createTempSync('flutter_module_test.');
     final Directory projectDir = Directory(path.join(tempDir.path, 'hello'));
     try {
@@ -44,7 +43,14 @@ Future<void> main() async {
       await inDirectory(tempDir, () async {
         await flutter(
           'create',
-          options: <String>['--org', 'io.flutter.devicelab', '--template', 'plugin', '--platforms=android', 'plugin_with_android'],
+          options: <String>[
+            '--org',
+            'io.flutter.devicelab',
+            '--template',
+            'plugin',
+            '--platforms=android',
+            'plugin_with_android',
+          ],
         );
       });
 
@@ -53,7 +59,14 @@ Future<void> main() async {
       await inDirectory(tempDir, () async {
         await flutter(
           'create',
-          options: <String>['--org', 'io.flutter.devicelab', '--template', 'plugin', '--platforms=ios', 'plugin_without_android'],
+          options: <String>[
+            '--org',
+            'io.flutter.devicelab',
+            '--template',
+            'plugin',
+            '--platforms=ios',
+            'plugin_without_android',
+          ],
         );
       });
 
@@ -62,56 +75,45 @@ Future<void> main() async {
       final File modulePubspec = File(path.join(projectDir.path, 'pubspec.yaml'));
       String content = modulePubspec.readAsStringSync();
       content = content.replaceFirst(
-        '${platformLineSep}dependencies:$platformLineSep',
-        '${platformLineSep}dependencies:$platformLineSep'
-          '  plugin_with_android:$platformLineSep'
-          '    path: ../plugin_with_android$platformLineSep'
-          '  plugin_without_android:$platformLineSep'
-          '    path: ../plugin_without_android$platformLineSep'
-          '  webcrypto: 0.5.2$platformLineSep', // Plugin that uses NDK.
+        '${Platform.lineTerminator}dependencies:${Platform.lineTerminator}',
+        '${Platform.lineTerminator}dependencies:${Platform.lineTerminator}'
+            '  plugin_with_android:${Platform.lineTerminator}'
+            '    path: ../plugin_with_android${Platform.lineTerminator}'
+            '  plugin_without_android:${Platform.lineTerminator}'
+            '    path: ../plugin_without_android${Platform.lineTerminator}',
       );
       modulePubspec.writeAsStringSync(content, flush: true);
 
       section('Run packages get in module project');
 
       await inDirectory(projectDir, () async {
-        await flutter(
-          'packages',
-          options: <String>['get'],
-        );
+        await flutter('packages', options: <String>['get']);
       });
 
       section('Build release AAR');
 
       await inDirectory(projectDir, () async {
-        await flutter(
-          'build',
-          options: <String>['aar', '--verbose'],
-        );
+        await flutter('build', options: <String>['aar']);
       });
 
-      final String repoPath = path.join(
-        projectDir.path,
-        'build',
-        'host',
-        'outputs',
-        'repo',
+      final String repoPath = path.join(projectDir.path, 'build', 'host', 'outputs', 'repo');
+
+      section('Check release Maven artifacts');
+
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'hello',
+          'flutter_release',
+          '1.0',
+          'flutter_release-1.0.aar',
+        ),
       );
 
-      section('Check release Maven artifacts (old format)');
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter_release',
-        '1.0',
-        'flutter_release-1.0.aar',
-      ));
-
-      final String releasePomOld = path.join(
+      final String releasePom = path.join(
         repoPath,
         'io',
         'flutter',
@@ -122,77 +124,33 @@ Future<void> main() async {
         'flutter_release-1.0.pom',
       );
 
-      checkFileExists(releasePomOld);
+      checkFileExists(releasePom);
 
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android_release',
-        '1.0',
-        'plugin_with_android_release-1.0.aar',
-      ));
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android_release',
-        '1.0',
-        'plugin_with_android_release-1.0.pom',
-      ));
-
-      section('Check release Maven artifacts (new format)');
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter',
-        '1.0',
-        'flutter-1.0-release.aar',
-      ));
-
-      final String releasePomNew = path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter',
-        '1.0',
-        'flutter-1.0.pom',
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'plugin_with_android',
+          'plugin_with_android_release',
+          '1.0',
+          'plugin_with_android_release-1.0.aar',
+        ),
       );
 
-      checkFileExists(releasePomNew);
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android',
-        '1.0',
-        'plugin_with_android-1.0-release.aar',
-      ));
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android',
-        '1.0',
-        'plugin_with_android-1.0.pom',
-      ));
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'plugin_with_android',
+          'plugin_with_android_release',
+          '1.0',
+          'plugin_with_android_release-1.0.pom',
+        ),
+      );
 
       section('Check AOT blobs in release POM');
 
@@ -201,17 +159,8 @@ Future<void> main() async {
         'armeabi_v7a_release',
         'arm64_v8a_release',
         'x86_64_release',
-        'plugin_with_android',
-        '<relocation>', //make sure the old pom contains the <relocation> tag
-      ], releasePomOld);
-
-      checkFileContains(<String>[
-        'flutter_embedding_release',
-        'armeabi_v7a_release',
-        'arm64_v8a_release',
-        'x86_64_release',
-        'plugin_with_android',
-      ], releasePomNew);
+        'plugin_with_android_release',
+      ], releasePom);
 
       section('Check assets in release AAR');
 
@@ -233,46 +182,26 @@ Future<void> main() async {
             'flutter_release',
             '1.0',
             'flutter_release-1.0.aar',
-          )
-        )
+          ),
+        ),
       );
 
-      checkCollectionContains<String>(
-          <String>[
-            ...flutterAssets,
-            // AOT snapshots
-            'jni/arm64-v8a/libapp.so',
-            'jni/armeabi-v7a/libapp.so',
-            'jni/x86_64/libapp.so',
-          ],
-          await getFilesInAar(
-              path.join(
-                repoPath,
-                'io',
-                'flutter',
-                'devicelab',
-                'hello',
-                'flutter',
-                '1.0',
-                'flutter-1.0-release.aar',
-              )
-          )
+      section('Check debug Maven artifacts');
+
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'hello',
+          'flutter_debug',
+          '1.0',
+          'flutter_debug-1.0.aar',
+        ),
       );
 
-      section('Check debug Maven artifacts (old format)');
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter_debug',
-        '1.0',
-        'flutter_debug-1.0.aar',
-      ));
-
-      final String debugPomOld = path.join(
+      final String debugPom = path.join(
         repoPath,
         'io',
         'flutter',
@@ -283,132 +212,60 @@ Future<void> main() async {
         'flutter_debug-1.0.pom',
       );
 
-      checkFileExists(debugPomOld);
+      checkFileExists(debugPom);
 
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android_debug',
-        '1.0',
-        'plugin_with_android_debug-1.0.aar',
-      ));
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android_debug',
-        '1.0',
-        'plugin_with_android_debug-1.0.pom',
-      ));
-
-      section('Check debug Maven artifacts (new format)');
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter',
-        '1.0',
-        'flutter-1.0-debug.aar',
-      ));
-
-      final String debugPomNew = path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter',
-        '1.0',
-        'flutter-1.0.pom',
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'plugin_with_android',
+          'plugin_with_android_debug',
+          '1.0',
+          'plugin_with_android_debug-1.0.aar',
+        ),
       );
 
-      checkFileExists(debugPomNew);
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android',
-        '1.0',
-        'plugin_with_android-1.0-debug.aar',
-      ));
-
-      checkFileExists(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'plugin_with_android',
-        'plugin_with_android',
-        '1.0',
-        'plugin_with_android-1.0.pom',
-      ));
+      checkFileExists(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'plugin_with_android',
+          'plugin_with_android_debug',
+          '1.0',
+          'plugin_with_android_debug-1.0.pom',
+        ),
+      );
 
       section('Check AOT blobs in debug POM');
 
       checkFileContains(<String>[
         'flutter_embedding_debug',
-        'x86_debug',
         'x86_64_debug',
         'armeabi_v7a_debug',
         'arm64_v8a_debug',
-        'plugin_with_android',
-        '<relocation>', //make sure the old pom contains the <relocation> tag
-      ], debugPomOld);
-
-      checkFileContains(<String>[
-        'flutter_embedding_debug',
-        'x86_debug',
-        'x86_64_debug',
-        'armeabi_v7a_debug',
-        'arm64_v8a_debug',
-        'plugin_with_android',
-      ], debugPomNew);
+        'plugin_with_android_debug',
+      ], debugPom);
 
       section('Check assets in debug AAR');
 
-      final Iterable<String> debugAar = await getFilesInAar(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter_debug',
-        '1.0',
-        'flutter_debug-1.0.aar',
-      ));
+      final Iterable<String> debugAar = await getFilesInAar(
+        path.join(
+          repoPath,
+          'io',
+          'flutter',
+          'devicelab',
+          'hello',
+          'flutter_debug',
+          '1.0',
+          'flutter_debug-1.0.aar',
+        ),
+      );
 
-      final Iterable<String> debugAarNew = await getFilesInAar(path.join(
-        repoPath,
-        'io',
-        'flutter',
-        'devicelab',
-        'hello',
-        'flutter',
-        '1.0',
-        'flutter-1.0-debug.aar',
-      ));
-
-      checkCollectionContains<String>(<String>[
-        ...flutterAssets,
-        ...debugAssets,
-      ], debugAar);
-
-      checkCollectionContains<String>(<String>[
-        ...flutterAssets,
-        ...debugAssets,
-      ], debugAarNew);
+      checkCollectionContains<String>(<String>[...flutterAssets, ...debugAssets], debugAar);
 
       return TaskResult.success(null);
     } on TaskResult catch (taskResult) {
