@@ -7,9 +7,11 @@ import 'package:flutter_devicelab/framework/utils.dart';
 import 'package:flutter_devicelab/tasks/perf_tests.dart';
 
 Future<void> main() async {
-  await task(MemoryTest(
-    '${flutterDirectory.path}/dev/integration_tests/flutter_gallery',
-    'test_memory/image_cache_memory.dart',
-    'io.flutter.demo.gallery',
-  ).run);
+  await task(
+    MemoryTest(
+      '${flutterDirectory.path}/dev/integration_tests/flutter_gallery',
+      'test_memory/image_cache_memory.dart',
+      'io.flutter.demo.gallery',
+    ).run,
+  );
 }
