@@ -14,7 +14,6 @@ Future<void> main() async {
   await task(() async {
     try {
       await runPluginProjectTest((FlutterPluginProject pluginProject) async {
-
         section('check main plugin file exists');
         final File pluginMainKotlinFile = File(
           path.join(
@@ -23,17 +22,14 @@ Future<void> main() async {
             'src',
             'main',
             'kotlin',
-            path.join(
-              'com',
-              'example',
-              'aaa',
-              'AaaPlugin.kt',
-            ),
+            path.join('com', 'example', 'aaa', 'AaaPlugin.kt'),
           ),
         );
 
         if (!pluginMainKotlinFile.existsSync()) {
-          throw TaskResult.failure("Expected ${pluginMainKotlinFile.path} to exist, but it doesn't");
+          throw TaskResult.failure(
+            "Expected ${pluginMainKotlinFile.path} to exist, but it doesn't",
+          );
         }
 
         section('add java 8 feature');
@@ -87,14 +83,9 @@ class AaaPlugin: FlutterPlugin, MethodCallHandler {
         await inDirectory(pluginProject.exampleAndroidPath, () {
           return flutter(
             'build',
-            options: <String>[
-              'apk',
-              '--debug',
-              '--target-platform=android-arm',
-            ],
+            options: <String>['apk', '--debug', '--target-platform=android-arm'],
           );
         });
-
       });
       return TaskResult.success(null);
     } on TaskResult catch (taskResult) {
