@@ -10,19 +10,13 @@ import 'package:path/path.dart' as path;
 
 Future<void> main() async {
   await task(() async {
-    final String projectDirectory = '${flutterDirectory.path}/dev/integration_tests/flutter_gallery';
+    final String projectDirectory =
+        '${flutterDirectory.path}/dev/integration_tests/flutter_gallery';
 
     await inDirectory(projectDirectory, () async {
       section('Build gallery app');
 
-      await flutter(
-        'build',
-        options: <String>[
-          'macos',
-          '-v',
-          '--debug',
-        ],
-      );
+      await flutter('build', options: <String>['macos', '-v', '--debug']);
     });
 
     section('Run platform unit tests');
