@@ -27,12 +27,18 @@ void main() {
       print('run: starting...');
       final Process run = await startFlutter(
         'run',
-        options: <String>['--verbose', '--no-fast-start', '--no-publish-port', '--disable-service-auth-codes', '-d', device.deviceId, 'lib/main.dart'],
+        options: <String>[
+          '--no-fast-start',
+          '--no-publish-port',
+          '--disable-service-auth-codes',
+          '-d',
+          device.deviceId,
+          'lib/main.dart',
+        ],
       );
-      run.stdout
-          .transform<String>(utf8.decoder)
-          .transform<String>(const LineSplitter())
-          .listen((String line) {
+      run.stdout.transform<String>(utf8.decoder).transform<String>(const LineSplitter()).listen((
+        String line,
+      ) {
         print('run:stdout: $line');
         if (vmServicePort == null) {
           vmServicePort = parseServicePort(line);
@@ -44,14 +50,17 @@ void main() {
           }
         }
       });
-      run.stderr
-          .transform<String>(utf8.decoder)
-          .transform<String>(const LineSplitter())
-          .listen((String line) {
+      run.stderr.transform<String>(utf8.decoder).transform<String>(const LineSplitter()).listen((
+        String line,
+      ) {
         stderr.writeln('run:stderr: $line');
       });
-      unawaited(run.exitCode.then<void>((int exitCode) { ok = false; }));
-      await Future.any<dynamic>(<Future<dynamic>>[ ready.future, run.exitCode ]);
+      unawaited(
+        run.exitCode.then<void>((int exitCode) {
+          ok = false;
+        }),
+      );
+      await Future.any<dynamic>(<Future<dynamic>>[ready.future, run.exitCode]);
       if (!ok) {
         throw 'Failed to run test app.';
       }
@@ -107,7 +116,8 @@ void main() {
       final Event navigationEvent = await navigationFuture;
       // validate the fields
       expect(navigationEvent.extensionData!.data['route'] is Map<dynamic, dynamic>);
-      final Map<dynamic, dynamic> route = navigationEvent.extensionData!.data['route'] as Map<dynamic, dynamic>;
+      final Map<dynamic, dynamic> route =
+          navigationEvent.extensionData!.data['route'] as Map<dynamic, dynamic>;
       expect(route['description'] is String);
       expect(route['settings'] is Map<dynamic, dynamic>);
       final Map<dynamic, dynamic> settings = route['settings'] as Map<dynamic, dynamic>;
