@@ -9,6 +9,7 @@ import 'task_result.dart';
 const String kBenchmarkTypeKeyName = 'benchmark_type';
 const String kBenchmarkVersionKeyName = 'version';
 const String kLocalEngineKeyName = 'local_engine';
+const String kLocalEngineHostKeyName = 'local_engine_host';
 const String kTaskNameKeyName = 'task_name';
 const String kRunStartKeyName = 'run_start';
 const String kRunEndKeyName = 'run_end';
@@ -24,20 +25,22 @@ enum FieldJustification { LEFT, RIGHT, CENTER }
 ///
 /// See [printSummary] for more.
 class ABTest {
-  ABTest(this.localEngine, this.taskName)
-      : runStart = DateTime.now(),
-        _aResults = <String, List<double>>{},
-        _bResults = <String, List<double>>{};
+  ABTest({required this.localEngine, required this.localEngineHost, required this.taskName})
+    : runStart = DateTime.now(),
+      _aResults = <String, List<double>>{},
+      _bResults = <String, List<double>>{};
 
   ABTest.fromJsonMap(Map<String, dynamic> jsonResults)
-      : localEngine = jsonResults[kLocalEngineKeyName] as String,
-        taskName = jsonResults[kTaskNameKeyName] as String,
-        runStart = DateTime.parse(jsonResults[kRunStartKeyName] as String),
-        _runEnd = DateTime.parse(jsonResults[kRunEndKeyName] as String),
-        _aResults = _convertFrom(jsonResults[kAResultsKeyName] as Map<String, dynamic>),
-        _bResults = _convertFrom(jsonResults[kBResultsKeyName] as Map<String, dynamic>);
+    : localEngine = jsonResults[kLocalEngineKeyName] as String,
+      localEngineHost = jsonResults[kLocalEngineHostKeyName] as String?,
+      taskName = jsonResults[kTaskNameKeyName] as String,
+      runStart = DateTime.parse(jsonResults[kRunStartKeyName] as String),
+      _runEnd = DateTime.parse(jsonResults[kRunEndKeyName] as String),
+      _aResults = _convertFrom(jsonResults[kAResultsKeyName] as Map<String, dynamic>),
+      _bResults = _convertFrom(jsonResults[kBResultsKeyName] as Map<String, dynamic>);
 
   final String localEngine;
+  final String? localEngineHost;
   final String taskName;
   final DateTime runStart;
   DateTime? _runEnd;
@@ -48,7 +51,7 @@ class ABTest {
 
   static Map<String, List<double>> _convertFrom(dynamic results) {
     final Map<String, dynamic> resultMap = results as Map<String, dynamic>;
-    return <String, List<double>> {
+    return <String, List<double>>{
       for (final String key in resultMap.keys)
         key: (resultMap[key] as List<dynamic>).cast<double>(),
     };
@@ -83,14 +86,15 @@ class ABTest {
   }
 
   Map<String, dynamic> get jsonMap => <String, dynamic>{
-    kBenchmarkTypeKeyName:     kBenchmarkResultsType,
-    kBenchmarkVersionKeyName:  kBenchmarkABVersion,
-    kLocalEngineKeyName:       localEngine,
-    kTaskNameKeyName:          taskName,
-    kRunStartKeyName:          runStart.toIso8601String(),
-    kRunEndKeyName:            runEnd!.toIso8601String(),
-    kAResultsKeyName:          _aResults,
-    kBResultsKeyName:          _bResults,
+    kBenchmarkTypeKeyName: kBenchmarkResultsType,
+    kBenchmarkVersionKeyName: kBenchmarkABVersion,
+    kLocalEngineKeyName: localEngine,
+    if (localEngineHost != null) kLocalEngineHostKeyName: localEngineHost,
+    kTaskNameKeyName: taskName,
+    kRunStartKeyName: runStart.toIso8601String(),
+    kRunEndKeyName: runEnd!.toIso8601String(),
+    kAResultsKeyName: _aResults,
+    kBResultsKeyName: _bResults,
   };
 
   static void updateColumnLengths(List<int> lengths, List<String?> results) {
@@ -101,28 +105,26 @@ class ABTest {
     }
   }
 
-  static void formatResult(StringBuffer buffer,
-                           List<int> lengths,
-                           List<FieldJustification> aligns,
-                           List<String?> values) {
+  static void formatResult(
+    StringBuffer buffer,
+    List<int> lengths,
+    List<FieldJustification> aligns,
+    List<String?> values,
+  ) {
     for (int column = 0; column < lengths.length; column++) {
       final int len = lengths[column];
       String? value = values[column];
       if (value == null) {
         value = ''.padRight(len);
       } else {
-        switch (aligns[column]) {
-          case FieldJustification.LEFT:
-            value = value.padRight(len);
-          case FieldJustification.RIGHT:
-            value = value.padLeft(len);
-          case FieldJustification.CENTER:
-            value = value.padLeft((len + value.length) ~/2);
-            value = value.padRight(len);
-        }
+        value = switch (aligns[column]) {
+          FieldJustification.LEFT => value.padRight(len),
+          FieldJustification.RIGHT => value.padLeft(len),
+          FieldJustification.CENTER => value.padLeft((len + value.length) ~/ 2).padRight(len),
+        };
       }
       if (column > 0) {
-        value = value.padLeft(len+1);
+        value = value.padLeft(len + 1);
       }
       buffer.write(value);
     }
@@ -140,22 +142,28 @@ class ABTest {
       for (final String scoreKey in <String>{...summariesA.keys, ...summariesB.keys})
         <String?>[
           scoreKey,
-          summariesA[scoreKey]?.averageString, summariesA[scoreKey]?.noiseString,
-          summariesB[scoreKey]?.averageString, summariesB[scoreKey]?.noiseString,
+          summariesA[scoreKey]?.averageString,
+          summariesA[scoreKey]?.noiseString,
+          summariesB[scoreKey]?.averageString,
+          summariesB[scoreKey]?.noiseString,
           summariesA[scoreKey]?.improvementOver(summariesB[scoreKey]),
         ],
     ];
 
     final List<String> titles = <String>[
       'Score',
-      'Average A', '(noise)',
-      'Average B', '(noise)',
+      'Average A',
+      '(noise)',
+      'Average B',
+      '(noise)',
       'Speed-up',
     ];
     final List<FieldJustification> alignments = <FieldJustification>[
       FieldJustification.LEFT,
-      FieldJustification.RIGHT, FieldJustification.LEFT,
-      FieldJustification.RIGHT, FieldJustification.LEFT,
+      FieldJustification.RIGHT,
+      FieldJustification.LEFT,
+      FieldJustification.RIGHT,
+      FieldJustification.LEFT,
       FieldJustification.CENTER,
     ];
 
@@ -166,11 +174,10 @@ class ABTest {
     }
 
     final StringBuffer buffer = StringBuffer();
-    formatResult(buffer, lengths,
-        <FieldJustification>[
-          FieldJustification.CENTER,
-          ...alignments.skip(1),
-        ], titles);
+    formatResult(buffer, lengths, <FieldJustification>[
+      FieldJustification.CENTER,
+      ...alignments.skip(1),
+    ], titles);
     for (final List<String?> row in tableRows) {
       formatResult(buffer, lengths, alignments, row);
     }
@@ -207,12 +214,7 @@ class ABTest {
     return buffer.toString();
   }
 
-  Set<String> get _allScoreKeys {
-    return <String>{
-      ..._aResults.keys,
-      ..._bResults.keys,
-    };
-  }
+  Set<String> get _allScoreKeys => <String>{..._aResults.keys, ..._bResults.keys};
 
   /// Returns the summary as a tab-separated spreadsheet.
   ///
@@ -254,10 +256,7 @@ class ABTest {
 }
 
 class _ScoreSummary {
-  _ScoreSummary({
-    required this.average,
-    required this.noise,
-  });
+  _ScoreSummary({required this.average, required this.noise});
 
   /// Average (arithmetic mean) of a series of values collected by a benchmark.
   final double average;
@@ -284,13 +283,14 @@ void _addResult(TaskResult result, Map<String, List<double>> results) {
 Map<String, _ScoreSummary> _summarize(Map<String, List<double>> results) {
   return results.map<String, _ScoreSummary>((String scoreKey, List<double> values) {
     final double average = _computeAverage(values);
-    return MapEntry<String, _ScoreSummary>(scoreKey, _ScoreSummary(
-      average: average,
-      // If the average is zero, the benchmark got the perfect score with no noise.
-      noise: average > 0
-        ? _computeStandardDeviationForPopulation(values) / average
-        : 0.0,
-    ));
+    return MapEntry<String, _ScoreSummary>(
+      scoreKey,
+      _ScoreSummary(
+        average: average,
+        // If the average is zero, the benchmark got the perfect score with no noise.
+        noise: average > 0 ? _computeStandardDeviationForPopulation(values) / average : 0.0,
+      ),
+    );
   });
 }
 
