@@ -17,12 +17,7 @@ Future<String> fileType(String pathToBinary) {
 }
 
 Future<String?> minPhoneOSVersion(String pathToBinary) async {
-  final String loadCommands = await eval('otool', <String>[
-    '-l',
-    '-arch',
-    'arm64',
-    pathToBinary,
-  ]);
+  final String loadCommands = await eval('otool', <String>['-l', '-arch', 'arm64', pathToBinary]);
   if (!loadCommands.contains('LC_VERSION_MIN_IPHONEOS')) {
     return null;
   }
@@ -37,9 +32,7 @@ Future<String?> minPhoneOSVersion(String pathToBinary) async {
   final List<String> lines = LineSplitter.split(loadCommands).toList();
   lines.asMap().forEach((int index, String line) {
     if (line.contains('LC_VERSION_MIN_IPHONEOS') && lines.length - index - 1 > 3) {
-      final String versionLine = lines
-          .skip(index - 1)
-          .take(4).last;
+      final String versionLine = lines.skip(index - 1).take(4).last;
       final RegExp versionRegex = RegExp(r'\s*version\s*(\S*)');
       minVersion = versionRegex.firstMatch(versionLine)?.group(1);
     }
@@ -56,43 +49,33 @@ Future<void> testWithNewIOSSimulator(
   SimulatorFunction testFunction, {
   String deviceTypeId = 'com.apple.CoreSimulator.SimDeviceType.iPhone-11',
 }) async {
-  final String availableRuntimes = await eval(
-    'xcrun',
-    <String>[
-      'simctl',
-      'list',
-      'runtimes',
-    ],
-    workingDirectory: flutterDirectory.path,
-  );
+  final String availableRuntimes = await eval('xcrun', <String>[
+    'simctl',
+    'list',
+    'runtimes',
+  ], workingDirectory: flutterDirectory.path);
 
-  final String runtimesForSelectedXcode = await eval(
-    'xcrun',
-    <String>[
-      'simctl',
-      'runtime',
-      'match',
-      'list',
-      '--json',
-    ],
-    workingDirectory: flutterDirectory.path,
-  );
+  final String runtimesForSelectedXcode = await eval('xcrun', <String>[
+    'simctl',
+    'runtime',
+    'match',
+    'list',
+    '--json',
+  ], workingDirectory: flutterDirectory.path);
 
-  // Get the preferred runtime build for the selected Xcode version. Preferred
+  // First check for userOverriddenBuild, which may be set in CI by mac_toolchain.
+  // Next, get the preferred runtime build for the selected Xcode version. Preferred
   // means the runtime was either bundled with Xcode, exactly matched your SDK
   // version, or it's indicated a better match for your SDK.
-  final Map<String, Object?> decodeResult = json.decode(runtimesForSelectedXcode) as Map<String, Object?>;
-  final String? iosKey = decodeResult.keys
-      .where((String key) => key.contains('iphoneos'))
-      .firstOrNull;
-  final Object? iosDetails = decodeResult[iosKey];
-  String? runtimeBuildForSelectedXcode;
-  if (iosDetails != null && iosDetails is Map<String, Object?>) {
-    final Object? preferredBuild = iosDetails['preferredBuild'];
-    if (preferredBuild is String) {
-      runtimeBuildForSelectedXcode = preferredBuild;
-    }
-  }
+  final Map<String, Object?> decodeResult =
+      json.decode(runtimesForSelectedXcode) as Map<String, Object?>;
+  final String? iosKey =
+      decodeResult.keys.where((String key) => key.contains('iphoneos')).firstOrNull;
+  final String? runtimeBuildForSelectedXcode = switch (decodeResult[iosKey]) {
+    {'userOverriddenBuild': final String build} => build,
+    {'preferredBuild': final String build} => build,
+    _ => null,
+  };
 
   String? iOSSimRuntime;
 
@@ -104,8 +87,7 @@ Future<void> testWithNewIOSSimulator(
   // For example, iOS 17 (released with Xcode 15) may be available even if the
   // selected Xcode version is 14.
   for (final String runtime in LineSplitter.split(availableRuntimes)) {
-    if (runtimeBuildForSelectedXcode != null &&
-        !runtime.contains(runtimeBuildForSelectedXcode)) {
+    if (runtimeBuildForSelectedXcode != null && !runtime.contains(runtimeBuildForSelectedXcode)) {
       continue;
     }
     // These seem to be in order, so allow matching multiple lines so it grabs
@@ -124,26 +106,18 @@ Future<void> testWithNewIOSSimulator(
     }
   }
 
-  final String deviceId = await eval(
-    'xcrun',
-    <String>[
-      'simctl',
-      'create',
-      deviceName,
-      deviceTypeId,
-      iOSSimRuntime,
-    ],
-    workingDirectory: flutterDirectory.path,
-  );
-  await eval(
-    'xcrun',
-    <String>[
-      'simctl',
-      'boot',
-      deviceId,
-    ],
-    workingDirectory: flutterDirectory.path,
-  );
+  final String deviceId = await eval('xcrun', <String>[
+    'simctl',
+    'create',
+    deviceName,
+    deviceTypeId,
+    iOSSimRuntime,
+  ], workingDirectory: flutterDirectory.path);
+  await eval('xcrun', <String>[
+    'simctl',
+    'boot',
+    deviceId,
+  ], workingDirectory: flutterDirectory.path);
 
   await testFunction(deviceId);
 }
@@ -153,21 +127,13 @@ Future<void> removeIOSSimulator(String? deviceId) async {
   if (deviceId != null && deviceId != '') {
     await eval(
       'xcrun',
-      <String>[
-        'simctl',
-        'shutdown',
-        deviceId,
-      ],
+      <String>['simctl', 'shutdown', deviceId],
       canFail: true,
       workingDirectory: flutterDirectory.path,
     );
     await eval(
       'xcrun',
-      <String>[
-        'simctl',
-        'delete',
-        deviceId,
-      ],
+      <String>['simctl', 'delete', deviceId],
       canFail: true,
       workingDirectory: flutterDirectory.path,
     );
@@ -178,7 +144,32 @@ Future<bool> runXcodeTests({
   required String platformDirectory,
   required String destination,
   required String testName,
+  List<String> actions = const <String>['test'],
   String configuration = 'Release',
+  List<String> extraOptions = const <String>[],
+  String scheme = 'Runner',
+  bool skipCodesign = false,
+}) {
+  return runXcodeBuild(
+    platformDirectory: platformDirectory,
+    destination: destination,
+    testName: testName,
+    actions: actions,
+    configuration: configuration,
+    extraOptions: extraOptions,
+    scheme: scheme,
+    skipCodesign: skipCodesign,
+  );
+}
+
+Future<bool> runXcodeBuild({
+  required String platformDirectory,
+  required String destination,
+  required String testName,
+  List<String> actions = const <String>['build'],
+  String configuration = 'Release',
+  List<String> extraOptions = const <String>[],
+  String scheme = 'Runner',
   bool skipCodesign = false,
 }) async {
   final Map<String, String> environment = Platform.environment;
@@ -206,21 +197,19 @@ Future<bool> runXcodeTests({
       '-workspace',
       'Runner.xcworkspace',
       '-scheme',
-      'Runner',
+      scheme,
       '-configuration',
       configuration,
       '-destination',
       destination,
       '-resultBundlePath',
       resultBundlePath,
-      'test',
+      ...actions,
+      ...extraOptions,
       'COMPILER_INDEX_STORE_ENABLE=NO',
-      if (developmentTeam != null)
-        'DEVELOPMENT_TEAM=$developmentTeam',
-      if (codeSignStyle != null)
-        'CODE_SIGN_STYLE=$codeSignStyle',
-      if (provisioningProfile != null)
-        'PROVISIONING_PROFILE_SPECIFIER=$provisioningProfile',
+      if (developmentTeam != null) 'DEVELOPMENT_TEAM=$developmentTeam',
+      if (codeSignStyle != null) 'CODE_SIGN_STYLE=$codeSignStyle',
+      if (provisioningProfile != null) 'PROVISIONING_PROFILE_SPECIFIER=$provisioningProfile',
       if (disabledSandboxEntitlementFile != null)
         'CODE_SIGN_ENTITLEMENTS=${disabledSandboxEntitlementFile.path}',
     ],
@@ -234,17 +223,13 @@ Future<bool> runXcodeTests({
     if (dumpDirectory != null) {
       if (xcresultBundle.existsSync()) {
         // Zip the test results to the artifacts directory for upload.
-        final String zipPath = path.join(dumpDirectory.path,
-            '$testName-${DateTime.now().toLocal().toIso8601String()}.zip');
+        final String zipPath = path.join(
+          dumpDirectory.path,
+          '$testName-${DateTime.now().toLocal().toIso8601String()}.zip',
+        );
         await exec(
           'zip',
-          <String>[
-            '-r',
-            '-9',
-            '-q',
-            zipPath,
-            path.basename(xcresultBundle.path),
-          ],
+          <String>['-r', '-9', '-q', zipPath, path.basename(xcresultBundle.path)],
           workingDirectory: resultBundleTemp,
           canFail: true, // Best effort to get the logs.
         );
@@ -264,10 +249,7 @@ Future<bool> runXcodeTests({
 /// access to the app. To workaround this in CI, we create and use a entitlements
 /// file with sandboxing disabled. See
 /// https://developer.apple.com/documentation/security/app_sandbox/accessing_files_from_the_macos_app_sandbox.
-File? _createDisabledSandboxEntitlementFile(
-  String platformDirectory,
-  String configuration,
-) {
+File? _createDisabledSandboxEntitlementFile(String platformDirectory, String configuration) {
   String entitlementDefaultFileName;
   if (configuration == 'Release') {
     entitlementDefaultFileName = 'Release';
@@ -287,15 +269,15 @@ File? _createDisabledSandboxEntitlementFile(
     return null;
   }
 
-  final String originalEntitlementFileContents =
-      entitlementFile.readAsStringSync();
-  final String tempEntitlementPath = Directory.systemTemp
-      .createTempSync('flutter_disable_sandbox_entitlement.')
-      .path;
-  final File disabledSandboxEntitlementFile = File(path.join(
-    tempEntitlementPath,
-    '${entitlementDefaultFileName}WithDisabledSandboxing.entitlements',
-  ));
+  final String originalEntitlementFileContents = entitlementFile.readAsStringSync();
+  final String tempEntitlementPath =
+      Directory.systemTemp.createTempSync('flutter_disable_sandbox_entitlement.').path;
+  final File disabledSandboxEntitlementFile = File(
+    path.join(
+      tempEntitlementPath,
+      '${entitlementDefaultFileName}WithDisabledSandboxing.entitlements',
+    ),
+  );
   disabledSandboxEntitlementFile.createSync(recursive: true);
   disabledSandboxEntitlementFile.writeAsStringSync(
     originalEntitlementFileContents.replaceAll(
@@ -308,3 +290,8 @@ File? _createDisabledSandboxEntitlementFile(
 
   return disabledSandboxEntitlementFile;
 }
+
+/// Returns global (external) symbol table entries, delimited by new lines.
+Future<String> dumpSymbolTable(String filePath) {
+  return eval('nm', <String>['--extern-only', '--just-symbol-name', filePath, '-arch', 'arm64']);
+}
