@@ -12,43 +12,75 @@ import '../framework/task_result.dart';
 import '../framework/utils.dart';
 import 'build_test_task.dart';
 
-final Directory galleryDirectory = dir('${flutterDirectory.path}/dev/integration_tests/flutter_gallery');
+final Directory galleryDirectory = dir(
+  '${flutterDirectory.path}/dev/integration_tests/flutter_gallery',
+);
 
 /// Temp function during gallery tests transition to build+test model.
 ///
 /// https://github.com/flutter/flutter/issues/103542
 TaskFunction createGalleryTransitionBuildTest(List<String> args, {bool semanticsEnabled = false}) {
-  return GalleryTransitionBuildTest(args, semanticsEnabled: semanticsEnabled);
+  return GalleryTransitionBuildTest(args, semanticsEnabled: semanticsEnabled).call;
 }
 
 TaskFunction createGalleryTransitionTest({bool semanticsEnabled = false}) {
-  return GalleryTransitionTest(semanticsEnabled: semanticsEnabled);
+  return GalleryTransitionTest(semanticsEnabled: semanticsEnabled).call;
 }
 
-TaskFunction createGalleryTransitionE2ETest({bool semanticsEnabled = false}) {
-  return GalleryTransitionTest(
-    testFile: semanticsEnabled
-        ? 'transitions_perf_e2e_with_semantics'
-        : 'transitions_perf_e2e',
+TaskFunction createGalleryTransitionE2EBuildTest(
+  List<String> args, {
+  bool semanticsEnabled = false,
+  bool? enableImpeller,
+}) {
+  return GalleryTransitionBuildTest(
+    args,
+    testFile: semanticsEnabled ? 'transitions_perf_e2e_with_semantics' : 'transitions_perf_e2e',
     needFullTimeline: false,
     timelineSummaryFile: 'e2e_perf_summary',
     transitionDurationFile: null,
     timelineTraceFile: null,
     driverFile: 'transitions_perf_e2e_test',
-  );
+    enableImpeller: enableImpeller,
+  ).call;
+}
+
+TaskFunction createGalleryTransitionE2ETest({bool semanticsEnabled = false, bool? enableImpeller}) {
+  return GalleryTransitionTest(
+    testFile: semanticsEnabled ? 'transitions_perf_e2e_with_semantics' : 'transitions_perf_e2e',
+    needFullTimeline: false,
+    timelineSummaryFile: 'e2e_perf_summary',
+    transitionDurationFile: null,
+    timelineTraceFile: null,
+    driverFile: 'transitions_perf_e2e_test',
+    enableImpeller: enableImpeller,
+  ).call;
+}
+
+TaskFunction createGalleryTransitionHybridBuildTest(
+  List<String> args, {
+  bool semanticsEnabled = false,
+}) {
+  return GalleryTransitionBuildTest(
+    args,
+    semanticsEnabled: semanticsEnabled,
+    driverFile:
+        semanticsEnabled
+            ? 'transitions_perf_hybrid_with_semantics_test'
+            : 'transitions_perf_hybrid_test',
+  ).call;
 }
 
 TaskFunction createGalleryTransitionHybridTest({bool semanticsEnabled = false}) {
   return GalleryTransitionTest(
     semanticsEnabled: semanticsEnabled,
-    driverFile: semanticsEnabled
-        ? 'transitions_perf_hybrid_with_semantics_test'
-        : 'transitions_perf_hybrid_test',
-  );
+    driverFile:
+        semanticsEnabled
+            ? 'transitions_perf_hybrid_with_semantics_test'
+            : 'transitions_perf_hybrid_test',
+  ).call;
 }
 
 class GalleryTransitionTest {
-
   GalleryTransitionTest({
     this.semanticsEnabled = false,
     this.testFile = 'transitions_perf',
@@ -59,12 +91,14 @@ class GalleryTransitionTest {
     this.driverFile,
     this.measureCpuGpu = true,
     this.measureMemory = true,
+    this.enableImpeller,
   });
 
   final bool semanticsEnabled;
   final bool needFullTimeline;
   final bool measureCpuGpu;
   final bool measureMemory;
+  final bool? enableImpeller;
   final String testFile;
   final String timelineSummaryFile;
   final String? timelineTraceFile;
@@ -75,7 +109,9 @@ class GalleryTransitionTest {
     final Device device = await devices.workingDevice;
     await device.unlock();
     final String deviceId = device.deviceId;
-    final Directory galleryDirectory = dir('${flutterDirectory.path}/dev/integration_tests/flutter_gallery');
+    final Directory galleryDirectory = dir(
+      '${flutterDirectory.path}/dev/integration_tests/flutter_gallery',
+    );
     await inDirectory<void>(galleryDirectory, () async {
       String? applicationBinaryPath;
       if (deviceOperatingSystem == DeviceOperatingSystem.android) {
@@ -95,38 +131,39 @@ class GalleryTransitionTest {
         applicationBinaryPath = 'build/app/outputs/flutter-apk/app-profile.apk';
       }
 
-      final String testDriver = driverFile ?? (semanticsEnabled
-          ? '${testFile}_with_semantics_test'
-          : '${testFile}_test');
+      final String testDriver =
+          driverFile ?? (semanticsEnabled ? '${testFile}_with_semantics_test' : '${testFile}_test');
       section('DRIVE START');
-      await flutter('drive', options: <String>[
-        '--no-dds',
-        '--profile',
-        if (needFullTimeline)
-          '--trace-startup',
-        if (applicationBinaryPath != null)
-          '--use-application-binary=$applicationBinaryPath'
-        else
-          ...<String>[
-            '-t',
-            'test_driver/$testFile.dart',
-          ],
-        '--driver',
-        'test_driver/$testDriver.dart',
-        '-d',
-        deviceId,
-      ]);
+      await flutter(
+        'drive',
+        options: <String>[
+          '--profile',
+          if (enableImpeller != null && enableImpeller!) '--enable-impeller',
+          if (enableImpeller != null && !enableImpeller!) '--no-enable-impeller',
+          if (needFullTimeline) '--trace-startup',
+          if (applicationBinaryPath != null)
+            '--use-application-binary=$applicationBinaryPath'
+          else ...<String>['-t', 'test_driver/$testFile.dart'],
+          '--driver',
+          'test_driver/$testDriver.dart',
+          '-d',
+          deviceId,
+          '-v',
+          '--verbose-system-logs',
+        ],
+      );
     });
 
-    final String testOutputDirectory = Platform.environment['FLUTTER_TEST_OUTPUTS_DIR'] ?? '${galleryDirectory.path}/build';
-    final Map<String, dynamic> summary = json.decode(
-      file('$testOutputDirectory/$timelineSummaryFile.json').readAsStringSync(),
-    ) as Map<String, dynamic>;
+    final String testOutputDirectory =
+        Platform.environment['FLUTTER_TEST_OUTPUTS_DIR'] ?? '${galleryDirectory.path}/build';
+    final Map<String, dynamic> summary =
+        json.decode(file('$testOutputDirectory/$timelineSummaryFile.json').readAsStringSync())
+            as Map<String, dynamic>;
 
     if (transitionDurationFile != null) {
-      final Map<String, dynamic> original = json.decode(
-        file('$testOutputDirectory/$transitionDurationFile.json').readAsStringSync(),
-      ) as Map<String, dynamic>;
+      final Map<String, dynamic> original =
+          json.decode(file('$testOutputDirectory/$transitionDurationFile.json').readAsStringSync())
+              as Map<String, dynamic>;
       final Map<String, List<int>> transitions = <String, List<int>>{};
       for (final String key in original.keys) {
         transitions[key] = List<int>.from(original[key] as List<dynamic>);
@@ -136,21 +173,20 @@ class GalleryTransitionTest {
     }
 
     final bool isAndroid = deviceOperatingSystem == DeviceOperatingSystem.android;
-    return TaskResult.success(summary,
+    return TaskResult.success(
+      summary,
       detailFiles: <String>[
-        if (transitionDurationFile != null)
-          '$testOutputDirectory/$transitionDurationFile.json',
-        if (timelineTraceFile != null)
-          '$testOutputDirectory/$timelineTraceFile.json',
+        if (transitionDurationFile != null) '$testOutputDirectory/$transitionDurationFile.json',
+        if (timelineTraceFile != null) '$testOutputDirectory/$timelineTraceFile.json',
       ],
       benchmarkScoreKeys: <String>[
-        if (transitionDurationFile != null)
-          'missed_transition_count',
+        if (transitionDurationFile != null) 'missed_transition_count',
         'average_frame_build_time_millis',
         'worst_frame_build_time_millis',
         '90th_percentile_frame_build_time_millis',
         '99th_percentile_frame_build_time_millis',
         'average_frame_rasterizer_time_millis',
+        'stddev_frame_rasterizer_time_millis',
         'worst_frame_rasterizer_time_millis',
         '90th_percentile_frame_rasterizer_time_millis',
         '99th_percentile_frame_rasterizer_time_millis',
@@ -198,42 +234,72 @@ class GalleryTransitionBuildTest extends BuildTestTask {
     this.driverFile,
     this.measureCpuGpu = true,
     this.measureMemory = true,
+    this.enableImpeller,
   }) : super(workingDirectory: galleryDirectory);
 
   final bool semanticsEnabled;
   final bool needFullTimeline;
   final bool measureCpuGpu;
   final bool measureMemory;
+  final bool? enableImpeller;
   final String testFile;
   final String timelineSummaryFile;
   final String? timelineTraceFile;
   final String? transitionDurationFile;
   final String? driverFile;
 
-  final String testOutputDirectory = Platform.environment['FLUTTER_TEST_OUTPUTS_DIR'] ?? '${galleryDirectory.path}/build';
+  final String testOutputDirectory =
+      Platform.environment['FLUTTER_TEST_OUTPUTS_DIR'] ?? '${galleryDirectory.path}/build';
+
+  @override
+  void copyArtifacts() {
+    if (applicationBinaryPath == null) {
+      return;
+    }
+    if (deviceOperatingSystem == DeviceOperatingSystem.android) {
+      copy(
+        file('${galleryDirectory.path}/build/app/outputs/flutter-apk/app-profile.apk'),
+        Directory(applicationBinaryPath!),
+      );
+    } else if (deviceOperatingSystem == DeviceOperatingSystem.ios) {
+      recursiveCopy(
+        Directory('${galleryDirectory.path}/build/ios/iphoneos'),
+        Directory(applicationBinaryPath!),
+      );
+    }
+  }
 
   @override
   List<String> getBuildArgs(DeviceOperatingSystem deviceOperatingSystem) {
-    return <String>[
-      'apk',
-      '--no-android-gradle-daemon',
-      '--profile',
-      '-t',
-      'test_driver/$testFile.dart',
-      '--target-platform',
-      'android-arm,android-arm64',
-    ];
+    if (deviceOperatingSystem == DeviceOperatingSystem.android) {
+      return <String>[
+        'apk',
+        '--no-android-gradle-daemon',
+        '--profile',
+        '-t',
+        'test_driver/$testFile.dart',
+        '--target-platform',
+        'android-arm,android-arm64',
+      ];
+    } else if (deviceOperatingSystem == DeviceOperatingSystem.ios) {
+      return <String>['ios', '--codesign', '--profile', '-t', 'test_driver/$testFile.dart'];
+    }
+    throw Exception('$deviceOperatingSystem has no build configuration');
   }
 
   @override
   List<String> getTestArgs(DeviceOperatingSystem deviceOperatingSystem, String deviceId) {
-    final String testDriver = driverFile ?? (semanticsEnabled ? '${testFile}_with_semantics_test' : '${testFile}_test');
+    final String testDriver =
+        driverFile ?? (semanticsEnabled ? '${testFile}_with_semantics_test' : '${testFile}_test');
     return <String>[
+      '--no-dds',
       '--profile',
+      if (enableImpeller != null && enableImpeller!) '--enable-impeller',
+      if (enableImpeller != null && !enableImpeller!) '--no-enable-impeller',
       if (needFullTimeline) '--trace-startup',
       '-t',
       'test_driver/$testFile.dart',
-      '--use-application-binary=${getApplicationBinaryPath()}',
+      if (applicationBinaryPath != null) '--use-application-binary=${getApplicationBinaryPath()}',
       '--driver',
       'test_driver/$testDriver.dart',
       '-d',
@@ -243,14 +309,14 @@ class GalleryTransitionBuildTest extends BuildTestTask {
 
   @override
   Future<TaskResult> parseTaskResult() async {
-    final Map<String, dynamic> summary = json.decode(
-      file('$testOutputDirectory/$timelineSummaryFile.json').readAsStringSync(),
-    ) as Map<String, dynamic>;
+    final Map<String, dynamic> summary =
+        json.decode(file('$testOutputDirectory/$timelineSummaryFile.json').readAsStringSync())
+            as Map<String, dynamic>;
 
     if (transitionDurationFile != null) {
-      final Map<String, dynamic> original = json.decode(
-        file('$testOutputDirectory/$transitionDurationFile.json').readAsStringSync(),
-      ) as Map<String, dynamic>;
+      final Map<String, dynamic> original =
+          json.decode(file('$testOutputDirectory/$transitionDurationFile.json').readAsStringSync())
+              as Map<String, dynamic>;
       final Map<String, List<int>> transitions = <String, List<int>>{};
       for (final String key in original.keys) {
         transitions[key] = List<int>.from(original[key] as List<dynamic>);
@@ -309,11 +375,13 @@ class GalleryTransitionBuildTest extends BuildTestTask {
 
   @override
   String getApplicationBinaryPath() {
-    if (applicationBinaryPath != null) {
+    if (deviceOperatingSystem == DeviceOperatingSystem.android) {
+      return '$applicationBinaryPath/app-profile.apk';
+    } else if (deviceOperatingSystem == DeviceOperatingSystem.ios) {
+      return '$applicationBinaryPath/Flutter Gallery.app';
+    } else {
       return applicationBinaryPath!;
     }
-
-    return 'build/app/outputs/flutter-apk/app-profile.apk';
   }
 }
 
@@ -323,7 +391,9 @@ int _countMissedTransitions(Map<String, List<int>> transitions) {
   transitions.forEach((String demoName, List<int> durations) {
     final int longestDuration = durations.reduce(math.max);
     if (longestDuration > kTransitionBudget) {
-      print('$demoName missed transition time budget ($longestDuration µs > $kTransitionBudget µs)');
+      print(
+        '$demoName missed transition time budget ($longestDuration µs > $kTransitionBudget µs)',
+      );
       count++;
     }
   });
