@@ -22,11 +22,11 @@ TaskFunction createPlatformInteractionTest() {
   ).call;
 }
 
-TaskFunction createFlavorsTest({Map<String, String>? environment}) {
+TaskFunction createFlavorsTest({Map<String, String>? environment, List<String>? extraOptions}) {
   return DriverTest(
     '${flutterDirectory.path}/dev/integration_tests/flavors',
     'lib/main.dart',
-    extraOptions: <String>['--flavor', 'paid'],
+    extraOptions: extraOptions ?? <String>['--flavor', 'paid'],
     environment: environment,
   ).call;
 }
@@ -40,7 +40,9 @@ TaskFunction createIntegrationTestFlavorsTest({Map<String, String>? environment}
   ).call;
 }
 
-TaskFunction createExternalTexturesFrameRateIntegrationTest({ List<String> extraOptions = const <String>[] }) {
+TaskFunction createExternalTexturesFrameRateIntegrationTest({
+  List<String> extraOptions = const <String>[],
+}) {
   return DriverTest(
     '${flutterDirectory.path}/dev/integration_tests/external_textures',
     'lib/frame_rate_main.dart',
@@ -89,9 +91,7 @@ TaskFunction createIOSPlatformViewTests() {
   return DriverTest(
     '${flutterDirectory.path}/dev/integration_tests/ios_platform_view_tests',
     'lib/main.dart',
-    extraOptions: <String>[
-      '--dart-define=ENABLE_DRIVER_EXTENSION=true',
-    ],
+    extraOptions: <String>['--dart-define=ENABLE_DRIVER_EXTENSION=true'],
   ).call;
 }
 
@@ -131,12 +131,59 @@ TaskFunction createEndToEndKeyboardTextfieldTest() {
   ).call;
 }
 
+TaskFunction createSolidColorTest({required bool enableImpeller}) {
+  return DriverTest(
+    '${flutterDirectory.path}/dev/integration_tests/ui',
+    'lib/solid_color.dart',
+    extraOptions: <String>[if (enableImpeller) '--enable-impeller'],
+  ).call;
+}
+
+// Can run on emulator or physical android device.
+// Device must have developer settings enabled.
+// Device must be android api 30 or higher.
+TaskFunction createDisplayCutoutTest() {
+  return IntegrationTest(
+    '${flutterDirectory.path}/dev/integration_tests/display_cutout_rotation/',
+    'integration_test/display_cutout_test.dart',
+    setup: (Device device) async {
+      if (device is! AndroidDevice) {
+        // Only android devices support this cutoutTest.
+        throw TaskResult.failure('This test should only target android');
+      }
+      // Test requires developer settings added in 28 and behavior added in 30.
+      final String sdkResult = await device.shellEval('getprop', <String>['ro.build.version.sdk']);
+      if (sdkResult.startsWith('2') || sdkResult.startsWith('1') || sdkResult.length == 1) {
+        throw TaskResult.failure('This test should only target android 30+.');
+      }
+      print('Adding Synthetic notch...');
+      // This command will cause any running android activity to be recreated.
+      await device.shellExec('cmd', <String>[
+        'overlay',
+        'enable',
+        'com.android.internal.display.cutout.emulation.tall',
+      ]);
+    },
+    tearDown: (Device device) async {
+      if (device is AndroidDevice) {
+        print('Removing Synthetic notch...');
+        await device.shellExec('cmd', <String>[
+          'overlay',
+          'disable',
+          'com.android.internal.display.cutout.emulation.tall',
+        ]);
+      }
+    },
+  ).call;
+}
+
 TaskFunction dartDefinesTask() {
   return DriverTest(
     '${flutterDirectory.path}/dev/integration_tests/ui',
-    'lib/defines.dart', extraOptions: <String>[
-    '--dart-define=test.valueA=Example,A',
-    '--dart-define=test.valueB=Value',
+    'lib/defines.dart',
+    extraOptions: <String>[
+      '--dart-define=test.valueA=Example,A',
+      '--dart-define=test.valueB=Value',
     ],
   ).call;
 }
@@ -175,11 +222,10 @@ class DriverTest {
   DriverTest(
     this.testDirectory,
     this.testTarget, {
-      this.extraOptions = const <String>[],
-      this.deviceIdOverride,
-      this.environment,
-    }
-  );
+    this.extraOptions = const <String>[],
+    this.deviceIdOverride,
+    this.environment,
+  });
 
   final String testDirectory;
   final String testTarget;
@@ -209,7 +255,6 @@ class DriverTest {
         ...extraOptions,
       ];
       await flutter('drive', options: options, environment: environment);
-
       return TaskResult.success(null);
     });
   }
@@ -219,12 +264,13 @@ class IntegrationTest {
   IntegrationTest(
     this.testDirectory,
     this.testTarget, {
-      this.extraOptions = const <String>[],
-      this.createPlatforms = const <String>[],
-      this.withTalkBack = false,
-      this.environment,
-    }
-  );
+    this.extraOptions = const <String>[],
+    this.createPlatforms = const <String>[],
+    this.withTalkBack = false,
+    this.environment,
+    this.setup,
+    this.tearDown,
+  });
 
   final String testDirectory;
   final String testTarget;
@@ -233,37 +279,39 @@ class IntegrationTest {
   final bool withTalkBack;
   final Map<String, String>? environment;
 
+  /// Run before flutter drive with the result from devices.workingDevice.
+  final Future<void> Function(Device device)? setup;
+
+  /// Run after flutter drive with the result from devices.workingDevice.
+  final Future<void> Function(Device device)? tearDown;
+
   Future<TaskResult> call() {
     return inDirectory<TaskResult>(testDirectory, () async {
       final Device device = await devices.workingDevice;
       await device.unlock();
       final String deviceId = device.deviceId;
       await flutter('packages', options: <String>['get']);
+      await setup?.call(await devices.workingDevice);
 
       if (createPlatforms.isNotEmpty) {
-        await flutter('create', options: <String>[
-          '--platforms',
-          createPlatforms.join(','),
-          '--no-overwrite',
-          '.'
-        ]);
+        await flutter(
+          'create',
+          options: <String>['--platforms', createPlatforms.join(','), '--no-overwrite', '.'],
+        );
       }
 
       if (withTalkBack) {
         if (device is! AndroidDevice) {
-          return TaskResult.failure('A test that enables TalkBack can only be run on Android devices');
+          return TaskResult.failure(
+            'A test that enables TalkBack can only be run on Android devices',
+          );
         }
         await enableTalkBack();
       }
 
-      final List<String> options = <String>[
-        '-v',
-        '-d',
-        deviceId,
-        testTarget,
-        ...extraOptions,
-      ];
+      final List<String> options = <String>['-v', '-d', deviceId, testTarget, ...extraOptions];
       await flutter('test', options: options, environment: environment);
+      await tearDown?.call(await devices.workingDevice);
 
       if (withTalkBack) {
         await disableTalkBack();
