@@ -7,23 +7,23 @@ import 'package:flutter/material.dart';
 import '../../gallery/demo.dart';
 
 const String _checkboxText =
-  'Checkboxes allow the user to select multiple options from a set. '
-  "A normal checkbox's value is true or false and a tristate checkbox's "
-  'value can also be null.';
+    'Checkboxes allow the user to select multiple options from a set. '
+    "A normal checkbox's value is true or false and a tristate checkbox's "
+    'value can also be null.';
 
 const String _checkboxCode = 'selectioncontrols_checkbox';
 
 const String _radioText =
-  'Radio buttons allow the user to select one option from a set. Use radio '
-  'buttons for exclusive selection if you think that the user needs to see '
-  'all available options side-by-side.';
+    'Radio buttons allow the user to select one option from a set. Use radio '
+    'buttons for exclusive selection if you think that the user needs to see '
+    'all available options side-by-side.';
 
 const String _radioCode = 'selectioncontrols_radio';
 
 const String _switchText =
-  'On/off switches toggle the state of a single settings option. The option '
-  'that the switch controls, as well as the state it’s in, should be made '
-  'clear from the corresponding inline label.';
+    'On/off switches toggle the state of a single settings option. The option '
+    'that the switch controls, as well as the state it’s in, should be made '
+    'clear from the corresponding inline label.';
 
 const String _switchCode = 'selectioncontrols_switch';
 
@@ -63,10 +63,7 @@ class _SelectionControlsDemoState extends State<SelectionControlsDemo> {
       ),
     ];
 
-    return TabbedComponentDemoScaffold(
-      title: 'Selection controls',
-      demos: demos,
-    );
+    return TabbedComponentDemoScaffold(title: 'Selection controls', demos: demos);
   }
 
   bool? checkboxValueA = true;
@@ -149,42 +146,18 @@ class _SelectionControlsDemoState extends State<SelectionControlsDemo> {
           Row(
             mainAxisSize: MainAxisSize.min,
             children: <Widget>[
-              Radio<int>(
-                value: 0,
-                groupValue: radioValue,
-                onChanged: handleRadioValueChanged,
-              ),
-              Radio<int>(
-                value: 1,
-                groupValue: radioValue,
-                onChanged: handleRadioValueChanged,
-              ),
-              Radio<int>(
-                value: 2,
-                groupValue: radioValue,
-                onChanged: handleRadioValueChanged,
-              ),
+              Radio<int>(value: 0, groupValue: radioValue, onChanged: handleRadioValueChanged),
+              Radio<int>(value: 1, groupValue: radioValue, onChanged: handleRadioValueChanged),
+              Radio<int>(value: 2, groupValue: radioValue, onChanged: handleRadioValueChanged),
             ],
           ),
           // Disabled radio buttons
           const Row(
             mainAxisSize: MainAxisSize.min,
             children: <Widget>[
-              Radio<int>(
-                value: 0,
-                groupValue: 0,
-                onChanged: null,
-              ),
-              Radio<int>(
-                value: 1,
-                groupValue: 0,
-                onChanged: null,
-              ),
-              Radio<int>(
-                value: 2,
-                groupValue: 0,
-                onChanged: null,
-              ),
+              Radio<int>(value: 0, groupValue: 0, onChanged: null),
+              Radio<int>(value: 1, groupValue: 0, onChanged: null),
+              Radio<int>(value: 2, groupValue: 0, onChanged: null),
             ],
           ),
         ],
