@@ -55,10 +55,14 @@ void main() {
     // Switch back to system theme setting: first menu button, choose 'System Default'
     await tester.tap(find.byIcon(Icons.arrow_drop_down).first);
     await tester.pumpAndSettle();
-    await tester.tap(find.descendant(
-        of: find.byWidgetPredicate((Widget widget) => widget.runtimeType.toString() == 'PopupMenuItem<ThemeMode>'),
-        matching: find.text('System Default')
-    ));
+    await tester.tap(
+      find.descendant(
+        of: find.byWidgetPredicate(
+          (Widget widget) => widget.runtimeType.toString() == 'PopupMenuItem<ThemeMode>',
+        ),
+        matching: find.text('System Default'),
+      ),
+    );
     await tester.pumpAndSettle();
     app = find.byType(MaterialApp).evaluate().first.widget as MaterialApp;
     expect(app.themeMode, ThemeMode.system);
@@ -76,10 +80,15 @@ void main() {
 
     await tester.tap(find.byIcon(Icons.arrow_drop_down).at(2));
     await tester.pumpAndSettle();
-    await tester.tap(find.descendant(
-        of: find.byWidgetPredicate((Widget widget) => widget.runtimeType.toString() == 'PopupMenuItem<GalleryVisualDensityValue>'),
-        matching: find.text('System Default')
-    ));
+    await tester.tap(
+      find.descendant(
+        of: find.byWidgetPredicate(
+          (Widget widget) =>
+              widget.runtimeType.toString() == 'PopupMenuItem<GalleryVisualDensityValue>',
+        ),
+        matching: find.text('System Default'),
+      ),
+    );
     await tester.pumpAndSettle();
     app = find.byType(MaterialApp).evaluate().first.widget as MaterialApp;
     expect(app.theme!.visualDensity, equals(VisualDensity.standard));
@@ -110,10 +119,15 @@ void main() {
     // Set font scale back to the default.
     await tester.tap(find.byIcon(Icons.arrow_drop_down).at(1));
     await tester.pumpAndSettle();
-    await tester.tap(find.descendant(
-        of: find.byWidgetPredicate((Widget widget) => widget.runtimeType.toString() == 'PopupMenuItem<GalleryTextScaleValue>'),
-        matching: find.text('System Default')
-    ));
+    await tester.tap(
+      find.descendant(
+        of: find.byWidgetPredicate(
+          (Widget widget) =>
+              widget.runtimeType.toString() == 'PopupMenuItem<GalleryTextScaleValue>',
+        ),
+        matching: find.text('System Default'),
+      ),
+    );
     await tester.pumpAndSettle();
     textSize = tester.getSize(find.text('Text size'));
     expect(textSize, origTextSize);
