@@ -60,14 +60,15 @@ class ExpandingBottomSheet extends StatefulWidget {
   @override
   ExpandingBottomSheetState createState() => ExpandingBottomSheetState();
 
-  static ExpandingBottomSheetState? of(BuildContext context,
-      {bool isNullOk = false}) {
-    final ExpandingBottomSheetState? result = context.findAncestorStateOfType<ExpandingBottomSheetState>();
+  static ExpandingBottomSheetState? of(BuildContext context, {bool isNullOk = false}) {
+    final ExpandingBottomSheetState? result =
+        context.findAncestorStateOfType<ExpandingBottomSheetState>();
     if (isNullOk || result != null) {
       return result;
     }
     throw FlutterError(
-        'ExpandingBottomSheet.of() called with a context that does not contain a ExpandingBottomSheet.\n');
+      'ExpandingBottomSheet.of() called with a context that does not contain a ExpandingBottomSheet.\n',
+    );
   }
 }
 
@@ -100,24 +101,16 @@ Animation<T> _getEmphasizedEasingAnimation<T>({
     secondWeight = _peakVelocityTime;
   }
 
-  return TweenSequence<T>(
-    <TweenSequenceItem<T>>[
-      TweenSequenceItem<T>(
-        weight: firstWeight,
-        tween: Tween<T>(
-          begin: begin,
-          end: peak,
-        ).chain(CurveTween(curve: firstCurve)),
-      ),
-      TweenSequenceItem<T>(
-        weight: secondWeight,
-        tween: Tween<T>(
-          begin: peak,
-          end: end,
-        ).chain(CurveTween(curve: secondCurve)),
-      ),
-    ],
-  ).animate(parent);
+  return TweenSequence<T>(<TweenSequenceItem<T>>[
+    TweenSequenceItem<T>(
+      weight: firstWeight,
+      tween: Tween<T>(begin: begin, end: peak).chain(CurveTween(curve: firstCurve)),
+    ),
+    TweenSequenceItem<T>(
+      weight: secondWeight,
+      tween: Tween<T>(begin: peak, end: end).chain(CurveTween(curve: secondCurve)),
+    ),
+  ]).animate(parent);
 }
 
 // Calculates the value where two double Animations should be joined. Used by
@@ -127,8 +120,7 @@ double _getPeakPoint({required double begin, required double end}) {
 }
 
 class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
-  final GlobalKey _expandingBottomSheetKey =
-      GlobalKey(debugLabel: 'Expanding bottom sheet');
+  final GlobalKey _expandingBottomSheetKey = GlobalKey(debugLabel: 'Expanding bottom sheet');
 
   // The width of the Material, calculated by _widthFor() & based on the number
   // of products in the cart. 64.0 is the width when there are 0 products
@@ -165,8 +157,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
         peak: _getPeakPoint(begin: _width, end: screenWidth),
         end: screenWidth,
         isForward: false,
-        parent: CurvedAnimation(
-            parent: _controller.view, curve: const Interval(0, 0.87)),
+        parent: CurvedAnimation(parent: _controller.view, curve: const Interval(0, 0.87)),
       );
     }
   }
@@ -184,10 +175,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
       );
     } else {
       // Closing animation
-      return Tween<double>(
-        begin: _height,
-        end: screenHeight,
-      ).animate(
+      return Tween<double>(begin: _height, end: screenHeight).animate(
         CurvedAnimation(
           parent: _controller.view,
           curve: const Interval(0.434, 1), // not used
@@ -207,18 +195,14 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
 
       return _getEmphasizedEasingAnimation(
         begin: collapsedGapHeight,
-        peak: collapsedGapHeight +
-            (expandedGapHeight - collapsedGapHeight) * _peakVelocityProgress,
+        peak: collapsedGapHeight + (expandedGapHeight - collapsedGapHeight) * _peakVelocityProgress,
         end: expandedGapHeight,
         isForward: true,
         parent: _controller.view,
       );
     } else {
       // Closing animation
-      return Tween<double>(
-        begin: collapsedGapHeight,
-        end: expandedGapHeight,
-      ).animate(
+      return Tween<double>(begin: collapsedGapHeight, end: expandedGapHeight).animate(
         CurvedAnimation(
           parent: _controller.view,
           curve: const Interval(0.434, 1), // not used
@@ -281,9 +265,10 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
     return Tween<double>(begin: 1, end: 0).animate(
       CurvedAnimation(
         parent: _controller.view,
-        curve: _controller.status == AnimationStatus.forward
-            ? const Interval(0, 0.3)
-            : const Interval(0.532, 0.766),
+        curve:
+            _controller.status == AnimationStatus.forward
+                ? const Interval(0, 0.3)
+                : const Interval(0.532, 0.766),
       ),
     );
   }
@@ -291,9 +276,10 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
   Animation<double> _getCartOpacityAnimation() {
     return CurvedAnimation(
       parent: _controller.view,
-      curve: _controller.status == AnimationStatus.forward
-          ? const Interval(0.3, 0.6)
-          : const Interval(0.766, 1),
+      curve:
+          _controller.status == AnimationStatus.forward
+              ? const Interval(0.3, 0.6)
+              : const Interval(0.766, 1),
     );
   }
 
@@ -305,10 +291,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
         min(numProducts, _maxThumbnailCount) * _paddedThumbnailHeight(context);
     final num overflowNumberWidth =
         numProducts > _maxThumbnailCount ? 30 * cappedTextScale(context) : 0;
-    return _cartIconWidth +
-        cartThumbnailGap +
-        thumbnailsWidth +
-        overflowNumberWidth;
+    return _cartIconWidth + cartThumbnailGap + thumbnailsWidth + overflowNumberWidth;
   }
 
   // Returns the correct height of the ExpandingBottomSheet based on the text scaling
@@ -331,10 +314,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
         min(numProducts, _maxThumbnailCount) * _paddedThumbnailHeight(context);
     final num overflowNumberHeight =
         numProducts > _maxThumbnailCount ? 28 * reducedTextScale(context) : 0;
-    return _cartIconHeight +
-        cartThumbnailGap +
-        thumbnailsHeight +
-        overflowNumberHeight;
+    return _cartIconHeight + cartThumbnailGap + thumbnailsHeight + overflowNumberHeight;
   }
 
   // Returns true if the cart is open or opening and false otherwise.
@@ -395,8 +375,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
           ),
           SizedBox(
             width: _width,
-            height: min(numProducts, _maxThumbnailCount) *
-                _paddedThumbnailHeight(context),
+            height: min(numProducts, _maxThumbnailCount) * _paddedThumbnailHeight(context),
             child: const ProductThumbnailRow(),
           ),
           const ExtraProductsNumber(),
@@ -414,8 +393,8 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
               ),
               Container(
                 // Accounts for the overflow number
-                width: min(numProducts, _maxThumbnailCount) *
-                        _paddedThumbnailHeight(context) +
+                width:
+                    min(numProducts, _maxThumbnailCount) * _paddedThumbnailHeight(context) +
                     (numProducts > 0 ? _thumbnailGap : 0),
                 height: _height - _bottomSafeArea,
                 padding: const EdgeInsets.symmetric(vertical: 8),
@@ -429,18 +408,12 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
     }
 
     return ExcludeSemantics(
-      child: Opacity(
-        opacity: _thumbnailOpacityAnimation.value,
-        child: thumbnails,
-      ),
+      child: Opacity(opacity: _thumbnailOpacityAnimation.value, child: thumbnails),
     );
   }
 
   Widget _buildShoppingCartPage() {
-    return Opacity(
-      opacity: _cartOpacityAnimation.value,
-      child: const ShoppingCartPage(),
-    );
+    return Opacity(opacity: _cartOpacityAnimation.value, child: const ShoppingCartPage());
   }
 
   Widget _buildCart(BuildContext context) {
@@ -455,25 +428,24 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
     final double screenWidth = screenSize.width;
     final double screenHeight = screenSize.height;
 
-    final double expandedCartWidth = isDesktop
-        ? (360 * cappedTextScale(context)).clamp(360, screenWidth).toDouble()
-        : screenWidth;
+    final double expandedCartWidth =
+        isDesktop
+            ? (360 * cappedTextScale(context)).clamp(360, screenWidth).toDouble()
+            : screenWidth;
 
-    _width = isDesktop
-        ? _desktopWidthFor(context)
-        : _mobileWidthFor(numProducts, context);
+    _width = isDesktop ? _desktopWidthFor(context) : _mobileWidthFor(numProducts, context);
     _widthAnimation = _getWidthAnimation(expandedCartWidth);
-    _height = isDesktop
-        ? _desktopHeightFor(numProducts, context)
-        : _mobileHeightFor(context) + _bottomSafeArea;
+    _height =
+        isDesktop
+            ? _desktopHeightFor(numProducts, context)
+            : _mobileHeightFor(context) + _bottomSafeArea;
     _heightAnimation = _getHeightAnimation(screenHeight);
     _topStartShapeAnimation = _getShapeTopStartAnimation(context);
     _bottomStartShapeAnimation = _getShapeBottomStartAnimation(context);
     _thumbnailOpacityAnimation = _getThumbnailOpacityAnimation();
     _cartOpacityAnimation = _getCartOpacityAnimation();
-    _gapAnimation = isDesktop
-        ? _getDesktopGapAnimation(116)
-        : const AlwaysStoppedAnimation<double>(0);
+    _gapAnimation =
+        isDesktop ? _getDesktopGapAnimation(116) : const AlwaysStoppedAnimation<double>(0);
 
     final Widget child = SizedBox(
       width: _widthAnimation.value,
@@ -488,33 +460,24 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
         ),
         elevation: 4,
         color: shrinePink50,
-        child: _cartIsVisible
-            ? _buildShoppingCartPage()
-            : _buildThumbnails(context, numProducts),
+        child: _cartIsVisible ? _buildShoppingCartPage() : _buildThumbnails(context, numProducts),
       ),
     );
 
-    final Widget childWithInteraction = productPageIsVisible(context)
-        ? Semantics(
-            button: true,
-            enabled: true,
-            label: GalleryLocalizations.of(context)!
-                .shrineScreenReaderCart(totalCartQuantity),
-            child: MouseRegion(
-              cursor: SystemMouseCursors.click,
-              child: GestureDetector(
-                behavior: HitTestBehavior.opaque,
-                onTap: open,
-                child: child,
+    final Widget childWithInteraction =
+        productPageIsVisible(context)
+            ? Semantics(
+              button: true,
+              enabled: true,
+              label: GalleryLocalizations.of(context)!.shrineScreenReaderCart(totalCartQuantity),
+              child: MouseRegion(
+                cursor: SystemMouseCursors.click,
+                child: GestureDetector(behavior: HitTestBehavior.opaque, onTap: open, child: child),
               ),
-            ),
-          )
-        : child;
+            )
+            : child;
 
-    return Padding(
-      padding: EdgeInsets.only(top: _gapAnimation.value),
-      child: childWithInteraction,
-    );
+    return Padding(padding: EdgeInsets.only(top: _gapAnimation.value), child: childWithInteraction);
   }
 
   // Builder for the hide and reveal animation when the backdrop opens and closes
@@ -524,8 +487,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
     if (isDesktop) {
       return child;
     } else {
-      final int textDirectionScalar =
-          Directionality.of(context) == TextDirection.ltr ? 1 : -1;
+      final int textDirectionScalar = Directionality.of(context) == TextDirection.ltr ? 1 : -1;
 
       _slideAnimation = _getEmphasizedEasingAnimation(
         begin: Offset(1.0 * textDirectionScalar, 0.0),
@@ -535,10 +497,7 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
         parent: widget.hideController,
       );
 
-      return SlideTransition(
-        position: _slideAnimation,
-        child: child,
-      );
+      return SlideTransition(position: _slideAnimation, child: child);
     }
   }
 
@@ -551,13 +510,16 @@ class ExpandingBottomSheetState extends State<ExpandingBottomSheet> {
       alignment: AlignmentDirectional.topStart,
       child: AnimatedBuilder(
         animation: widget.hideController,
-        builder: (BuildContext context, Widget? child) => AnimatedBuilder(
-          animation: widget.expandingController,
-          builder: (BuildContext context, Widget? child) => ScopedModelDescendant<AppStateModel>(
-            builder: (BuildContext context, Widget? child, AppStateModel model) =>
-                _buildSlideAnimation(context, _buildCart(context)),
-          ),
-        ),
+        builder:
+            (BuildContext context, Widget? child) => AnimatedBuilder(
+              animation: widget.expandingController,
+              builder:
+                  (BuildContext context, Widget? child) => ScopedModelDescendant<AppStateModel>(
+                    builder:
+                        (BuildContext context, Widget? child, AppStateModel model) =>
+                            _buildSlideAnimation(context, _buildCart(context)),
+                  ),
+            ),
       ),
     );
   }
@@ -585,8 +547,7 @@ class _ProductThumbnailRowState extends State<ProductThumbnailRow> {
     super.initState();
     _list = _ListModel(
       listKey: _listKey,
-      initialItems:
-          ScopedModel.of<AppStateModel>(context).productsInCart.keys.toList(),
+      initialItems: ScopedModel.of<AppStateModel>(context).productsInCart.keys.toList(),
       removedItemBuilder: _buildRemovedThumbnail,
     );
     _internalList = List<int>.from(_list.list);
@@ -598,18 +559,13 @@ class _ProductThumbnailRowState extends State<ProductThumbnailRow> {
     return product;
   }
 
-  Widget _buildRemovedThumbnail(
-      int item, BuildContext context, Animation<double> animation) {
+  Widget _buildRemovedThumbnail(int item, BuildContext context, Animation<double> animation) {
     return ProductThumbnail(animation, animation, _productWithId(item));
   }
 
-  Widget _buildThumbnail(
-      BuildContext context, int index, Animation<double> animation) {
+  Widget _buildThumbnail(BuildContext context, int index, Animation<double> animation) {
     final Animation<double> thumbnailSize = Tween<double>(begin: 0.8, end: 1).animate(
-      CurvedAnimation(
-        curve: const Interval(0.33, 1, curve: Curves.easeIn),
-        parent: animation,
-      ),
+      CurvedAnimation(curve: const Interval(0.33, 1, curve: Curves.easeIn), parent: animation),
     );
 
     final Animation<double> opacity = CurvedAnimation(
@@ -617,8 +573,7 @@ class _ProductThumbnailRowState extends State<ProductThumbnailRow> {
       parent: animation,
     );
 
-    return ProductThumbnail(
-        thumbnailSize, opacity, _productWithId(_list[index]));
+    return ProductThumbnail(thumbnailSize, opacity, _productWithId(_list[index]));
   }
 
   // If the lists are the same length, assume nothing has changed.
@@ -626,8 +581,7 @@ class _ProductThumbnailRowState extends State<ProductThumbnailRow> {
   // If the internalList is longer, then an item has been added.
   void _updateLists() {
     // Update _internalList based on the model
-    _internalList =
-        ScopedModel.of<AppStateModel>(context).productsInCart.keys.toList();
+    _internalList = ScopedModel.of<AppStateModel>(context).productsInCart.keys.toList();
     final Set<int> internalSet = Set<int>.from(_internalList);
     final Set<int> listSet = Set<int>.from(_list.list);
 
@@ -708,8 +662,7 @@ class ExtraProductsNumber extends StatelessWidget {
 
     final int numOverflowProducts = _calculateOverflow(model);
     // Maximum of 99 so padding doesn't get messy.
-    final int displayedOverflowProducts =
-        numOverflowProducts <= 99 ? numOverflowProducts : 99;
+    final int displayedOverflowProducts = numOverflowProducts <= 99 ? numOverflowProducts : 99;
     return Text(
       '+$displayedOverflowProducts',
       style: Theme.of(context).primaryTextTheme.labelLarge,
@@ -719,14 +672,15 @@ class ExtraProductsNumber extends StatelessWidget {
   @override
   Widget build(BuildContext context) {
     return ScopedModelDescendant<AppStateModel>(
-      builder: (BuildContext builder, Widget? child, AppStateModel model) => _buildOverflow(model, context),
+      builder:
+          (BuildContext builder, Widget? child, AppStateModel model) =>
+              _buildOverflow(model, context),
     );
   }
 }
 
 class ProductThumbnail extends StatelessWidget {
-  const ProductThumbnail(this.animation, this.opacityAnimation, this.product,
-      {super.key});
+  const ProductThumbnail(this.animation, this.opacityAnimation, this.product, {super.key});
 
   final Animation<double> animation;
   final Animation<double> opacityAnimation;
@@ -753,9 +707,10 @@ class ProductThumbnail extends StatelessWidget {
             ),
             borderRadius: const BorderRadius.all(Radius.circular(10)),
           ),
-          margin: isDesktop
-              ? const EdgeInsetsDirectional.only(start: 12, end: 12, bottom: 16)
-              : const EdgeInsetsDirectional.only(start: 16),
+          margin:
+              isDesktop
+                  ? const EdgeInsetsDirectional.only(start: 12, end: 12, bottom: 16)
+                  : const EdgeInsetsDirectional.only(start: 16),
         ),
       ),
     );
@@ -764,15 +719,11 @@ class ProductThumbnail extends StatelessWidget {
 
 // _ListModel manipulates an internal list and an AnimatedList
 class _ListModel {
-  _ListModel({
-    required this.listKey,
-    required this.removedItemBuilder,
-    Iterable<int>? initialItems,
-  }) : _items = initialItems?.toList() ?? <int>[];
+  _ListModel({required this.listKey, required this.removedItemBuilder, Iterable<int>? initialItems})
+    : _items = initialItems?.toList() ?? <int>[];
 
   final GlobalKey<AnimatedListState> listKey;
-  final Widget Function(int, BuildContext, Animation<double>)
-      removedItemBuilder;
+  final Widget Function(int, BuildContext, Animation<double>) removedItemBuilder;
   final List<int> _items;
 
   AnimatedListState? get _animatedList => listKey.currentState;
@@ -783,8 +734,7 @@ class _ListModel {
 
   void _insert(int index, int item) {
     _items.insert(index, item);
-    _animatedList!
-        .insertItem(index, duration: const Duration(milliseconds: 225));
+    _animatedList!.insertItem(index, duration: const Duration(milliseconds: 225));
   }
 
   void remove(int product) {
