@@ -15,8 +15,7 @@ Future<TestStepResult> systemNavigatorPop() {
   final Completer<TestStepResult> completer = Completer<TestStepResult>();
 
   channel.setMessageHandler((String? message) async {
-    completer.complete(
-        const TestStepResult('System navigation pop', '', TestStatus.ok));
+    completer.complete(const TestStepResult('System navigation pop', '', TestStatus.ok));
     return '';
   });
   SystemNavigator.pop();
