@@ -17,7 +17,7 @@ import 'package:web/web.dart' as web;
 // framework's ability to parse stack traces in all build modes.
 Future<void> main() async {
   final StringBuffer errorMessage = StringBuffer();
-  debugPrint = (String? message, { int? wrapWidth }) {
+  debugPrint = (String? message, {int? wrapWidth}) {
     errorMessage.writeln(message);
   };
 
@@ -29,19 +29,15 @@ Future<void> main() async {
   final StringBuffer output = StringBuffer();
   if (_errorMessageFormattedCorrectly(errorMessage.toString())) {
     output.writeln('--- TEST SUCCEEDED ---');
-  } else  {
+  } else {
     output.writeln('--- UNEXPECTED ERROR MESSAGE FORMAT ---');
     output.writeln(errorMessage);
     output.writeln('--- TEST FAILED ---');
   }
 
-  await web.window.fetch(
-    '/test-result'.toJS,
-    web.RequestInit(
-      method: 'POST',
-      body: '$output'.toJS,
-    )
-  ).toDart;
+  await web.window
+      .fetch('/test-result'.toJS, web.RequestInit(method: 'POST', body: '$output'.toJS))
+      .toDart;
   print(output);
 }
 
