@@ -5,7 +5,10 @@
 import 'template.dart';
 
 class BottomAppBarTemplate extends TokenTemplate {
-  const BottomAppBarTemplate(super.blockName, super.fileName, super.tokens, {
+  const BottomAppBarTemplate(
+    super.blockName,
+    super.fileName,
+    super.tokens, {
     super.colorSchemePrefix = '_colors.',
   });
 
@@ -15,7 +18,7 @@ class _${blockName}DefaultsM3 extends BottomAppBarTheme {
   _${blockName}DefaultsM3(this.context)
     : super(
       elevation: ${elevation('md.comp.bottom-app-bar.container')},
-      height: ${tokens['md.comp.bottom-app-bar.container.height']},
+      height: ${getToken('md.comp.bottom-app-bar.container.height')},
       shape: const AutomaticNotchedShape(${shape('md.comp.bottom-app-bar.container', '')}),
     );
 
@@ -26,7 +29,7 @@ class _${blockName}DefaultsM3 extends BottomAppBarTheme {
   Color? get color => ${componentColor('md.comp.bottom-app-bar.container')};
 
   @override
-  Color? get surfaceTintColor => ${componentColor('md.comp.bottom-app-bar.container.surface-tint-layer')};
+  Color? get surfaceTintColor => ${colorOrTransparent('md.comp.bottom-app-bar.container.surface-tint-layer')};
 
   @override
   Color? get shadowColor => Colors.transparent;
