@@ -26,32 +26,18 @@ class CupertinoButtonExample extends StatelessWidget {
   @override
   Widget build(BuildContext context) {
     return CupertinoPageScaffold(
-      navigationBar: const CupertinoNavigationBar(
-        middle: Text('CupertinoButton Sample'),
-      ),
+      navigationBar: const CupertinoNavigationBar(middle: Text('CupertinoButton Sample')),
       child: Center(
         child: Column(
           mainAxisSize: MainAxisSize.min,
           children: <Widget>[
-            const CupertinoButton(
-              onPressed: null,
-              child: Text('Disabled'),
-            ),
+            const CupertinoButton(onPressed: null, child: Text('Disabled')),
             const SizedBox(height: 30),
-            const CupertinoButton.filled(
-              onPressed: null,
-              child: Text('Disabled'),
-            ),
+            const CupertinoButton.filled(onPressed: null, child: Text('Disabled')),
             const SizedBox(height: 30),
-            CupertinoButton(
-              onPressed: () {},
-              child: const Text('Enabled'),
-            ),
+            CupertinoButton(onPressed: () {}, child: const Text('Enabled')),
             const SizedBox(height: 30),
-            CupertinoButton.filled(
-              onPressed: () {},
-              child: const Text('Enabled'),
-            ),
+            CupertinoButton.filled(onPressed: () {}, child: const Text('Enabled')),
           ],
         ),
       ),
