@@ -2,10 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for BottomAppBar
-
 import 'package:flutter/material.dart';
 
+/// Flutter code sample for [BottomAppBar].
+
 void main() {
   runApp(const BottomAppBarDemo());
 }
@@ -20,8 +20,7 @@ class BottomAppBarDemo extends StatefulWidget {
 class _BottomAppBarDemoState extends State<BottomAppBarDemo> {
   bool _showFab = true;
   bool _showNotch = true;
-  FloatingActionButtonLocation _fabLocation =
-      FloatingActionButtonLocation.endDocked;
+  FloatingActionButtonLocation _fabLocation = FloatingActionButtonLocation.endDocked;
 
   void _onShowNotchChanged(bool value) {
     setState(() {
@@ -45,17 +44,12 @@ class _BottomAppBarDemoState extends State<BottomAppBarDemo> {
   Widget build(BuildContext context) {
     return MaterialApp(
       home: Scaffold(
-        appBar: AppBar(
-          automaticallyImplyLeading: false,
-          title: const Text('Bottom App Bar Demo'),
-        ),
+        appBar: AppBar(automaticallyImplyLeading: false, title: const Text('Bottom App Bar Demo')),
         body: ListView(
           padding: const EdgeInsets.only(bottom: 88),
           children: <Widget>[
             SwitchListTile(
-              title: const Text(
-                'Floating Action Button',
-              ),
+              title: const Text('Floating Action Button'),
               value: _showFab,
               onChanged: _onShowFabChanged,
             ),
@@ -94,13 +88,14 @@ class _BottomAppBarDemoState extends State<BottomAppBarDemo> {
             ),
           ],
         ),
-        floatingActionButton: _showFab
-            ? FloatingActionButton(
-                onPressed: () {},
-                tooltip: 'Create',
-                child: const Icon(Icons.add),
-              )
-            : null,
+        floatingActionButton:
+            _showFab
+                ? FloatingActionButton(
+                  onPressed: () {},
+                  tooltip: 'Create',
+                  child: const Icon(Icons.add),
+                )
+                : null,
         floatingActionButtonLocation: _fabLocation,
         bottomNavigationBar: _DemoBottomAppBar(
           fabLocation: _fabLocation,
@@ -120,8 +115,7 @@ class _DemoBottomAppBar extends StatelessWidget {
   final FloatingActionButtonLocation fabLocation;
   final NotchedShape? shape;
 
-  static final List<FloatingActionButtonLocation> centerLocations =
-      <FloatingActionButtonLocation>[
+  static final List<FloatingActionButtonLocation> centerLocations = <FloatingActionButtonLocation>[
     FloatingActionButtonLocation.centerDocked,
     FloatingActionButtonLocation.centerFloat,
   ];
@@ -141,16 +135,8 @@ class _DemoBottomAppBar extends StatelessWidget {
               onPressed: () {},
             ),
             if (centerLocations.contains(fabLocation)) const Spacer(),
-            IconButton(
-              tooltip: 'Search',
-              icon: const Icon(Icons.search),
-              onPressed: () {},
-            ),
-            IconButton(
-              tooltip: 'Favorite',
-              icon: const Icon(Icons.favorite),
-              onPressed: () {},
-            ),
+            IconButton(tooltip: 'Search', icon: const Icon(Icons.search), onPressed: () {}),
+            IconButton(tooltip: 'Favorite', icon: const Icon(Icons.favorite), onPressed: () {}),
           ],
         ),
       ),
