@@ -13,10 +13,7 @@ class CustomListItemApp extends StatelessWidget {
 
   @override
   Widget build(BuildContext context) {
-    return MaterialApp(
-      theme: ThemeData(useMaterial3: true),
-      home: const CustomListItemExample(),
-    );
+    return const MaterialApp(home: CustomListItemExample());
   }
 }
 
@@ -44,9 +41,7 @@ class _ArticleDescription extends StatelessWidget {
           title,
           maxLines: 2,
           overflow: TextOverflow.ellipsis,
-          style: const TextStyle(
-            fontWeight: FontWeight.bold,
-          ),
+          style: const TextStyle(fontWeight: FontWeight.bold),
         ),
         const Padding(padding: EdgeInsets.only(bottom: 2.0)),
         Expanded(
@@ -54,25 +49,13 @@ class _ArticleDescription extends StatelessWidget {
             subtitle,
             maxLines: 2,
             overflow: TextOverflow.ellipsis,
-            style: const TextStyle(
-              fontSize: 12.0,
-              color: Colors.black54,
-            ),
-          ),
-        ),
-        Text(
-          author,
-          style: const TextStyle(
-            fontSize: 12.0,
-            color: Colors.black87,
+            style: const TextStyle(fontSize: 12.0, color: Colors.black54),
           ),
         ),
+        Text(author, style: const TextStyle(fontSize: 12.0, color: Colors.black87)),
         Text(
           '$publishDate - $readDuration',
-          style: const TextStyle(
-            fontSize: 12.0,
-            color: Colors.black54,
-          ),
+          style: const TextStyle(fontSize: 12.0, color: Colors.black54),
         ),
       ],
     );
@@ -106,10 +89,7 @@ class CustomListItemTwo extends StatelessWidget {
         child: Row(
           crossAxisAlignment: CrossAxisAlignment.start,
           children: <Widget>[
-            AspectRatio(
-              aspectRatio: 1.0,
-              child: thumbnail,
-            ),
+            AspectRatio(aspectRatio: 1.0, child: thumbnail),
             Expanded(
               child: Padding(
                 padding: const EdgeInsets.fromLTRB(20.0, 0.0, 2.0, 0.0),
@@ -140,20 +120,17 @@ class CustomListItemExample extends StatelessWidget {
         padding: const EdgeInsets.all(10.0),
         children: <Widget>[
           CustomListItemTwo(
-            thumbnail: Container(
-              decoration: const BoxDecoration(color: Colors.pink),
-            ),
+            thumbnail: Container(decoration: const BoxDecoration(color: Colors.pink)),
             title: 'Flutter 1.0 Launch',
-            subtitle: 'Flutter continues to improve and expand its horizons. '
+            subtitle:
+                'Flutter continues to improve and expand its horizons. '
                 'This text should max out at two lines and clip',
             author: 'Dash',
             publishDate: 'Dec 28',
             readDuration: '5 mins',
           ),
           CustomListItemTwo(
-            thumbnail: Container(
-              decoration: const BoxDecoration(color: Colors.blue),
-            ),
+            thumbnail: Container(decoration: const BoxDecoration(color: Colors.blue)),
             title: 'Flutter 1.2 Release - Continual updates to the framework',
             subtitle: 'Flutter once again improves and makes updates.',
             author: 'Flutter',
