@@ -13,10 +13,7 @@ class RadioListTileApp extends StatelessWidget {
 
   @override
   Widget build(BuildContext context) {
-    return MaterialApp(
-      theme: ThemeData(useMaterial3: true),
-      home: const RadioListTileExample(),
-    );
+    return const MaterialApp(home: RadioListTileExample());
   }
 }
 
@@ -59,7 +56,8 @@ class _RadioListTileExampleState extends State<RadioListTileExample> {
             },
             title: const Text('Tomato'),
             subtitle: const Text(
-                'Longer supporting text to demonstrate how the text wraps and the radio is centered vertically with the text.'),
+              'Longer supporting text to demonstrate how the text wraps and the radio is centered vertically with the text.',
+            ),
           ),
           RadioListTile<Groceries>(
             value: Groceries.lettuce,
@@ -71,7 +69,8 @@ class _RadioListTileExampleState extends State<RadioListTileExample> {
             },
             title: const Text('Lettuce'),
             subtitle: const Text(
-                "Longer supporting text to demonstrate how the text wraps and how setting 'RadioListTile.isThreeLine = true' aligns the radio to the top vertically with the text."),
+              "Longer supporting text to demonstrate how the text wraps and how setting 'RadioListTile.isThreeLine = true' aligns the radio to the top vertically with the text.",
+            ),
             isThreeLine: true,
           ),
         ],
