@@ -14,12 +14,9 @@ class SwitchListTileApp extends StatelessWidget {
   @override
   Widget build(BuildContext context) {
     return MaterialApp(
-      theme: ThemeData(useMaterial3: true),
       home: Scaffold(
         appBar: AppBar(title: const Text('SwitchListTile Sample')),
-        body: const Center(
-          child: SwitchListTileExample(),
-        ),
+        body: const Center(child: SwitchListTileExample()),
       ),
     );
   }
