@@ -14,9 +14,7 @@ class TextFormFieldExampleApp extends StatelessWidget {
 
   @override
   Widget build(BuildContext context) {
-    return const MaterialApp(
-      home: TextFormFieldExample(),
-    );
+    return const MaterialApp(home: TextFormFieldExample());
   }
 }
 
