@@ -2,26 +2,22 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for Tooltip
-
 import 'package:flutter/material.dart';
 
-void main() => runApp(const MyApp());
+/// Flutter code sample for [Tooltip].
 
-class MyApp extends StatelessWidget {
-  const MyApp({super.key});
+void main() => runApp(const TooltipExampleApp());
 
-  static const String _title = 'Tooltip Sample';
+class TooltipExampleApp extends StatelessWidget {
+  const TooltipExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
     return MaterialApp(
-      title: _title,
+      theme: ThemeData(tooltipTheme: const TooltipThemeData(preferBelow: false)),
       home: Scaffold(
-        appBar: AppBar(title: const Text(_title)),
-        body: const Center(
-          child: TooltipSample(),
-        ),
+        appBar: AppBar(title: const Text('Tooltip Sample')),
+        body: const Center(child: TooltipSample()),
       ),
     );
   }
@@ -36,15 +32,12 @@ class TooltipSample extends StatelessWidget {
       message: 'I am a Tooltip',
       decoration: BoxDecoration(
         borderRadius: BorderRadius.circular(25),
-        gradient:
-            const LinearGradient(colors: <Color>[Colors.amber, Colors.red]),
+        gradient: const LinearGradient(colors: <Color>[Colors.amber, Colors.red]),
       ),
-      height: 50,
+      constraints: const BoxConstraints(minWidth: 250),
       padding: const EdgeInsets.all(8.0),
-      preferBelow: false,
-      textStyle: const TextStyle(
-        fontSize: 24,
-      ),
+      preferBelow: true,
+      textStyle: const TextStyle(fontSize: 24),
       showDuration: const Duration(seconds: 2),
       waitDuration: const Duration(seconds: 1),
       child: const Text('Tap this text and hold down to show a tooltip.'),
