@@ -2,11 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import 'dart:ui';
-
 import 'package:flutter/widgets.dart';
 
-/// Flutter code sample for [FontFeature.FontFeature.caseSensitiveForms].
+/// Flutter code sample for [FontFeature.caseSensitiveForms].
 
 void main() => runApp(const ExampleApp());
 
@@ -33,9 +31,7 @@ class ExampleWidget extends StatelessWidget {
       '(A) [A] {A} «A» A/B A•B',
       style: TextStyle(
         fontFamily: 'Piazzolla',
-        fontFeatures: <FontFeature>[
-          FontFeature.caseSensitiveForms(),
-        ],
+        fontFeatures: <FontFeature>[FontFeature.caseSensitiveForms()],
       ),
     );
   }
