@@ -2,11 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for FontFeature.FontFeature.liningFigures
-import 'dart:ui';
-
 import 'package:flutter/widgets.dart';
 
+/// Flutter code sample for [FontFeature.liningFigures].
+
 void main() => runApp(const ExampleApp());
 
 class ExampleApp extends StatelessWidget {
@@ -26,14 +25,13 @@ class ExampleWidget extends StatelessWidget {
 
   @override
   Widget build(BuildContext context) {
-    // The Sorts Mill Goudy font can be downloaded from Google Fonts (https://www.google.com/fonts).
+    // The Sorts Mill Goudy font can be downloaded from Google Fonts
+    // (https://www.google.com/fonts).
     return const Text(
       'CALL 311-555-2368 NOW!',
       style: TextStyle(
         fontFamily: 'Sorts Mill Goudy',
-        fontFeatures: <FontFeature>[
-          FontFeature.liningFigures(),
-        ],
+        fontFeatures: <FontFeature>[FontFeature.liningFigures()],
       ),
     );
   }
