@@ -4,7 +4,7 @@
 
 import 'package:flutter/widgets.dart';
 
-/// Flutter code sample for [FontFeature.FontFeature.oldstyleFigures].
+/// Flutter code sample for [FontFeature.oldstyleFigures].
 
 void main() => runApp(const ExampleApp());
 
@@ -31,9 +31,7 @@ class ExampleWidget extends StatelessWidget {
       'Call 311-555-2368 now!',
       style: TextStyle(
         fontFamily: 'Piazzolla',
-        fontFeatures: <FontFeature>[
-          FontFeature.oldstyleFigures(),
-        ],
+        fontFeatures: <FontFeature>[FontFeature.oldstyleFigures()],
       ),
     );
   }
