@@ -2,11 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import 'dart:ui';
-
 import 'package:flutter/widgets.dart';
 
-/// Flutter code sample for [FontFeature.FontFeature.scientificInferiors].
+/// Flutter code sample for [FontFeature.scientificInferiors].
 
 void main() => runApp(const ExampleApp());
 
@@ -33,9 +31,7 @@ class ExampleWidget extends StatelessWidget {
       'C8H10N4O2',
       style: TextStyle(
         fontFamily: 'Piazzolla',
-        fontFeatures: <FontFeature>[
-          FontFeature.scientificInferiors(),
-        ],
+        fontFeatures: <FontFeature>[FontFeature.scientificInferiors()],
       ),
     );
   }
