@@ -2,11 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import 'dart:ui';
-
 import 'package:flutter/widgets.dart';
 
-/// Flutter code sample for [dart]:ui FontFeature.FontFeature.tabularFigures.
+/// Flutter code sample for [FontFeature.tabularFigures].
 
 void main() => runApp(const ExampleApp());
 
@@ -33,9 +31,7 @@ class ExampleWidget extends StatelessWidget {
       'Call 311-555-2368 now!',
       style: TextStyle(
         fontFamily: 'Piazzolla',
-        fontFeatures: <FontFeature>[
-          FontFeature.tabularFigures(),
-        ],
+        fontFeatures: <FontFeature>[FontFeature.tabularFigures()],
       ),
     );
   }
