@@ -8,13 +8,13 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('Has 2 CupertinoRadio widgets', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const example.CupertinoRadioApp(),
-    );
+    await tester.pumpWidget(const example.CupertinoRadioApp());
 
     expect(find.byType(CupertinoRadio<example.SingingCharacter>), findsNWidgets(2));
 
-    CupertinoRadio<example.SingingCharacter> radio = tester.widget(find.byType(CupertinoRadio<example.SingingCharacter>).first);
+    CupertinoRadio<example.SingingCharacter> radio = tester.widget(
+      find.byType(CupertinoRadio<example.SingingCharacter>).first,
+    );
     expect(radio.groupValue, example.SingingCharacter.lafayette);
 
     radio = tester.widget(find.byType(CupertinoRadio<example.SingingCharacter>).last);
