@@ -4,14 +4,12 @@
 
 import 'package:flutter/cupertino.dart';
 import 'package:flutter_api_samples/cupertino/text_form_field_row/cupertino_text_form_field_row.1.dart'
-  as example;
+    as example;
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('Can enter text in CupertinoTextFormFieldRow', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const example.FormSectionApp(),
-    );
+    await tester.pumpWidget(const example.FormSectionApp());
 
     expect(find.byType(CupertinoFormSection), findsOneWidget);
     expect(find.byType(CupertinoTextFormFieldRow), findsNWidgets(5));
