@@ -2,7 +2,6 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import 'package:flutter/material.dart';
 import 'package:flutter_api_samples/material/dialog/dialog.0.dart' as example;
 import 'package:flutter_test/flutter_test.dart';
 
@@ -10,13 +9,7 @@ void main() {
   testWidgets('Show Dialog', (WidgetTester tester) async {
     const String dialogText = 'This is a typical dialog.';
 
-    await tester.pumpWidget(
-      const MaterialApp(
-        home: Scaffold(
-          body: example.DialogExampleApp(),
-        ),
-      ),
-    );
+    await tester.pumpWidget(const example.DialogExampleApp());
 
     expect(find.text(dialogText), findsNothing);
 
@@ -32,13 +25,7 @@ void main() {
   testWidgets('Show Dialog.fullscreen', (WidgetTester tester) async {
     const String dialogText = 'This is a fullscreen dialog.';
 
-    await tester.pumpWidget(
-      const MaterialApp(
-        home: Scaffold(
-          body: example.DialogExampleApp(),
-        ),
-      ),
-    );
+    await tester.pumpWidget(const example.DialogExampleApp());
 
     expect(find.text(dialogText), findsNothing);
 
