@@ -3,15 +3,14 @@
 // found in the LICENSE file.
 
 import 'package:flutter/material.dart';
-import 'package:flutter_api_samples/material/segmented_button/segmented_button.1.dart'
-    as example;
+import 'package:flutter_api_samples/material/segmented_button/segmented_button.1.dart' as example;
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
-  testWidgets('Can use SegmentedButton.styleFrom to customize SegmentedButton', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const example.SegmentedButtonApp(),
-    );
+  testWidgets('Can use SegmentedButton.styleFrom to customize SegmentedButton', (
+    WidgetTester tester,
+  ) async {
+    await tester.pumpWidget(const example.SegmentedButtonApp());
 
     final Color unselectedBackgroundColor = Colors.grey[200]!;
     const Color unselectedForegroundColor = Colors.red;
@@ -19,10 +18,9 @@ void main() {
     const Color selectedForegroundColor = Colors.white;
 
     Material getMaterial(String text) {
-      return tester.widget<Material>(find.ancestor(
-        of: find.text(text),
-        matching: find.byType(Material),
-      ).first);
+      return tester.widget<Material>(
+        find.ancestor(of: find.text(text), matching: find.byType(Material)).first,
+      );
     }
 
     // Verify the unselected button style.
