@@ -3,20 +3,19 @@
 // found in the LICENSE file.
 
 import 'package:flutter/material.dart';
-import 'package:flutter_api_samples/ui/text/font_feature.font_feature_denominator.0.dart' as example;
+import 'package:flutter_api_samples/ui/text/font_feature.font_feature_denominator.0.dart'
+    as example;
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('shows font features', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const MaterialApp(
-        home: example.ExampleWidget(),
-      ),
-    );
+    await tester.pumpWidget(const MaterialApp(home: example.ExampleWidget()));
 
     expect(find.byType(Text), findsOneWidget);
     expect((tester.widget(find.byType(Text).first) as Text).style!.fontFamily, equals('Piazzolla'));
-    expect((tester.widget(find.byType(Text).first) as Text).style!.fontFeatures,
-        equals(const <FontFeature>[FontFeature.denominator()]));
+    expect(
+      (tester.widget(find.byType(Text).first) as Text).style!.fontFeatures,
+      equals(const <FontFeature>[FontFeature.denominator()]),
+    );
   });
 }
