@@ -8,9 +8,7 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('Clicking on the menu icon opens the Flow menu', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const example.FlowApp(),
-    );
+    await tester.pumpWidget(const example.FlowApp());
 
     // The menu icon is in the top left corner of the screen.
     Offset menuIcon = tester.getCenter(find.byIcon(Icons.menu));
