@@ -17,7 +17,7 @@ class SectorConstraints extends Constraints {
   }) : assert(maxDeltaRadius >= minDeltaRadius),
        assert(maxDeltaTheta >= minDeltaTheta);
 
-  const SectorConstraints.tight({ double deltaRadius = 0.0, double deltaTheta = 0.0 })
+  const SectorConstraints.tight({double deltaRadius = 0.0, double deltaTheta = 0.0})
     : minDeltaRadius = deltaRadius,
       maxDeltaRadius = deltaRadius,
       minDeltaTheta = deltaTheta,
@@ -53,7 +53,7 @@ class SectorConstraints extends Constraints {
 }
 
 class SectorDimensions {
-  const SectorDimensions({ this.deltaRadius = 0.0, this.deltaTheta = 0.0 });
+  const SectorDimensions({this.deltaRadius = 0.0, this.deltaTheta = 0.0});
 
   factory SectorDimensions.withConstraints(
     SectorConstraints constraints, {
@@ -88,11 +88,11 @@ class SectorParentData extends ParentData {
 ///  * [RenderBox], which is the base class for [RenderObject]s that live in a
 ///    Cartesian coordinate space.
 abstract class RenderSector extends RenderObject {
-
   @override
   void setupParentData(RenderObject child) {
-    if (child.parentData is! SectorParentData)
+    if (child.parentData is! SectorParentData) {
       child.parentData = SectorParentData();
+    }
   }
 
   // RenderSectors always use SectorParentData subclasses, as they need to be
@@ -109,10 +109,7 @@ abstract class RenderSector extends RenderObject {
 
   @override
   void debugAssertDoesMeetConstraints() {
-    assert(constraints != null);
-    assert(deltaRadius != null);
     assert(deltaRadius < double.infinity);
-    assert(deltaTheta != null);
     assert(deltaTheta < double.infinity);
     assert(constraints.minDeltaRadius <= deltaRadius);
     assert(deltaRadius <= math.max(constraints.minDeltaRadius, constraints.maxDeltaRadius));
@@ -139,31 +136,40 @@ abstract class RenderSector extends RenderObject {
   Rect get paintBounds => Rect.fromLTWH(0.0, 0.0, 2.0 * deltaRadius, 2.0 * deltaRadius);
 
   @override
-  Rect get semanticBounds => Rect.fromLTWH(-deltaRadius, -deltaRadius, 2.0 * deltaRadius, 2.0 * deltaRadius);
+  Rect get semanticBounds =>
+      Rect.fromLTWH(-deltaRadius, -deltaRadius, 2.0 * deltaRadius, 2.0 * deltaRadius);
 
-  bool hitTest(SectorHitTestResult result, { required double radius, required double theta }) {
-    if (radius < parentData!.radius || radius >= parentData!.radius + deltaRadius ||
-        theta < parentData!.theta || theta >= parentData!.theta + deltaTheta)
+  bool hitTest(SectorHitTestResult result, {required double radius, required double theta}) {
+    if (radius < parentData!.radius ||
+        radius >= parentData!.radius + deltaRadius ||
+        theta < parentData!.theta ||
+        theta >= parentData!.theta + deltaTheta) {
       return false;
+    }
     hitTestChildren(result, radius: radius, theta: theta);
     result.add(SectorHitTestEntry(this, radius: radius, theta: theta));
     return true;
   }
-  void hitTestChildren(SectorHitTestResult result, { required double radius, required double theta }) { }
+
+  void hitTestChildren(
+    SectorHitTestResult result, {
+    required double radius,
+    required double theta,
+  }) {}
 
   late double deltaRadius;
   late double deltaTheta;
 }
 
 abstract class RenderDecoratedSector extends RenderSector {
-
   RenderDecoratedSector(BoxDecoration? decoration) : _decoration = decoration;
 
   BoxDecoration? _decoration;
   BoxDecoration? get decoration => _decoration;
   set decoration(BoxDecoration? value) {
-    if (value == _decoration)
+    if (value == _decoration) {
       return;
+    }
     _decoration = value;
     markNeedsPaint();
   }
@@ -171,42 +177,58 @@ abstract class RenderDecoratedSector extends RenderSector {
   // offset must point to the center of the circle
   @override
   void paint(PaintingContext context, Offset offset) {
-    assert(deltaRadius != null);
-    assert(deltaTheta != null);
     assert(parentData is SectorParentData);
 
-    if (_decoration == null)
+    if (_decoration == null) {
       return;
+    }
 
     if (_decoration!.color != null) {
       final Canvas canvas = context.canvas;
       final Paint paint = Paint()..color = _decoration!.color!;
       final Path path = Path();
       final double outerRadius = parentData!.radius + deltaRadius;
-      final Rect outerBounds = Rect.fromLTRB(offset.dx-outerRadius, offset.dy-outerRadius, offset.dx+outerRadius, offset.dy+outerRadius);
+      final Rect outerBounds = Rect.fromLTRB(
+        offset.dx - outerRadius,
+        offset.dy - outerRadius,
+        offset.dx + outerRadius,
+        offset.dy + outerRadius,
+      );
       path.arcTo(outerBounds, parentData!.theta, deltaTheta, true);
       final double innerRadius = parentData!.radius;
-      final Rect innerBounds = Rect.fromLTRB(offset.dx-innerRadius, offset.dy-innerRadius, offset.dx+innerRadius, offset.dy+innerRadius);
+      final Rect innerBounds = Rect.fromLTRB(
+        offset.dx - innerRadius,
+        offset.dy - innerRadius,
+        offset.dx + innerRadius,
+        offset.dy + innerRadius,
+      );
       path.arcTo(innerBounds, parentData!.theta + deltaTheta, -deltaTheta, false);
       path.close();
       canvas.drawPath(path, paint);
     }
   }
-
 }
 
-class SectorChildListParentData extends SectorParentData with ContainerParentDataMixin<RenderSector> { }
+class SectorChildListParentData extends SectorParentData
+    with ContainerParentDataMixin<RenderSector> {}
 
-class RenderSectorWithChildren extends RenderDecoratedSector with ContainerRenderObjectMixin<RenderSector, SectorChildListParentData> {
+class RenderSectorWithChildren extends RenderDecoratedSector
+    with ContainerRenderObjectMixin<RenderSector, SectorChildListParentData> {
   RenderSectorWithChildren(super.decoration);
 
   @override
-  void hitTestChildren(SectorHitTestResult result, { required double radius, required double theta }) {
+  void hitTestChildren(
+    SectorHitTestResult result, {
+    required double radius,
+    required double theta,
+  }) {
     RenderSector? child = lastChild;
     while (child != null) {
-      if (child.hitTest(result, radius: radius, theta: theta))
+      if (child.hitTest(result, radius: radius, theta: theta)) {
         return;
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      }
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.previousSibling;
     }
   }
@@ -216,7 +238,8 @@ class RenderSectorWithChildren extends RenderDecoratedSector with ContainerRende
     RenderSector? child = lastChild;
     while (child != null) {
       visitor(child);
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.previousSibling;
     }
   }
@@ -237,7 +260,6 @@ class RenderSectorRing extends RenderSectorWithChildren {
   double _desiredDeltaRadius;
   double get desiredDeltaRadius => _desiredDeltaRadius;
   set desiredDeltaRadius(double value) {
-    assert(value != null);
     assert(value >= 0);
     if (_desiredDeltaRadius != value) {
       _desiredDeltaRadius = value;
@@ -249,7 +271,6 @@ class RenderSectorRing extends RenderSectorWithChildren {
   double get padding => _padding;
   set padding(double value) {
     // TODO(ianh): avoid code duplication
-    assert(value != null);
     if (_padding != value) {
       _padding = value;
       markNeedsLayout();
@@ -259,8 +280,9 @@ class RenderSectorRing extends RenderSectorWithChildren {
   @override
   void setupParentData(RenderObject child) {
     // TODO(ianh): avoid code duplication
-    if (child.parentData is! SectorChildListParentData)
+    if (child.parentData is! SectorChildListParentData) {
       child.parentData = SectorChildListParentData();
+    }
   }
 
   @override
@@ -270,17 +292,24 @@ class RenderSectorRing extends RenderSectorWithChildren {
     final double childRadius = radius + padding;
     final double paddingTheta = math.atan(padding / (radius + outerDeltaRadius));
     double innerTheta = paddingTheta; // increments with each child
-    double remainingDeltaTheta = math.max(0.0, constraints.maxDeltaTheta - (innerTheta + paddingTheta));
+    double remainingDeltaTheta = math.max(
+      0.0,
+      constraints.maxDeltaTheta - (innerTheta + paddingTheta),
+    );
     RenderSector? child = firstChild;
     while (child != null) {
       final SectorConstraints innerConstraints = SectorConstraints(
         maxDeltaRadius: innerDeltaRadius,
         maxDeltaTheta: remainingDeltaTheta,
       );
-      final SectorDimensions childDimensions = child.getIntrinsicDimensions(innerConstraints, childRadius);
+      final SectorDimensions childDimensions = child.getIntrinsicDimensions(
+        innerConstraints,
+        childRadius,
+      );
       innerTheta += childDimensions.deltaTheta;
       remainingDeltaTheta -= childDimensions.deltaTheta;
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
       if (child != null) {
         innerTheta += paddingTheta;
@@ -316,7 +345,8 @@ class RenderSectorRing extends RenderSectorWithChildren {
       child.layout(innerConstraints, parentUsesSize: true);
       innerTheta += child.deltaTheta;
       remainingDeltaTheta -= child.deltaTheta;
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
       if (child != null) {
         innerTheta += paddingTheta;
@@ -335,26 +365,24 @@ class RenderSectorRing extends RenderSectorWithChildren {
     RenderSector? child = firstChild;
     while (child != null) {
       context.paintChild(child, offset);
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
     }
   }
-
 }
 
 class RenderSectorSlice extends RenderSectorWithChildren {
   // lays out RenderSector children in a stack
 
-  RenderSectorSlice({
-    BoxDecoration? decoration,
-    double deltaTheta = kTwoPi,
-    double padding = 0.0,
-  }) : _padding = padding, _desiredDeltaTheta = deltaTheta, super(decoration);
+  RenderSectorSlice({BoxDecoration? decoration, double deltaTheta = kTwoPi, double padding = 0.0})
+    : _padding = padding,
+      _desiredDeltaTheta = deltaTheta,
+      super(decoration);
 
   double _desiredDeltaTheta;
   double get desiredDeltaTheta => _desiredDeltaTheta;
   set desiredDeltaTheta(double value) {
-    assert(value != null);
     if (_desiredDeltaTheta != value) {
       _desiredDeltaTheta = value;
       markNeedsLayout();
@@ -365,7 +393,6 @@ class RenderSectorSlice extends RenderSectorWithChildren {
   double get padding => _padding;
   set padding(double value) {
     // TODO(ianh): avoid code duplication
-    assert(value != null);
     if (_padding != value) {
       _padding = value;
       markNeedsLayout();
@@ -375,8 +402,9 @@ class RenderSectorSlice extends RenderSectorWithChildren {
   @override
   void setupParentData(RenderObject child) {
     // TODO(ianh): avoid code duplication
-    if (child.parentData is! SectorChildListParentData)
+    if (child.parentData is! SectorChildListParentData) {
       child.parentData = SectorChildListParentData();
+    }
   }
 
   @override
@@ -393,10 +421,14 @@ class RenderSectorSlice extends RenderSectorWithChildren {
         maxDeltaRadius: remainingDeltaRadius,
         maxDeltaTheta: innerDeltaTheta,
       );
-      final SectorDimensions childDimensions = child.getIntrinsicDimensions(innerConstraints, childRadius);
+      final SectorDimensions childDimensions = child.getIntrinsicDimensions(
+        innerConstraints,
+        childRadius,
+      );
       childRadius += childDimensions.deltaRadius;
       remainingDeltaRadius -= childDimensions.deltaRadius;
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
       childRadius += padding;
       remainingDeltaRadius -= padding;
@@ -429,7 +461,8 @@ class RenderSectorSlice extends RenderSectorWithChildren {
       child.layout(innerConstraints, parentUsesSize: true);
       childRadius += child.deltaRadius;
       remainingDeltaRadius -= child.deltaRadius;
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
       childRadius += padding;
       remainingDeltaRadius -= padding;
@@ -447,15 +480,16 @@ class RenderSectorSlice extends RenderSectorWithChildren {
     while (child != null) {
       assert(child.parentData is SectorChildListParentData);
       context.paintChild(child, offset);
-      final SectorChildListParentData childParentData = child.parentData! as SectorChildListParentData;
+      final SectorChildListParentData childParentData =
+          child.parentData! as SectorChildListParentData;
       child = childParentData.nextSibling;
     }
   }
-
 }
 
-class RenderBoxToRenderSectorAdapter extends RenderBox with RenderObjectWithChildMixin<RenderSector> {
-  RenderBoxToRenderSectorAdapter({ double innerRadius = 0.0, RenderSector? child })
+class RenderBoxToRenderSectorAdapter extends RenderBox
+    with RenderObjectWithChildMixin<RenderSector> {
+  RenderBoxToRenderSectorAdapter({double innerRadius = 0.0, RenderSector? child})
     : _innerRadius = innerRadius {
     this.child = child;
   }
@@ -469,50 +503,54 @@ class RenderBoxToRenderSectorAdapter extends RenderBox with RenderObjectWithChil
 
   @override
   void setupParentData(RenderObject child) {
-    if (child.parentData is! SectorParentData)
+    if (child.parentData is! SectorParentData) {
       child.parentData = SectorParentData();
+    }
   }
 
   @override
   double computeMinIntrinsicWidth(double height) {
-    if (child == null)
+    if (child == null) {
       return 0.0;
+    }
     return getIntrinsicDimensions(height: height).width;
   }
 
   @override
   double computeMaxIntrinsicWidth(double height) {
-    if (child == null)
+    if (child == null) {
       return 0.0;
+    }
     return getIntrinsicDimensions(height: height).width;
   }
 
   @override
   double computeMinIntrinsicHeight(double width) {
-    if (child == null)
+    if (child == null) {
       return 0.0;
+    }
     return getIntrinsicDimensions(width: width).height;
   }
 
   @override
   double computeMaxIntrinsicHeight(double width) {
-    if (child == null)
+    if (child == null) {
       return 0.0;
+    }
     return getIntrinsicDimensions(width: width).height;
   }
 
-  Size getIntrinsicDimensions({
-    double width = double.infinity,
-    double height = double.infinity,
-  }) {
+  Size getIntrinsicDimensions({double width = double.infinity, double height = double.infinity}) {
     assert(child is RenderSector);
     assert(child!.parentData is SectorParentData);
-    assert(width != null);
-    assert(height != null);
-    if (!width.isFinite && !height.isFinite)
+    if (!width.isFinite && !height.isFinite) {
       return Size.zero;
+    }
     final double maxChildDeltaRadius = math.max(0.0, math.min(width, height) / 2.0 - innerRadius);
-    final SectorDimensions childDimensions = child!.getIntrinsicDimensions(SectorConstraints(maxDeltaRadius: maxChildDeltaRadius), innerRadius);
+    final SectorDimensions childDimensions = child!.getIntrinsicDimensions(
+      SectorConstraints(maxDeltaRadius: maxChildDeltaRadius),
+      innerRadius,
+    );
     final double dimension = (innerRadius + childDimensions.deltaRadius) * 2.0;
     return Size.square(dimension);
   }
@@ -526,7 +564,8 @@ class RenderBoxToRenderSectorAdapter extends RenderBox with RenderObjectWithChil
     }
     assert(child is RenderSector);
     assert(child!.parentData is SectorParentData);
-    final double maxChildDeltaRadius = math.min(constraints.maxWidth, constraints.maxHeight) / 2.0 - innerRadius;
+    final double maxChildDeltaRadius =
+        math.min(constraints.maxWidth, constraints.maxHeight) / 2.0 - innerRadius;
     child!.parentData!.radius = innerRadius;
     child!.parentData!.theta = 0.0;
     child!.layout(SectorConstraints(maxDeltaRadius: maxChildDeltaRadius), parentUsesSize: true);
@@ -545,9 +584,10 @@ class RenderBoxToRenderSectorAdapter extends RenderBox with RenderObjectWithChil
   }
 
   @override
-  bool hitTest(BoxHitTestResult result, { required Offset position }) {
-    if (child == null)
+  bool hitTest(BoxHitTestResult result, {required Offset position}) {
+    if (child == null) {
       return false;
+    }
     double x = position.dx;
     double y = position.dy;
     // translate to our origin
@@ -556,12 +596,15 @@ class RenderBoxToRenderSectorAdapter extends RenderBox with RenderObjectWithChil
     // convert to radius/theta
     final double radius = math.sqrt(x * x + y * y);
     final double theta = (math.atan2(x, -y) - math.pi / 2.0) % kTwoPi;
-    if (radius < innerRadius)
+    if (radius < innerRadius) {
       return false;
-    if (radius >= innerRadius + child!.deltaRadius)
+    }
+    if (radius >= innerRadius + child!.deltaRadius) {
       return false;
-    if (theta > child!.deltaTheta)
+    }
+    if (theta > child!.deltaTheta) {
       return false;
+    }
     child!.hitTest(SectorHitTestResult.wrap(result), radius: radius, theta: theta);
     result.add(BoxHitTestEntry(this, position));
     return true;
@@ -630,11 +673,7 @@ class SectorHitTestResult extends HitTestResult {
 /// A hit test entry used by [RenderSector].
 class SectorHitTestEntry extends HitTestEntry {
   /// Creates a box hit test entry.
-  ///
-  /// The [radius] and [theta] argument must not be null.
-  SectorHitTestEntry(RenderSector super.target, { required this.radius,  required this.theta })
-      : assert(radius != null),
-        assert(theta != null);
+  SectorHitTestEntry(RenderSector super.target, {required this.radius, required this.theta});
 
   @override
   RenderSector get target => super.target as RenderSector;
