@@ -10,7 +10,9 @@ import '../../../rendering/flex_layout.dart' as demo;
 
 void main() {
   test('layers smoketest for rendering/flex_layout.dart', () {
-    FlutterError.onError = (FlutterErrorDetails details) { throw details.exception; };
+    FlutterError.onError = (FlutterErrorDetails details) {
+      throw details.exception;
+    };
     demo.main();
     expect(SchedulerBinding.instance.hasScheduledFrame, true);
   });
