@@ -18,8 +18,7 @@ void main() {
     });
 
     test('tap on the button, verify result', () async {
-      final SerializableFinder batteryLevelLabel =
-          find.byValueKey('Battery level label');
+      final SerializableFinder batteryLevelLabel = find.byValueKey('Battery level label');
       expect(batteryLevelLabel, isNotNull);
 
       final SerializableFinder button = find.text('Refresh');
