@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 /// Defines the type model. The type model is part of the
 /// [element model](../dart_element_element/dart_element_element-library.html)
 /// in that most types are defined by Dart code (the types `dynamic` and `void`
@@ -21,16 +23,17 @@
 /// the references to `String` and `int` are type arguments.
 library;
 
-import 'package:_fe_analyzer_shared/src/types/shared_type.dart';
 import 'package:analyzer/dart/element/element.dart';
+import 'package:analyzer/dart/element/element2.dart';
 import 'package:analyzer/dart/element/nullability_suffix.dart';
 import 'package:analyzer/dart/element/type_visitor.dart';
 import 'package:analyzer/src/dart/element/type.dart' show RecordTypeImpl;
+import 'package:meta/meta.dart';
 
 /// The type associated with elements in the element model.
 ///
 /// Clients may not extend, implement or mix-in this class.
-abstract class DartType implements SharedType {
+abstract class DartType {
   /// If this type is an instantiation of a type alias, information about
   /// the alias element, and the type arguments.
   /// Otherwise return `null`.
@@ -42,8 +45,8 @@ abstract class DartType implements SharedType {
 
   /// Return the element representing the declaration of this type, or `null`
   /// if the type is not associated with an element.
-  @Deprecated('Use element instead')
-  Element? get element2;
+  @experimental
+  Element2? get element3;
 
   /// The extension type erasure of this type.
   ///
@@ -63,7 +66,7 @@ abstract class DartType implements SharedType {
   /// dart:async library.
   bool get isDartAsyncFuture;
 
-  /// Return `true` if this type represents the type 'FutureOr<T>' defined in
+  /// Return `true` if this type represents the type `FutureOr<T>` defined in
   /// the dart:async library.
   bool get isDartAsyncFutureOr;
 
@@ -135,20 +138,13 @@ abstract class DartType implements SharedType {
   /// dart:core library.
   bool get isDartCoreType;
 
-  /// Return `true` if this type represents the type 'dynamic'.
-  @Deprecated('Use `is DynamicType` instead')
-  bool get isDynamic;
-
-  /// Return `true` if this type represents the type 'void'.
-  @Deprecated('Use `is VoidType` instead')
-  bool get isVoid;
-
   /// Return the name of this type, or `null` if the type does not have a name,
   /// such as when the type represents the type of an unnamed function.
   @Deprecated('Check element, or use getDisplayString()')
   String? get name;
 
-  @override
+  /// If this type ends in a suffix (`?` or `*`), the suffix it ends with;
+  /// otherwise [NullabilitySuffix.none].
   NullabilitySuffix get nullabilitySuffix;
 
   /// Use the given [visitor] to visit this type.
@@ -177,6 +173,24 @@ abstract class DartType implements SharedType {
   /// the interface implemented by the bound.
   InterfaceType? asInstanceOf(InterfaceElement element);
 
+  /// Return the canonical interface that this type implements for [element],
+  /// or `null` if such an interface does not exist.
+  ///
+  /// For example, given the following definitions
+  /// ```
+  /// class A<E> {}
+  /// class B<E> implements A<E> {}
+  /// class C implements A<String> {}
+  /// ```
+  /// Asking the type `B<int>` for the type associated with `A` will return the
+  /// type `A<int>`. Asking the type `C` for the type associated with `A` will
+  /// return the type `A<String>`.
+  ///
+  /// For a [TypeParameterType] with a bound (declared or promoted), returns
+  /// the interface implemented by the bound.
+  @experimental
+  InterfaceType? asInstanceOf2(InterfaceElement2 element);
+
   /// Return the presentation of this type as it should appear when presented
   /// to users in contexts such as error messages.
   ///
@@ -189,19 +203,18 @@ abstract class DartType implements SharedType {
   ///
   /// Clients should not depend on the content of the returned value as it will
   /// be changed if doing so would improve the UX.
-  @override
   String getDisplayString({
     @Deprecated('Only non-nullable by default mode is supported')
     bool withNullability = true,
   });
 
-  /// If this type is a [TypeParameterType], returns its bound if it has one, or
-  /// [objectType] otherwise.
+  /// Determines whether this type is the same as [other].
   ///
-  /// For any other type, returns `this`. Applies recursively -- if the bound is
-  /// itself a type parameter, that is resolved too.
-  @Deprecated('Use TypeSystem.resolveToBound() instead')
-  DartType resolveToBound(DartType objectType);
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use `==` instead.
+  @Deprecated('Use `==` instead')
+  bool isStructurallyEqualTo(covariant DartType other);
 }
 
 /// The type `dynamic` is a type which is a supertype of all other types, just
@@ -227,9 +240,9 @@ abstract class FunctionType implements DartType {
   @override
   Null get element;
 
-  @Deprecated('Use element instead')
-  @override
-  Null get element2;
+  /// The formal parameters.
+  @experimental
+  List<FormalParameterElement> get formalParameters;
 
   /// A map from the names of named parameters to the types of the named
   /// parameters of this type of function.
@@ -239,10 +252,6 @@ abstract class FunctionType implements DartType {
   /// named parameters declared, then the map will be empty.
   Map<String, DartType> get namedParameterTypes;
 
-  /// The names of the required positional parameters of this type of function,
-  /// not necessarily in the order that the parameters appear.
-  List<String> get normalParameterNames;
-
   /// A list containing the types of the normal parameters of this type of
   /// function.
   ///
@@ -250,10 +259,6 @@ abstract class FunctionType implements DartType {
   /// in the declaration of the function.
   List<DartType> get normalParameterTypes;
 
-  /// The names of the optional positional parameters of this type of function,
-  /// not necessarily in the order that the parameters appear.
-  List<String> get optionalParameterNames;
-
   /// A map from the names of optional (positional) parameters to the types of
   /// the optional parameters of this type of function.
   ///
@@ -268,9 +273,38 @@ abstract class FunctionType implements DartType {
   /// in the declaration of the function.
   List<ParameterElement> get parameters;
 
+  /// All the positional parameter types, starting with the required ones, and
+  /// followed by the optional ones.
+  ///
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use
+  /// [normalParameterTypes] and [optionalParameterTypes] instead.
+  @Deprecated('Please use normalParameterTypes and optionalParameterTypes')
+  List<DartType> get positionalParameterTypes;
+
+  /// The number of elements of [positionalParameterTypes] that are required
+  /// parameters.
+  ///
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use
+  /// [normalParameterTypes].length instead.
+  @Deprecated('Please use normalParameterTypes.length')
+  int get requiredPositionalParameterCount;
+
   /// The type of object returned by this type of function.
   DartType get returnType;
 
+  /// All the named parameters, sorted by name.
+  ///
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use [parameters]
+  /// instead.
+  @Deprecated('Please use parameters')
+  List<ParameterElement> get sortedNamedParameters;
+
   /// The formal type parameters of this generic function; for example,
   /// `<T> T -> T`.
   //
@@ -280,6 +314,10 @@ abstract class FunctionType implements DartType {
   // from the perspective of this function type.
   List<TypeParameterElement> get typeFormals;
 
+  /// The type parameters.
+  @experimental
+  List<TypeParameterElement2> get typeParameters;
+
   /// Produces a new function type by substituting type parameters of this
   /// function type with the given [argumentTypes].
   ///
@@ -293,6 +331,10 @@ abstract class InstantiatedTypeAliasElement {
   /// The alias element that is instantiated to produce a [DartType].
   TypeAliasElement get element;
 
+  /// The alias element that is instantiated to produce a [DartType].
+  @experimental
+  TypeAliasElement2 get element2;
+
   /// The type arguments with which the [element] was instantiated.
   /// This list will be empty if the [element] is not generic.
   List<DartType> get typeArguments;
@@ -314,12 +356,20 @@ abstract class InterfaceType implements ParameterizedType {
   /// Return a list containing all of the constructors declared in this type.
   List<ConstructorElement> get constructors;
 
+  /// Return a list containing all of the constructors declared in this type.
+  @experimental
+  List<ConstructorElement2> get constructors2;
+
   @override
   InterfaceElement get element;
 
-  @Deprecated('Use element instead')
+  @experimental
   @override
-  InterfaceElement get element2;
+  InterfaceElement2 get element3;
+
+  /// Return a list containing all of the getters declared in this type.
+  @experimental
+  List<GetterElement> get getters;
 
   /// Return a list containing all of the interfaces that are implemented by
   /// this interface. Note that this is <b>not</b>, in general, equivalent to
@@ -330,6 +380,10 @@ abstract class InterfaceType implements ParameterizedType {
   /// Return a list containing all of the methods declared in this type.
   List<MethodElement> get methods;
 
+  /// Return a list containing all of the methods declared in this type.
+  @experimental
+  List<MethodElement2> get methods2;
+
   /// Return a list containing all of the mixins that are applied to the class
   /// being extended in order to derive the superclass of this class. Note that
   /// this is <b>not</b>, in general, equivalent to getting the mixins from this
@@ -337,6 +391,10 @@ abstract class InterfaceType implements ParameterizedType {
   /// their type parameters replaced.
   List<InterfaceType> get mixins;
 
+  /// Return a list containing all of the setters declared in this type.
+  @experimental
+  List<SetterElement> get setters;
+
   /// Return the type representing the superclass of this type, or null if this
   /// type represents the class 'Object'. Note that this is <b>not</b>, in
   /// general, equivalent to getting the superclass from this type's element
@@ -359,6 +417,11 @@ abstract class InterfaceType implements ParameterizedType {
   /// with the given name.
   MethodElement? getMethod(String name);
 
+  /// Return the element representing the method with the given [name] that is
+  /// declared in this class, or `null` if this class does not declare a method
+  /// with the given name.
+  MethodElement2? getMethod2(String name);
+
   /// Return the element representing the setter with the given [name] that is
   /// declared in this class, or `null` if this class does not declare a setter
   /// with the given name.
@@ -394,6 +457,24 @@ abstract class InterfaceType implements ParameterizedType {
     bool recoveryStatic = false,
   });
 
+  /// Return the getter with the given [name].
+  ///
+  /// If [concrete] is `true`, then the concrete implementation is returned,
+  /// from this type, or its superclass.
+  ///
+  /// If [inherited] is `true`, then only getters from the superclass are
+  /// considered.
+  ///
+  /// If [recoveryStatic] is `true`, then static getters of the class,
+  /// and its superclasses are considered. Clients should not use it.
+  GetterElement? lookUpGetter3(
+    String name,
+    LibraryElement2 library, {
+    bool concrete = false,
+    bool inherited = false,
+    bool recoveryStatic = false,
+  });
+
   /// Return the method with the given [name].
   ///
   /// If [concrete] is `true`, then the concrete implementation is returned,
@@ -412,6 +493,24 @@ abstract class InterfaceType implements ParameterizedType {
     bool recoveryStatic = false,
   });
 
+  /// Return the method with the given [name].
+  ///
+  /// If [concrete] is `true`, then the concrete implementation is returned,
+  /// from this type, or its superclass.
+  ///
+  /// If [inherited] is `true`, then only methods from the superclass are
+  /// considered.
+  ///
+  /// If [recoveryStatic] is `true`, then static methods of the class,
+  /// and its superclasses are considered. Clients should not use it.
+  MethodElement2? lookUpMethod3(
+    String name,
+    LibraryElement2 library, {
+    bool concrete = false,
+    bool inherited = false,
+    bool recoveryStatic = false,
+  });
+
   /// Return the setter with the given [name].
   ///
   /// If [concrete] is `true`, then the concrete implementation is returned,
@@ -429,6 +528,24 @@ abstract class InterfaceType implements ParameterizedType {
     bool inherited = false,
     bool recoveryStatic = false,
   });
+
+  /// Return the setter with the given [name].
+  ///
+  /// If [concrete] is `true`, then the concrete implementation is returned,
+  /// from this type, or its superclass.
+  ///
+  /// If [inherited] is `true`, then only setters from the superclass are
+  /// considered.
+  ///
+  /// If [recoveryStatic] is `true`, then static setters of the class,
+  /// and its superclasses are considered. Clients should not use it.
+  SetterElement? lookUpSetter3(
+    String name,
+    LibraryElement2 library, {
+    bool concrete = false,
+    bool inherited = false,
+    bool recoveryStatic = false,
+  });
 }
 
 /// The type arising from code with errors, such as invalid type annotations,
@@ -466,7 +583,7 @@ abstract class ParameterizedType implements DartType {
 /// The type of a record literal or a record type annotation.
 ///
 /// Clients may not extend, implement or mix-in this class.
-abstract class RecordType implements DartType, SharedRecordType<DartType> {
+abstract class RecordType implements DartType {
   /// Creates a record type from of [positional] and [named] fields.
   factory RecordType({
     required List<DartType> positional,
@@ -477,15 +594,29 @@ abstract class RecordType implements DartType, SharedRecordType<DartType> {
   @override
   Null get element;
 
-  @Deprecated('Use element instead')
-  @override
-  Null get element2;
-
   /// The named fields (might be empty).
   List<RecordTypeNamedField> get namedFields;
 
   /// The positional fields (might be empty).
   List<RecordTypePositionalField> get positionalFields;
+
+  /// The types of the positional fields (might be empty).
+  ///
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use
+  /// [positionalFields] instead.
+  @Deprecated('Use positionalFields instead')
+  List<DartType> get positionalTypes;
+
+  /// All the named fields, sorted by name (might be empty).
+  ///
+  /// Deprecated: this getter is a part of the analyzer's private
+  /// implementation, and was exposed by accident (see
+  /// https://github.com/dart-lang/sdk/issues/59763). Please use [namedFields]
+  /// instead.
+  @Deprecated('Use namedFields instead')
+  List<RecordTypeNamedField> get sortedNamedTypes;
 }
 
 /// A field in a [RecordType].
@@ -499,10 +630,8 @@ abstract class RecordTypeField {
 /// A named field in a [RecordType].
 ///
 /// Clients may not extend, implement or mix-in this class.
-abstract class RecordTypeNamedField
-    implements RecordTypeField, SharedNamedType<DartType> {
+abstract class RecordTypeNamedField implements RecordTypeField {
   /// The name of the field.
-  @override
   String get name;
 }
 
@@ -529,9 +658,9 @@ abstract class TypeParameterType implements DartType {
   @override
   TypeParameterElement get element;
 
-  @Deprecated('Use element instead')
+  @experimental
   @override
-  TypeParameterElement get element2;
+  TypeParameterElement2 get element3;
 }
 
 /// The special type `void` is used to indicate that the value of an
@@ -539,8 +668,4 @@ abstract class TypeParameterType implements DartType {
 abstract class VoidType implements DartType {
   @override
   Null get element;
-
-  @Deprecated('Use element instead')
-  @override
-  Null get element2;
 }
