@@ -2,20 +2,19 @@
 
 // ignore_for_file: camel_case_types
 // ignore_for_file: comment_references
-// ignore_for_file: file_names
-// ignore_for_file: library_names
+// ignore_for_file: deprecated_member_use_from_same_package
 // ignore_for_file: lines_longer_than_80_chars
 // ignore_for_file: non_constant_identifier_names
-// ignore_for_file: prefer_expression_function_bodies
 // ignore_for_file: prefer_interpolation_to_compose_strings
 // ignore_for_file: unnecessary_brace_in_string_interps
 // ignore_for_file: unnecessary_lambdas
+// ignore_for_file: unnecessary_library_directive
 // ignore_for_file: unnecessary_string_interpolations
 
 /// Enterprise License Manager API - v1
 ///
-/// The Google Enterprise License Manager API's allows you to license apps for
-/// all the users of a domain managed by you.
+/// The Google Enterprise License Manager API lets you manage Google Workspace
+/// and related licenses for all users of a customer that you manage.
 ///
 /// For more information, see
 /// <https://developers.google.com/admin-sdk/licensing/>
@@ -23,7 +22,7 @@
 /// Create an instance of [LicensingApi] to access these resources:
 ///
 /// - [LicenseAssignmentsResource]
-library licensing.v1;
+library licensing_v1;
 
 import 'dart:async' as async;
 import 'dart:convert' as convert;
@@ -32,13 +31,14 @@ import 'dart:core' as core;
 import 'package:_discoveryapis_commons/_discoveryapis_commons.dart' as commons;
 import 'package:http/http.dart' as http;
 
+import '../shared.dart';
 import '../src/user_agent.dart';
 
 export 'package:_discoveryapis_commons/_discoveryapis_commons.dart'
     show ApiRequestError, DetailedApiRequestError;
 
-/// The Google Enterprise License Manager API's allows you to license apps for
-/// all the users of a domain managed by you.
+/// The Google Enterprise License Manager API lets you manage Google Workspace
+/// and related licenses for all users of a customer that you manage.
 class LicensingApi {
   /// View and manage G Suite licenses for your domain
   static const appsLicensingScope =
@@ -93,23 +93,23 @@ class LicenseAssignmentsResource {
     core.String userId, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/user/' +
         commons.escapeVariable('$userId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'DELETE',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
-    return Empty.fromJson(_response as core.Map<core.String, core.dynamic>);
+    return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// Get a specific user's license by product SKU.
@@ -144,24 +144,24 @@ class LicenseAssignmentsResource {
     core.String userId, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/user/' +
         commons.escapeVariable('$userId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return LicenseAssignment.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// Assign a license.
@@ -192,25 +192,25 @@ class LicenseAssignmentsResource {
     core.String skuId, {
     core.String? $fields,
   }) async {
-    final _body = convert.json.encode(request.toJson());
-    final _queryParams = <core.String, core.List<core.String>>{
+    final body_ = convert.json.encode(request);
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/user';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'POST',
-      body: _body,
-      queryParams: _queryParams,
+      body: body_,
+      queryParams: queryParams_,
     );
     return LicenseAssignment.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// List all users assigned licenses for a specific product SKU.
@@ -220,9 +220,9 @@ class LicenseAssignmentsResource {
   /// [productId] - A product's unique identifier. For more information about
   /// products in this version of the API, see Products and SKUs.
   ///
-  /// [customerId] - Customer's `customerId`. A previous version of this API
-  /// accepted the primary domain name as a value for this field. If the
-  /// customer is suspended, the server returns an error.
+  /// [customerId] - The customer's unique ID as defined in the Admin console,
+  /// such as `C00000000`. If the customer is suspended, the server returns an
+  /// error.
   ///
   /// [maxResults] - The `maxResults` query string determines how many entries
   /// are returned on each page of a large response. This is an optional
@@ -251,24 +251,24 @@ class LicenseAssignmentsResource {
     core.String? pageToken,
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       'customerId': [customerId],
       if (maxResults != null) 'maxResults': ['${maxResults}'],
       if (pageToken != null) 'pageToken': [pageToken],
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/users';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return LicenseAssignmentList.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// List all users assigned licenses for a specific product SKU.
@@ -281,9 +281,9 @@ class LicenseAssignmentsResource {
   /// [skuId] - A product SKU's unique identifier. For more information about
   /// available SKUs in this version of the API, see Products and SKUs.
   ///
-  /// [customerId] - Customer's `customerId`. A previous version of this API
-  /// accepted the primary domain name as a value for this field. If the
-  /// customer is suspended, the server returns an error.
+  /// [customerId] - The customer's unique ID as defined in the Admin console,
+  /// such as `C00000000`. If the customer is suspended, the server returns an
+  /// error.
   ///
   /// [maxResults] - The `maxResults` query string determines how many entries
   /// are returned on each page of a large response. This is an optional
@@ -313,26 +313,26 @@ class LicenseAssignmentsResource {
     core.String? pageToken,
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       'customerId': [customerId],
       if (maxResults != null) 'maxResults': ['${maxResults}'],
       if (pageToken != null) 'pageToken': [pageToken],
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/users';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return LicenseAssignmentList.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// Reassign a user's product SKU with a different SKU in the same product.
@@ -372,26 +372,26 @@ class LicenseAssignmentsResource {
     core.String userId, {
     core.String? $fields,
   }) async {
-    final _body = convert.json.encode(request.toJson());
-    final _queryParams = <core.String, core.List<core.String>>{
+    final body_ = convert.json.encode(request);
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/user/' +
         commons.escapeVariable('$userId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'PATCH',
-      body: _body,
-      queryParams: _queryParams,
+      body: body_,
+      queryParams: queryParams_,
     );
     return LicenseAssignment.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// Reassign a user's product SKU with a different SKU in the same product.
@@ -429,26 +429,26 @@ class LicenseAssignmentsResource {
     core.String userId, {
     core.String? $fields,
   }) async {
-    final _body = convert.json.encode(request.toJson());
-    final _queryParams = <core.String, core.List<core.String>>{
+    final body_ = convert.json.encode(request);
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'apps/licensing/v1/product/' +
+    final url_ = 'apps/licensing/v1/product/' +
         commons.escapeVariable('$productId') +
         '/sku/' +
         commons.escapeVariable('$skuId') +
         '/user/' +
         commons.escapeVariable('$userId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'PUT',
-      body: _body,
-      queryParams: _queryParams,
+      body: body_,
+      queryParams: queryParams_,
     );
     return LicenseAssignment.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -457,17 +457,8 @@ class LicenseAssignmentsResource {
 ///
 /// A typical example is to use it as the request or the response type of an API
 /// method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns
-/// (google.protobuf.Empty); } The JSON representation for `Empty` is empty JSON
-/// object `{}`.
-class Empty {
-  Empty();
-
-  Empty.fromJson(
-      // ignore: avoid_unused_constructor_parameters
-      core.Map _json);
-
-  core.Map<core.String, core.dynamic> toJson() => {};
-}
+/// (google.protobuf.Empty); }
+typedef Empty = $Empty;
 
 /// Representation of a license assignment.
 class LicenseAssignment {
@@ -508,34 +499,40 @@ class LicenseAssignment {
   /// status changes.
   core.String? userId;
 
-  LicenseAssignment();
+  LicenseAssignment({
+    this.etags,
+    this.kind,
+    this.productId,
+    this.productName,
+    this.selfLink,
+    this.skuId,
+    this.skuName,
+    this.userId,
+  });
 
-  LicenseAssignment.fromJson(core.Map _json) {
-    if (_json.containsKey('etags')) {
-      etags = _json['etags'] as core.String;
-    }
-    if (_json.containsKey('kind')) {
-      kind = _json['kind'] as core.String;
-    }
-    if (_json.containsKey('productId')) {
-      productId = _json['productId'] as core.String;
-    }
-    if (_json.containsKey('productName')) {
-      productName = _json['productName'] as core.String;
-    }
-    if (_json.containsKey('selfLink')) {
-      selfLink = _json['selfLink'] as core.String;
-    }
-    if (_json.containsKey('skuId')) {
-      skuId = _json['skuId'] as core.String;
-    }
-    if (_json.containsKey('skuName')) {
-      skuName = _json['skuName'] as core.String;
-    }
-    if (_json.containsKey('userId')) {
-      userId = _json['userId'] as core.String;
-    }
-  }
+  LicenseAssignment.fromJson(core.Map json_)
+      : this(
+          etags:
+              json_.containsKey('etags') ? json_['etags'] as core.String : null,
+          kind: json_.containsKey('kind') ? json_['kind'] as core.String : null,
+          productId: json_.containsKey('productId')
+              ? json_['productId'] as core.String
+              : null,
+          productName: json_.containsKey('productName')
+              ? json_['productName'] as core.String
+              : null,
+          selfLink: json_.containsKey('selfLink')
+              ? json_['selfLink'] as core.String
+              : null,
+          skuId:
+              json_.containsKey('skuId') ? json_['skuId'] as core.String : null,
+          skuName: json_.containsKey('skuName')
+              ? json_['skuName'] as core.String
+              : null,
+          userId: json_.containsKey('userId')
+              ? json_['userId'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (etags != null) 'etags': etags!,
@@ -554,13 +551,16 @@ class LicenseAssignmentInsert {
   /// Email id of the user
   core.String? userId;
 
-  LicenseAssignmentInsert();
+  LicenseAssignmentInsert({
+    this.userId,
+  });
 
-  LicenseAssignmentInsert.fromJson(core.Map _json) {
-    if (_json.containsKey('userId')) {
-      userId = _json['userId'] as core.String;
-    }
-  }
+  LicenseAssignmentInsert.fromJson(core.Map json_)
+      : this(
+          userId: json_.containsKey('userId')
+              ? json_['userId'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (userId != null) 'userId': userId!,
@@ -584,30 +584,31 @@ class LicenseAssignmentList {
   /// `maxResults` determines how many entries are returned on each next page.
   core.String? nextPageToken;
 
-  LicenseAssignmentList();
+  LicenseAssignmentList({
+    this.etag,
+    this.items,
+    this.kind,
+    this.nextPageToken,
+  });
 
-  LicenseAssignmentList.fromJson(core.Map _json) {
-    if (_json.containsKey('etag')) {
-      etag = _json['etag'] as core.String;
-    }
-    if (_json.containsKey('items')) {
-      items = (_json['items'] as core.List)
-          .map<LicenseAssignment>((value) => LicenseAssignment.fromJson(
-              value as core.Map<core.String, core.dynamic>))
-          .toList();
-    }
-    if (_json.containsKey('kind')) {
-      kind = _json['kind'] as core.String;
-    }
-    if (_json.containsKey('nextPageToken')) {
-      nextPageToken = _json['nextPageToken'] as core.String;
-    }
-  }
+  LicenseAssignmentList.fromJson(core.Map json_)
+      : this(
+          etag: json_.containsKey('etag') ? json_['etag'] as core.String : null,
+          items: json_.containsKey('items')
+              ? (json_['items'] as core.List)
+                  .map((value) => LicenseAssignment.fromJson(
+                      value as core.Map<core.String, core.dynamic>))
+                  .toList()
+              : null,
+          kind: json_.containsKey('kind') ? json_['kind'] as core.String : null,
+          nextPageToken: json_.containsKey('nextPageToken')
+              ? json_['nextPageToken'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (etag != null) 'etag': etag!,
-        if (items != null)
-          'items': items!.map((value) => value.toJson()).toList(),
+        if (items != null) 'items': items!,
         if (kind != null) 'kind': kind!,
         if (nextPageToken != null) 'nextPageToken': nextPageToken!,
       };
