@@ -2,14 +2,13 @@
 
 // ignore_for_file: camel_case_types
 // ignore_for_file: comment_references
-// ignore_for_file: file_names
-// ignore_for_file: library_names
+// ignore_for_file: deprecated_member_use_from_same_package
 // ignore_for_file: lines_longer_than_80_chars
 // ignore_for_file: non_constant_identifier_names
-// ignore_for_file: prefer_expression_function_bodies
 // ignore_for_file: prefer_interpolation_to_compose_strings
 // ignore_for_file: unnecessary_brace_in_string_interps
 // ignore_for_file: unnecessary_lambdas
+// ignore_for_file: unnecessary_library_directive
 // ignore_for_file: unnecessary_string_interpolations
 
 /// Local Services API - v1
@@ -20,7 +19,7 @@
 ///
 /// - [AccountReportsResource]
 /// - [DetailedLeadReportsResource]
-library localservices.v1;
+library localservices_v1;
 
 import 'dart:async' as async;
 import 'dart:core' as core;
@@ -28,13 +27,14 @@ import 'dart:core' as core;
 import 'package:_discoveryapis_commons/_discoveryapis_commons.dart' as commons;
 import 'package:http/http.dart' as http;
 
+import '../shared.dart';
 import '../src/user_agent.dart';
 
 export 'package:_discoveryapis_commons/_discoveryapis_commons.dart'
     show ApiRequestError, DetailedApiRequestError;
 
 class LocalservicesApi {
-  /// Manage your AdWords campaigns
+  /// See, edit, create, and delete your Google Ads accounts and data.
   static const adwordsScope = 'https://www.googleapis.com/auth/adwords';
 
   final commons.ApiRequester _requester;
@@ -124,7 +124,7 @@ class AccountReportsResource {
     core.int? startDate_year,
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if (endDate_day != null) 'endDate.day': ['${endDate_day}'],
       if (endDate_month != null) 'endDate.month': ['${endDate_month}'],
       if (endDate_year != null) 'endDate.year': ['${endDate_year}'],
@@ -137,15 +137,15 @@ class AccountReportsResource {
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/accountReports:search';
+    const url_ = 'v1/accountReports:search';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse
-        .fromJson(_response as core.Map<core.String, core.dynamic>);
+        .fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -224,7 +224,7 @@ class DetailedLeadReportsResource {
     core.int? startDate_year,
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if (endDate_day != null) 'endDate.day': ['${endDate_day}'],
       if (endDate_month != null) 'endDate.month': ['${endDate_month}'],
       if (endDate_year != null) 'endDate.year': ['${endDate_year}'],
@@ -237,15 +237,15 @@ class DetailedLeadReportsResource {
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/detailedLeadReports:search';
+    const url_ = 'v1/detailedLeadReports:search';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse
-        .fromJson(_response as core.Map<core.String, core.dynamic>);
+        .fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -315,77 +315,91 @@ class GoogleAdsHomeservicesLocalservicesV1AccountReport {
   /// Total number of reviews the account has up to current date.
   core.int? totalReview;
 
-  GoogleAdsHomeservicesLocalservicesV1AccountReport();
+  GoogleAdsHomeservicesLocalservicesV1AccountReport({
+    this.accountId,
+    this.aggregatorInfo,
+    this.averageFiveStarRating,
+    this.averageWeeklyBudget,
+    this.businessName,
+    this.currencyCode,
+    this.currentPeriodChargedLeads,
+    this.currentPeriodConnectedPhoneCalls,
+    this.currentPeriodPhoneCalls,
+    this.currentPeriodTotalCost,
+    this.impressionsLastTwoDays,
+    this.phoneLeadResponsiveness,
+    this.previousPeriodChargedLeads,
+    this.previousPeriodConnectedPhoneCalls,
+    this.previousPeriodPhoneCalls,
+    this.previousPeriodTotalCost,
+    this.totalReview,
+  });
 
-  GoogleAdsHomeservicesLocalservicesV1AccountReport.fromJson(core.Map _json) {
-    if (_json.containsKey('accountId')) {
-      accountId = _json['accountId'] as core.String;
-    }
-    if (_json.containsKey('aggregatorInfo')) {
-      aggregatorInfo =
-          GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(
-              _json['aggregatorInfo'] as core.Map<core.String, core.dynamic>);
-    }
-    if (_json.containsKey('averageFiveStarRating')) {
-      averageFiveStarRating =
-          (_json['averageFiveStarRating'] as core.num).toDouble();
-    }
-    if (_json.containsKey('averageWeeklyBudget')) {
-      averageWeeklyBudget =
-          (_json['averageWeeklyBudget'] as core.num).toDouble();
-    }
-    if (_json.containsKey('businessName')) {
-      businessName = _json['businessName'] as core.String;
-    }
-    if (_json.containsKey('currencyCode')) {
-      currencyCode = _json['currencyCode'] as core.String;
-    }
-    if (_json.containsKey('currentPeriodChargedLeads')) {
-      currentPeriodChargedLeads =
-          _json['currentPeriodChargedLeads'] as core.String;
-    }
-    if (_json.containsKey('currentPeriodConnectedPhoneCalls')) {
-      currentPeriodConnectedPhoneCalls =
-          _json['currentPeriodConnectedPhoneCalls'] as core.String;
-    }
-    if (_json.containsKey('currentPeriodPhoneCalls')) {
-      currentPeriodPhoneCalls = _json['currentPeriodPhoneCalls'] as core.String;
-    }
-    if (_json.containsKey('currentPeriodTotalCost')) {
-      currentPeriodTotalCost =
-          (_json['currentPeriodTotalCost'] as core.num).toDouble();
-    }
-    if (_json.containsKey('impressionsLastTwoDays')) {
-      impressionsLastTwoDays = _json['impressionsLastTwoDays'] as core.String;
-    }
-    if (_json.containsKey('phoneLeadResponsiveness')) {
-      phoneLeadResponsiveness =
-          (_json['phoneLeadResponsiveness'] as core.num).toDouble();
-    }
-    if (_json.containsKey('previousPeriodChargedLeads')) {
-      previousPeriodChargedLeads =
-          _json['previousPeriodChargedLeads'] as core.String;
-    }
-    if (_json.containsKey('previousPeriodConnectedPhoneCalls')) {
-      previousPeriodConnectedPhoneCalls =
-          _json['previousPeriodConnectedPhoneCalls'] as core.String;
-    }
-    if (_json.containsKey('previousPeriodPhoneCalls')) {
-      previousPeriodPhoneCalls =
-          _json['previousPeriodPhoneCalls'] as core.String;
-    }
-    if (_json.containsKey('previousPeriodTotalCost')) {
-      previousPeriodTotalCost =
-          (_json['previousPeriodTotalCost'] as core.num).toDouble();
-    }
-    if (_json.containsKey('totalReview')) {
-      totalReview = _json['totalReview'] as core.int;
-    }
-  }
+  GoogleAdsHomeservicesLocalservicesV1AccountReport.fromJson(core.Map json_)
+      : this(
+          accountId: json_.containsKey('accountId')
+              ? json_['accountId'] as core.String
+              : null,
+          aggregatorInfo: json_.containsKey('aggregatorInfo')
+              ? GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(
+                  json_['aggregatorInfo']
+                      as core.Map<core.String, core.dynamic>)
+              : null,
+          averageFiveStarRating: json_.containsKey('averageFiveStarRating')
+              ? (json_['averageFiveStarRating'] as core.num).toDouble()
+              : null,
+          averageWeeklyBudget: json_.containsKey('averageWeeklyBudget')
+              ? (json_['averageWeeklyBudget'] as core.num).toDouble()
+              : null,
+          businessName: json_.containsKey('businessName')
+              ? json_['businessName'] as core.String
+              : null,
+          currencyCode: json_.containsKey('currencyCode')
+              ? json_['currencyCode'] as core.String
+              : null,
+          currentPeriodChargedLeads:
+              json_.containsKey('currentPeriodChargedLeads')
+                  ? json_['currentPeriodChargedLeads'] as core.String
+                  : null,
+          currentPeriodConnectedPhoneCalls:
+              json_.containsKey('currentPeriodConnectedPhoneCalls')
+                  ? json_['currentPeriodConnectedPhoneCalls'] as core.String
+                  : null,
+          currentPeriodPhoneCalls: json_.containsKey('currentPeriodPhoneCalls')
+              ? json_['currentPeriodPhoneCalls'] as core.String
+              : null,
+          currentPeriodTotalCost: json_.containsKey('currentPeriodTotalCost')
+              ? (json_['currentPeriodTotalCost'] as core.num).toDouble()
+              : null,
+          impressionsLastTwoDays: json_.containsKey('impressionsLastTwoDays')
+              ? json_['impressionsLastTwoDays'] as core.String
+              : null,
+          phoneLeadResponsiveness: json_.containsKey('phoneLeadResponsiveness')
+              ? (json_['phoneLeadResponsiveness'] as core.num).toDouble()
+              : null,
+          previousPeriodChargedLeads:
+              json_.containsKey('previousPeriodChargedLeads')
+                  ? json_['previousPeriodChargedLeads'] as core.String
+                  : null,
+          previousPeriodConnectedPhoneCalls:
+              json_.containsKey('previousPeriodConnectedPhoneCalls')
+                  ? json_['previousPeriodConnectedPhoneCalls'] as core.String
+                  : null,
+          previousPeriodPhoneCalls:
+              json_.containsKey('previousPeriodPhoneCalls')
+                  ? json_['previousPeriodPhoneCalls'] as core.String
+                  : null,
+          previousPeriodTotalCost: json_.containsKey('previousPeriodTotalCost')
+              ? (json_['previousPeriodTotalCost'] as core.num).toDouble()
+              : null,
+          totalReview: json_.containsKey('totalReview')
+              ? json_['totalReview'] as core.int
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (accountId != null) 'accountId': accountId!,
-        if (aggregatorInfo != null) 'aggregatorInfo': aggregatorInfo!.toJson(),
+        if (aggregatorInfo != null) 'aggregatorInfo': aggregatorInfo!,
         if (averageFiveStarRating != null)
           'averageFiveStarRating': averageFiveStarRating!,
         if (averageWeeklyBudget != null)
@@ -424,13 +438,16 @@ class GoogleAdsHomeservicesLocalservicesV1AggregatorInfo {
   /// GLS system.
   core.String? aggregatorProviderId;
 
-  GoogleAdsHomeservicesLocalservicesV1AggregatorInfo();
+  GoogleAdsHomeservicesLocalservicesV1AggregatorInfo({
+    this.aggregatorProviderId,
+  });
 
-  GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(core.Map _json) {
-    if (_json.containsKey('aggregatorProviderId')) {
-      aggregatorProviderId = _json['aggregatorProviderId'] as core.String;
-    }
-  }
+  GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(core.Map json_)
+      : this(
+          aggregatorProviderId: json_.containsKey('aggregatorProviderId')
+              ? json_['aggregatorProviderId'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (aggregatorProviderId != null)
@@ -438,6 +455,62 @@ class GoogleAdsHomeservicesLocalservicesV1AggregatorInfo {
       };
 }
 
+/// Container for booking lead specific information.
+class GoogleAdsHomeservicesLocalservicesV1BookingLead {
+  /// Timestamp of when service is provided by advertiser.
+  core.String? bookingAppointmentTimestamp;
+
+  /// Consumer email associated with the booking lead.
+  core.String? consumerEmail;
+
+  /// Consumer phone number associated with the booking lead.
+  core.String? consumerPhoneNumber;
+
+  /// Name of the customer who created the lead.
+  core.String? customerName;
+
+  /// The job type of the specified lead.
+  core.String? jobType;
+
+  GoogleAdsHomeservicesLocalservicesV1BookingLead({
+    this.bookingAppointmentTimestamp,
+    this.consumerEmail,
+    this.consumerPhoneNumber,
+    this.customerName,
+    this.jobType,
+  });
+
+  GoogleAdsHomeservicesLocalservicesV1BookingLead.fromJson(core.Map json_)
+      : this(
+          bookingAppointmentTimestamp:
+              json_.containsKey('bookingAppointmentTimestamp')
+                  ? json_['bookingAppointmentTimestamp'] as core.String
+                  : null,
+          consumerEmail: json_.containsKey('consumerEmail')
+              ? json_['consumerEmail'] as core.String
+              : null,
+          consumerPhoneNumber: json_.containsKey('consumerPhoneNumber')
+              ? json_['consumerPhoneNumber'] as core.String
+              : null,
+          customerName: json_.containsKey('customerName')
+              ? json_['customerName'] as core.String
+              : null,
+          jobType: json_.containsKey('jobType')
+              ? json_['jobType'] as core.String
+              : null,
+        );
+
+  core.Map<core.String, core.dynamic> toJson() => {
+        if (bookingAppointmentTimestamp != null)
+          'bookingAppointmentTimestamp': bookingAppointmentTimestamp!,
+        if (consumerEmail != null) 'consumerEmail': consumerEmail!,
+        if (consumerPhoneNumber != null)
+          'consumerPhoneNumber': consumerPhoneNumber!,
+        if (customerName != null) 'customerName': customerName!,
+        if (jobType != null) 'jobType': jobType!,
+      };
+}
+
 /// A Detailed Lead Report of a lead identified by their lead id and contains
 /// consumer, account, monetization, and lead data.
 class GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport {
@@ -447,6 +520,9 @@ class GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport {
   /// Aggregator specific information related to the lead.
   GoogleAdsHomeservicesLocalservicesV1AggregatorInfo? aggregatorInfo;
 
+  /// More information associated to only booking leads.
+  GoogleAdsHomeservicesLocalservicesV1BookingLead? bookingLead;
+
   /// Business name associated to the account.
   core.String? businessName;
 
@@ -483,6 +559,7 @@ class GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport {
   /// - "LEAD_TYPE_UNSPECIFIED" : Not specified.
   /// - "MESSAGE" : Message lead.
   /// - "PHONE_CALL" : Phone call lead.
+  /// - "BOOKING" : Booking lead.
   core.String? leadType;
 
   /// More information associated to only message leads.
@@ -494,65 +571,86 @@ class GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport {
   /// Timezone of the particular provider associated to a lead.
   GoogleTypeTimeZone? timezone;
 
-  GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport();
+  GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport({
+    this.accountId,
+    this.aggregatorInfo,
+    this.bookingLead,
+    this.businessName,
+    this.chargeStatus,
+    this.currencyCode,
+    this.disputeStatus,
+    this.geo,
+    this.leadCategory,
+    this.leadCreationTimestamp,
+    this.leadId,
+    this.leadPrice,
+    this.leadType,
+    this.messageLead,
+    this.phoneLead,
+    this.timezone,
+  });
 
   GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport.fromJson(
-      core.Map _json) {
-    if (_json.containsKey('accountId')) {
-      accountId = _json['accountId'] as core.String;
-    }
-    if (_json.containsKey('aggregatorInfo')) {
-      aggregatorInfo =
-          GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(
-              _json['aggregatorInfo'] as core.Map<core.String, core.dynamic>);
-    }
-    if (_json.containsKey('businessName')) {
-      businessName = _json['businessName'] as core.String;
-    }
-    if (_json.containsKey('chargeStatus')) {
-      chargeStatus = _json['chargeStatus'] as core.String;
-    }
-    if (_json.containsKey('currencyCode')) {
-      currencyCode = _json['currencyCode'] as core.String;
-    }
-    if (_json.containsKey('disputeStatus')) {
-      disputeStatus = _json['disputeStatus'] as core.String;
-    }
-    if (_json.containsKey('geo')) {
-      geo = _json['geo'] as core.String;
-    }
-    if (_json.containsKey('leadCategory')) {
-      leadCategory = _json['leadCategory'] as core.String;
-    }
-    if (_json.containsKey('leadCreationTimestamp')) {
-      leadCreationTimestamp = _json['leadCreationTimestamp'] as core.String;
-    }
-    if (_json.containsKey('leadId')) {
-      leadId = _json['leadId'] as core.String;
-    }
-    if (_json.containsKey('leadPrice')) {
-      leadPrice = (_json['leadPrice'] as core.num).toDouble();
-    }
-    if (_json.containsKey('leadType')) {
-      leadType = _json['leadType'] as core.String;
-    }
-    if (_json.containsKey('messageLead')) {
-      messageLead = GoogleAdsHomeservicesLocalservicesV1MessageLead.fromJson(
-          _json['messageLead'] as core.Map<core.String, core.dynamic>);
-    }
-    if (_json.containsKey('phoneLead')) {
-      phoneLead = GoogleAdsHomeservicesLocalservicesV1PhoneLead.fromJson(
-          _json['phoneLead'] as core.Map<core.String, core.dynamic>);
-    }
-    if (_json.containsKey('timezone')) {
-      timezone = GoogleTypeTimeZone.fromJson(
-          _json['timezone'] as core.Map<core.String, core.dynamic>);
-    }
-  }
+      core.Map json_)
+      : this(
+          accountId: json_.containsKey('accountId')
+              ? json_['accountId'] as core.String
+              : null,
+          aggregatorInfo: json_.containsKey('aggregatorInfo')
+              ? GoogleAdsHomeservicesLocalservicesV1AggregatorInfo.fromJson(
+                  json_['aggregatorInfo']
+                      as core.Map<core.String, core.dynamic>)
+              : null,
+          bookingLead: json_.containsKey('bookingLead')
+              ? GoogleAdsHomeservicesLocalservicesV1BookingLead.fromJson(
+                  json_['bookingLead'] as core.Map<core.String, core.dynamic>)
+              : null,
+          businessName: json_.containsKey('businessName')
+              ? json_['businessName'] as core.String
+              : null,
+          chargeStatus: json_.containsKey('chargeStatus')
+              ? json_['chargeStatus'] as core.String
+              : null,
+          currencyCode: json_.containsKey('currencyCode')
+              ? json_['currencyCode'] as core.String
+              : null,
+          disputeStatus: json_.containsKey('disputeStatus')
+              ? json_['disputeStatus'] as core.String
+              : null,
+          geo: json_.containsKey('geo') ? json_['geo'] as core.String : null,
+          leadCategory: json_.containsKey('leadCategory')
+              ? json_['leadCategory'] as core.String
+              : null,
+          leadCreationTimestamp: json_.containsKey('leadCreationTimestamp')
+              ? json_['leadCreationTimestamp'] as core.String
+              : null,
+          leadId: json_.containsKey('leadId')
+              ? json_['leadId'] as core.String
+              : null,
+          leadPrice: json_.containsKey('leadPrice')
+              ? (json_['leadPrice'] as core.num).toDouble()
+              : null,
+          leadType: json_.containsKey('leadType')
+              ? json_['leadType'] as core.String
+              : null,
+          messageLead: json_.containsKey('messageLead')
+              ? GoogleAdsHomeservicesLocalservicesV1MessageLead.fromJson(
+                  json_['messageLead'] as core.Map<core.String, core.dynamic>)
+              : null,
+          phoneLead: json_.containsKey('phoneLead')
+              ? GoogleAdsHomeservicesLocalservicesV1PhoneLead.fromJson(
+                  json_['phoneLead'] as core.Map<core.String, core.dynamic>)
+              : null,
+          timezone: json_.containsKey('timezone')
+              ? GoogleTypeTimeZone.fromJson(
+                  json_['timezone'] as core.Map<core.String, core.dynamic>)
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (accountId != null) 'accountId': accountId!,
-        if (aggregatorInfo != null) 'aggregatorInfo': aggregatorInfo!.toJson(),
+        if (aggregatorInfo != null) 'aggregatorInfo': aggregatorInfo!,
+        if (bookingLead != null) 'bookingLead': bookingLead!,
         if (businessName != null) 'businessName': businessName!,
         if (chargeStatus != null) 'chargeStatus': chargeStatus!,
         if (currencyCode != null) 'currencyCode': currencyCode!,
@@ -564,9 +662,9 @@ class GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport {
         if (leadId != null) 'leadId': leadId!,
         if (leadPrice != null) 'leadPrice': leadPrice!,
         if (leadType != null) 'leadType': leadType!,
-        if (messageLead != null) 'messageLead': messageLead!.toJson(),
-        if (phoneLead != null) 'phoneLead': phoneLead!.toJson(),
-        if (timezone != null) 'timezone': timezone!.toJson(),
+        if (messageLead != null) 'messageLead': messageLead!,
+        if (phoneLead != null) 'phoneLead': phoneLead!,
+        if (timezone != null) 'timezone': timezone!,
       };
 }
 
@@ -584,22 +682,28 @@ class GoogleAdsHomeservicesLocalservicesV1MessageLead {
   /// The postal code of the customer who created the lead.
   core.String? postalCode;
 
-  GoogleAdsHomeservicesLocalservicesV1MessageLead();
+  GoogleAdsHomeservicesLocalservicesV1MessageLead({
+    this.consumerPhoneNumber,
+    this.customerName,
+    this.jobType,
+    this.postalCode,
+  });
 
-  GoogleAdsHomeservicesLocalservicesV1MessageLead.fromJson(core.Map _json) {
-    if (_json.containsKey('consumerPhoneNumber')) {
-      consumerPhoneNumber = _json['consumerPhoneNumber'] as core.String;
-    }
-    if (_json.containsKey('customerName')) {
-      customerName = _json['customerName'] as core.String;
-    }
-    if (_json.containsKey('jobType')) {
-      jobType = _json['jobType'] as core.String;
-    }
-    if (_json.containsKey('postalCode')) {
-      postalCode = _json['postalCode'] as core.String;
-    }
-  }
+  GoogleAdsHomeservicesLocalservicesV1MessageLead.fromJson(core.Map json_)
+      : this(
+          consumerPhoneNumber: json_.containsKey('consumerPhoneNumber')
+              ? json_['consumerPhoneNumber'] as core.String
+              : null,
+          customerName: json_.containsKey('customerName')
+              ? json_['customerName'] as core.String
+              : null,
+          jobType: json_.containsKey('jobType')
+              ? json_['jobType'] as core.String
+              : null,
+          postalCode: json_.containsKey('postalCode')
+              ? json_['postalCode'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (consumerPhoneNumber != null)
@@ -621,20 +725,25 @@ class GoogleAdsHomeservicesLocalservicesV1PhoneLead {
   /// Consumer phone number associated with the phone lead.
   core.String? consumerPhoneNumber;
 
-  GoogleAdsHomeservicesLocalservicesV1PhoneLead();
+  GoogleAdsHomeservicesLocalservicesV1PhoneLead({
+    this.chargedCallTimestamp,
+    this.chargedConnectedCallDurationSeconds,
+    this.consumerPhoneNumber,
+  });
 
-  GoogleAdsHomeservicesLocalservicesV1PhoneLead.fromJson(core.Map _json) {
-    if (_json.containsKey('chargedCallTimestamp')) {
-      chargedCallTimestamp = _json['chargedCallTimestamp'] as core.String;
-    }
-    if (_json.containsKey('chargedConnectedCallDurationSeconds')) {
-      chargedConnectedCallDurationSeconds =
-          _json['chargedConnectedCallDurationSeconds'] as core.String;
-    }
-    if (_json.containsKey('consumerPhoneNumber')) {
-      consumerPhoneNumber = _json['consumerPhoneNumber'] as core.String;
-    }
-  }
+  GoogleAdsHomeservicesLocalservicesV1PhoneLead.fromJson(core.Map json_)
+      : this(
+          chargedCallTimestamp: json_.containsKey('chargedCallTimestamp')
+              ? json_['chargedCallTimestamp'] as core.String
+              : null,
+          chargedConnectedCallDurationSeconds:
+              json_.containsKey('chargedConnectedCallDurationSeconds')
+                  ? json_['chargedConnectedCallDurationSeconds'] as core.String
+                  : null,
+          consumerPhoneNumber: json_.containsKey('consumerPhoneNumber')
+              ? json_['consumerPhoneNumber'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (chargedCallTimestamp != null)
@@ -662,26 +771,29 @@ class GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse {
   /// list returned is the last page in the result set.
   core.String? nextPageToken;
 
-  GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse();
+  GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse({
+    this.accountReports,
+    this.nextPageToken,
+  });
 
   GoogleAdsHomeservicesLocalservicesV1SearchAccountReportsResponse.fromJson(
-      core.Map _json) {
-    if (_json.containsKey('accountReports')) {
-      accountReports = (_json['accountReports'] as core.List)
-          .map<GoogleAdsHomeservicesLocalservicesV1AccountReport>((value) =>
-              GoogleAdsHomeservicesLocalservicesV1AccountReport.fromJson(
-                  value as core.Map<core.String, core.dynamic>))
-          .toList();
-    }
-    if (_json.containsKey('nextPageToken')) {
-      nextPageToken = _json['nextPageToken'] as core.String;
-    }
-  }
+      core.Map json_)
+      : this(
+          accountReports: json_.containsKey('accountReports')
+              ? (json_['accountReports'] as core.List)
+                  .map((value) =>
+                      GoogleAdsHomeservicesLocalservicesV1AccountReport
+                          .fromJson(
+                              value as core.Map<core.String, core.dynamic>))
+                  .toList()
+              : null,
+          nextPageToken: json_.containsKey('nextPageToken')
+              ? json_['nextPageToken'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
-        if (accountReports != null)
-          'accountReports':
-              accountReports!.map((value) => value.toJson()).toList(),
+        if (accountReports != null) 'accountReports': accountReports!,
         if (nextPageToken != null) 'nextPageToken': nextPageToken!,
       };
 }
@@ -702,54 +814,34 @@ class GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse {
   /// list returned is the last page in the result set.
   core.String? nextPageToken;
 
-  GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse();
+  GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse({
+    this.detailedLeadReports,
+    this.nextPageToken,
+  });
 
   GoogleAdsHomeservicesLocalservicesV1SearchDetailedLeadReportsResponse.fromJson(
-      core.Map _json) {
-    if (_json.containsKey('detailedLeadReports')) {
-      detailedLeadReports = (_json['detailedLeadReports'] as core.List)
-          .map<GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport>(
-              (value) => GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport
-                  .fromJson(value as core.Map<core.String, core.dynamic>))
-          .toList();
-    }
-    if (_json.containsKey('nextPageToken')) {
-      nextPageToken = _json['nextPageToken'] as core.String;
-    }
-  }
+      core.Map json_)
+      : this(
+          detailedLeadReports: json_.containsKey('detailedLeadReports')
+              ? (json_['detailedLeadReports'] as core.List)
+                  .map((value) =>
+                      GoogleAdsHomeservicesLocalservicesV1DetailedLeadReport
+                          .fromJson(
+                              value as core.Map<core.String, core.dynamic>))
+                  .toList()
+              : null,
+          nextPageToken: json_.containsKey('nextPageToken')
+              ? json_['nextPageToken'] as core.String
+              : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (detailedLeadReports != null)
-          'detailedLeadReports':
-              detailedLeadReports!.map((value) => value.toJson()).toList(),
+          'detailedLeadReports': detailedLeadReports!,
         if (nextPageToken != null) 'nextPageToken': nextPageToken!,
       };
 }
 
 /// Represents a time zone from the
 /// [IANA Time Zone Database](https://www.iana.org/time-zones).
-class GoogleTypeTimeZone {
-  /// IANA Time Zone Database time zone, e.g. "America/New_York".
-  core.String? id;
-
-  /// IANA Time Zone Database version number, e.g. "2019a".
-  ///
-  /// Optional.
-  core.String? version;
-
-  GoogleTypeTimeZone();
-
-  GoogleTypeTimeZone.fromJson(core.Map _json) {
-    if (_json.containsKey('id')) {
-      id = _json['id'] as core.String;
-    }
-    if (_json.containsKey('version')) {
-      version = _json['version'] as core.String;
-    }
-  }
-
-  core.Map<core.String, core.dynamic> toJson() => {
-        if (id != null) 'id': id!,
-        if (version != null) 'version': version!,
-      };
-}
+typedef GoogleTypeTimeZone = $TimeZone;
