@@ -7,6 +7,7 @@
 
 import 'dart:async';
 import 'dart:io';
+import 'dart:math';
 
 import 'package:flutter/foundation.dart';
 import 'package:flutter/material.dart';
@@ -39,6 +40,7 @@ class VideoPlayerValue {
     this.isBuffering = false,
     this.playbackSpeed = 1.0,
     this.errorDescription,
+    this.rotationCorrection = 0,
   });
 
   /// Returns an instance for a video that hasn't been loaded.
@@ -83,6 +85,9 @@ class VideoPlayerValue {
   /// Indicates whether or not the video has been loaded and is ready to play.
   final bool isInitialized;
 
+  /// Degrees to rotate the video (clockwise) so it is displayed correctly.
+  final int rotationCorrection;
+
   /// Indicates whether or not the video is in an error state. If this is true
   /// [errorDescription] should have information about the problem.
   bool get hasError => errorDescription != null;
@@ -116,6 +121,7 @@ class VideoPlayerValue {
     bool? isBuffering,
     double? playbackSpeed,
     String? errorDescription,
+    int? rotationCorrection,
   }) {
     return VideoPlayerValue(
       duration: duration ?? this.duration,
@@ -127,6 +133,7 @@ class VideoPlayerValue {
       isBuffering: isBuffering ?? this.isBuffering,
       playbackSpeed: playbackSpeed ?? this.playbackSpeed,
       errorDescription: errorDescription ?? this.errorDescription,
+      rotationCorrection: rotationCorrection ?? this.rotationCorrection,
     );
   }
 
@@ -143,7 +150,8 @@ class VideoPlayerValue {
           playbackSpeed == other.playbackSpeed &&
           errorDescription == other.errorDescription &&
           size == other.size &&
-          isInitialized == other.isInitialized;
+          isInitialized == other.isInitialized &&
+          rotationCorrection == other.rotationCorrection;
 
   @override
   int get hashCode => Object.hash(
@@ -156,6 +164,7 @@ class VideoPlayerValue {
         errorDescription,
         size,
         isInitialized,
+        rotationCorrection,
       );
 }
 
@@ -167,20 +176,27 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
   /// The name of the asset is given by the [dataSource] argument and must not be
   /// null. The [package] argument must be non-null when the asset comes from a
   /// package and null otherwise.
-  MiniController.asset(this.dataSource, {this.package})
-      : dataSourceType = DataSourceType.asset,
+  MiniController.asset(
+    this.dataSource, {
+    this.package,
+    this.viewType = VideoViewType.textureView,
+  })  : dataSourceType = DataSourceType.asset,
         super(const VideoPlayerValue(duration: Duration.zero));
 
   /// Constructs a [MiniController] playing a video from obtained from
   /// the network.
-  MiniController.network(this.dataSource)
-      : dataSourceType = DataSourceType.network,
+  MiniController.network(
+    this.dataSource, {
+    this.viewType = VideoViewType.textureView,
+  })  : dataSourceType = DataSourceType.network,
         package = null,
         super(const VideoPlayerValue(duration: Duration.zero));
 
   /// Constructs a [MiniController] playing a video from obtained from a file.
-  MiniController.file(File file)
-      : dataSource = Uri.file(file.absolute.path).toString(),
+  MiniController.file(
+    File file, {
+    this.viewType = VideoViewType.textureView,
+  })  : dataSource = Uri.file(file.absolute.path).toString(),
         dataSourceType = DataSourceType.file,
         package = null,
         super(const VideoPlayerValue(duration: Duration.zero));
@@ -196,19 +212,22 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
   /// Only set for [asset] videos. The package that the asset was loaded from.
   final String? package;
 
+  /// The type of view used to display the video.
+  final VideoViewType viewType;
+
   Timer? _timer;
   Completer<void>? _creatingCompleter;
   StreamSubscription<dynamic>? _eventSubscription;
 
-  /// The id of a texture that hasn't been initialized.
+  /// The id of a player that hasn't been initialized.
   @visibleForTesting
-  static const int kUninitializedTextureId = -1;
-  int _textureId = kUninitializedTextureId;
+  static const int kUninitializedPlayerId = -1;
+  int _playerId = kUninitializedPlayerId;
 
   /// This is just exposed for testing. It shouldn't be used by anyone depending
   /// on the plugin.
   @visibleForTesting
-  int get textureId => _textureId;
+  int get playerId => _playerId;
 
   /// Attempts to open the given [dataSource] and load metadata about the video.
   Future<void> initialize() async {
@@ -239,8 +258,13 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
         );
     }
 
-    _textureId = (await _platform.create(dataSourceDescription)) ??
-        kUninitializedTextureId;
+    final VideoCreationOptions creationOptions = VideoCreationOptions(
+      dataSource: dataSourceDescription,
+      viewType: viewType,
+    );
+
+    _playerId = (await _platform.createWithOptions(creationOptions)) ??
+        kUninitializedPlayerId;
     _creatingCompleter!.complete(null);
     final Completer<void> initializingCompleter = Completer<void>();
 
@@ -249,12 +273,13 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
         case VideoEventType.initialized:
           value = value.copyWith(
             duration: event.duration,
+            rotationCorrection: event.rotationCorrection,
             size: event.size,
             isInitialized: event.duration != null,
           );
           initializingCompleter.complete(null);
-          _platform.setVolume(_textureId, 1.0);
-          _platform.setLooping(_textureId, true);
+          _platform.setVolume(_playerId, 1.0);
+          _platform.setLooping(_playerId, true);
           _applyPlayPause();
         case VideoEventType.completed:
           pause().then((void pauseResult) => seekTo(value.duration));
@@ -281,7 +306,7 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
     }
 
     _eventSubscription = _platform
-        .videoEventsFor(_textureId)
+        .videoEventsFor(_playerId)
         .listen(eventListener, onError: errorListener);
     return initializingCompleter.future;
   }
@@ -292,7 +317,7 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
       await _creatingCompleter!.future;
       _timer?.cancel();
       await _eventSubscription?.cancel();
-      await _platform.dispose(_textureId);
+      await _platform.dispose(_playerId);
     }
     super.dispose();
   }
@@ -312,7 +337,7 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
   Future<void> _applyPlayPause() async {
     _timer?.cancel();
     if (value.isPlaying) {
-      await _platform.play(_textureId);
+      await _platform.play(_playerId);
 
       _timer = Timer.periodic(
         const Duration(milliseconds: 500),
@@ -326,14 +351,14 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
       );
       await _applyPlaybackSpeed();
     } else {
-      await _platform.pause(_textureId);
+      await _platform.pause(_playerId);
     }
   }
 
   Future<void> _applyPlaybackSpeed() async {
     if (value.isPlaying) {
       await _platform.setPlaybackSpeed(
-        _textureId,
+        _playerId,
         value.playbackSpeed,
       );
     }
@@ -341,7 +366,7 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
 
   /// The position in the current video.
   Future<Duration?> get position async {
-    return _platform.getPosition(_textureId);
+    return _platform.getPosition(_playerId);
   }
 
   /// Sets the video's current timestamp to be at [position].
@@ -351,7 +376,7 @@ class MiniController extends ValueNotifier<VideoPlayerValue> {
     } else if (position < Duration.zero) {
       position = Duration.zero;
     }
-    await _platform.seekTo(_textureId, position);
+    await _platform.seekTo(_playerId, position);
     _updatePosition(position);
   }
 
@@ -382,10 +407,10 @@ class VideoPlayer extends StatefulWidget {
 class _VideoPlayerState extends State<VideoPlayer> {
   _VideoPlayerState() {
     _listener = () {
-      final int newTextureId = widget.controller.textureId;
-      if (newTextureId != _textureId) {
+      final int newPlayerId = widget.controller.playerId;
+      if (newPlayerId != _playerId) {
         setState(() {
-          _textureId = newTextureId;
+          _playerId = newPlayerId;
         });
       }
     };
@@ -393,13 +418,13 @@ class _VideoPlayerState extends State<VideoPlayer> {
 
   late VoidCallback _listener;
 
-  late int _textureId;
+  late int _playerId;
 
   @override
   void initState() {
     super.initState();
-    _textureId = widget.controller.textureId;
-    // Need to listen for initialization events since the actual texture ID
+    _playerId = widget.controller.playerId;
+    // Need to listen for initialization events since the actual player ID
     // becomes available after asynchronous initialization finishes.
     widget.controller.addListener(_listener);
   }
@@ -408,7 +433,7 @@ class _VideoPlayerState extends State<VideoPlayer> {
   void didUpdateWidget(VideoPlayer oldWidget) {
     super.didUpdateWidget(oldWidget);
     oldWidget.controller.removeListener(_listener);
-    _textureId = widget.controller.textureId;
+    _playerId = widget.controller.playerId;
     widget.controller.addListener(_listener);
   }
 
@@ -420,9 +445,34 @@ class _VideoPlayerState extends State<VideoPlayer> {
 
   @override
   Widget build(BuildContext context) {
-    return _textureId == MiniController.kUninitializedTextureId
+    return _playerId == MiniController.kUninitializedPlayerId
         ? Container()
-        : _platform.buildView(_textureId);
+        : _VideoPlayerWithRotation(
+            rotation: widget.controller.value.rotationCorrection,
+            child: _platform.buildViewWithOptions(
+              VideoViewOptions(playerId: _playerId),
+            ),
+          );
+  }
+}
+
+class _VideoPlayerWithRotation extends StatelessWidget {
+  const _VideoPlayerWithRotation({
+    required this.rotation,
+    required this.child,
+  });
+
+  final int rotation;
+  final Widget child;
+
+  @override
+  Widget build(BuildContext context) {
+    return rotation == 0
+        ? child
+        : Transform.rotate(
+            angle: rotation * pi / 180,
+            child: child,
+          );
   }
 }
 
