@@ -7,6 +7,7 @@ import 'package:path/path.dart' as p;
 
 import '../code_generator.dart';
 import '../strings.dart' as strings;
+import 'unique_namer.dart';
 import 'utils.dart';
 
 final _logger = Logger('ffigen.code_generator.writer');
@@ -100,7 +101,8 @@ class Writer {
 
   /// Initial namers set after running constructor. Namers are reset to this
   /// initial state everytime [generate] is called.
-  late UniqueNamer _initialTopLevelUniqueNamer, _initialWrapperLevelUniqueNamer;
+  late UniqueNamer _initialTopLevelUniqueNamer;
+  late UniqueNamer _initialWrapperLevelUniqueNamer;
 
   /// Used by [Binding]s for generating required code.
   late UniqueNamer _topLevelUniqueNamer;
@@ -110,11 +112,6 @@ class Writer {
   late UniqueNamer _objCLevelUniqueNamer;
   UniqueNamer get objCLevelUniqueNamer => _objCLevelUniqueNamer;
 
-  late String _arrayHelperClassPrefix;
-
-  /// Guaranteed to be a unique prefix.
-  String get arrayHelperClassPrefix => _arrayHelperClassPrefix;
-
   /// Set true after calling [generate]. Indicates if
   /// [generateSymbolOutputYamlMap] can be called.
   bool get canGenerateSymbolOutput => _canGenerateSymbolOutput;
@@ -128,22 +125,22 @@ class Writer {
     required this.noLookUpBindings,
     required String className,
     required this.nativeAssetId,
-    List<LibraryImport>? additionalImports,
+    List<LibraryImport> additionalImports = const <LibraryImport>[],
     this.classDocComment,
     this.header,
     required this.generateForPackageObjectiveC,
     required this.silenceEnumWarning,
     required this.nativeEntryPoints,
   }) {
-    final globalLevelNameSet = noLookUpBindings.map((e) => e.name).toSet();
-    final wrapperLevelNameSet = lookUpBindings.map((e) => e.name).toSet();
-    final allNameSet = <String>{}
-      ..addAll(globalLevelNameSet)
-      ..addAll(wrapperLevelNameSet);
+    final globalLevelNames = noLookUpBindings.map((e) => e.name);
+    final wrapperLevelNames = lookUpBindings.map((e) => e.name);
 
-    _initialTopLevelUniqueNamer = UniqueNamer(globalLevelNameSet);
-    _initialWrapperLevelUniqueNamer = UniqueNamer(wrapperLevelNameSet);
-    final allLevelsUniqueNamer = UniqueNamer(allNameSet);
+    _initialTopLevelUniqueNamer = UniqueNamer()..markAllUsed(globalLevelNames);
+    _initialWrapperLevelUniqueNamer = UniqueNamer()
+      ..markAllUsed(wrapperLevelNames);
+    final allLevelsUniqueNamer = UniqueNamer()
+      ..markAllUsed(globalLevelNames)
+      ..markAllUsed(wrapperLevelNames);
 
     /// Wrapper class name must be unique among all names.
     _className = _resolveNameConflict(
@@ -153,24 +150,21 @@ class Writer {
     );
 
     /// Library imports prefix should be unique unique among all names.
-    if (additionalImports != null) {
-      for (final lib in additionalImports) {
-        lib.prefix = _resolveNameConflict(
-          name: lib.prefix,
-          makeUnique: allLevelsUniqueNamer,
-          markUsed: [
-            _initialWrapperLevelUniqueNamer,
-            _initialTopLevelUniqueNamer
-          ],
-        );
-      }
+    for (final lib in [...additionalImports, ...allLibraries]) {
+      lib.prefix = _resolveNameConflict(
+        name: lib.prefix,
+        makeUnique: allLevelsUniqueNamer,
+        markUsed: [
+          _initialWrapperLevelUniqueNamer,
+          _initialTopLevelUniqueNamer
+        ],
+      );
     }
 
     /// [_lookupFuncIdentifier] should be unique in top level.
     _lookupFuncIdentifier = _resolveNameConflict(
       name: '_lookup',
       makeUnique: _initialTopLevelUniqueNamer,
-      markUsed: [_initialTopLevelUniqueNamer],
     );
 
     /// Resolve name conflicts of identifiers used for SymbolAddresses.
@@ -182,29 +176,13 @@ class Writer {
     _symbolAddressVariableName = _resolveNameConflict(
       name: 'addresses',
       makeUnique: _initialWrapperLevelUniqueNamer,
-      markUsed: [_initialWrapperLevelUniqueNamer],
     );
     _symbolAddressLibraryVarName = _resolveNameConflict(
       name: '_library',
       makeUnique: _initialWrapperLevelUniqueNamer,
-      markUsed: [_initialWrapperLevelUniqueNamer],
     );
 
-    /// Finding a unique prefix for Array Helper Classes and store into
-    /// [_arrayHelperClassPrefix].
-    final base = 'ArrayHelper';
-    _arrayHelperClassPrefix = base;
-    var suffixInt = 0;
-    for (var i = 0; i < allNameSet.length; i++) {
-      if (allNameSet.elementAt(i).startsWith(_arrayHelperClassPrefix)) {
-        // Not a unique prefix, start over with a new suffix.
-        i = -1;
-        suffixInt++;
-        _arrayHelperClassPrefix = '$base$suffixInt';
-      }
-    }
-
-    _resetUniqueNamersNamers();
+    _resetUniqueNamers();
   }
 
   /// Resolved name conflict using [makeUnique] and marks the result as used in
@@ -222,10 +200,11 @@ class Writer {
   }
 
   /// Resets the namers to initial state. Namers are reset before generating.
-  void _resetUniqueNamersNamers() {
-    _topLevelUniqueNamer = _initialTopLevelUniqueNamer.clone();
-    _wrapperLevelUniqueNamer = _initialWrapperLevelUniqueNamer.clone();
-    _objCLevelUniqueNamer = UniqueNamer({});
+  void _resetUniqueNamers() {
+    _topLevelUniqueNamer = UniqueNamer(parent: _initialTopLevelUniqueNamer);
+    _wrapperLevelUniqueNamer =
+        UniqueNamer(parent: _initialWrapperLevelUniqueNamer);
+    _objCLevelUniqueNamer = UniqueNamer();
   }
 
   void markImportUsed(LibraryImport import) {
@@ -241,7 +220,7 @@ class Writer {
     final result = StringBuffer();
 
     // Reset unique namers to initial state.
-    _resetUniqueNamersNamers();
+    _resetUniqueNamers();
 
     // Reset [usedEnumCTypes].
     usedEnumCTypes.clear();
@@ -274,9 +253,7 @@ class Writer {
     /// Write [lookUpBindings].
     if (lookUpBindings.isNotEmpty) {
       // Write doc comment for wrapper class.
-      if (classDocComment != null) {
-        s.write(makeDartDoc(classDocComment!));
-      }
+      s.write(makeDartDoc(classDocComment));
       // Write wrapper classs.
       s.write('class $_className{\n');
       // Write dylib.
@@ -433,18 +410,59 @@ class Writer {
     s.write('''
 #include <stdint.h>
 #import <Foundation/Foundation.h>
+#import <objc/message.h>
 ''');
 
     for (final entryPoint in nativeEntryPoints) {
       s.write(_objcImport(entryPoint, outDir));
     }
-    s.write('''
+    s.write(r'''
 
 #if !__has_feature(objc_arc)
 #error "This file must be compiled with ARC enabled"
 #endif
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wundeclared-selector"
+
+typedef struct {
+  int64_t version;
+  void* (*newWaiter)(void);
+  void (*awaitWaiter)(void*);
+  void* (*currentIsolate)(void);
+  void (*enterIsolate)(void*);
+  void (*exitIsolate)(void);
+  int64_t (*getMainPortId)(void);
+  bool (*getCurrentThreadOwnsIsolate)(int64_t);
+} DOBJC_Context;
+
 id objc_retainBlock(id);
+
+#define BLOCKING_BLOCK_IMPL(ctx, BLOCK_SIG, INVOKE_DIRECT, INVOKE_LISTENER)    \
+  assert(ctx->version >= 1);                                                   \
+  void* targetIsolate = ctx->currentIsolate();                                 \
+  int64_t targetPort = ctx->getMainPortId == NULL ? 0 : ctx->getMainPortId();  \
+  return BLOCK_SIG {                                                           \
+    void* currentIsolate = ctx->currentIsolate();                              \
+    bool mayEnterIsolate =                                                     \
+        currentIsolate == NULL &&                                              \
+        ctx->getCurrentThreadOwnsIsolate != NULL &&                            \
+        ctx->getCurrentThreadOwnsIsolate(targetPort);                          \
+    if (currentIsolate == targetIsolate || mayEnterIsolate) {                  \
+      if (mayEnterIsolate) {                                                   \
+        ctx->enterIsolate(targetIsolate);                                      \
+      }                                                                        \
+      INVOKE_DIRECT;                                                           \
+      if (mayEnterIsolate) {                                                   \
+        ctx->exitIsolate();                                                    \
+      }                                                                        \
+    } else {                                                                   \
+      void* waiter = ctx->newWaiter();                                         \
+      INVOKE_LISTENER;                                                         \
+      ctx->awaitWaiter(waiter);                                                \
+    }                                                                          \
+  };
+
 ''');
 
     var empty = true;
@@ -455,6 +473,13 @@ id objc_retainBlock(id);
         s.write(bindingString.string);
       }
     }
+
+    s.write('''
+#undef BLOCKING_BLOCK_IMPL
+
+#pragma clang diagnostic pop
+''');
+
     return empty ? null : s.toString();
   }
 }
