@@ -1,3 +1,7 @@
+// Copyright (c) 2023, the Dart project authors. Please see the AUTHORS file
+// for details. All rights reserved. Use of this source code is governed by a
+// BSD-style license that can be found in the LICENSE file.
+
 import 'package:logging/logging.dart';
 import 'package:yaml/yaml.dart';
 
@@ -28,7 +32,7 @@ abstract class ConfigSpec<TE extends Object?, RE extends Object?> {
   String? schemaDescription;
 
   /// Custom validation hook, called post validation if successful.
-  bool Function(ConfigValue node)? customValidation;
+  bool Function(ConfigValue<Object?> node)? customValidation;
 
   /// Used to transform the payload to another type before passing to parent
   /// nodes and [result].
@@ -44,12 +48,12 @@ abstract class ConfigSpec<TE extends Object?, RE extends Object?> {
     required this.result,
   });
 
-  bool _validateNode(ConfigValue o, {bool log = true});
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true});
 
-  ConfigValue<RE> _extractNode(ConfigValue o);
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o);
 
-  /// ConfigSpec objects should call [_getJsonRefOrSchemaNode] instead to get the
-  /// child json schema.
+  /// ConfigSpec objects should call [_getJsonRefOrSchemaNode] instead to get
+  /// the child json schema.
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs);
 
   Map<String, dynamic> _getJsonRefOrSchemaNode(Map<String, dynamic> defs) {
@@ -57,19 +61,19 @@ abstract class ConfigSpec<TE extends Object?, RE extends Object?> {
       return _generateJsonSchemaNode(defs);
     }
     defs.putIfAbsent(schemaDefName!, () => _generateJsonSchemaNode(defs));
-    return {r"$ref": "#/\$defs/$schemaDefName"};
+    return {r'$ref': '#/\$defs/$schemaDefName'};
   }
 
   Map<String, dynamic> generateJsonSchema(String schemaId) {
     final defs = <String, dynamic>{};
     final schemaMap = _generateJsonSchemaNode(defs);
     return {
-      r"$id": schemaId,
-      r"$comment":
-          "This file is generated. To regenerate run: dart tool/generate_json_schema.dart in github.com/dart-lang/native/tree/main/pkgs/ffigen",
-      r"$schema": "https://json-schema.org/draft/2020-12/schema",
+      r'$id': schemaId,
+      r'$comment':
+          'This file is generated. To regenerate run: dart tool/generate_json_schema.dart in github.com/dart-lang/native/tree/main/pkgs/ffigen',
+      r'$schema': 'https://json-schema.org/draft/2020-12/schema',
       ...schemaMap,
-      r"$defs": defs,
+      r'$defs': defs,
     };
   }
 
@@ -78,19 +82,21 @@ abstract class ConfigSpec<TE extends Object?, RE extends Object?> {
     return _validateNode(ConfigValue(path: [], value: value));
   }
 
-  /// Extract ConfigSpecNode from [value]. This will call the [transform] for all
-  /// underlying ConfigSpecs if valid.
+  /// Extract ConfigSpecNode from [value]. This will call the [transform] for
+  /// all underlying ConfigSpecs if valid.
   /// Should ideally only be called if [validate] returns True. Throws
   /// [ConfigSpecExtractionError] if any validation fails.
-  ConfigValue extract(dynamic value) {
+  ConfigValue<Object?> extract(dynamic value) {
     return _extractNode(ConfigValue(path: [], value: value));
   }
 }
 
-/// An individual value in a config for a specific [path] instantiated from a [ConfigSpec].
+/// An individual value in a config for a specific [path] instantiated from a
+/// [ConfigSpec].
 ///
-/// A config value contains both the [value] that users of the configuration would want
-/// to use, as well as the [rawValue] that was provided as input to the configuration.
+/// A config value contains both the [value] that users of the configuration
+/// would want to use, as well as the [rawValue] that was provided as input to
+/// the configuration.
 class ConfigValue<TE> {
   /// The path to this node.
   ///
@@ -100,7 +106,7 @@ class ConfigValue<TE> {
   /// Get a string representation for path.
   ///
   /// E.g - "path -> to -> arr -> [1] -> item"
-  String get pathString => path.join(" -> ");
+  String get pathString => path.join(' -> ');
 
   /// Contains the underlying node value after all transformations and
   /// default values have been applied.
@@ -128,7 +134,7 @@ class ConfigValue<TE> {
   }
 
   /// Transforms this with a nullable [transform] or return itself
-  /// and calls the [result] callback
+  /// and calls the [resultCallback].
   ConfigValue<RE> transformOrThis<RE extends Object?>(
     RE Function(ConfigValue<TE> value)? transform,
     void Function(ConfigValue<RE> node)? resultCallback,
@@ -147,8 +153,8 @@ class ConfigValue<TE> {
   bool checkType<T>({bool log = true}) {
     if (value is! T) {
       if (log) {
-        _logger.severe(
-            "Expected value of key '$pathString' to be of type '$T' (Got ${value.runtimeType}).");
+        _logger.severe("Expected value of key '$pathString' to be of type"
+            " '$T' (Got ${value.runtimeType}).");
       }
       return false;
     }
@@ -157,16 +163,16 @@ class ConfigValue<TE> {
 }
 
 class ConfigSpecExtractionError extends Error {
-  final ConfigValue? item;
+  final ConfigValue<Object?>? item;
   final String message;
-  ConfigSpecExtractionError(this.item, [this.message = "Invalid ConfigSpec"]);
+  ConfigSpecExtractionError(this.item, [this.message = 'Invalid ConfigSpec']);
 
   @override
   String toString() {
     if (item != null) {
-      return "$runtimeType: $message @ ${item!.pathString}";
+      return '$runtimeType: $message @ ${item!.pathString}';
     }
-    return "$runtimeType: $message";
+    return '$runtimeType: $message';
   }
 }
 
@@ -186,7 +192,7 @@ class HeterogeneousMapEntry {
   });
 }
 
-enum AdditionalProperties { Allow, Warn, Error }
+enum AdditionalProperties { allow, warn, error }
 
 /// ConfigSpec for a Map which has a fixed set of known keys.
 ///
@@ -207,20 +213,20 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
     super.customValidation,
     super.transform,
     super.result,
-    this.additionalProperties = AdditionalProperties.Warn,
+    this.additionalProperties = AdditionalProperties.warn,
   })  : requiredKeys = {
           for (final kv in entries.where((kv) => kv.required)) kv.key
         },
         allKeys = {for (final kv in entries) kv.key};
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
-    if (!o.checkType<Map>(log: log)) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
+    if (!o.checkType<Map<dynamic, dynamic>>(log: log)) {
       return false;
     }
 
     var result = true;
-    final inputMap = (o.value as Map);
+    final inputMap = o.value as Map;
 
     for (final requiredKey in requiredKeys) {
       if (!inputMap.containsKey(requiredKey)) {
@@ -245,13 +251,13 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
       }
     }
 
-    if (additionalProperties != AdditionalProperties.Allow) {
+    if (additionalProperties != AdditionalProperties.allow) {
       for (final key in inputMap.keys) {
         if (!allKeys.contains(key)) {
           if (log) {
             _logger.severe("Unknown key - '${[...o.path, key].join(' -> ')}'.");
           }
-          if (additionalProperties == AdditionalProperties.Error) {
+          if (additionalProperties == AdditionalProperties.error) {
             result = false;
           }
         }
@@ -264,7 +270,7 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
     return result;
   }
 
-  dynamic _getAllDefaults(ConfigValue o) {
+  dynamic _getAllDefaults(ConfigValue<Object?> o) {
     final result = <dynamic, CE>{};
     for (final entry in entries) {
       final path = [...o.path, entry.key];
@@ -296,18 +302,18 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
-    if (!o.checkType<Map>(log: false)) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
+    if (!o.checkType<Map<dynamic, dynamic>>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
 
-    final inputMap = (o.value as Map);
+    final inputMap = o.value as Map;
     final childExtracts = <dynamic, CE>{};
 
     for (final requiredKey in requiredKeys) {
       if (!inputMap.containsKey(requiredKey)) {
         throw ConfigSpecExtractionError(
-            null, "Invalid config spec, missing required key - $requiredKey.");
+            null, 'Invalid config spec, missing required key - $requiredKey.');
       }
     }
 
@@ -347,11 +353,11 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
       }
     }
 
-    if (additionalProperties == AdditionalProperties.Error) {
+    if (additionalProperties == AdditionalProperties.error) {
       for (final key in inputMap.keys) {
         if (!allKeys.contains(key)) {
           throw ConfigSpecExtractionError(
-              o, "Invalid ConfigSpec: additional properties not allowed.");
+              o, 'Invalid ConfigSpec: additional properties not allowed.');
         }
       }
     }
@@ -364,16 +370,16 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "object",
-      if (additionalProperties != AdditionalProperties.Allow)
-        "additionalProperties": false,
-      if (schemaDescription != null) "description": schemaDescription!,
+      'type': 'object',
+      if (additionalProperties != AdditionalProperties.allow)
+        'additionalProperties': false,
+      if (schemaDescription != null) 'description': schemaDescription!,
       if (entries.isNotEmpty)
-        "properties": {
+        'properties': {
           for (final kv in entries)
             kv.key: kv.valueConfigSpec._getJsonRefOrSchemaNode(defs)
         },
-      if (requiredKeys.isNotEmpty) "required": requiredKeys.toList(),
+      if (requiredKeys.isNotEmpty) 'required': requiredKeys.toList(),
     };
   }
 }
@@ -385,11 +391,11 @@ class HeterogeneousMapConfigSpec<CE extends Object?, RE extends Object?>
 /// [RE] typecasts result returned by this node.
 class MapConfigSpec<CE extends Object?, RE extends Object?>
     extends ConfigSpec<Map<dynamic, CE>, RE> {
-  /// Both [keyRegexp] - [valueConfigSpec] pair is used to match a set of
+  /// Both keyRegexp - valueConfigSpec pair is used to match a set of
   /// key-value input. Atleast one entry must match against an input for it
   /// to be considered valid.
   ///
-  /// Note: [keyRegexp] will be matched against key.toString()
+  /// Note: keyRegexp will be matched against key.toString()
   final List<({String keyRegexp, ConfigSpec valueConfigSpec})>
       keyValueConfigSpecs;
 
@@ -403,13 +409,13 @@ class MapConfigSpec<CE extends Object?, RE extends Object?>
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
-    if (!o.checkType<Map>(log: log)) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
+    if (!o.checkType<Map<dynamic, dynamic>>(log: log)) {
       return false;
     }
 
     var result = true;
-    final inputMap = (o.value as Map);
+    final inputMap = o.value as Map;
 
     for (final MapEntry(key: key, value: value) in inputMap.entries) {
       final configSpecNode =
@@ -430,12 +436,14 @@ class MapConfigSpec<CE extends Object?, RE extends Object?>
         // No configSpec matched, running again to print logs this time.
         if (log) {
           _logger.severe(
-              "'${configSpecNode.pathString}' must match atleast one of the allowed key regex and configSpec.");
+              "'${configSpecNode.pathString}' must match atleast one of the "
+              'allowed key regex and configSpec.');
           for (final (keyRegexp: keyRegexp, valueConfigSpec: valueConfigSpec)
               in keyValueConfigSpecs) {
             if (!RegExp(keyRegexp, dotAll: true).hasMatch(key.toString())) {
               _logger.severe(
-                  "'${configSpecNode.pathString}' does not match regex - '$keyRegexp' (Input - $key)");
+                  "'${configSpecNode.pathString}' does not match regex - "
+                  "'$keyRegexp' (Input - $key)");
               continue;
             }
             if (valueConfigSpec._validateNode(configSpecNode, log: log)) {
@@ -453,12 +461,12 @@ class MapConfigSpec<CE extends Object?, RE extends Object?>
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
-    if (!o.checkType<Map>(log: false)) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
+    if (!o.checkType<Map<dynamic, dynamic>>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
 
-    final inputMap = (o.value as Map);
+    final inputMap = o.value as Map;
     final childExtracts = <dynamic, CE>{};
     for (final MapEntry(key: key, value: value) in inputMap.entries) {
       final configSpecNode =
@@ -487,10 +495,10 @@ class MapConfigSpec<CE extends Object?, RE extends Object?>
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "object",
-      if (schemaDescription != null) "description": schemaDescription!,
+      'type': 'object',
+      if (schemaDescription != null) 'description': schemaDescription!,
       if (keyValueConfigSpecs.isNotEmpty)
-        "patternProperties": {
+        'patternProperties': {
           for (final (keyRegexp: keyRegexp, valueConfigSpec: valueConfigSpec)
               in keyValueConfigSpecs)
             keyRegexp: valueConfigSpec._getJsonRefOrSchemaNode(defs)
@@ -518,7 +526,7 @@ class ListConfigSpec<CE extends Object?, RE extends Object?>
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     if (!o.checkType<YamlList>(log: log)) {
       return false;
     }
@@ -526,7 +534,7 @@ class ListConfigSpec<CE extends Object?, RE extends Object?>
     var result = true;
     for (final (i, input) in inputList.indexed) {
       final configSpecNode =
-          ConfigValue(path: [...o.path, "[$i]"], value: input);
+          ConfigValue(path: [...o.path, '[$i]'], value: input);
       if (!childConfigSpec._validateNode(configSpecNode, log: log)) {
         result = false;
         continue;
@@ -540,7 +548,7 @@ class ListConfigSpec<CE extends Object?, RE extends Object?>
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     if (!o.checkType<YamlList>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
@@ -563,9 +571,9 @@ class ListConfigSpec<CE extends Object?, RE extends Object?>
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "array",
-      if (schemaDescription != null) "description": schemaDescription!,
-      "items": childConfigSpec._getJsonRefOrSchemaNode(defs),
+      'type': 'array',
+      if (schemaDescription != null) 'description': schemaDescription!,
+      'items': childConfigSpec._getJsonRefOrSchemaNode(defs),
     };
   }
 }
@@ -587,14 +595,15 @@ class StringConfigSpec<RE extends Object?> extends ConfigSpec<String, RE> {
   }) : _regexp = pattern == null ? null : RegExp(pattern, dotAll: true);
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     if (!o.checkType<String>(log: log)) {
       return false;
     }
     if (!(_regexp?.hasMatch(o.value as String) ?? true)) {
       if (log) {
-        _logger.severe(
-            "Expected value of key '${o.pathString}' to match pattern $pattern (Input - ${o.value}).");
+        _logger
+            .severe("Expected value of key '${o.pathString}' to match pattern "
+                '$pattern (Input - ${o.value}).');
       }
       return false;
     }
@@ -605,7 +614,7 @@ class StringConfigSpec<RE extends Object?> extends ConfigSpec<String, RE> {
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     if (!o.checkType<String>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
@@ -617,9 +626,9 @@ class StringConfigSpec<RE extends Object?> extends ConfigSpec<String, RE> {
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "string",
-      if (schemaDescription != null) "description": schemaDescription!,
-      if (pattern != null) "pattern": pattern,
+      'type': 'string',
+      if (schemaDescription != null) 'description': schemaDescription!,
+      if (pattern != null) 'pattern': pattern,
     };
   }
 }
@@ -637,7 +646,7 @@ class IntConfigSpec<RE extends Object?> extends ConfigSpec<int, RE> {
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     if (!o.checkType<int>(log: log)) {
       return false;
     }
@@ -648,7 +657,7 @@ class IntConfigSpec<RE extends Object?> extends ConfigSpec<int, RE> {
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     if (!o.checkType<int>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
@@ -660,8 +669,8 @@ class IntConfigSpec<RE extends Object?> extends ConfigSpec<int, RE> {
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "integer",
-      if (schemaDescription != null) "description": schemaDescription!,
+      'type': 'integer',
+      if (schemaDescription != null) 'description': schemaDescription!,
     };
   }
 }
@@ -683,11 +692,12 @@ class EnumConfigSpec<CE extends Object?, RE extends Object?>
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     if (!allowedValues.contains(o.value)) {
       if (log) {
         _logger.severe(
-            "'${o.pathString}' must be one of the following - $allowedValues (Got ${o.value})");
+            "'${o.pathString}' must be one of the following - $allowedValues "
+            '(Got ${o.value})');
       }
       return false;
     }
@@ -698,7 +708,7 @@ class EnumConfigSpec<CE extends Object?, RE extends Object?>
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     if (!allowedValues.contains(o.value)) {
       throw ConfigSpecExtractionError(o);
     }
@@ -710,8 +720,8 @@ class EnumConfigSpec<CE extends Object?, RE extends Object?>
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "enum": allowedValues.toList(),
-      if (schemaDescription != null) "description": schemaDescription!,
+      'enum': allowedValues.toList(),
+      if (schemaDescription != null) 'description': schemaDescription!,
     };
   }
 }
@@ -729,7 +739,7 @@ class BoolConfigSpec<RE> extends ConfigSpec<bool, RE> {
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     if (!o.checkType<bool>(log: log)) {
       return false;
     }
@@ -740,7 +750,7 @@ class BoolConfigSpec<RE> extends ConfigSpec<bool, RE> {
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     if (!o.checkType<bool>(log: false)) {
       throw ConfigSpecExtractionError(o);
     }
@@ -752,15 +762,16 @@ class BoolConfigSpec<RE> extends ConfigSpec<bool, RE> {
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      "type": "boolean",
-      if (schemaDescription != null) "description": schemaDescription!,
+      'type': 'boolean',
+      if (schemaDescription != null) 'description': schemaDescription!,
     };
   }
 }
 
 /// ConfigSpec that requires atleast one underlying match.
 ///
-/// [TE] typecasts the result returned by the the first valid [childConfigSpecs].
+/// [TE] typecasts the result returned by the the first valid
+/// [childConfigSpecs].
 ///
 /// [RE] typecasts result returned by this node.
 class OneOfConfigSpec<TE extends Object?, RE extends Object?>
@@ -777,7 +788,7 @@ class OneOfConfigSpec<TE extends Object?, RE extends Object?>
   });
 
   @override
-  bool _validateNode(ConfigValue o, {bool log = true}) {
+  bool _validateNode(ConfigValue<Object?> o, {bool log = true}) {
     // Running first time with no logs.
     for (final spec in childConfigSpecs) {
       if (spec._validateNode(o, log: false)) {
@@ -789,8 +800,8 @@ class OneOfConfigSpec<TE extends Object?, RE extends Object?>
     }
     // No configSpec matched, running again to print logs this time.
     if (log) {
-      _logger.severe(
-          "'${o.pathString}' must match atleast one of the allowed configSpec -");
+      _logger.severe("'${o.pathString}' must match atleast one of the allowed "
+          'configSpec -');
       for (final spec in childConfigSpecs) {
         spec._validateNode(o, log: log);
       }
@@ -799,7 +810,7 @@ class OneOfConfigSpec<TE extends Object?, RE extends Object?>
   }
 
   @override
-  ConfigValue<RE> _extractNode(ConfigValue o) {
+  ConfigValue<RE> _extractNode(ConfigValue<Object?> o) {
     for (final spec in childConfigSpecs) {
       if (spec._validateNode(o, log: false)) {
         return o
@@ -813,8 +824,8 @@ class OneOfConfigSpec<TE extends Object?, RE extends Object?>
   @override
   Map<String, dynamic> _generateJsonSchemaNode(Map<String, dynamic> defs) {
     return {
-      if (schemaDescription != null) "description": schemaDescription!,
-      r"$oneOf": childConfigSpecs
+      if (schemaDescription != null) 'description': schemaDescription!,
+      r'$oneOf': childConfigSpecs
           .map((child) => child._getJsonRefOrSchemaNode(defs))
           .toList(),
     };
