@@ -4,13 +4,13 @@
 
 import 'dart:collection';
 
-import 'package:analyzer/dart/analysis/context_locator.dart';
 import 'package:analyzer/dart/analysis/context_root.dart';
 import 'package:analyzer/file_system/file_system.dart';
 import 'package:analyzer/file_system/physical_file_system.dart'
     show PhysicalResourceProvider;
 import 'package:analyzer/src/analysis_options/analysis_options_provider.dart';
 import 'package:analyzer/src/context/packages.dart';
+import 'package:analyzer/src/dart/analysis/analysis_options.dart';
 import 'package:analyzer/src/dart/analysis/context_root.dart';
 import 'package:analyzer/src/task/options.dart';
 import 'package:analyzer/src/util/file_paths.dart' as file_paths;
@@ -21,18 +21,15 @@ import 'package:analyzer/src/workspace/blaze.dart';
 import 'package:analyzer/src/workspace/gn.dart';
 import 'package:analyzer/src/workspace/pub.dart';
 import 'package:analyzer/src/workspace/workspace.dart';
+import 'package:collection/collection.dart';
 import 'package:glob/glob.dart';
 import 'package:path/path.dart';
 import 'package:yaml/yaml.dart';
 
-/// An implementation of a context locator.
-class ContextLocatorImpl implements ContextLocator {
-  /// A flag indicating if analysis contexts are limited to one corresponding
-  /// analysis options file.
-  ///
-  /// See: https://github.com/dart-lang/sdk/issues/53876
-  static bool singleOptionContexts = false;
-
+/// Determines the list of analysis contexts that can be used to analyze the
+/// files and folders that should be analyzed given a list of included files and
+/// folders and a list of excluded files and folders.
+class ContextLocatorImpl {
   /// The resource provider used to access the file system.
   final ResourceProvider resourceProvider;
 
@@ -43,7 +40,17 @@ class ContextLocatorImpl implements ContextLocator {
       : resourceProvider =
             resourceProvider ?? PhysicalResourceProvider.INSTANCE;
 
-  @override
+  /// Return a list of the context roots that should be used to analyze the
+  /// files that are included by the list of [includedPaths] and not excluded by
+  /// the list of [excludedPaths].
+  ///
+  /// If an [optionsFile] is specified, then it is assumed to be the path to the
+  /// `analysis_options.yaml` file that should be used in place of the ones that
+  /// would be found by looking in the directories containing the context roots.
+  ///
+  /// If a [packagesFile] is specified, then it is assumed to be the path to the
+  /// `.packages` file that should be used in place of the one that would be
+  /// found by looking in the directories containing the context roots.
   List<ContextRoot> locateRoots({
     required List<String> includedPaths,
     List<String>? excludedPaths,
@@ -126,8 +133,20 @@ class ContextLocatorImpl implements ContextLocator {
         root.included.add(folder);
       }
 
-      _createContextRootsIn(roots, {}, folder, excludedFolders, root,
-          root.excludedGlobs, defaultOptionsFile, defaultPackagesFile);
+      var rootEnabledLegacyPlugins =
+          _getEnabledLegacyPlugins(location.workspace, location.optionsFile);
+
+      _createContextRootsIn(
+        roots,
+        {},
+        folder,
+        excludedFolders,
+        root,
+        rootEnabledLegacyPlugins,
+        root.excludedGlobs,
+        defaultOptionsFile,
+        defaultPackagesFile,
+      );
     }
 
     for (File file in includedFiles) {
@@ -295,6 +314,7 @@ class ContextLocatorImpl implements ContextLocator {
       Folder folder,
       List<Folder> excludedFolders,
       ContextRoot containingRoot,
+      Set<String> containingRootEnabledLegacyPlugins,
       List<LocatedGlob> excludedGlobs,
       File? optionsFile,
       File? packagesFile) {
@@ -312,22 +332,17 @@ class ContextLocatorImpl implements ContextLocator {
     }
     var buildGnFile = folder.getExistingFile(file_paths.buildGn);
 
-    if (localOptionsFile != null) {
-      (containingRoot as ContextRootImpl).optionsFileMap[folder] =
-          localOptionsFile;
-      // Add excluded globs.
-      var excludes =
-          _getExcludedGlobs(localOptionsFile, containingRoot.workspace);
-      containingRoot.excludedGlobs.addAll(excludes);
-    }
+    var localEnabledPlugins =
+        _getEnabledLegacyPlugins(containingRoot.workspace, localOptionsFile);
+    // Legacy plugins differ only if there is an analysis_options and it
+    // contains a different set of plugins from the containing context.
+    var pluginsDiffer = localOptionsFile != null &&
+        !const SetEquality<String>()
+            .equals(containingRootEnabledLegacyPlugins, localEnabledPlugins);
 
-    //
     // Create a context root for the given [folder] if a packages or build file
-    // is locally specified.
-    //
-    if (localPackagesFile != null ||
-        (singleOptionContexts && localOptionsFile != null) ||
-        buildGnFile != null) {
+    // is locally specified, or the set of enabled legacy plugins changed.
+    if (pluginsDiffer || localPackagesFile != null || buildGnFile != null) {
       if (optionsFile != null) {
         localOptionsFile = optionsFile;
       }
@@ -342,16 +357,48 @@ class ContextLocatorImpl implements ContextLocator {
       );
       var root = ContextRootImpl(resourceProvider, folder, workspace);
       root.packagesFile = rootPackagesFile;
+      // Check for analysis options file in the parent directories, from
+      // root folder to the containing root folder. Pick the one closest
+      // to the root.
+      if (localOptionsFile == null) {
+        var parentFolder = root.root.parent;
+        while (parentFolder != containingRoot.root) {
+          localOptionsFile = parentFolder.existingAnalysisOptionsYamlFile;
+          if (localOptionsFile != null) {
+            break;
+          }
+          parentFolder = parentFolder.parent;
+        }
+      }
       root.optionsFile = localOptionsFile ?? containingRoot.optionsFile;
       root.included.add(folder);
       containingRoot.excluded.add(folder);
       roots.add(root);
       containingRoot = root;
+      containingRootEnabledLegacyPlugins = localEnabledPlugins;
       excludedGlobs = _getExcludedGlobs(root.optionsFile, workspace);
       root.excludedGlobs = excludedGlobs;
     }
-    _createContextRootsIn(roots, visited, folder, excludedFolders,
-        containingRoot, excludedGlobs, optionsFile, packagesFile);
+
+    if (localOptionsFile != null) {
+      (containingRoot as ContextRootImpl).optionsFileMap[folder] =
+          localOptionsFile;
+      // Add excluded globs.
+      var excludes =
+          _getExcludedGlobs(localOptionsFile, containingRoot.workspace);
+      containingRoot.excludedGlobs.addAll(excludes);
+    }
+    _createContextRootsIn(
+      roots,
+      visited,
+      folder,
+      excludedFolders,
+      containingRoot,
+      containingRootEnabledLegacyPlugins,
+      excludedGlobs,
+      optionsFile,
+      packagesFile,
+    );
   }
 
   /// For each directory within the given [folder] that is neither in the list
@@ -366,6 +413,7 @@ class ContextLocatorImpl implements ContextLocator {
       Folder folder,
       List<Folder> excludedFolders,
       ContextRoot containingRoot,
+      Set<String> containingRootEnabledLegacyPlugins,
       List<LocatedGlob> excludedGlobs,
       File? optionsFile,
       File? packagesFile) {
@@ -403,8 +451,17 @@ class ContextLocatorImpl implements ContextLocator {
           if (excludedFolders.contains(child)) {
             containingRoot.excluded.add(child);
           } else if (!isExcluded(child)) {
-            _createContextRoots(roots, visited, child, excludedFolders,
-                containingRoot, excludedGlobs, optionsFile, packagesFile);
+            _createContextRoots(
+              roots,
+              visited,
+              child,
+              excludedFolders,
+              containingRoot,
+              containingRootEnabledLegacyPlugins,
+              excludedGlobs,
+              optionsFile,
+              packagesFile,
+            );
           }
         }
       }
@@ -485,6 +542,30 @@ class ContextLocatorImpl implements ContextLocator {
     return null;
   }
 
+  /// Gets the set of enabled legacy plugins for [optionsFile], taking into
+  /// account any includes.
+  Set<String> _getEnabledLegacyPlugins(Workspace workspace, File? optionsFile) {
+    if (optionsFile == null) {
+      return const {};
+    }
+    try {
+      var provider =
+          AnalysisOptionsProvider(workspace.createSourceFactory(null, null));
+
+      var options = AnalysisOptionsImpl.fromYaml(
+        optionsMap: provider.getOptionsFromFile(optionsFile),
+        file: optionsFile,
+        resourceProvider: resourceProvider,
+      );
+
+      return options.enabledLegacyPluginNames.toSet();
+    } catch (_) {
+      // No legacy plugins will be enabled if the file doesn't parse or cannot
+      // be read for any reason.
+      return {};
+    }
+  }
+
   /// Return a list containing the glob patterns used to exclude files from
   /// analysis by the given [optionsFile]. The list will be empty if there is no
   /// options file or if there are no exclusion patterns in the options file.
@@ -496,9 +577,10 @@ class ContextLocatorImpl implements ContextLocator {
             AnalysisOptionsProvider(workspace.createSourceFactory(null, null))
                 .getOptionsFromFile(optionsFile);
 
-        var analyzerOptions = doc.valueAt(AnalyzerOptions.analyzer);
+        var analyzerOptions = doc.valueAt(AnalysisOptionsFile.analyzer);
         if (analyzerOptions is YamlMap) {
-          var excludeOptions = analyzerOptions.valueAt(AnalyzerOptions.exclude);
+          var excludeOptions =
+              analyzerOptions.valueAt(AnalysisOptionsFile.exclude);
           if (excludeOptions is YamlList) {
             var pathContext = resourceProvider.pathContext;
 
