@@ -208,7 +208,6 @@ class ToSourceVisitor implements AstVisitor<void> {
     _visitNodeList(node.metadata, separator: ' ', suffix: ' ');
     _visitToken(node.augmentKeyword, suffix: ' ');
     _visitToken(node.abstractKeyword, suffix: ' ');
-    _visitToken(node.macroKeyword, suffix: ' ');
     _visitToken(node.sealedKeyword, suffix: ' ');
     _visitToken(node.baseKeyword, suffix: ' ');
     _visitToken(node.interfaceKeyword, suffix: ' ');
@@ -992,13 +991,6 @@ class ToSourceVisitor implements AstVisitor<void> {
     sink.write(')');
   }
 
-  @Deprecated('Use visitMixinOnClause() instead')
-  @override
-  void visitOnClause(OnClause node) {
-    sink.write('on ');
-    _visitNodeList(node.superclassConstraints, separator: ', ');
-  }
-
   @override
   void visitParenthesizedExpression(ParenthesizedExpression node) {
     sink.write('(');
