@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'dart:collection';
 
 import 'package:_fe_analyzer_shared/src/exhaustiveness/dart_template_buffer.dart';
@@ -9,7 +11,6 @@ import 'package:_fe_analyzer_shared/src/exhaustiveness/exhaustive.dart';
 import 'package:_fe_analyzer_shared/src/exhaustiveness/space.dart';
 import 'package:analyzer/dart/analysis/declared_variables.dart';
 import 'package:analyzer/dart/analysis/features.dart';
-import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/ast/token.dart';
 import 'package:analyzer/dart/ast/visitor.dart';
 import 'package:analyzer/dart/constant/value.dart';
@@ -48,9 +49,6 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
   /// The type provider used to access the known types.
   final TypeProvider _typeProvider;
 
-  /// The set of variables declared using '-D' on the command line.
-  final DeclaredVariables declaredVariables;
-
   /// The current library that is being analyzed.
   final LibraryElementImpl _currentLibrary;
 
@@ -70,7 +68,7 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
 
   Map<Expression, DartObjectImpl>? _mapPatternKeyValues;
 
-  late final ExhaustivenessDataForTesting? exhaustivenessDataForTesting;
+  final ExhaustivenessDataForTesting? exhaustivenessDataForTesting;
 
   /// Initialize a newly created constant verifier.
   ConstantVerifier(ErrorReporter errorReporter,
@@ -82,7 +80,9 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
           currentLibrary.typeSystem,
           currentLibrary.typeProvider,
           declaredVariables,
-          retainDataForTesting,
+          AnalyzerExhaustivenessCache(
+              currentLibrary.typeSystem, currentLibrary),
+          retainDataForTesting: retainDataForTesting,
         );
 
   ConstantVerifier._(
@@ -90,18 +90,16 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
     this._currentLibrary,
     this._typeSystem,
     this._typeProvider,
-    this.declaredVariables,
-    bool retainDataForTesting,
-  )   : _evaluationEngine = ConstantEvaluationEngine(
+    DeclaredVariables declaredVariables,
+    this._exhaustivenessCache, {
+    required bool retainDataForTesting,
+  })  : _evaluationEngine = ConstantEvaluationEngine(
           declaredVariables: declaredVariables,
           configuration: ConstantEvaluationConfiguration(),
         ),
-        _exhaustivenessCache =
-            AnalyzerExhaustivenessCache(_typeSystem, _currentLibrary) {
-    exhaustivenessDataForTesting = retainDataForTesting
-        ? ExhaustivenessDataForTesting(_exhaustivenessCache)
-        : null;
-  }
+        exhaustivenessDataForTesting = retainDataForTesting
+            ? ExhaustivenessDataForTesting(_exhaustivenessCache)
+            : null;
 
   @override
   void visitAnnotation(Annotation node) {
@@ -483,7 +481,7 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
     if (initializer != null && (node.isConst || node.isFinal)) {
       var element = node.declaredElement as VariableElementImpl;
       if (element is FieldElement && !element.isStatic) {
-        var enclosingElement = element.enclosingElement;
+        var enclosingElement = element.enclosingElement3;
         if (enclosingElement is ClassElementImpl &&
             !enclosingElement.hasGenerativeConstConstructor) {
           // TODO(kallentu): Evaluate if we need to do this check for inline
@@ -653,6 +651,8 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
         identical(errorCode, CompileTimeErrorCode.CONST_EVAL_FOR_ELEMENT) ||
         identical(
             errorCode, CompileTimeErrorCode.CONST_EVAL_METHOD_INVOCATION) ||
+        identical(
+            errorCode, CompileTimeErrorCode.CONST_EVAL_PRIMITIVE_EQUALITY) ||
         identical(errorCode, CompileTimeErrorCode.CONST_EVAL_PROPERTY_ACCESS) ||
         identical(
             errorCode, CompileTimeErrorCode.CONST_EVAL_THROWS_EXCEPTION) ||
@@ -897,9 +897,10 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
     var scrutineeType = scrutinee.typeOrThrow;
     var scrutineeTypeEx = _exhaustivenessCache.getStaticType(scrutineeType);
 
-    var caseNodesWithSpace = <AstNode>[];
+    var caseNodesWithSpace = <CaseNodeImpl>[];
+    var caseIsGuarded = <bool>[];
     var caseSpaces = <Space>[];
-    var hasDefault = false;
+    SwitchDefault? defaultNode;
 
     var patternConverter = PatternConverter(
       languageVersion: _currentLibrary.languageVersion.effective,
@@ -912,79 +913,81 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
 
     // Build spaces for cases.
     for (var caseNode in caseNodes) {
-      GuardedPattern? guardedPattern;
       if (caseNode is SwitchCase) {
         // Should not happen, ignore.
       } else if (caseNode is SwitchDefault) {
-        hasDefault = true;
-      } else if (caseNode is SwitchExpressionCase) {
-        guardedPattern = caseNode.guardedPattern;
-      } else if (caseNode is SwitchPatternCase) {
-        guardedPattern = caseNode.guardedPattern;
+        defaultNode = caseNode;
+      } else if (caseNode is CaseNodeImpl) {
+        Space space = patternConverter.createRootSpace(
+            scrutineeTypeEx, caseNode.guardedPattern.pattern);
+        caseNodesWithSpace.add(caseNode);
+        caseIsGuarded.add(caseNode.guardedPattern.whenClause != null);
+        caseSpaces.add(space);
       } else {
         throw UnimplementedError('(${caseNode.runtimeType}) $caseNode');
       }
-
-      if (guardedPattern != null) {
-        Space space = patternConverter.createRootSpace(
-            scrutineeTypeEx, guardedPattern.pattern,
-            hasGuard: guardedPattern.whenClause != null);
-        caseNodesWithSpace.add(caseNode);
-        caseSpaces.add(space);
-      }
     }
+    var reportNonExhaustive = mustBeExhaustive && defaultNode == null;
 
     // Prepare for recording data for testing.
     var exhaustivenessDataForTesting = this.exhaustivenessDataForTesting;
 
     // Compute and report errors.
-    var errors = patternConverter.hasInvalidType
-        ? const <ExhaustivenessError>[]
-        : reportErrors(_exhaustivenessCache, scrutineeTypeEx, caseSpaces,
-            computeUnreachable: true);
-
-    var reportNonExhaustive = mustBeExhaustive && !hasDefault;
-    for (var error in errors) {
-      if (error is UnreachableCaseError) {
-        var caseNode = caseNodesWithSpace[error.index];
-        Token errorToken;
-        if (caseNode is SwitchExpressionCase) {
-          errorToken = caseNode.arrow;
-        } else if (caseNode is SwitchPatternCase) {
-          errorToken = caseNode.keyword;
-        } else {
-          throw UnimplementedError('(${caseNode.runtimeType}) $caseNode');
-        }
+    List<CaseUnreachability> caseUnreachabilities = [];
+    NonExhaustiveness? nonExhaustiveness;
+    if (!patternConverter.hasInvalidType) {
+      nonExhaustiveness = computeExhaustiveness(
+          _exhaustivenessCache, scrutineeTypeEx, caseIsGuarded, caseSpaces,
+          caseUnreachabilities: caseUnreachabilities);
+      for (var caseUnreachability in caseUnreachabilities) {
+        var caseNode = caseNodesWithSpace[caseUnreachability.index];
+        var errorToken = switch (caseNode) {
+          SwitchExpressionCaseImpl() => caseNode.arrow,
+          SwitchPatternCaseImpl() => caseNode.keyword
+        };
         _errorReporter.atToken(
           errorToken,
           WarningCode.UNREACHABLE_SWITCH_CASE,
         );
-      } else if (error is NonExhaustiveError && reportNonExhaustive) {
-        var errorBuffer = SimpleDartBuffer();
-        error.witnesses.first.toDart(errorBuffer, forCorrection: false);
-        var correctionTextBuffer = SimpleDartBuffer();
-        error.witnesses.first.toDart(correctionTextBuffer, forCorrection: true);
+      }
+      if (nonExhaustiveness != null) {
+        if (reportNonExhaustive) {
+          var errorBuffer = SimpleDartBuffer();
+          nonExhaustiveness.witnesses.first
+              .toDart(errorBuffer, forCorrection: false);
+          var correctionTextBuffer = SimpleDartBuffer();
+          nonExhaustiveness.witnesses.first
+              .toDart(correctionTextBuffer, forCorrection: true);
 
-        var correctionData = <List<MissingPatternPart>>[];
-        for (var witness in error.witnesses) {
-          var correctionDataBuffer = AnalyzerDartTemplateBuffer();
-          witness.toDart(correctionDataBuffer, forCorrection: true);
-          if (correctionDataBuffer.isComplete) {
-            correctionData.add(correctionDataBuffer.parts);
+          var correctionData = <List<MissingPatternPart>>[];
+          for (var witness in nonExhaustiveness.witnesses) {
+            var correctionDataBuffer = AnalyzerDartTemplateBuffer();
+            witness.toDart(correctionDataBuffer, forCorrection: true);
+            if (correctionDataBuffer.isComplete) {
+              correctionData.add(correctionDataBuffer.parts);
+            }
           }
+          _errorReporter.atToken(
+            switchKeyword,
+            isSwitchExpression
+                ? CompileTimeErrorCode.NON_EXHAUSTIVE_SWITCH_EXPRESSION
+                : CompileTimeErrorCode.NON_EXHAUSTIVE_SWITCH_STATEMENT,
+            arguments: [
+              scrutineeType,
+              errorBuffer.toString(),
+              correctionTextBuffer.toString(),
+            ],
+            data: correctionData.isNotEmpty ? correctionData : null,
+          );
+        }
+      } else {
+        if (defaultNode != null && mustBeExhaustive) {
+          // Default node is unreachable
+          _errorReporter.atToken(
+            defaultNode.keyword,
+            WarningCode.UNREACHABLE_SWITCH_DEFAULT,
+          );
         }
-        _errorReporter.atToken(
-          switchKeyword,
-          isSwitchExpression
-              ? CompileTimeErrorCode.NON_EXHAUSTIVE_SWITCH_EXPRESSION
-              : CompileTimeErrorCode.NON_EXHAUSTIVE_SWITCH_STATEMENT,
-          arguments: [
-            scrutineeType,
-            errorBuffer.toString(),
-            correctionTextBuffer.toString(),
-          ],
-          data: correctionData.isNotEmpty ? correctionData : null,
-        );
       }
     }
 
@@ -996,13 +999,13 @@ class ConstantVerifier extends RecursiveAstVisitor<void> {
       }
       exhaustivenessDataForTesting.switchScrutineeType[node] = scrutineeTypeEx;
       exhaustivenessDataForTesting.switchCases[node] = caseSpaces;
-      for (var error in errors) {
-        if (error is UnreachableCaseError) {
-          exhaustivenessDataForTesting.errors[caseNodesWithSpace[error.index]] =
-              error;
-        } else if (reportNonExhaustive) {
-          exhaustivenessDataForTesting.errors[node] = error;
-        }
+      for (var caseUnreachability in caseUnreachabilities) {
+        exhaustivenessDataForTesting.caseUnreachabilities[
+            caseNodesWithSpace[caseUnreachability.index]] = caseUnreachability;
+      }
+      if (nonExhaustiveness != null && reportNonExhaustive) {
+        exhaustivenessDataForTesting.nonExhaustivenesses[node] =
+            nonExhaustiveness;
       }
     }
   }
@@ -1156,6 +1159,26 @@ class _ConstLiteralVerifier {
         return _validateMapSpread(mapConfig, element, value);
       }
 
+      return true;
+    } else if (element is NullAwareElement) {
+      var value = verifier._evaluateAndReportError(element.value, errorCode);
+      if (value is! DartObjectImpl) return false;
+
+      var listElementType = this.listElementType;
+      if (listElementType != null) {
+        return _validateListExpression(
+            verifier._typeSystem.makeNullable(listElementType),
+            element.value,
+            value);
+      }
+
+      // If the value is `null`, skip verifying it with the set, as it won't be
+      // added as an element.
+      var setConfig = this.setConfig;
+      if (setConfig != null && !value.type.isDartCoreNull) {
+        return _validateSetExpression(setConfig, element.value, value);
+      }
+
       return true;
     }
     throw UnsupportedError(
@@ -1206,11 +1229,20 @@ class _ConstLiteralVerifier {
   bool _validateListExpression(
       DartType listElementType, Expression expression, DartObjectImpl value) {
     if (!verifier._runtimeTypeMatch(value, listElementType)) {
-      verifier._errorReporter.atNode(
-        expression,
-        CompileTimeErrorCode.LIST_ELEMENT_TYPE_NOT_ASSIGNABLE,
-        arguments: [value.type, listElementType],
-      );
+      if (verifier._runtimeTypeMatch(
+          value, verifier._typeSystem.makeNullable(listElementType))) {
+        verifier._errorReporter.atNode(
+          expression,
+          CompileTimeErrorCode.LIST_ELEMENT_TYPE_NOT_ASSIGNABLE_NULLABILITY,
+          arguments: [value.type, listElementType],
+        );
+      } else {
+        verifier._errorReporter.atNode(
+          expression,
+          CompileTimeErrorCode.LIST_ELEMENT_TYPE_NOT_ASSIGNABLE,
+          arguments: [value.type, listElementType],
+        );
+      }
       return false;
     }
 
@@ -1273,6 +1305,9 @@ class _ConstLiteralVerifier {
     var keyExpression = entry.key;
     var valueExpression = entry.value;
 
+    var isKeyNullAware = entry.keyQuestion != null;
+    var isValueNullAware = entry.valueQuestion != null;
+
     var keyValue = verifier._evaluateAndReportError(
       keyExpression,
       CompileTimeErrorCode.NON_CONSTANT_MAP_KEY,
@@ -1284,13 +1319,27 @@ class _ConstLiteralVerifier {
 
     if (keyValue is DartObjectImpl) {
       var keyType = keyValue.type;
+      var expectedKeyType = config.keyType;
+      if (isKeyNullAware) {
+        expectedKeyType = verifier._typeSystem.makeNullable(expectedKeyType);
+      }
 
-      if (!verifier._runtimeTypeMatch(keyValue, config.keyType)) {
-        verifier._errorReporter.atNode(
-          keyExpression,
-          CompileTimeErrorCode.MAP_KEY_TYPE_NOT_ASSIGNABLE,
-          arguments: [keyType, config.keyType],
-        );
+      if (!verifier._runtimeTypeMatch(keyValue, expectedKeyType)) {
+        if (!isKeyNullAware &&
+            verifier._runtimeTypeMatch(
+                keyValue, verifier._typeSystem.makeNullable(expectedKeyType))) {
+          verifier._errorReporter.atNode(
+            keyExpression,
+            CompileTimeErrorCode.MAP_KEY_TYPE_NOT_ASSIGNABLE_NULLABILITY,
+            arguments: [keyType, expectedKeyType],
+          );
+        } else {
+          verifier._errorReporter.atNode(
+            keyExpression,
+            CompileTimeErrorCode.MAP_KEY_TYPE_NOT_ASSIGNABLE,
+            arguments: [keyType, expectedKeyType],
+          );
+        }
       }
 
       var featureSet = verifier._currentLibrary.featureSet;
@@ -1302,21 +1351,43 @@ class _ConstLiteralVerifier {
         );
       }
 
-      var existingKey = config.uniqueKeys[keyValue];
-      if (existingKey != null) {
-        config.duplicateKeys[keyExpression] = existingKey;
-      } else {
-        config.uniqueKeys[keyValue] = keyExpression;
+      // Don't check the key for uniqueness if the key is null aware and is
+      // `null` or the value is null aware and is `null`, since it won't be
+      // added to the map in that case.
+      if ((!isKeyNullAware || !keyValue.type.isDartCoreNull) &&
+          (!isValueNullAware ||
+              valueValue is DartObjectImpl &&
+                  !valueValue.type.isDartCoreNull)) {
+        var existingKey = config.uniqueKeys[keyValue];
+        if (existingKey != null) {
+          config.duplicateKeys[keyExpression] = existingKey;
+        } else {
+          config.uniqueKeys[keyValue] = keyExpression;
+        }
       }
     }
 
+    var expectedValueType = config.valueType;
+    if (isValueNullAware) {
+      expectedValueType = verifier._typeSystem.makeNullable(expectedValueType);
+    }
     if (valueValue is DartObjectImpl) {
-      if (!verifier._runtimeTypeMatch(valueValue, config.valueType)) {
-        verifier._errorReporter.atNode(
-          valueExpression,
-          CompileTimeErrorCode.MAP_VALUE_TYPE_NOT_ASSIGNABLE,
-          arguments: [valueValue.type, config.valueType],
-        );
+      if (!verifier._runtimeTypeMatch(valueValue, expectedValueType)) {
+        if (!isValueNullAware &&
+            verifier._runtimeTypeMatch(valueValue,
+                verifier._typeSystem.makeNullable(expectedValueType))) {
+          verifier._errorReporter.atNode(
+            valueExpression,
+            CompileTimeErrorCode.MAP_VALUE_TYPE_NOT_ASSIGNABLE_NULLABILITY,
+            arguments: [valueValue.type, expectedValueType],
+          );
+        } else {
+          verifier._errorReporter.atNode(
+            valueExpression,
+            CompileTimeErrorCode.MAP_VALUE_TYPE_NOT_ASSIGNABLE,
+            arguments: [valueValue.type, expectedValueType],
+          );
+        }
       }
     }
 
@@ -1360,11 +1431,20 @@ class _ConstLiteralVerifier {
     DartObjectImpl value,
   ) {
     if (!verifier._runtimeTypeMatch(value, config.elementType)) {
-      verifier._errorReporter.atNode(
-        expression,
-        CompileTimeErrorCode.SET_ELEMENT_TYPE_NOT_ASSIGNABLE,
-        arguments: [value.type, config.elementType],
-      );
+      if (verifier._runtimeTypeMatch(
+          value, verifier._typeSystem.makeNullable(config.elementType))) {
+        verifier._errorReporter.atNode(
+          expression,
+          CompileTimeErrorCode.SET_ELEMENT_TYPE_NOT_ASSIGNABLE_NULLABILITY,
+          arguments: [value.type, config.elementType],
+        );
+      } else {
+        verifier._errorReporter.atNode(
+          expression,
+          CompileTimeErrorCode.SET_ELEMENT_TYPE_NOT_ASSIGNABLE,
+          arguments: [value.type, config.elementType],
+        );
+      }
       return false;
     }
 
