@@ -2,20 +2,22 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'dart:typed_data';
 
 import 'package:analyzer/dart/analysis/declared_variables.dart';
 import 'package:analyzer/dart/analysis/features.dart';
 import 'package:analyzer/dart/analysis/results.dart';
 import 'package:analyzer/dart/element/element.dart';
+import 'package:analyzer/dart/element/element2.dart';
 import 'package:analyzer/error/error.dart';
 import 'package:analyzer/file_system/file_system.dart';
 import 'package:analyzer/source/line_info.dart';
 import 'package:analyzer/src/analysis_options/analysis_options_provider.dart';
-import 'package:analyzer/src/analysis_options/apply_options.dart';
-import 'package:analyzer/src/context/packages.dart';
+import 'package:analyzer/src/clients/build_resolvers/build_resolvers.dart';
+import 'package:analyzer/src/dart/analysis/analysis_options.dart';
 import 'package:analyzer/src/dart/analysis/analysis_options_map.dart';
-import 'package:analyzer/src/dart/analysis/byte_store.dart';
 import 'package:analyzer/src/dart/analysis/cache.dart';
 import 'package:analyzer/src/dart/analysis/context_root.dart';
 import 'package:analyzer/src/dart/analysis/driver.dart' show ErrorEncoding;
@@ -28,16 +30,17 @@ import 'package:analyzer/src/dart/analysis/performance_logger.dart';
 import 'package:analyzer/src/dart/analysis/results.dart';
 import 'package:analyzer/src/dart/analysis/search.dart';
 import 'package:analyzer/src/dart/analysis/unlinked_unit_store.dart';
+import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/dart/micro/analysis_context.dart';
 import 'package:analyzer/src/dart/micro/utils.dart';
 import 'package:analyzer/src/dart/resolver/flow_analysis_visitor.dart';
-import 'package:analyzer/src/generated/engine.dart' show AnalysisOptionsImpl;
 import 'package:analyzer/src/generated/source.dart';
 import 'package:analyzer/src/summary/api_signature.dart';
 import 'package:analyzer/src/summary/format.dart';
 import 'package:analyzer/src/summary/idl.dart';
 import 'package:analyzer/src/summary/package_bundle_reader.dart';
 import 'package:analyzer/src/util/performance/operation_performance.dart';
+import 'package:analyzer/src/utilities/extensions/element.dart';
 import 'package:analyzer/src/utilities/extensions/file_system.dart';
 import 'package:analyzer/src/utilities/uri_cache.dart';
 import 'package:analyzer/src/workspace/workspace.dart';
@@ -244,14 +247,6 @@ class FileResolver {
     releaseAndClearRemovedIds();
   }
 
-  /// Collects all the cached artifacts and add all the cache id's for the
-  /// removed artifacts to [removedCacheKeys].
-  @Deprecated('Use dispose() instead')
-  void collectSharedDataIdentifiers() {
-    removedCacheKeys.addAll(fsState!.dispose());
-    removedCacheKeys.addAll(libraryContext!.dispose());
-  }
-
   /// Notifies this object that it is about to be discarded, so it should
   /// release any shared data.
   void dispose() {
@@ -260,10 +255,20 @@ class FileResolver {
     releaseAndClearRemovedIds();
   }
 
+  /// Looks for references to the given Element. All the files currently
+  ///  cached by the resolver are searched, generated files are ignored.
+  Future<List<CiderSearchMatch>> findReferences(Element2 element,
+      {OperationPerformanceImpl? performance}) {
+    return findReferences2(
+      element.asElement!,
+      performance: performance,
+    );
+  }
+
   /// Looks for references to the given Element. All the files currently
   ///  cached by the resolver are searched, generated files are ignored.
   Future<List<CiderSearchMatch>> findReferences2(Element element,
-      {OperationPerformanceImpl? performance}) async {
+      {OperationPerformanceImpl? performance}) {
     return logger.runAsync('findReferences for ${element.name}', () async {
       var references = <CiderSearchMatch>[];
 
@@ -302,6 +307,7 @@ class FileResolver {
         for (var filePath in result) {
           await collectReferences2(filePath, performance!);
         }
+        _clearFileSystemStateParsedCache();
       }
       return references;
     });
@@ -310,7 +316,7 @@ class FileResolver {
   Future<ErrorsResult> getErrors2({
     required String path,
     OperationPerformanceImpl? performance,
-  }) async {
+  }) {
     _throwIfNotAbsoluteNormalizedPath(path);
 
     performance ??= OperationPerformanceImpl('<default>');
@@ -356,9 +362,7 @@ class FileResolver {
         content: file.content,
         uri: file.uri,
         lineInfo: file.lineInfo,
-        isAugmentation: file.kind is AugmentationFileKind,
         isLibrary: file.kind is LibraryFileKind,
-        isMacroAugmentation: file.isMacroAugmentation,
         isPart: file.kind is PartFileKind,
         errors: errors,
         analysisOptions: file.analysisOptions,
@@ -399,7 +403,7 @@ class FileResolver {
     return fsState.getFilesWithTopLevelDeclarations(name);
   }
 
-  Future<LibraryElement> getLibraryByUri2({
+  Future<LibraryElementImpl> getLibraryByUri2({
     required String uriStr,
     OperationPerformanceImpl? performance,
   }) async {
@@ -423,11 +427,12 @@ class FileResolver {
       throw ArgumentError('$uri is not a library.');
     }
 
-    await performance.runAsync('libraryContext', (performance) async {
-      await libraryContext!.load(
+    performance.run('libraryContext', (performance) {
+      libraryContext!.load(
         targetLibrary: kind,
         performance: performance,
       );
+      _clearFileSystemStateParsedCache();
     });
 
     return libraryContext!.elementFactory.libraryOfUri2(uri);
@@ -477,7 +482,7 @@ class FileResolver {
     var libraryKind = file.kind.library ?? file.kind.asLibrary;
 
     // Load the library, link if necessary.
-    await libraryContext!.load(
+    libraryContext!.load(
       targetLibrary: libraryKind,
       performance: performance,
     );
@@ -487,7 +492,7 @@ class FileResolver {
     var linkedKeysToRelease = libraryContext!.unloadAll();
 
     // Load the library again, the reference count is `>= 2`.
-    await libraryContext!.load(
+    libraryContext!.load(
       targetLibrary: libraryKind,
       performance: performance,
     );
@@ -522,7 +527,7 @@ class FileResolver {
   Future<ResolvedUnitResult> resolve({
     required String path,
     OperationPerformanceImpl? performance,
-  }) async {
+  }) {
     _throwIfNotAbsoluteNormalizedPath(path);
 
     performance ??= OperationPerformanceImpl('<default>');
@@ -541,6 +546,7 @@ class FileResolver {
         path: libraryFile.path,
         performance: performance,
       );
+      _clearFileSystemStateParsedCache();
       var unit = libraryResult.units.firstWhereOrNull(
         (unitResult) => unitResult.path == path,
       );
@@ -559,7 +565,7 @@ class FileResolver {
     required int completionColumn,
     required String path,
     OperationPerformanceImpl? performance,
-  }) async {
+  }) {
     _throwIfNotAbsoluteNormalizedPath(path);
 
     performance ??= OperationPerformanceImpl('<default>');
@@ -575,8 +581,8 @@ class FileResolver {
       var lineOffset = file.lineInfo.getOffsetOfLine(completionLine);
       var completionOffset = lineOffset + completionColumn;
 
-      await performance.runAsync('libraryContext', (performance) async {
-        await libraryContext!.load(
+      performance.run('libraryContext', (performance) {
+        libraryContext!.load(
           targetLibrary: libraryKind,
           performance: performance,
         );
@@ -600,8 +606,10 @@ class FileResolver {
           libraryElement,
           analysisSession.inheritanceManager,
           libraryKind,
+          performance: OperationPerformanceImpl('<root>'),
           typeSystemOperations: typeSystemOperations,
         );
+        _clearFileSystemStateParsedCache();
 
         var analysisResult = performance!.run('analyze', (performance) {
           return libraryAnalyzer.analyzeForCompletion(
@@ -649,8 +657,8 @@ class FileResolver {
       var file = fileContext.file;
       var libraryKind = file.kind.library ?? file.kind.asLibrary;
 
-      await performance.runAsync('libraryContext', (performance) async {
-        await libraryContext!.load(
+      performance.run('libraryContext', (performance) {
+        libraryContext!.load(
           targetLibrary: libraryKind,
           performance: performance,
         );
@@ -674,6 +682,7 @@ class FileResolver {
           libraryElement,
           libraryContext!.elementFactory.analysisSession.inheritanceManager,
           libraryKind,
+          performance: OperationPerformanceImpl('<root>'),
           typeSystemOperations: typeSystemOperations,
         );
 
@@ -705,6 +714,10 @@ class FileResolver {
     });
   }
 
+  void _clearFileSystemStateParsedCache() {
+    fsState?.parsedFileStateCache.clear();
+  }
+
   /// Make sure that [fsState], [contextObjects], and [libraryContext] are
   /// created and configured with the given [fileAnalysisOptions].
   ///
@@ -718,15 +731,21 @@ class FileResolver {
   /// system. And there are lints that are enabled for one package, but not
   /// for another.
   void _createContext(String path, AnalysisOptionsImpl fileAnalysisOptions) {
+    // Clear it here too, so that even if we miss the invocation somewhere,
+    // we still eventually do it, and so limit the number of cached items.
+    _clearFileSystemStateParsedCache();
+
     if (contextObjects != null) {
       libraryContext!.analysisContext.analysisOptions = fileAnalysisOptions;
       return;
     }
 
-    var analysisOptions = AnalysisOptionsImpl()
-      ..strictInference = fileAnalysisOptions.strictInference
-      ..contextFeatures = FeatureSet.latestLanguageVersion()
-      ..nonPackageFeatureSet = FeatureSet.latestLanguageVersion();
+    var analysisOptions = (AnalysisOptionsBuilder()
+          ..strictInference = fileAnalysisOptions.strictInference
+          ..contextFeatures =
+              FeatureSet.latestLanguageVersion() as ExperimentStatus
+          ..nonPackageFeatureSet = FeatureSet.latestLanguageVersion())
+        .build();
 
     if (fsState == null) {
       var featureSetProvider = FeatureSetProvider.build(
@@ -736,7 +755,6 @@ class FileResolver {
       );
 
       fsState = FileSystemState(
-        logger,
         byteStore,
         resourceProvider,
         'contextName',
@@ -783,7 +801,6 @@ class FileResolver {
         fileSystemState: fsState!,
         sourceFactory: sourceFactory,
         externalSummaries: SummaryDataStore(),
-        macroSupport: null,
         packagesFile: null,
         testData: testData?.libraryContext,
       );
@@ -853,12 +870,14 @@ class FileResolver {
       }
     }
 
-    var options = AnalysisOptionsImpl();
+    late AnalysisOptionsImpl options;
 
-    if (optionMap != null) {
+    if (optionMap case YamlMap map) {
       performance.run('applyToAnalysisOptions', (_) {
-        options.applyOptions(optionMap!);
+        options = AnalysisOptionsImpl.fromYaml(optionsMap: map);
       });
+    } else {
+      options = AnalysisOptionsImpl();
     }
 
     if (isThirdParty) {
