@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+import 'package:_fe_analyzer_shared/src/type_inference/type_analysis_result.dart';
+import 'package:_fe_analyzer_shared/src/types/shared_type.dart';
 import 'package:analyzer/src/dart/ast/ast.dart';
 import 'package:analyzer/src/dart/ast/extensions.dart';
 import 'package:analyzer/src/error/codes.dart';
@@ -12,7 +14,7 @@ class ListPatternResolver {
 
   ListPatternResolver(this.resolverVisitor);
 
-  void resolve({
+  PatternResult resolve({
     required ListPatternImpl node,
     required SharedMatchContext context,
   }) {
@@ -22,23 +24,27 @@ class ListPatternResolver {
       // Check that we have exactly one type argument.
       var length = typeArguments.arguments.length;
       if (length != 1) {
-        resolverVisitor.errorReporter.reportErrorForNode(
-          CompileTimeErrorCode.EXPECTED_ONE_LIST_PATTERN_TYPE_ARGUMENTS,
+        resolverVisitor.errorReporter.atNode(
           typeArguments,
-          [length],
+          CompileTimeErrorCode.EXPECTED_ONE_LIST_PATTERN_TYPE_ARGUMENTS,
+          arguments: [length],
         );
       }
     }
 
-    final result = resolverVisitor.analyzeListPattern(context, node,
-        elementType: typeArguments?.arguments.first.typeOrThrow,
+    var elementType = typeArguments?.arguments.first.typeOrThrow;
+    var result = resolverVisitor.analyzeListPattern(context, node,
+        elementType: elementType?.wrapSharedTypeView(),
         elements: node.elements);
-    node.requiredType = result.requiredType;
+    node.requiredType = result.requiredType.unwrapTypeView();
 
     resolverVisitor.checkPatternNeverMatchesValueType(
       context: context,
       pattern: node,
-      requiredType: result.requiredType,
+      requiredType: result.requiredType.unwrapTypeView(),
+      matchedValueType: result.matchedValueType.unwrapTypeView(),
     );
+
+    return result;
   }
 }
