@@ -2,13 +2,16 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'package:_fe_analyzer_shared/src/type_inference/type_analyzer.dart'
     as shared;
 import 'package:_fe_analyzer_shared/src/type_inference/variable_bindings.dart';
 import 'package:analyzer/dart/analysis/features.dart';
+import 'package:analyzer/dart/ast/token.dart';
 import 'package:analyzer/dart/ast/visitor.dart';
 import 'package:analyzer/dart/element/element.dart';
-import 'package:analyzer/dart/element/nullability_suffix.dart';
+import 'package:analyzer/dart/element/element2.dart';
 import 'package:analyzer/dart/element/scope.dart';
 import 'package:analyzer/dart/element/type.dart';
 import 'package:analyzer/dart/element/type_provider.dart';
@@ -19,7 +22,10 @@ import 'package:analyzer/src/dart/ast/extensions.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/dart/element/scope.dart';
 import 'package:analyzer/src/dart/element/type.dart';
+import 'package:analyzer/src/dart/element/type_constraint_gatherer.dart';
+import 'package:analyzer/src/dart/element/type_provider.dart';
 import 'package:analyzer/src/dart/resolver/ast_rewrite.dart';
+import 'package:analyzer/src/dart/resolver/flow_analysis_visitor.dart';
 import 'package:analyzer/src/dart/resolver/named_type_resolver.dart';
 import 'package:analyzer/src/dart/resolver/record_type_annotation_resolver.dart';
 import 'package:analyzer/src/dart/resolver/scope.dart';
@@ -28,6 +34,7 @@ import 'package:analyzer/src/error/codes.dart';
 import 'package:analyzer/src/generated/element_walker.dart';
 import 'package:analyzer/src/generated/utilities_dart.dart';
 import 'package:analyzer/src/utilities/extensions/collection.dart';
+import 'package:analyzer/src/utilities/extensions/element.dart';
 
 class ElementHolder {
   final ElementImpl _element;
@@ -53,7 +60,7 @@ class ElementHolder {
   }
 
   void enclose(ElementImpl element) {
-    element.enclosingElement = _element;
+    element.enclosingElement3 = _element;
   }
 }
 
@@ -66,10 +73,9 @@ class ElementHolder {
 /// 4. Resolve all [GenericFunctionType]s - set their types.
 /// 5. Rewrite AST where resolution provides a more accurate understanding.
 class ResolutionVisitor extends RecursiveAstVisitor<void> {
-  LibraryElementImpl _libraryElement;
-  final TypeProvider _typeProvider;
+  final LibraryElementImpl _libraryElement;
+  final TypeProviderImpl _typeProvider;
   final CompilationUnitElementImpl _unitElement;
-  final bool _isNonNullableByDefault;
   final ErrorReporter _errorReporter;
   final AstRewriter _astRewriter;
   final NamedTypeResolver _namedTypeResolver;
@@ -102,46 +108,58 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     typeProvider: _typeProvider,
   );
 
+  /// The set of required operations on types.
+  final TypeSystemOperations typeSystemOperations;
+
+  final TypeConstraintGenerationDataForTesting? dataForTesting;
+
   factory ResolutionVisitor({
     required CompilationUnitElementImpl unitElement,
     required AnalysisErrorListener errorListener,
-    required FeatureSet featureSet,
     required Scope nameScope,
+    required bool strictInference,
+    required bool strictCasts,
     ElementWalker? elementWalker,
+    required TypeConstraintGenerationDataForTesting? dataForTesting,
   }) {
     var libraryElement = unitElement.library;
     var typeProvider = libraryElement.typeProvider;
     var unitSource = unitElement.source;
-    var isNonNullableByDefault = featureSet.isEnabled(Feature.non_nullable);
-    var errorReporter = ErrorReporter(
-      errorListener,
-      unitSource,
-      isNonNullableByDefault: isNonNullableByDefault,
+    var errorReporter = ErrorReporter(errorListener, unitSource);
+
+    var typeSystemOperations = TypeSystemOperations(
+      unitElement.library.typeSystem,
+      strictCasts: strictCasts,
     );
 
     var namedTypeResolver = NamedTypeResolver(
       libraryElement,
-      isNonNullableByDefault,
+      unitElement,
       errorReporter,
+      strictInference: strictInference,
+      strictCasts: strictCasts,
+      typeSystemOperations: typeSystemOperations,
     );
 
-    final recordTypeResolver = RecordTypeAnnotationResolver(
+    var recordTypeResolver = RecordTypeAnnotationResolver(
       typeProvider: typeProvider,
       errorReporter: errorReporter,
+      libraryElement: libraryElement,
     );
 
     return ResolutionVisitor._(
       libraryElement,
       typeProvider,
       unitElement,
-      isNonNullableByDefault,
       errorReporter,
-      AstRewriter(errorReporter, typeProvider),
+      AstRewriter(errorReporter),
       namedTypeResolver,
       recordTypeResolver,
       nameScope,
       elementWalker,
       ElementHolder(unitElement),
+      typeSystemOperations,
+      dataForTesting,
     );
   }
 
@@ -149,7 +167,6 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     this._libraryElement,
     this._typeProvider,
     this._unitElement,
-    this._isNonNullableByDefault,
     this._errorReporter,
     this._astRewriter,
     this._namedTypeResolver,
@@ -157,9 +174,11 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     this._nameScope,
     this._elementWalker,
     this._elementHolder,
+    this.typeSystemOperations,
+    this.dataForTesting,
   );
 
-  DartType get _dynamicType => _typeProvider.dynamicType;
+  TypeImpl get _dynamicType => _typeProvider.dynamicType;
 
   @override
   void visitAnnotation(covariant AnnotationImpl node) {
@@ -180,32 +199,20 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     node.element = element;
 
     if (element == null) {
-      _errorReporter.reportErrorForToken(
-        CompileTimeErrorCode.UNDEFINED_IDENTIFIER,
+      _errorReporter.atToken(
         node.name,
-        [name],
+        CompileTimeErrorCode.UNDEFINED_IDENTIFIER,
+        arguments: [name],
       );
     } else if (!(element is LocalVariableElement ||
         element is ParameterElement)) {
-      _errorReporter.reportErrorForToken(
-        CompileTimeErrorCode.PATTERN_ASSIGNMENT_NOT_LOCAL_VARIABLE,
+      _errorReporter.atToken(
         node.name,
+        CompileTimeErrorCode.PATTERN_ASSIGNMENT_NOT_LOCAL_VARIABLE,
       );
     }
   }
 
-  @override
-  void visitAugmentationImportDirective(AugmentationImportDirective node) {
-    final element = node.element;
-    if (element is AugmentationImportElementImpl) {
-      _setOrCreateMetadataElements(element, node.metadata);
-    }
-
-    _withElementWalker(null, () {
-      super.visitAugmentationImportDirective(node);
-    });
-  }
-
   @override
   void visitBlock(Block node) {
     var outerScope = _nameScope;
@@ -240,9 +247,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         element.isFinal = true;
         if (exceptionTypeNode == null) {
           element.hasImplicitType = true;
-          var type =
-              _isNonNullableByDefault ? _typeProvider.objectType : _dynamicType;
-          element.type = type;
+          element.type = _typeProvider.objectType;
         } else {
           element.type = exceptionTypeNode.typeOrThrow;
         }
@@ -409,13 +414,13 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       covariant DeclaredVariablePatternImpl node) {
     node.type?.accept(this);
 
-    final name = node.name.lexeme;
+    var name = node.name.lexeme;
     var element = BindPatternVariableElementImpl(
       node,
       name,
       node.name.offset,
     );
-    _patternVariables.add(name, element);
+    _patternVariables.add(name, element.element);
     _elementHolder.enclose(element);
     _define(element);
     element.hasImplicitType = node.type == null;
@@ -543,7 +548,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitExportDirective(ExportDirective node) {
+  void visitExportDirective(covariant ExportDirectiveImpl node) {
     var element = node.element;
     if (element is LibraryExportElementImpl) {
       _setOrCreateMetadataElements(element, node.metadata);
@@ -566,7 +571,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       _withNameScope(() {
         _buildTypeParameterElements(node.typeParameters);
         node.typeParameters?.accept(this);
-        node.extendedType.accept(this);
+        node.onClause?.accept(this);
 
         _defineElements(element.accessors);
         _defineElements(element.methods);
@@ -579,7 +584,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   void visitExtensionTypeDeclaration(
     covariant ExtensionTypeDeclarationImpl node,
   ) {
-    final element = _elementWalker!.getExtensionType();
+    var element = _elementWalker!.getExtensionType();
     node.declaredElement = element;
     _namedTypeResolver.enclosingClass = element;
 
@@ -669,7 +674,8 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     super.visitForEachPartsWithPattern(node);
     var variablesMap = _patternVariables.casePatternFinish();
     node.variables = variablesMap.values
-        .whereType<BindPatternVariableElementImpl>()
+        .whereType<BindPatternVariableElementImpl2>()
+        .map((e) => e.asElement)
         .toList();
   }
 
@@ -689,14 +695,23 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   @override
   void visitFunctionDeclaration(covariant FunctionDeclarationImpl node) {
+    var expression = node.functionExpression;
+
     ExecutableElementImpl element;
     if (_elementWalker != null) {
       element = node.isGetter || node.isSetter
           ? _elementWalker!.getAccessor()
           : _elementWalker!.getFunction();
       node.declaredElement = element;
+      expression.declaredElement = element;
+      expression.declaredFragment = element;
     } else {
-      element = node.declaredElement as ExecutableElementImpl;
+      var functionElement = node.declaredElement as FunctionElementImpl;
+      functionElement.element = LocalFunctionElementImpl(functionElement);
+
+      element = functionElement;
+      expression.declaredElement = functionElement;
+      expression.declaredFragment = functionElement;
 
       _setCodeRange(element, node);
       setElementDocumentationComment(element, node);
@@ -713,9 +728,6 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       }
     }
 
-    var expression = node.functionExpression;
-    expression.declaredElement = element;
-
     _setOrCreateMetadataElements(element, node.metadata);
 
     var holder = ElementHolder(element);
@@ -761,34 +773,37 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitFunctionExpression(FunctionExpression node) {
-    var element = FunctionElementImpl.forOffset(node.offset);
-    _elementHolder.enclose(element);
-    (node as FunctionExpressionImpl).declaredElement = element;
+  void visitFunctionExpression(covariant FunctionExpressionImpl node) {
+    var fragment = FunctionElementImpl.forOffset(node.offset);
+    fragment.element = LocalFunctionElementImpl(fragment);
 
-    element.hasImplicitReturnType = true;
-    element.returnType = DynamicTypeImpl.instance;
+    _elementHolder.enclose(fragment);
+    node.declaredElement = fragment;
+    node.declaredFragment = fragment;
+
+    fragment.hasImplicitReturnType = true;
+    fragment.returnType = DynamicTypeImpl.instance;
 
     FunctionBody body = node.body;
-    element.isAsynchronous = body.isAsynchronous;
-    element.isGenerator = body.isGenerator;
+    fragment.isAsynchronous = body.isAsynchronous;
+    fragment.isGenerator = body.isGenerator;
 
-    var holder = ElementHolder(element);
+    var holder = ElementHolder(fragment);
     _withElementHolder(holder, () {
       _withNameScope(() {
         _buildTypeParameterElements(node.typeParameters);
         node.typeParameters?.accept(this);
-        element.typeParameters = holder.typeParameters;
+        fragment.typeParameters = holder.typeParameters;
 
         node.parameters!.accept(this);
-        element.parameters = holder.parameters;
+        fragment.parameters = holder.parameters;
 
-        _defineParameters(element.parameters);
+        _defineParameters(fragment.parameters);
         node.body.accept(this);
       });
     });
 
-    _setCodeRange(element, node);
+    _setCodeRange(fragment, node);
   }
 
   @override
@@ -934,7 +949,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitImportDirective(ImportDirective node) {
+  void visitImportDirective(covariant ImportDirectiveImpl node) {
     var element = node.element;
     if (element is LibraryImportElementImpl) {
       _setOrCreateMetadataElements(element, node.metadata);
@@ -962,8 +977,10 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         //
         // This is a case where the parser does not report an error, because the
         // parser thinks this could be an InstanceCreationExpression.
-        _errorReporter.reportErrorForNode(
-            WarningCode.SDK_VERSION_CONSTRUCTOR_TEAROFFS, node, []);
+        _errorReporter.atNode(
+          node,
+          WarningCode.SDK_VERSION_CONSTRUCTOR_TEAROFFS,
+        );
       }
       return newNode.accept(this);
     }
@@ -994,19 +1011,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitLibraryAugmentationDirective(LibraryAugmentationDirective node) {
-    final element = node.element;
-    if (element is LibraryOrAugmentationElementImpl) {
-      _setOrCreateMetadataElements(element, node.metadata);
-    }
-
-    _withElementWalker(null, () {
-      super.visitLibraryAugmentationDirective(node);
-    });
-  }
-
-  @override
-  void visitLibraryDirective(LibraryDirective node) {
+  void visitLibraryDirective(covariant LibraryDirectiveImpl node) {
     ++_libraryDirectiveIndex;
     var element = node.element;
     if (element is LibraryElementImpl && _libraryDirectiveIndex == 1) {
@@ -1103,7 +1108,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     node.typeArguments?.accept(this);
 
     _namedTypeResolver.nameScope = _nameScope;
-    _namedTypeResolver.resolve(node);
+    _namedTypeResolver.resolve(node, dataForTesting: dataForTesting);
 
     if (_namedTypeResolver.rewriteResult != null) {
       _namedTypeResolver.rewriteResult!.accept(this);
@@ -1111,7 +1116,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitPartDirective(PartDirective node) {
+  void visitPartDirective(covariant PartDirectiveImpl node) {
     var element = node.element;
     if (element is PartElementImpl) {
       _setOrCreateMetadataElements(element, node.metadata);
@@ -1148,7 +1153,8 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     super.visitPatternVariableDeclaration(node);
     var variablesMap = _patternVariables.casePatternFinish();
     node.elements = variablesMap.values
-        .whereType<BindPatternVariableElementImpl>()
+        .whereType<BindPatternVariableElementImpl2>()
+        .map((e) => e.asElement)
         .toList();
   }
 
@@ -1185,8 +1191,11 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   void visitRepresentationDeclaration(
     covariant RepresentationDeclarationImpl node,
   ) {
-    node.fieldElement = _elementWalker!.getVariable() as FieldElementImpl;
-    node.constructorElement = _elementWalker!.getConstructor();
+    var element = _elementWalker!.element as ExtensionTypeElementImpl;
+    if (element.augmentationTarget == null) {
+      node.fieldElement = _elementWalker!.getVariable() as FieldElementImpl;
+      node.constructorElement = _elementWalker!.getConstructor();
+    }
 
     super.visitRepresentationDeclaration(node);
   }
@@ -1238,7 +1247,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   @override
   void visitSimpleIdentifier(covariant SimpleIdentifierImpl node) {
-    final newNode = _astRewriter.simpleIdentifier(_nameScope, node);
+    var newNode = _astRewriter.simpleIdentifier(_nameScope, node);
     if (newNode != node) {
       return newNode.accept(this);
     }
@@ -1368,7 +1377,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitTypeParameter(TypeParameter node) {
+  void visitTypeParameter(covariant TypeParameterImpl node) {
     var element = node.declaredElement as TypeParameterElementImpl;
 
     _setOrCreateMetadataElements(element, node.metadata);
@@ -1394,7 +1403,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       var localElement = node.declaredElement as LocalVariableElementImpl;
       element = localElement;
 
-      var varList = node.parent as VariableDeclarationList;
+      var varList = node.parent as VariableDeclarationListImpl;
       localElement.hasImplicitType = varList.type == null;
       localElement.hasInitializer = initializerNode != null;
       localElement.type = varList.type?.type ?? _dynamicType;
@@ -1410,7 +1419,9 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   @override
-  void visitVariableDeclarationList(VariableDeclarationList node) {
+  void visitVariableDeclarationList(
+    covariant VariableDeclarationListImpl node,
+  ) {
     var parent = node.parent;
     if (parent is ForPartsWithDeclarations ||
         parent is VariableDeclarationStatement &&
@@ -1420,10 +1431,10 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
     node.visitChildren(this);
 
-    NodeList<Annotation> annotations;
-    if (parent is FieldDeclaration) {
+    NodeList<AnnotationImpl> annotations;
+    if (parent is FieldDeclarationImpl) {
       annotations = parent.metadata;
-    } else if (parent is TopLevelVariableDeclaration) {
+    } else if (parent is TopLevelVariableDeclarationImpl) {
       annotations = parent.metadata;
     } else {
       // Local variable declaration
@@ -1472,10 +1483,22 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       covariant FunctionDeclarationStatementImpl statement) {
     var node = statement.functionDeclaration;
     var nameToken = node.name;
-    var element = FunctionElementImpl(nameToken.lexeme, nameToken.offset);
-    node.declaredElement = element;
-    _define(element);
-    _elementHolder.enclose(element);
+
+    var fragment = FunctionElementImpl(nameToken.lexeme, nameToken.offset);
+    fragment.name2 = nameToken.nameIfNotEmpty;
+    fragment.nameOffset2 = nameToken.offsetIfNotEmpty;
+    node.declaredElement = fragment;
+
+    fragment.element = LocalFunctionElementImpl(fragment);
+    node.functionExpression.declaredFragment = fragment;
+
+    // The fragment's old enclosing element needs to be set before we can get
+    // the new element for it.
+    _elementHolder.enclose(fragment);
+
+    if (!_isWildCardVariable(nameToken.lexeme)) {
+      _define(fragment);
+    }
   }
 
   void _buildLocalVariableElements(VariableDeclarationList variableList) {
@@ -1523,12 +1546,18 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         element = _elementWalker!.getTypeParameter();
       } else {
         element = TypeParameterElementImpl(name.lexeme, name.offset);
+        element.name2 = name.lexeme;
+        element.nameOffset2 = name.offset;
         _elementHolder.addTypeParameter(element);
 
         _setCodeRange(element, typeParameter);
       }
       typeParameter.declaredElement = element;
-      _define(element);
+
+      if (!_isWildCardVariable(element.name)) {
+        _define(element);
+      }
+
       _setOrCreateMetadataElements(element, typeParameter.metadata);
     }
   }
@@ -1541,7 +1570,9 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   void _define(Element element) {
-    (_nameScope as LocalScope).add(element);
+    if (_nameScope case LocalScope nameScope) {
+      nameScope.add(element.asElement2!);
+    }
   }
 
   /// Define given [elements] in the [_nameScope].
@@ -1565,16 +1596,17 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   }
 
   NullabilitySuffix _getNullability(bool hasQuestion) {
-    if (_isNonNullableByDefault) {
-      if (hasQuestion) {
-        return NullabilitySuffix.question;
-      } else {
-        return NullabilitySuffix.none;
-      }
+    if (hasQuestion) {
+      return NullabilitySuffix.question;
+    } else {
+      return NullabilitySuffix.none;
     }
-    return NullabilitySuffix.star;
   }
 
+  bool _isWildCardVariable(String name) =>
+      name == '_' &&
+      _libraryElement.featureSet.isEnabled(Feature.wildcard_variables);
+
   void _resolveGuardedPattern(
     GuardedPatternImpl guardedPattern, {
     Object? sharedCaseScopeKey,
@@ -1588,7 +1620,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     // Matched variables are available in `whenClause`.
     _withNameScope(() {
       for (var variable in variables.values) {
-        _define(variable);
+        _define(variable.asElement!);
       }
       guardedPattern.variables = variables.cast();
       guardedPattern.whenClause?.accept(this);
@@ -1613,7 +1645,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   void _resolveOnClause({
     required Declaration? declaration,
-    required OnClauseImpl? clause,
+    required MixinOnClauseImpl? clause,
   }) {
     if (clause == null) return;
 
@@ -1651,27 +1683,27 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       return;
     }
 
-    final type = namedType.typeOrThrow;
+    var type = namedType.typeOrThrow;
 
-    final enclosingElement = _namedTypeResolver.enclosingClass;
+    var enclosingElement = _namedTypeResolver.enclosingClass;
     if (enclosingElement is ExtensionTypeElementImpl) {
       _verifyExtensionElementImplements(enclosingElement, namedType, type);
       return;
     }
 
-    final element = type.element;
+    var element = type.element;
     switch (element) {
       case ClassElement():
         return;
       case MixinElement():
         if (clause is ImplementsClause ||
-            clause is OnClause ||
+            clause is MixinOnClause ||
             clause is WithClause) {
           return;
         }
     }
 
-    if (_libraryElement.shouldIgnoreUndefinedNamedType(namedType)) {
+    if (_unitElement.shouldIgnoreUndefinedNamedType(namedType)) {
       return;
     }
 
@@ -1689,7 +1721,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         }
       case ImplementsClause():
         errorCode = CompileTimeErrorCode.IMPLEMENTS_NON_CLASS;
-      case OnClause():
+      case MixinOnClause():
         errorCode =
             CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE;
       case WithClause():
@@ -1702,10 +1734,14 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       return;
     }
 
-    final firstToken = namedType.importPrefix?.name ?? namedType.name2;
-    final offset = firstToken.offset;
-    final length = namedType.name2.end - offset;
-    _errorReporter.reportErrorForOffset(errorCode, offset, length);
+    var firstToken = namedType.importPrefix?.name ?? namedType.name2;
+    var offset = firstToken.offset;
+    var length = namedType.name2.end - offset;
+    _errorReporter.atOffset(
+      offset: offset,
+      length: length,
+      errorCode: errorCode,
+    );
   }
 
   /// Resolve the types in the given list of type names.
@@ -1754,7 +1790,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   void _setOrCreateMetadataElements(
     ElementImpl element,
-    NodeList<Annotation> annotations, {
+    NodeList<AnnotationImpl> annotations, {
     bool visitNodes = true,
   }) {
     if (visitNodes) {
@@ -1774,31 +1810,35 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     NamedTypeImpl node,
     DartType type,
   ) {
-    final typeSystem = _libraryElement.typeSystem;
+    var typeSystem = _libraryElement.typeSystem;
 
     if (!typeSystem.isValidExtensionTypeSuperinterface(type)) {
-      _errorReporter.reportErrorForNode(
-        CompileTimeErrorCode.EXTENSION_TYPE_IMPLEMENTS_DISALLOWED_TYPE,
+      _errorReporter.atNode(
         node,
-        [type],
+        CompileTimeErrorCode.EXTENSION_TYPE_IMPLEMENTS_DISALLOWED_TYPE,
+        arguments: [type],
       );
       return;
     }
 
+    var declaredRepresentation = declaredElement.representation.type;
+    if (typeSystem.isSubtypeOf(declaredRepresentation, type)) {
+      return;
+    }
+
     // When `type` is an extension type.
     if (type is InterfaceTypeImpl) {
-      final implementedRepresentation = type.representationType;
+      var implementedRepresentation = type.representationType;
       if (implementedRepresentation != null) {
-        final declaredRepresentation = declaredElement.representation.type;
         if (!typeSystem.isSubtypeOf(
           declaredRepresentation,
           implementedRepresentation,
         )) {
-          _errorReporter.reportErrorForNode(
+          _errorReporter.atNode(
+            node,
             CompileTimeErrorCode
                 .EXTENSION_TYPE_IMPLEMENTS_REPRESENTATION_NOT_SUPERTYPE,
-            node,
-            [
+            arguments: [
               implementedRepresentation,
               type.element.name,
               declaredRepresentation,
@@ -1810,14 +1850,11 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       }
     }
 
-    final declaredRepresentation = declaredElement.representation.type;
-    if (!typeSystem.isSubtypeOf(declaredRepresentation, type)) {
-      _errorReporter.reportErrorForNode(
-        CompileTimeErrorCode.EXTENSION_TYPE_IMPLEMENTS_NOT_SUPERTYPE,
-        node,
-        [type, declaredRepresentation],
-      );
-    }
+    _errorReporter.atNode(
+      node,
+      CompileTimeErrorCode.EXTENSION_TYPE_IMPLEMENTS_NOT_SUPERTYPE,
+      arguments: [type, declaredRepresentation],
+    );
   }
 
   void _visitIf(IfElementOrStatementImpl node) {
@@ -1877,7 +1914,9 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   /// Associate each of the annotation [nodes] with the corresponding
   /// [ElementAnnotation] in [annotations].
   static void _setElementAnnotations(
-      List<Annotation> nodes, List<ElementAnnotation> annotations) {
+    List<AnnotationImpl> nodes,
+    List<ElementAnnotationImpl> annotations,
+  ) {
     int nodeCount = nodes.length;
     if (nodeCount != annotations.length) {
       throw StateError(
@@ -1886,13 +1925,13 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
       );
     }
     for (int i = 0; i < nodeCount; i++) {
-      (nodes[i] as AnnotationImpl).elementAnnotation = annotations[i];
+      nodes[i].elementAnnotation = annotations[i];
     }
   }
 }
 
 class _VariableBinder
-    extends VariableBinder<DartPatternImpl, PromotableElement> {
+    extends VariableBinder<DartPatternImpl, PromotableElementImpl2> {
   final TypeProvider typeProvider;
 
   _VariableBinder({
@@ -1901,61 +1940,63 @@ class _VariableBinder
   });
 
   @override
-  JoinPatternVariableElementImpl joinPatternVariables({
+  JoinPatternVariableElementImpl2 joinPatternVariables({
     required Object key,
-    required List<PromotableElement> components,
+    required List<PromotableElement2> components,
     required shared.JoinedPatternVariableInconsistency inconsistency,
   }) {
     var first = components.first;
     List<PatternVariableElementImpl> expandedVariables;
     if (key is LogicalOrPatternImpl) {
       expandedVariables = components.expand((variable) {
-        variable as PatternVariableElementImpl;
-        if (variable is JoinPatternVariableElementImpl) {
+        variable as PatternVariableElementImpl2;
+        if (variable is JoinPatternVariableElementImpl2) {
           return variable.variables;
         } else {
-          return [variable];
+          return [variable.asElement as PatternVariableElementImpl];
         }
       }).toList(growable: false);
     } else if (key is SwitchStatementCaseGroup) {
       expandedVariables = components
-          .map((e) => e as PatternVariableElementImpl)
+          .map((e) => e.asElement as PatternVariableElementImpl)
           .toList(growable: false);
     } else {
       throw UnimplementedError('(${key.runtimeType}) $key');
     }
-    return JoinPatternVariableElementImpl(
-      first.name,
+    return (JoinPatternVariableElementImpl(
+      first.name3!,
       -1,
       expandedVariables,
       inconsistency.maxWithAll(
         components
-            .whereType<JoinPatternVariableElementImpl>()
+            .whereType<JoinPatternVariableElementImpl2>()
             .map((e) => e.inconsistency),
       ),
     )
-      ..enclosingElement = first.enclosingElement
-      ..type = InvalidTypeImpl.instance;
+          ..enclosingElement3 =
+              first.firstFragment.enclosingFragment!.element.asElement!
+          ..type = InvalidTypeImpl.instance)
+        .element;
   }
 }
 
 class _VariableBinderErrors
-    implements VariableBinderErrors<DartPatternImpl, PromotableElement> {
+    implements VariableBinderErrors<DartPatternImpl, PromotableElementImpl2> {
   final ResolutionVisitor visitor;
 
   _VariableBinderErrors(this.visitor);
 
   @override
   void assertInErrorRecovery() {
-    // TODO: implement assertInErrorRecovery
+    // TODO(scheglov): implement assertInErrorRecovery
     throw UnimplementedError();
   }
 
   @override
   void duplicateVariablePattern({
     required String name,
-    required covariant BindPatternVariableElementImpl original,
-    required covariant BindPatternVariableElementImpl duplicate,
+    required covariant BindPatternVariableElementImpl2 original,
+    required covariant BindPatternVariableElementImpl2 duplicate,
   }) {
     visitor._errorReporter.reportError(
       DiagnosticFactory().duplicateDefinitionForNodes(
@@ -1974,12 +2015,22 @@ class _VariableBinderErrors
     required covariant LogicalOrPatternImpl node,
     required bool hasInLeft,
     required String name,
-    required PromotableElement variable,
+    required PromotableElement2 variable,
   }) {
-    visitor._errorReporter.reportErrorForNode(
-      CompileTimeErrorCode.MISSING_VARIABLE_PATTERN,
+    visitor._errorReporter.atNode(
       hasInLeft ? node.rightOperand : node.leftOperand,
-      [name],
+      CompileTimeErrorCode.MISSING_VARIABLE_PATTERN,
+      arguments: [name],
     );
   }
 }
+
+extension on Token {
+  String? get nameIfNotEmpty {
+    return lexeme.isNotEmpty ? lexeme : null;
+  }
+
+  int? get offsetIfNotEmpty {
+    return lexeme.isNotEmpty ? offset : null;
+  }
+}
