@@ -8,9 +8,22 @@ import 'package:yaml/yaml.dart';
 
 /// Validate the value of the required `name` field.
 void nameValidator(PubspecValidationContext ctx) {
-  var nameField = ctx.contents[PubspecField.NAME_FIELD];
+  var contents = ctx.contents;
+  if (contents is! YamlMap) {
+    ctx.reporter.atOffset(
+      offset: 0,
+      length: 0,
+      errorCode: PubspecWarningCode.MISSING_NAME,
+    );
+    return;
+  }
+  var nameField = contents.nodes[PubspecField.NAME_FIELD];
   if (nameField == null) {
-    ctx.reporter.reportErrorForOffset(PubspecWarningCode.MISSING_NAME, 0, 0);
+    ctx.reporter.atOffset(
+      offset: 0,
+      length: 0,
+      errorCode: PubspecWarningCode.MISSING_NAME,
+    );
   } else if (nameField is! YamlScalar || nameField.value is! String) {
     ctx.reportErrorForNode(nameField, PubspecWarningCode.NAME_NOT_STRING);
   }
