@@ -106,11 +106,14 @@ class _StorageImpl implements Storage {
   }
 
   @override
-  Future copyObject(String src, String dest) {
+  Future copyObject(String src, String dest, {ObjectMetadata? metadata}) {
     var srcName = _AbsoluteName.parse(src);
     var destName = _AbsoluteName.parse(dest);
+    metadata ??= _ObjectMetadata();
+    var objectMetadata = metadata as _ObjectMetadata;
+    final object = objectMetadata._object;
     return _api.objects
-        .copy(storage_api.Object(), srcName.bucketName, srcName.objectName,
+        .copy(object, srcName.bucketName, srcName.objectName,
             destName.bucketName, destName.objectName)
         .then((_) => null);
   }
@@ -283,13 +286,13 @@ class _BucketImpl implements Bucket {
     // TODO: support other ObjectMetadata implementations?
     var md = metadata as _ObjectMetadata;
     var object = md._object;
-    if (md._object.acl == null && _defaultObjectAcl == null) {
-      throw ArgumentError('ACL is required for update');
-    }
     if (md.contentType == null) {
       throw ArgumentError('Content-Type is required for update');
     }
-    md._object.acl ??= _defaultObjectAcl!._toObjectAccessControlList();
+    // If no ACL is passed use the default (if any).
+    if (object.acl == null && _defaultObjectAcl != null) {
+      object.acl = _defaultObjectAcl!._toObjectAccessControlList();
+    }
     return _api.objects.update(object, bucketName, objectName);
   }
 
@@ -346,9 +349,9 @@ class _ObjectPageImpl implements Page<BucketEntry> {
       storage_api.Objects response)
       : items = [
           for (final item in response.prefixes ?? const <String>[])
-            BucketEntry._directory(item),
+            BucketDirectoryEntry._(item),
           for (final item in response.items ?? const <storage_api.Object>[])
-            BucketEntry._object(item.name!)
+            _BucketObjectEntry(item)
         ],
         _nextPageToken = response.nextPageToken;
 
@@ -427,6 +430,16 @@ class _ObjectInfoImpl implements ObjectInfo {
   ObjectMetadata get metadata => _metadata;
 }
 
+class _BucketObjectEntry extends _ObjectInfoImpl implements BucketObjectEntry {
+  _BucketObjectEntry(storage_api.Object object) : super(object);
+
+  @override
+  bool get isDirectory => false;
+
+  @override
+  bool get isObject => true;
+}
+
 class _ObjectMetadata implements ObjectMetadata {
   final storage_api.Object _object;
   Acl? _cachedAcl;
@@ -501,8 +514,8 @@ class _ObjectMetadata implements ObjectMetadata {
         contentType: contentType ?? this.contentType,
         contentEncoding: contentEncoding ?? this.contentEncoding,
         cacheControl: cacheControl ?? this.cacheControl,
-        contentDisposition: contentDisposition ?? this.contentEncoding,
-        contentLanguage: contentLanguage ?? this.contentEncoding,
+        contentDisposition: contentDisposition ?? this.contentDisposition,
+        contentLanguage: contentLanguage ?? this.contentLanguage,
         custom: custom != null ? Map.from(custom) : this.custom);
   }
 }
