@@ -2,11 +2,15 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'dart:typed_data';
 
+import 'package:_fe_analyzer_shared/src/type_inference/type_analyzer_operations.dart';
 import 'package:analyzer/dart/analysis/features.dart';
 import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/element/element.dart';
+import 'package:analyzer/dart/element/element2.dart';
 import 'package:analyzer/dart/element/nullability_suffix.dart';
 import 'package:analyzer/dart/element/type.dart';
 import 'package:analyzer/src/dart/analysis/experiments.dart';
@@ -15,16 +19,14 @@ import 'package:analyzer/src/dart/element/field_name_non_promotability_info.dart
 import 'package:analyzer/src/dart/element/member.dart';
 import 'package:analyzer/src/dart/element/type.dart';
 import 'package:analyzer/src/dart/element/type_algebra.dart';
-import 'package:analyzer/src/dart/resolver/variance.dart';
+import 'package:analyzer/src/error/inference_error.dart';
 import 'package:analyzer/src/summary2/ast_binary_tag.dart';
 import 'package:analyzer/src/summary2/ast_binary_writer.dart';
 import 'package:analyzer/src/summary2/data_writer.dart';
 import 'package:analyzer/src/summary2/element_flags.dart';
 import 'package:analyzer/src/summary2/export.dart';
-import 'package:analyzer/src/summary2/macro_application_error.dart';
 import 'package:analyzer/src/summary2/reference.dart';
-import 'package:analyzer/src/task/inference_error.dart';
-import 'package:collection/collection.dart';
+import 'package:analyzer/src/utilities/extensions/object.dart';
 
 class BundleWriter {
   late final _BundleWriterReferences _references;
@@ -57,17 +59,6 @@ class BundleWriter {
   /// and read them later on demand.
   List<int> _classMembersLengths = [];
 
-  /// [_writePropertyAccessorElement] adds augmentations here, so that after
-  /// reading the library we can read them, and while doing this, update
-  /// `getter` and `setter` of augmented variables.
-  List<PropertyAccessorElementImpl> _accessorAugmentations = [];
-
-  /// [_writeFieldElement] adds augmentations here, so that after
-  /// reading the library we can read them, and while doing this, update
-  /// getters and setter to point at this property augmentation, and set
-  /// `getter` and `setter` of the augmentation.
-  List<PropertyInducingElementImpl> _propertyAugmentations = [];
-
   final StringIndexer _stringIndexer = StringIndexer();
 
   final List<_Library> _libraries = [];
@@ -85,9 +76,6 @@ class BundleWriter {
       _sink._writeStringReference(library.uriStr);
       _sink.writeUInt30(library.offset);
       _sink.writeUint30List(library.classMembersOffsets);
-      _sink.writeOptionalObject(library.macroGenerated, (it) {
-        _sink.writeStringUtf8(it.code);
-      });
     });
 
     var referencesOffset = _sink.offset;
@@ -112,70 +100,55 @@ class BundleWriter {
   void writeLibraryElement(LibraryElementImpl libraryElement) {
     var libraryOffset = _sink.offset;
     _classMembersLengths = [];
-    _accessorAugmentations = [];
-    _propertyAugmentations = [];
 
-    _sink.writeUInt30(_resolutionSink.offset);
+    // Write non-resolution data for the library.
     _sink._writeStringReference(libraryElement.name);
     _writeFeatureSet(libraryElement.featureSet);
+    LibraryElementFlags.write(_sink, libraryElement);
     _writeLanguageVersion(libraryElement.languageVersion);
-    _writeLibraryOrAugmentationElement(libraryElement);
-    for (final partElement in libraryElement.parts) {
-      _resolutionSink._writeAnnotationList(partElement.metadata);
-    }
+    _writeExportedReferences(libraryElement.exportedReferences);
+    _sink.writeUint30List(libraryElement.nameUnion.mask);
+    _writeLoadLibraryFunctionReferences(libraryElement);
+
+    // Write the library units.
+    // This will write also resolution data, e.g. for classes.
+    _writeUnitElement(libraryElement.definingCompilationUnit);
+
+    // Write resolution data for the library.
+    _sink.writeUInt30(_resolutionSink.offset);
+    _resolutionSink._writeAnnotationList(libraryElement.metadata);
     _resolutionSink.writeElement(libraryElement.entryPoint);
     _writeFieldNameNonPromotabilityInfo(
         libraryElement.fieldNameNonPromotabilityInfo);
-    LibraryElementFlags.write(_sink, libraryElement);
-    _writeUnitElement(libraryElement.definingCompilationUnit);
-    _writeList(libraryElement.parts, _writePartElement);
-
-    _writeExportedReferences(libraryElement.exportedReferences);
-
-    _sink.writeUint30List(libraryElement.nameUnion.mask);
-
-    _writePropertyAccessorAugmentations();
-
-    final lastAugmentation = libraryElement.augmentations.lastOrNull;
-    final macroGenerated = lastAugmentation?.macroGenerated;
 
     _libraries.add(
       _Library(
         uriStr: '${libraryElement.source.uri}',
         offset: libraryOffset,
         classMembersOffsets: _classMembersLengths,
-        macroGenerated: macroGenerated,
       ),
     );
   }
 
-  void _writeAugmentationElement(LibraryAugmentationElementImpl augmentation) {
-    _sink.writeOptionalObject(augmentation.macroGenerated, (macroGenerated) {
-      _sink.writeStringUtf8(macroGenerated.code);
-      _sink.writeUint8List(macroGenerated.informativeBytes);
-    });
-    _writeUnitElement(augmentation.definingCompilationUnit);
-    // The offset where resolution for the augmentation starts.
-    // We need it to skip resolution information from the unit.
-    _sink.writeUInt30(_resolutionSink.offset);
-    _writeLibraryOrAugmentationElement(augmentation);
-  }
+  void _writeAugmentationTargetAny<T extends AugmentableElement<T>>(
+    T fragment,
+  ) {
+    var target = fragment.augmentationTargetAny;
+    _writeOptionalReference(target?.reference);
 
-  void _writeAugmentationImportElement(AugmentationImportElementImpl element) {
-    _resolutionSink._writeAnnotationList(element.metadata);
-    _writeDirectiveUri(element.uri);
+    var maybeFragment = fragment.augmentationTarget?.augmentation;
+    var shouldSetAugmentation = identical(maybeFragment, fragment);
+    _sink.writeBool(shouldSetAugmentation);
   }
 
   void _writeClassElement(ClassElementImpl element) {
     _sink.writeUInt30(_resolutionSink.offset);
 
     _writeReference(element);
+    _writeReference2(element.augmented.reference);
+    _writeFragmentName(element);
     ClassElementFlags.write(_sink, element);
-
-    _sink.writeList<MacroApplicationError>(
-      element.macroApplicationErrors,
-      (x) => x.write(_sink),
-    );
+    _writeAugmentationTargetAny(element);
 
     _resolutionSink._writeAnnotationList(element.metadata);
 
@@ -183,21 +156,14 @@ class BundleWriter {
       _resolutionSink.writeType(element.supertype);
       _resolutionSink._writeTypeList(element.mixins);
       _resolutionSink._writeTypeList(element.interfaces);
-      _resolutionSink.writeElement(element.augmentation);
-      if (element.isAugmentation) {
-        _resolutionSink.writeElement(element.augmentationTarget);
-      } else {
-        _resolutionSink.writeIfType<AugmentedClassElementImpl>(
-          element.augmented,
-          (augmented) {
-            _resolutionSink._writeTypeList(augmented.mixins);
-            _resolutionSink._writeTypeList(augmented.interfaces);
-            _resolutionSink._writeElementList(augmented.fields);
-            _resolutionSink._writeElementList(augmented.constructors);
-            _resolutionSink._writeElementList(augmented.accessors);
-            _resolutionSink._writeElementList(augmented.methods);
-          },
-        );
+      if (element.augmentationTarget == null) {
+        var augmented = element.augmented;
+        _resolutionSink._writeTypeList(augmented.mixins);
+        _resolutionSink._writeTypeList(augmented.interfaces);
+        _resolutionSink._writeElementList(augmented.fields);
+        _resolutionSink._writeElementList(augmented.constructors);
+        _resolutionSink._writeElementList(augmented.accessors);
+        _resolutionSink._writeElementList(augmented.methods);
       }
 
       if (!element.isMixinApplication) {
@@ -220,7 +186,10 @@ class BundleWriter {
   void _writeConstructorElement(ConstructorElementImpl element) {
     _sink.writeUInt30(_resolutionSink.offset);
     _writeReference(element);
+    _sink._writeOptionalStringReference(element.typeName);
+    _sink._writeStringReference(element.name2);
     ConstructorElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _resolutionSink.localElements.withElements(element.parameters, () {
@@ -246,11 +215,7 @@ class BundleWriter {
       _sink._writeStringReference('${element.source.uri}');
     }
 
-    if (element is DirectiveUriWithAugmentationImpl) {
-      _sink.writeByte(DirectiveUriKind.withAugmentation.index);
-      writeWithSource(element);
-      _writeAugmentationElement(element.augmentation);
-    } else if (element is DirectiveUriWithLibrary) {
+    if (element is DirectiveUriWithLibrary) {
       _sink.writeByte(DirectiveUriKind.withLibrary.index);
       writeWithSource(element);
     } else if (element is DirectiveUriWithUnitImpl) {
@@ -274,13 +239,26 @@ class BundleWriter {
   void _writeEnumElement(EnumElementImpl element) {
     _sink.writeUInt30(_resolutionSink.offset);
     _writeReference(element);
+    _writeReference2(element.augmented.reference);
+    _writeFragmentName(element);
     EnumElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
+
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
       _resolutionSink.writeType(element.supertype);
       _resolutionSink._writeTypeList(element.mixins);
       _resolutionSink._writeTypeList(element.interfaces);
+      if (element.augmentationTarget == null) {
+        var augmented = element.augmented;
+        _resolutionSink._writeTypeList(augmented.mixins);
+        _resolutionSink._writeTypeList(augmented.interfaces);
+        _resolutionSink._writeElementList(augmented.fields);
+        _resolutionSink._writeElementList(augmented.constructors);
+        _resolutionSink._writeElementList(augmented.accessors);
+        _resolutionSink._writeElementList(augmented.methods);
+      }
 
       _writeList(
         element.fields.where((e) {
@@ -299,7 +277,7 @@ class BundleWriter {
 
   void _writeExportedReferences(List<ExportedReference> elements) {
     _writeList<ExportedReference>(elements, (exported) {
-      final index = _references._indexOfReference(exported.reference);
+      var index = _references._indexOfReference(exported.reference);
       if (exported is ExportedReferenceDeclared) {
         _sink.writeByte(0);
         _sink.writeUInt30(index);
@@ -320,7 +298,7 @@ class BundleWriter {
   }
 
   void _writeExportLocation(ExportLocation location) {
-    _sink.writeUInt30(location.containerIndex);
+    _sink.writeUInt30(location.fragmentIndex);
     _sink.writeUInt30(location.exportIndex);
   }
 
@@ -328,12 +306,21 @@ class BundleWriter {
     _sink.writeUInt30(_resolutionSink.offset);
 
     _writeReference(element);
-    _sink.writeBool(element.name != null);
+    _writeReference2(element.augmented.reference);
+    _writeFragmentName(element);
+    ExtensionElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
 
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
-      _resolutionSink.writeType(element.extendedType);
+      if (element.augmentationTarget == null) {
+        var augmented = element.augmented;
+        _resolutionSink.writeType(augmented.extendedType);
+        _resolutionSink._writeElementList(augmented.fields);
+        _resolutionSink._writeElementList(augmented.accessors);
+        _resolutionSink._writeElementList(augmented.methods);
+      }
 
       _writeList(
         element.accessors.where((e) => !e.isSynthetic).toList(),
@@ -350,12 +337,25 @@ class BundleWriter {
   void _writeExtensionTypeElement(ExtensionTypeElementImpl element) {
     _sink.writeUInt30(_resolutionSink.offset);
     _writeReference(element);
+    _writeReference2(element.augmented.reference);
+    _writeFragmentName(element);
     ExtensionTypeElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
+
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
-      _resolutionSink.writeType(element.typeErasure);
       _resolutionSink._writeTypeList(element.interfaces);
+      if (element.augmentationTarget == null) {
+        var augmented = element.augmented;
+        _resolutionSink._writeTypeList(augmented.interfaces);
+        _resolutionSink._writeElementList(augmented.fields);
+        _resolutionSink._writeElementList(augmented.accessors);
+        _resolutionSink._writeElementList(augmented.constructors);
+        _resolutionSink._writeElementList(augmented.methods);
+        _resolutionSink.writeType(augmented.typeErasure);
+      }
+
       _writeList(
         element.fields.where((e) => !e.isSynthetic).toList(),
         _writeFieldElement,
@@ -380,77 +380,75 @@ class BundleWriter {
     _writeReference(element);
     _writeOptionalReference(element.getter?.reference);
     _writeOptionalReference(element.setter?.reference);
+    _writeFragmentName(element);
+    _sink._writeStringReference(element.name);
     _sink.writeBool(element is ConstFieldElementImpl);
     FieldElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
     _sink._writeTopLevelInferenceError(element.typeInferenceError);
     _resolutionSink._writeAnnotationList(element.metadata);
     _resolutionSink.writeType(element.type);
-
-    _resolutionSink.writeElement(element.augmentationTarget);
-    if (element.isAugmentation) {
-      _propertyAugmentations.add(element);
-    }
-
     _resolutionSink._writeOptionalNode(element.constantInitializer);
   }
 
   void _writeFieldNameNonPromotabilityInfo(
       Map<String, FieldNameNonPromotabilityInfo>? info) {
-    // The summary format for `LibraryElementImpl.fieldNameNonPromotabilityInfo`
-    // is as follows:
-    // - bool: `true` if field name non-promotability information is present,
-    //   `false` if not.
-    // - If information is present:
-    //   - Uint30: number of entries in the map.
-    //   - For each map entry:
-    //     - String reference: key
-    //     - Element list: `FieldNameNonPromotabilityInfo.conflictingFields`
-    //     - Element list: `FieldNameNonPromotabilityInfo.conflictingGetters`
-    //     - Element list: `FieldNameNonPromotabilityInfo.conflictingNsmClasses`
-    _resolutionSink.writeBool(info != null);
-    if (info == null) {
-      return;
-    }
-    _resolutionSink.writeUInt30(info.length);
-    for (var MapEntry(:key, :value) in info.entries) {
-      _resolutionSink._writeStringReference(key);
-      _resolutionSink._writeElementList(value.conflictingFields);
-      _resolutionSink._writeElementList(value.conflictingGetters);
-      _resolutionSink._writeElementList(value.conflictingNsmClasses);
-    }
+    _resolutionSink.writeOptionalObject(info, (info) {
+      _resolutionSink.writeMap(
+        info,
+        writeKey: (key) {
+          _resolutionSink._writeStringReference(key);
+        },
+        writeValue: (value) {
+          _resolutionSink._writeElementList(value.conflictingFields);
+          _resolutionSink._writeElementList(value.conflictingGetters);
+          _resolutionSink._writeElementList(value.conflictingNsmClasses);
+        },
+      );
+    });
   }
 
-  void _writeFunctionElement(FunctionElementImpl element) {
+  void _writeFragmentName(Fragment fragment) {
+    _sink._writeOptionalStringReference(fragment.name2);
+  }
+
+  void _writeFunctionElement(FunctionElementImpl fragment) {
     _sink.writeUInt30(_resolutionSink.offset);
-    _writeReference(element);
-    FunctionElementFlags.write(_sink, element);
 
-    _resolutionSink._writeAnnotationList(element.metadata);
+    var element = fragment.element as TopLevelFunctionElementImpl;
 
-    _writeTypeParameters(element.typeParameters, () {
-      _resolutionSink.writeType(element.returnType);
-      _writeList(element.parameters, _writeParameterElement);
+    _writeReference(fragment);
+    _writeReference2(element.reference);
+    _writeFragmentName(fragment);
+    FunctionElementFlags.write(_sink, fragment);
+    _writeAugmentationTargetAny(fragment);
+
+    _resolutionSink._writeAnnotationList(fragment.metadata);
+
+    _writeTypeParameters(fragment.typeParameters, () {
+      _resolutionSink.writeType(fragment.returnType);
+      _writeList(fragment.parameters, _writeParameterElement);
     });
-
-    _resolutionSink.writeElement(element.augmentation);
-    _resolutionSink.writeElement(element.augmentationTarget);
   }
 
   void _writeImportElement(LibraryImportElementImpl element) {
     _resolutionSink._writeAnnotationList(element.metadata);
     _sink.writeList(element.combinators, _writeNamespaceCombinator);
     _writeImportElementPrefix(element.prefix);
+    _writeLibraryImportPrefixFragment(element.prefix2);
     _writeDirectiveUri(element.uri);
     LibraryImportElementFlags.write(_sink, element);
   }
 
-  void _writeImportElementPrefix(ImportElementPrefix? prefix) {
-    if (prefix is DeferredImportElementPrefix) {
+  void _writeImportElementPrefix(ImportElementPrefixImpl? prefix) {
+    if (prefix is DeferredImportElementPrefixImpl) {
       _sink.writeByte(ImportElementPrefixKind.isDeferred.index);
       _sink._writeStringReference(prefix.element.name);
-    } else if (prefix is ImportElementPrefix) {
+      _writeReference(prefix.element);
+    } else if (prefix is ImportElementPrefixImpl) {
       _sink.writeByte(ImportElementPrefixKind.isNotDeferred.index);
       _sink._writeStringReference(prefix.element.name);
+      _writeReference(prefix.element);
     } else {
       _sink.writeByte(ImportElementPrefixKind.isNull.index);
     }
@@ -470,16 +468,12 @@ class BundleWriter {
     }
   }
 
-  void _writeLibraryOrAugmentationElement(
-    LibraryOrAugmentationElementImpl container,
-  ) {
-    _resolutionSink._writeAnnotationList(container.metadata);
-    _writeList(container.libraryImports, _writeImportElement);
-    _writeList(container.libraryExports, _writeExportElement);
-    _writeList(
-      container.augmentationImports,
-      _writeAugmentationImportElement,
-    );
+  void _writeLibraryImportPrefixFragment(PrefixFragmentImpl? fragment) {
+    _sink.writeOptionalObject(fragment, (fragment) {
+      _writeFragmentName(fragment);
+      _writeReference2(fragment.element.reference);
+      _sink.writeBool(fragment.isDeferred);
+    });
   }
 
   void _writeList<T>(List<T> elements, void Function(T) writeElement) {
@@ -489,19 +483,27 @@ class BundleWriter {
     }
   }
 
-  void _writeMethodElement(MethodElementImpl element) {
+  void _writeLoadLibraryFunctionReferences(LibraryElementImpl library) {
+    var element = library.loadLibraryFunction2;
+    _writeReference2(element.firstFragment.reference);
+    _writeReference2(element.reference);
+  }
+
+  void _writeMethodElement(MethodElementImpl fragment) {
     _sink.writeUInt30(_resolutionSink.offset);
-    _writeReference(element);
-    MethodElementFlags.write(_sink, element);
+    _writeReference(fragment);
+    _writeReference2(fragment.element.reference);
+    _writeFragmentName(fragment);
+    _sink._writeStringReference(fragment.name);
+    MethodElementFlags.write(_sink, fragment);
+    _writeAugmentationTargetAny(fragment);
 
-    _resolutionSink._writeAnnotationList(element.metadata);
+    _resolutionSink._writeAnnotationList(fragment.metadata);
 
-    _writeTypeParameters(element.typeParameters, () {
-      _writeList(element.parameters, _writeParameterElement);
-      _sink._writeTopLevelInferenceError(element.typeInferenceError);
-      _resolutionSink.writeType(element.returnType);
-      _resolutionSink.writeElement(element.augmentation);
-      _resolutionSink.writeElement(element.augmentationTarget);
+    _writeTypeParameters(fragment.typeParameters, () {
+      _writeList(fragment.parameters, _writeParameterElement);
+      _sink._writeTopLevelInferenceError(fragment.typeInferenceError);
+      _resolutionSink.writeType(fragment.returnType);
     });
   }
 
@@ -509,26 +511,23 @@ class BundleWriter {
     _sink.writeUInt30(_resolutionSink.offset);
 
     _writeReference(element);
+    _writeReference2(element.augmented.reference);
+    _writeFragmentName(element);
     MixinElementFlags.write(_sink, element);
+    _writeAugmentationTargetAny(element);
+
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
       _resolutionSink._writeTypeList(element.superclassConstraints);
       _resolutionSink._writeTypeList(element.interfaces);
-      _resolutionSink.writeElement(element.augmentation);
-      if (element.isAugmentation) {
-        _resolutionSink.writeElement(element.augmentationTarget);
-      } else {
-        _resolutionSink.writeIfType<AugmentedMixinElementImpl>(
-          element.augmented,
-          (augmented) {
-            _resolutionSink._writeTypeList(augmented.superclassConstraints);
-            _resolutionSink._writeTypeList(augmented.interfaces);
-            _resolutionSink._writeElementList(augmented.fields);
-            _resolutionSink._writeElementList(augmented.accessors);
-            _resolutionSink._writeElementList(augmented.methods);
-          },
-        );
+      if (element.augmentationTarget == null) {
+        var augmented = element.augmented;
+        _resolutionSink._writeTypeList(augmented.superclassConstraints);
+        _resolutionSink._writeTypeList(augmented.interfaces);
+        _resolutionSink._writeElementList(augmented.fields);
+        _resolutionSink._writeElementList(augmented.accessors);
+        _resolutionSink._writeElementList(augmented.methods);
       }
 
       _writeList(
@@ -546,31 +545,31 @@ class BundleWriter {
   }
 
   void _writeNamespaceCombinator(NamespaceCombinator combinator) {
-    if (combinator is HideElementCombinator) {
-      _sink.writeByte(Tag.HideCombinator);
-      _sink.writeList<String>(combinator.hiddenNames, (name) {
-        _sink._writeStringReference(name);
-      });
-    } else if (combinator is ShowElementCombinator) {
-      _sink.writeByte(Tag.ShowCombinator);
-      _sink.writeList<String>(combinator.shownNames, (name) {
-        _sink._writeStringReference(name);
-      });
-    } else {
-      throw UnimplementedError('${combinator.runtimeType}');
+    switch (combinator) {
+      case HideElementCombinator():
+        _sink.writeByte(Tag.HideCombinator);
+        _sink.writeList<String>(combinator.hiddenNames, (name) {
+          _sink._writeStringReference(name);
+        });
+      case ShowElementCombinator():
+        _sink.writeByte(Tag.ShowCombinator);
+        _sink.writeList<String>(combinator.shownNames, (name) {
+          _sink._writeStringReference(name);
+        });
     }
   }
 
   void _writeOptionalReference(Reference? reference) {
     _sink.writeOptionalObject(reference, (reference) {
-      final index = _references._indexOfReference(reference);
+      var index = _references._indexOfReference(reference);
       _sink.writeUInt30(index);
     });
   }
 
-  /// TODO(scheglov) Deduplicate parameter writing implementation.
+  // TODO(scheglov): Deduplicate parameter writing implementation.
   void _writeParameterElement(ParameterElement element) {
     element as ParameterElementImpl;
+    _writeFragmentName(element);
     _sink._writeStringReference(element.name);
     _sink.writeBool(element is ConstVariableElement);
     _sink.writeBool(element.isInitializingFormal);
@@ -599,72 +598,100 @@ class BundleWriter {
     _writeDirectiveUri(element.uri);
   }
 
-  /// Write information to update `getter` and `setter` properties of
-  /// augmented variables to use the corresponding augmentations.
-  void _writePropertyAccessorAugmentations() {
-    final offset = _resolutionSink.offset;
-    _resolutionSink._writeElementList(_accessorAugmentations);
-    _resolutionSink._writeElementList(_propertyAugmentations);
-    _sink.writeUInt30(offset);
+  /// We write metadata here, to keep it inside [unitElement] resolution
+  /// data, because [_writePartElement] recursively writes included unit
+  /// elements. But the bundle reader wants all metadata for `parts`
+  /// sequentially.
+  void _writePartElementsMetadata(CompilationUnitElementImpl unitElement) {
+    for (var element in unitElement.parts) {
+      _resolutionSink._writeAnnotationList(element.metadata);
+    }
   }
 
-  void _writePropertyAccessorElement(PropertyAccessorElementImpl element) {
+  void _writePropertyAccessorElement(PropertyAccessorElementImpl fragment) {
     _sink.writeUInt30(_resolutionSink.offset);
-    _writeReference(element);
-    PropertyAccessorElementFlags.write(_sink, element);
+    _writeReference(fragment);
+    _writeFragmentName(fragment);
+    PropertyAccessorElementFlags.write(_sink, fragment);
+    _writeAugmentationTargetAny(fragment);
 
-    _resolutionSink._writeAnnotationList(element.metadata);
-    _resolutionSink.writeType(element.returnType);
-    _writeList(element.parameters, _writeParameterElement);
+    _resolutionSink._writeAnnotationList(fragment.metadata);
+    _resolutionSink.writeType(fragment.returnType);
+    _writeList(fragment.parameters, _writeParameterElement);
 
-    _resolutionSink.writeElement(element.augmentationTarget);
-    if (element.isAugmentation) {
-      _accessorAugmentations.add(element);
+    // Write the reference for the variable, the reader will use it.
+    if (!fragment.isAugmentation) {
+      var variableFragment = fragment.variable2!;
+      _writeReference(variableFragment);
+      _writeOptionalReference(
+        variableFragment
+            .ifTypeOrNull<TopLevelVariableElementImpl>()
+            ?.element
+            .reference,
+      );
+      switch (variableFragment) {
+        case FieldElementImpl fieldFragment:
+          var field = fieldFragment.element;
+          _sink.writeBool(field.isPromotable);
+      }
     }
   }
 
   /// Write the reference of a non-local element.
   void _writeReference(ElementImpl element) {
-    final reference = element.reference;
-    final index = _references._indexOfReference(reference);
+    _writeReference2(element.reference);
+  }
+
+  void _writeReference2(Reference? reference) {
+    var index = _references._indexOfReference(reference);
     _sink.writeUInt30(index);
   }
 
-  void _writeTopLevelVariableElement(TopLevelVariableElementImpl element) {
+  void _writeTopLevelVariableElement(TopLevelVariableElementImpl fragment) {
     _sink.writeUInt30(_resolutionSink.offset);
-    _writeReference(element);
-    _writeOptionalReference(element.getter?.reference);
-    _writeOptionalReference(element.setter?.reference);
-    _sink.writeBool(element.isConst);
-    TopLevelVariableElementFlags.write(_sink, element);
-    _sink._writeTopLevelInferenceError(element.typeInferenceError);
-    _resolutionSink._writeAnnotationList(element.metadata);
-    _resolutionSink.writeType(element.type);
-    _resolutionSink._writeOptionalNode(element.constantInitializer);
+    _writeReference(fragment);
+    _writeReference2(fragment.element.reference);
+    _writeOptionalReference(fragment.getter?.reference);
+    _writeOptionalReference(fragment.setter?.reference);
+    _writeFragmentName(fragment);
+    _sink._writeStringReference(fragment.name);
+    _sink.writeBool(fragment.isConst);
+    TopLevelVariableElementFlags.write(_sink, fragment);
+    _writeAugmentationTargetAny(fragment);
+    _sink._writeTopLevelInferenceError(fragment.typeInferenceError);
+    _resolutionSink._writeAnnotationList(fragment.metadata);
+    _resolutionSink.writeType(fragment.type);
+
+    _resolutionSink._writeOptionalNode(fragment.constantInitializer);
   }
 
-  void _writeTypeAliasElement(TypeAliasElementImpl element) {
+  void _writeTypeAliasElement(TypeAliasElementImpl fragment) {
     _sink.writeUInt30(_resolutionSink.offset);
 
-    _writeReference(element);
-    _sink.writeBool(element.isFunctionTypeAliasBased);
-    TypeAliasElementFlags.write(_sink, element);
+    _writeReference(fragment);
+    _writeReference2(fragment.element.reference);
+    _writeFragmentName(fragment);
+    _sink._writeStringReference(fragment.name);
+    _sink.writeBool(fragment.isFunctionTypeAliasBased);
+    TypeAliasElementFlags.write(_sink, fragment);
+    _writeAugmentationTargetAny(fragment);
 
-    _resolutionSink._writeAnnotationList(element.metadata);
+    _resolutionSink._writeAnnotationList(fragment.metadata);
 
-    _writeTypeParameters(element.typeParameters, () {
-      _resolutionSink._writeAliasedElement(element.aliasedElement);
-      _resolutionSink.writeType(element.aliasedType);
+    _writeTypeParameters(fragment.typeParameters, () {
+      _resolutionSink._writeAliasedElement(fragment.aliasedElement);
+      _resolutionSink.writeType(fragment.aliasedType);
     });
   }
 
-  void _writeTypeParameterElement(TypeParameterElement typeParameter) {
-    typeParameter as TypeParameterElementImpl;
-    _sink._writeStringReference(typeParameter.name);
-    _sink.writeByte(_encodeVariance(typeParameter).index);
-    _resolutionSink._writeAnnotationList(typeParameter.metadata);
-    _resolutionSink.writeType(typeParameter.bound);
-    _resolutionSink.writeType(typeParameter.defaultType);
+  void _writeTypeParameterElement(TypeParameterElement element) {
+    element as TypeParameterElementImpl;
+    _sink._writeStringReference(element.name);
+    _writeFragmentName(element);
+    _sink.writeByte(_encodeVariance(element).index);
+    _resolutionSink._writeAnnotationList(element.metadata);
+    _resolutionSink.writeType(element.bound);
+    _resolutionSink.writeType(element.defaultType);
   }
 
   /// Add [typeParameters] to the indexing scope, so make them available
@@ -684,6 +711,14 @@ class BundleWriter {
 
     _sink._writeOptionalStringReference(unitElement.uri);
     _sink.writeBool(unitElement.isSynthetic);
+
+    _writeList(unitElement.libraryImports, _writeImportElement);
+    _writeList(unitElement.libraryExports, _writeExportElement);
+
+    // Write the metadata for parts here, even though we write parts below.
+    // The reason is that resolution data must be in a single chunk.
+    _writePartElementsMetadata(unitElement);
+
     _writeList(unitElement.classes, _writeClassElement);
     _writeList(unitElement.enums, _writeEnumElement);
     _writeList(unitElement.extensions, _writeExtensionElement);
@@ -702,6 +737,10 @@ class BundleWriter {
       unitElement.accessors.where((e) => !e.isSynthetic).toList(),
       _writePropertyAccessorElement,
     );
+
+    // Write parts after this library fragment, so that when we read, we
+    // process fragments of declarations in the same order as we build them.
+    _writeList(unitElement.parts, _writePartElement);
   }
 
   static TypeParameterVarianceTag _encodeVariance(
@@ -743,32 +782,20 @@ class ResolutionSink extends _SummaryDataWriter {
     required _BundleWriterReferences references,
   }) : _references = references;
 
-  /// TODO(scheglov) Triage places where we write elements.
-  /// Some of then cannot be members, e.g. type names.
+  // TODO(scheglov): Triage places where we write elements.
+  // Some of then cannot be members, e.g. type names.
   void writeElement(Element? element) {
     if (element is Member) {
       var declaration = element.declaration;
-      var isLegacy = element.isLegacy;
 
       var typeArguments = _enclosingClassTypeArguments(
         declaration,
         element.substitution.map,
       );
 
-      if (isLegacy) {
-        if (typeArguments.isEmpty) {
-          writeByte(Tag.MemberLegacyWithoutTypeArguments);
-          _writeElement(declaration);
-        } else {
-          writeByte(Tag.MemberLegacyWithTypeArguments);
-          _writeElement(declaration);
-          _writeTypeList(typeArguments);
-        }
-      } else {
-        writeByte(Tag.MemberWithTypeArguments);
-        _writeElement(declaration);
-        _writeTypeList(typeArguments);
-      }
+      writeByte(Tag.MemberWithTypeArguments);
+      _writeElement(declaration);
+      _writeTypeList(typeArguments);
     } else {
       writeByte(Tag.RawElement);
       _writeElement(element);
@@ -801,14 +828,12 @@ class ResolutionSink extends _SummaryDataWriter {
           writeByte(Tag.InterfaceType_noTypeArguments_none);
         } else if (nullabilitySuffix == NullabilitySuffix.question) {
           writeByte(Tag.InterfaceType_noTypeArguments_question);
-        } else if (nullabilitySuffix == NullabilitySuffix.star) {
-          writeByte(Tag.InterfaceType_noTypeArguments_star);
         }
-        // TODO(scheglov) Write raw
+        // TODO(scheglov): Write raw
         writeElement(type.element);
       } else {
         writeByte(Tag.InterfaceType);
-        // TODO(scheglov) Write raw
+        // TODO(scheglov): Write raw
         writeElement(type.element);
         writeUInt30(typeArguments.length);
         for (var i = 0; i < typeArguments.length; ++i) {
@@ -895,7 +920,7 @@ class ResolutionSink extends _SummaryDataWriter {
 
   void _writeElementList(List<Element> elements) {
     writeUInt30(elements.length);
-    for (final element in elements) {
+    for (var element in elements) {
       writeElement(element);
     }
   }
@@ -1018,12 +1043,12 @@ class ResolutionSink extends _SummaryDataWriter {
     Element declaration,
     Map<TypeParameterElement, DartType> substitution,
   ) {
-    // TODO(scheglov) Just keep it null in class Member?
+    // TODO(scheglov): Just keep it null in class Member?
     if (substitution.isEmpty) {
       return const [];
     }
 
-    var enclosing = declaration.enclosingElement;
+    var enclosing = declaration.enclosingElement3;
     if (enclosing is InstanceElement) {
       var typeParameters = enclosing.typeParameters;
       if (typeParameters.isEmpty) {
@@ -1032,7 +1057,7 @@ class ResolutionSink extends _SummaryDataWriter {
 
       return typeParameters
           .map((typeParameter) => substitution[typeParameter])
-          .whereNotNull()
+          .nonNulls
           .toList(growable: false);
     }
 
@@ -1183,14 +1208,10 @@ class _Library {
   final int offset;
   final List<int> classMembersOffsets;
 
-  /// The only (if any) macro generated augmentation.
-  final MacroGeneratedAugmentationLibrary? macroGenerated;
-
   _Library({
     required this.uriStr,
     required this.offset,
     required this.classMembersOffsets,
-    required this.macroGenerated,
   });
 }
 
