@@ -2,21 +2,25 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'package:analyzer/src/dart/ast/ast.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/dart/element/scope.dart';
 import 'package:analyzer/src/summary2/ast_resolver.dart';
+import 'package:analyzer/src/summary2/library_builder.dart';
 import 'package:analyzer/src/summary2/link.dart';
 import 'package:analyzer/src/summary2/linking_node_scope.dart';
+import 'package:analyzer/src/utilities/extensions/element.dart';
 
 class ConstructorInitializerResolver {
   final Linker _linker;
-  final LibraryElementImpl _libraryElement;
+  final LibraryBuilder _libraryBuilder;
 
-  ConstructorInitializerResolver(this._linker, this._libraryElement);
+  ConstructorInitializerResolver(this._linker, this._libraryBuilder);
 
   void resolve() {
-    for (var unitElement in _libraryElement.units) {
+    for (var unitElement in _libraryBuilder.element.units) {
       var interfaceElements = <InterfaceElementImpl>[
         ...unitElement.classes,
         ...unitElement.enums,
@@ -27,8 +31,7 @@ class ConstructorInitializerResolver {
         for (var constructorElement in interfaceElement.constructors) {
           _constructor(
             unitElement,
-            // TODO(scheglov) Avoid cast.
-            interfaceElement.augmented!.declaration as InterfaceElementImpl,
+            interfaceElement.augmented.firstFragment,
             constructorElement,
           );
         }
@@ -49,10 +52,12 @@ class ConstructorInitializerResolver {
     var functionScope = LinkingNodeContext.get(node).scope;
     var initializerScope = ConstructorInitializerScope(
       functionScope,
-      element,
+      element.asElement2,
     );
 
-    var astResolver = AstResolver(_linker, unitElement, initializerScope,
+    var analysisOptions = _libraryBuilder.kind.file.analysisOptions;
+    var astResolver = AstResolver(
+        _linker, unitElement, initializerScope, analysisOptions,
         enclosingClassElement: classElement,
         enclosingExecutableElement: element);
 
