@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'dart:typed_data';
 
 import 'package:analyzer/dart/ast/token.dart';
@@ -92,18 +94,27 @@ class InformativeDataApplier {
     var unitReader = SummaryDataReader(unitInfoBytes);
     var unitInfo = _InfoUnit(_infoDeclarationStore, unitReader);
 
-    var enclosing = unitElement.enclosingElement;
-    if (enclosing is LibraryElementImpl) {
-      if (identical(enclosing.definingCompilationUnit, unitElement)) {
-        _applyToLibrary(enclosing, unitInfo);
-      }
-    } else if (enclosing is LibraryAugmentationElementImpl) {
-      _applyToAugmentation(enclosing, unitInfo);
+    var libraryElement = unitElement.library;
+    if (identical(libraryElement.definingCompilationUnit, unitElement)) {
+      _applyToLibrary(libraryElement, unitInfo);
     }
 
     unitElement.setCodeRange(unitInfo.codeOffset, unitInfo.codeLength);
     unitElement.lineInfo = LineInfo(unitInfo.lineStarts);
 
+    _applyToImports(unitElement.libraryImports_unresolved, unitInfo);
+    _applyToExports(unitElement.libraryExports_unresolved, unitInfo);
+
+    var applyOffsets = ApplyConstantOffsets(
+      unitInfo.libraryConstantOffsets,
+      (applier) {
+        applier.applyToMetadata(unitElement);
+        applier.applyToImports(unitElement.libraryImports);
+        applier.applyToExports(unitElement.libraryExports);
+        applier.applyToParts(unitElement.parts);
+      },
+    );
+
     _applyToAccessors(unitElement.accessors, unitInfo.accessors);
 
     forCorrespondingPairs(
@@ -157,6 +168,13 @@ class InformativeDataApplier {
       unitInfo.genericTypeAliases,
       _applyToGenericTypeAlias,
     );
+
+    var linkedData = unitElement.linkedData;
+    if (linkedData is CompilationUnitElementLinkedData) {
+      linkedData.applyConstantOffsets = applyOffsets;
+    } else {
+      applyOffsets.perform();
+    }
   }
 
   void _applyToAccessors(
@@ -170,6 +188,7 @@ class InformativeDataApplier {
         element as PropertyAccessorElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
         element.nameOffset = info.nameOffset;
+        element.nameOffset2 = info.nameOffset2;
         element.documentationComment = info.documentationComment;
         _applyToFormalParameters(
           element.parameters_unresolved,
@@ -195,35 +214,6 @@ class InformativeDataApplier {
     );
   }
 
-  void _applyToAugmentation(
-    LibraryAugmentationElementImpl element,
-    _InfoUnit info,
-  ) {
-    if (info.docComment.isNotEmpty) {
-      element.documentationComment = info.docComment;
-    }
-
-    _applyToImports(element, info);
-    _applyToExports(element, info);
-
-    var applyOffsets = ApplyConstantOffsets(
-      info.libraryConstantOffsets,
-      (applier) {
-        applier.applyToMetadata(element);
-        applier.applyToImports(element.libraryImports);
-        applier.applyToExports(element.libraryExports);
-        applier.applyToAugmentationImports(element.augmentationImports);
-      },
-    );
-
-    var linkedData = element.linkedData;
-    if (linkedData is LibraryAugmentationElementLinkedData) {
-      linkedData.applyConstantOffsets = applyOffsets;
-    } else {
-      applyOffsets.perform();
-    }
-  }
-
   void _applyToClassDeclaration(
     ClassElement element,
     _InfoClassDeclaration info,
@@ -231,6 +221,7 @@ class InformativeDataApplier {
     element as ClassElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -269,6 +260,7 @@ class InformativeDataApplier {
     element as ClassElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -321,9 +313,11 @@ class InformativeDataApplier {
       (element, info) {
         element as ConstructorElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
+        element.typeNameOffset = info.typeNameOffset;
         element.periodOffset = info.periodOffset;
         element.nameOffset = info.nameOffset;
         element.nameEnd = info.nameEnd;
+        element.nameOffset2 = info.nameOffset2;
         element.documentationComment = info.documentationComment;
 
         _applyToFormalParameters(
@@ -357,6 +351,7 @@ class InformativeDataApplier {
     element as EnumElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
 
     _applyToTypeParameters(
@@ -385,11 +380,11 @@ class InformativeDataApplier {
   }
 
   void _applyToExports(
-    LibraryOrAugmentationElementImpl element,
+    List<LibraryExportElementImpl> exports,
     _InfoUnit info,
   ) {
     forCorrespondingPairs<LibraryExportElement, _InfoExport>(
-      element.exports_unresolved,
+      exports,
       info.exports,
       (element, info) {
         element as LibraryExportElementImpl;
@@ -406,6 +401,7 @@ class InformativeDataApplier {
     element as ExtensionElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -438,6 +434,7 @@ class InformativeDataApplier {
     element as ExtensionTypeElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -448,6 +445,7 @@ class InformativeDataApplier {
       var representationField = element.fields.first;
       var infoRep = info.representation;
       representationField.nameOffset = infoRep.fieldNameOffset;
+      representationField.nameOffset2 = infoRep.fieldNameOffset2;
       representationField.setCodeRange(
         infoRep.fieldCodeOffset,
         infoRep.fieldCodeLength,
@@ -472,13 +470,16 @@ class InformativeDataApplier {
         infoRep.constructorCodeOffset,
         infoRep.constructorCodeLength,
       );
+      primaryConstructor.typeNameOffset = infoRep.typeNameOffset;
       primaryConstructor.periodOffset = infoRep.constructorPeriodOffset;
       primaryConstructor.nameOffset = infoRep.constructorNameOffset;
       primaryConstructor.nameEnd = infoRep.constructorNameEnd;
+      primaryConstructor.nameOffset2 = infoRep.constructorNameOffset2;
 
       var primaryConstructorParameter = primaryConstructor
           .parameters_unresolved.first as ParameterElementImpl;
       primaryConstructorParameter.nameOffset = infoRep.fieldNameOffset;
+      primaryConstructorParameter.nameOffset2 = infoRep.fieldNameOffset2;
       primaryConstructorParameter.setCodeRange(
         infoRep.fieldCodeOffset,
         infoRep.fieldCodeLength,
@@ -524,6 +525,7 @@ class InformativeDataApplier {
         element as FieldElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
         element.nameOffset = info.nameOffset;
+        element.nameOffset2 = info.nameOffset2;
         element.documentationComment = info.documentationComment;
 
         var applyOffsets = ApplyConstantOffsets(
@@ -555,6 +557,7 @@ class InformativeDataApplier {
         element as ParameterElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
         element.nameOffset = info.nameOffset;
+        element.nameOffset2 = info.nameOffset2;
         _applyToTypeParameters(element.typeParameters, info.typeParameters);
         _applyToFormalParameters(element.parameters, info.parameters);
       },
@@ -568,6 +571,7 @@ class InformativeDataApplier {
     element as FunctionElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -602,6 +606,7 @@ class InformativeDataApplier {
     element as TypeAliasElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -622,6 +627,7 @@ class InformativeDataApplier {
     element as TypeAliasElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -637,11 +643,11 @@ class InformativeDataApplier {
   }
 
   void _applyToImports(
-    LibraryOrAugmentationElementImpl element,
+    List<LibraryImportElementImpl> imports,
     _InfoUnit info,
   ) {
     forCorrespondingPairs<LibraryImportElement, _InfoImport>(
-      element.imports_unresolved,
+      imports,
       info.imports,
       (element, info) {
         element as LibraryImportElementImpl;
@@ -649,9 +655,14 @@ class InformativeDataApplier {
 
         var prefixElement = element.prefix?.element;
         if (prefixElement is PrefixElementImpl) {
-          prefixElement.nameOffset = info.prefixOffset;
+          if (prefixElement.nameOffset == -1) {
+            prefixElement.nameOffset = info.prefixOffset;
+          }
         }
 
+        if (element.prefix2 case var prefixFragment?) {
+          prefixFragment.nameOffset2 = info.prefixOffset2;
+        }
         _applyToCombinators(element.combinators, info.combinators);
       },
     );
@@ -665,25 +676,10 @@ class InformativeDataApplier {
       element.documentationComment = info.docComment;
     }
 
-    _applyToImports(element, info);
-    _applyToExports(element, info);
-
-    forCorrespondingPairs<PartElement, _InfoPart>(
-      element.parts,
-      info.parts,
-      (element, info) {
-        element as PartElementImpl;
-      },
-    );
-
     var applyOffsets = ApplyConstantOffsets(
       info.libraryConstantOffsets,
       (applier) {
         applier.applyToMetadata(element);
-        applier.applyToImports(element.libraryImports);
-        applier.applyToExports(element.libraryExports);
-        applier.applyToAugmentationImports(element.augmentationImports);
-        applier.applyToPartDirectives(element.parts);
       },
     );
 
@@ -706,6 +702,7 @@ class InformativeDataApplier {
         element as MethodElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
         element.nameOffset = info.nameOffset;
+        element.nameOffset2 = info.nameOffset2;
         element.documentationComment = info.documentationComment;
         _applyToTypeParameters(
           element.typeParameters_unresolved,
@@ -742,6 +739,7 @@ class InformativeDataApplier {
     element as MixinElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
     _applyToTypeParameters(
       element.typeParameters_unresolved,
@@ -775,6 +773,7 @@ class InformativeDataApplier {
     element as TopLevelVariableElementImpl;
     element.setCodeRange(info.codeOffset, info.codeLength);
     element.nameOffset = info.nameOffset;
+    element.nameOffset2 = info.nameOffset2;
     element.documentationComment = info.documentationComment;
 
     var applyOffsets = ApplyConstantOffsets(
@@ -804,22 +803,14 @@ class InformativeDataApplier {
         element as TypeParameterElementImpl;
         element.setCodeRange(info.codeOffset, info.codeLength);
         element.nameOffset = info.nameOffset;
+        element.nameOffset2 = info.nameOffset2;
       },
     );
   }
 
-  Uint8List? _getInfoUnitBytes(CompilationUnitElement element) {
+  Uint8List? _getInfoUnitBytes(CompilationUnitElementImpl element) {
     var uri = element.source.uri;
-    if (_unitsInformativeBytes2[uri] case var bytes?) {
-      return bytes;
-    }
-
-    switch (element.enclosingElement) {
-      case LibraryAugmentationElementImpl(:var macroGenerated?):
-        return macroGenerated.informativeBytes;
-    }
-
-    return null;
+    return _unitsInformativeBytes2[uri];
   }
 
   void _setupApplyConstantOffsetsForTypeAlias(
@@ -867,6 +858,7 @@ class _InfoClassDeclaration {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoConstructorDeclaration> constructors;
@@ -892,6 +884,7 @@ class _InfoClassDeclaration {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30() - nameOffsetDelta,
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -919,6 +912,7 @@ class _InfoClassDeclaration {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.constructors,
@@ -933,6 +927,7 @@ class _InfoClassTypeAlias {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final Uint32List constantOffsets;
@@ -942,6 +937,7 @@ class _InfoClassTypeAlias {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -954,6 +950,7 @@ class _InfoClassTypeAlias {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.constantOffsets,
@@ -980,9 +977,11 @@ class _InfoCombinator {
 class _InfoConstructorDeclaration {
   final int codeOffset;
   final int codeLength;
+  final int? typeNameOffset;
   final int? periodOffset;
   final int nameOffset;
-  final int nameEnd;
+  final int? nameEnd;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoFormalParameter> parameters;
   final Uint32List constantOffsets;
@@ -991,9 +990,11 @@ class _InfoConstructorDeclaration {
     return _InfoConstructorDeclaration._(
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
+      typeNameOffset: reader.readUInt30(),
       periodOffset: reader.readOptionalUInt30(),
       nameOffset: reader.readUInt30(),
-      nameEnd: reader.readUInt30(),
+      nameEnd: reader.readOptionalUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       parameters: reader.readTypedList(
         () => _InfoFormalParameter(reader),
@@ -1005,9 +1006,11 @@ class _InfoConstructorDeclaration {
   _InfoConstructorDeclaration._({
     required this.codeOffset,
     required this.codeLength,
+    required this.typeNameOffset,
     required this.periodOffset,
     required this.nameOffset,
     required this.nameEnd,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.parameters,
     required this.constantOffsets,
@@ -1037,6 +1040,7 @@ class _InfoExtensionTypeDeclaration {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final _InfoExtensionTypeRepresentation representation;
@@ -1051,6 +1055,7 @@ class _InfoExtensionTypeDeclaration {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -1076,6 +1081,7 @@ class _InfoExtensionTypeDeclaration {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.representation,
@@ -1090,24 +1096,30 @@ class _InfoExtensionTypeDeclaration {
 class _InfoExtensionTypeRepresentation {
   final int constructorCodeOffset;
   final int constructorCodeLength;
+  final int? typeNameOffset;
   final int? constructorPeriodOffset;
   final int constructorNameOffset;
   final int? constructorNameEnd;
+  final int? constructorNameOffset2;
   final int fieldCodeOffset;
   final int fieldCodeLength;
   final int fieldNameOffset;
+  final int? fieldNameOffset2;
   final Uint32List fieldConstantOffsets;
 
   factory _InfoExtensionTypeRepresentation(SummaryDataReader reader) {
     return _InfoExtensionTypeRepresentation._(
       constructorCodeOffset: reader.readUInt30(),
       constructorCodeLength: reader.readUInt30(),
+      typeNameOffset: reader.readOptionalUInt30(),
       constructorPeriodOffset: reader.readOptionalUInt30(),
       constructorNameOffset: reader.readUInt30(),
       constructorNameEnd: reader.readOptionalUInt30(),
+      constructorNameOffset2: reader.readOptionalUInt30(),
       fieldCodeOffset: reader.readUInt30(),
       fieldCodeLength: reader.readUInt30(),
       fieldNameOffset: reader.readUInt30(),
+      fieldNameOffset2: reader.readOptionalUInt30(),
       fieldConstantOffsets: reader.readUInt30List(),
     );
   }
@@ -1115,12 +1127,15 @@ class _InfoExtensionTypeRepresentation {
   _InfoExtensionTypeRepresentation._({
     required this.constructorCodeOffset,
     required this.constructorCodeLength,
+    required this.typeNameOffset,
     required this.constructorPeriodOffset,
     required this.constructorNameOffset,
     required this.constructorNameEnd,
+    required this.constructorNameOffset2,
     required this.fieldCodeOffset,
     required this.fieldCodeLength,
     required this.fieldNameOffset,
+    required this.fieldNameOffset2,
     required this.fieldConstantOffsets,
   });
 }
@@ -1129,6 +1144,7 @@ class _InfoFieldDeclaration {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final Uint32List constantOffsets;
 
@@ -1137,6 +1153,7 @@ class _InfoFieldDeclaration {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       constantOffsets: reader.readUInt30List(),
     );
@@ -1146,6 +1163,7 @@ class _InfoFieldDeclaration {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.constantOffsets,
   });
@@ -1155,6 +1173,7 @@ class _InfoFormalParameter {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoFormalParameter> parameters;
 
@@ -1163,6 +1182,7 @@ class _InfoFormalParameter {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30() - 1,
+      nameOffset2: reader.readOptionalUInt30(),
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
       ),
@@ -1176,6 +1196,7 @@ class _InfoFormalParameter {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.typeParameters,
     required this.parameters,
   });
@@ -1185,6 +1206,7 @@ class _InfoFunctionDeclaration {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoFormalParameter> parameters;
@@ -1195,6 +1217,7 @@ class _InfoFunctionDeclaration {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -1210,6 +1233,7 @@ class _InfoFunctionDeclaration {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.parameters,
@@ -1221,6 +1245,7 @@ class _InfoFunctionTypeAlias {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoFormalParameter> parameters;
@@ -1231,6 +1256,7 @@ class _InfoFunctionTypeAlias {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -1246,6 +1272,7 @@ class _InfoFunctionTypeAlias {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.parameters,
@@ -1257,6 +1284,7 @@ class _InfoGenericTypeAlias {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoTypeParameter> aliasedTypeParameters;
@@ -1268,6 +1296,7 @@ class _InfoGenericTypeAlias {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -1286,6 +1315,7 @@ class _InfoGenericTypeAlias {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.aliasedTypeParameters,
@@ -1297,12 +1327,14 @@ class _InfoGenericTypeAlias {
 class _InfoImport {
   final int nameOffset;
   final int prefixOffset;
+  final int? prefixOffset2;
   final List<_InfoCombinator> combinators;
 
   factory _InfoImport(SummaryDataReader reader) {
     return _InfoImport._(
       nameOffset: reader.readUInt30(),
       prefixOffset: reader.readUInt30() - 1,
+      prefixOffset2: reader.readOptionalUInt30(),
       combinators: reader.readTypedList(
         () => _InfoCombinator(reader),
       ),
@@ -1312,6 +1344,7 @@ class _InfoImport {
   _InfoImport._({
     required this.nameOffset,
     required this.prefixOffset,
+    required this.prefixOffset2,
     required this.combinators,
   });
 }
@@ -1337,6 +1370,7 @@ class _InfoMethodDeclaration {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final List<_InfoTypeParameter> typeParameters;
   final List<_InfoFormalParameter> parameters;
@@ -1347,6 +1381,7 @@ class _InfoMethodDeclaration {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       typeParameters: reader.readTypedList(
         () => _InfoTypeParameter(reader),
@@ -1362,6 +1397,7 @@ class _InfoMethodDeclaration {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.typeParameters,
     required this.parameters,
@@ -1402,6 +1438,7 @@ class _InformativeDataWriter {
     sink.writeList2<ImportDirective>(unit.directives, (directive) {
       sink.writeUInt30(directive.importKeyword.offset);
       sink.writeUInt30(1 + (directive.prefix?.offset ?? -1));
+      sink.writeOptionalUInt30(directive.prefix?.token.offsetIfNotEmpty);
       _writeCombinators(directive.combinators);
     });
 
@@ -1418,6 +1455,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeConstructors(node.members);
@@ -1434,6 +1472,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeOffsets(
@@ -1446,6 +1485,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeConstructors(node.members);
@@ -1463,6 +1503,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(1 + (node.name?.offset ?? -1));
+      sink.writeOptionalUInt30(node.name?.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeConstructors(node.members);
@@ -1479,6 +1520,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeRepresentation(node, node.representation);
@@ -1501,6 +1543,7 @@ class _InformativeDataWriter {
         sink.writeUInt30(node.offset);
         sink.writeUInt30(node.length);
         sink.writeUInt30(node.name.offset);
+        sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
         _writeDocumentationComment(node);
         _writeTypeParameters(node.functionExpression.typeParameters);
         _writeFormalParameters(node.functionExpression.parameters);
@@ -1520,6 +1563,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.functionExpression.typeParameters);
       _writeFormalParameters(node.functionExpression.parameters);
@@ -1534,6 +1578,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeFormalParameters(node.parameters);
@@ -1549,6 +1594,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       if (aliasedType is GenericFunctionType) {
@@ -1569,6 +1615,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeTypeParameters(node.typeParameters);
       _writeConstructors(node.members);
@@ -1610,10 +1657,13 @@ class _InformativeDataWriter {
     sink.writeList2<ConstructorDeclaration>(members, (node) {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
+      sink.writeUInt30(node.returnType.offset);
       sink.writeOptionalUInt30(node.period?.offset);
       var nameNode = node.name ?? node.returnType;
       sink.writeUInt30(nameNode.offset);
-      sink.writeUInt30(nameNode.end);
+      sink.writeOptionalUInt30(nameNode.end);
+      sink.writeOptionalUInt30(node.name?.offsetIfNotEmpty);
+
       _writeDocumentationComment(node);
       _writeFormalParameters(node.parameters);
       _writeOffsets(
@@ -1650,6 +1700,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(codeOffset);
       sink.writeUInt30(node.end - codeOffset);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
       _writeDocumentationComment(node);
       _writeOffsets(
         metadata: node.metadata,
@@ -1667,6 +1718,7 @@ class _InformativeDataWriter {
     sink.writeUInt30(codeOffset);
     sink.writeUInt30(node.end - codeOffset);
     sink.writeUInt30(node.name.offset);
+    sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
     _writeDocumentationComment(node);
 
     // TODO(scheglov): Replace with some kind of double-iterating list.
@@ -1694,7 +1746,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(1 + (node.name?.offset ?? -1));
-
+      sink.writeOptionalUInt30(node.name?.offsetIfNotEmpty);
       var notDefault = node.notDefault;
       if (notDefault is FieldFormalParameter) {
         _writeTypeParameters(notDefault.typeParameters);
@@ -1722,6 +1774,7 @@ class _InformativeDataWriter {
         sink.writeUInt30(node.offset);
         sink.writeUInt30(node.length);
         sink.writeUInt30(node.name.offset);
+        sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
         _writeDocumentationComment(node);
         _writeTypeParameters(node.typeParameters);
         _writeFormalParameters(node.parameters);
@@ -1755,8 +1808,6 @@ class _InformativeDataWriter {
       metadata: firstDirective?.metadata,
       importDirectives: unit.directives.whereType<ImportDirective>(),
       exportDirectives: unit.directives.whereType<ExportDirective>(),
-      augmentationImportDirectives:
-          unit.directives.whereType<AugmentationImportDirective>(),
       partDirectives: unit.directives.whereType<PartDirective>(),
     );
   }
@@ -1771,6 +1822,7 @@ class _InformativeDataWriter {
         sink.writeUInt30(node.offset);
         sink.writeUInt30(node.length);
         sink.writeUInt30(node.name.offset);
+        sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
         _writeDocumentationComment(node);
         _writeTypeParameters(node.typeParameters);
         _writeFormalParameters(node.parameters);
@@ -1787,7 +1839,6 @@ class _InformativeDataWriter {
     NodeList<Annotation>? metadata,
     Iterable<ImportDirective>? importDirectives,
     Iterable<ExportDirective>? exportDirectives,
-    Iterable<AugmentationImportDirective>? augmentationImportDirectives,
     Iterable<PartDirective>? partDirectives,
     TypeParameterList? typeParameters,
     FormalParameterList? formalParameters,
@@ -1834,7 +1885,6 @@ class _InformativeDataWriter {
     metadata?.accept(collector);
     addDirectives(importDirectives);
     addDirectives(exportDirectives);
-    addDirectives(augmentationImportDirectives);
     addDirectives(partDirectives);
     addTypeParameters(typeParameters);
     addFormalParameters(formalParameters);
@@ -1855,19 +1905,24 @@ class _InformativeDataWriter {
   }
 
   void _writeRepresentation(
-      ExtensionTypeDeclaration declaration, RepresentationDeclaration node) {
+    ExtensionTypeDeclaration declaration,
+    RepresentationDeclaration node,
+  ) {
     // Constructor code range.
     sink.writeUInt30(node.offset);
     sink.writeUInt30(node.length);
+    sink.writeOptionalUInt30(declaration.name.offsetIfNotEmpty);
 
     var constructorName = node.constructorName;
     if (constructorName != null) {
       sink.writeOptionalUInt30(constructorName.period.offset);
       sink.writeUInt30(constructorName.name.offset);
       sink.writeOptionalUInt30(constructorName.name.end);
+      sink.writeOptionalUInt30(constructorName.name.offsetIfNotEmpty);
     } else {
       sink.writeOptionalUInt30(null);
       sink.writeUInt30(declaration.name.offset);
+      sink.writeOptionalUInt30(declaration.name.end);
       sink.writeOptionalUInt30(null);
     }
 
@@ -1877,6 +1932,7 @@ class _InformativeDataWriter {
     sink.writeUInt30(codeOffset);
     sink.writeUInt30(codeEnd - codeOffset);
     sink.writeUInt30(node.fieldName.offset);
+    sink.writeOptionalUInt30(node.fieldName.offsetIfNotEmpty);
 
     _writeOffsets(
       metadata: node.fieldMetadata,
@@ -1888,6 +1944,7 @@ class _InformativeDataWriter {
     sink.writeUInt30(codeOffset);
     sink.writeUInt30(node.end - codeOffset);
     sink.writeUInt30(node.name.offset);
+    sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
     _writeDocumentationComment(node);
 
     // TODO(scheglov): Replace with some kind of double-iterating list.
@@ -1905,6 +1962,7 @@ class _InformativeDataWriter {
       sink.writeUInt30(node.offset);
       sink.writeUInt30(node.length);
       sink.writeUInt30(node.name.offset);
+      sink.writeOptionalUInt30(node.name.offsetIfNotEmpty);
     });
   }
 }
@@ -1913,6 +1971,7 @@ class _InfoTopLevelVariable {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
   final String? documentationComment;
   final Uint32List constantOffsets;
 
@@ -1921,6 +1980,7 @@ class _InfoTopLevelVariable {
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
       documentationComment: reader.readStringUtf8().nullIfEmpty,
       constantOffsets: reader.readUInt30List(),
     );
@@ -1930,6 +1990,7 @@ class _InfoTopLevelVariable {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
     required this.documentationComment,
     required this.constantOffsets,
   });
@@ -1939,12 +2000,14 @@ class _InfoTypeParameter {
   final int codeOffset;
   final int codeLength;
   final int nameOffset;
+  final int? nameOffset2;
 
   factory _InfoTypeParameter(SummaryDataReader reader) {
     return _InfoTypeParameter._(
       codeOffset: reader.readUInt30(),
       codeLength: reader.readUInt30(),
       nameOffset: reader.readUInt30(),
+      nameOffset2: reader.readOptionalUInt30(),
     );
   }
 
@@ -1952,6 +2015,7 @@ class _InfoTypeParameter {
     required this.codeOffset,
     required this.codeLength,
     required this.nameOffset,
+    required this.nameOffset2,
   });
 }
 
@@ -2076,12 +2140,6 @@ class _OffsetsApplier extends _OffsetsAstVisitor {
 
   _OffsetsApplier(this._iterator);
 
-  void applyToAugmentationImports(List<AugmentationImportElement> elements) {
-    for (var element in elements) {
-      applyToMetadata(element);
-    }
-  }
-
   void applyToConstantInitializer(Element element) {
     if (element is ConstFieldElementImpl && element.isEnumConstant) {
       _applyToEnumConstantInitializer(element);
@@ -2135,6 +2193,12 @@ class _OffsetsApplier extends _OffsetsAstVisitor {
     }
   }
 
+  void applyToParts(List<PartElementImpl> elements) {
+    for (var element in elements) {
+      applyToMetadata(element);
+    }
+  }
+
   void applyToTypeParameters(List<TypeParameterElement> typeParameters) {
     for (var typeParameter in typeParameters) {
       applyToMetadata(typeParameter);
@@ -2578,6 +2642,12 @@ class _SafeListIterator<T> {
   }
 }
 
+extension on Token {
+  int? get offsetIfNotEmpty {
+    return lexeme.isNotEmpty ? offset : null;
+  }
+}
+
 extension on String {
   String? get nullIfEmpty {
     return isNotEmpty ? this : null;
