@@ -3,7 +3,6 @@
 // BSD-style license that can be found in the LICENSE file.
 
 import 'dart:async';
-import 'dart:convert';
 import 'dart:io';
 
 import 'package:logging/logging.dart';
@@ -44,30 +43,37 @@ Future<RunProcessResult> runProcess({
     runInShell: Platform.isWindows && workingDirectory != null,
   );
 
-  final stdoutSub = process.stdout
-      .transform(utf8.decoder)
-      .transform(const LineSplitter())
-      .listen(captureOutput
-          ? (s) {
-              logger?.fine(s);
-              stdoutBuffer.writeln(s);
-            }
-          : logger?.fine);
-  final stderrSub = process.stderr
-      .transform(utf8.decoder)
-      .transform(const LineSplitter())
-      .listen(captureOutput
-          ? (s) {
-              logger?.severe(s);
-              stderrBuffer.writeln(s);
-            }
-          : logger?.severe);
+  final stdoutSub = process.stdout.listen((List<int> data) {
+    try {
+      final decoded = systemEncoding.decode(data);
+      logger?.fine(decoded);
+      if (captureOutput) {
+        stdoutBuffer.write(decoded);
+      }
+    } catch (e) {
+      logger?.warning('Failed to decode stdout: $e');
+      stdoutBuffer.write('Failed to decode stdout: $e');
+    }
+  });
+  final stderrSub = process.stderr.listen((List<int> data) {
+    try {
+      final decoded = systemEncoding.decode(data);
+      logger?.severe(decoded);
+      if (captureOutput) {
+        stderrBuffer.write(decoded);
+      }
+    } catch (e) {
+      logger?.severe('Failed to decode stderr: $e');
+      stderrBuffer.write('Failed to decode stderr: $e');
+    }
+  });
 
-  final (exitCode, _, _) = await (
-    process.exitCode,
-    stdoutSub.asFuture<void>(),
-    stderrSub.asFuture<void>()
-  ).wait;
+  final (exitCode, _, _) =
+      await (
+        process.exitCode,
+        stdoutSub.asFuture<void>(),
+        stderrSub.asFuture<void>(),
+      ).wait;
   final result = RunProcessResult(
     pid: process.pid,
     command: commandString,
