@@ -43,7 +43,7 @@
 /// In most cases relative names are used. Absolute names are typically
 /// only used for operations involving objects in different buckets.
 ///
-/// For most of the APIs in ths library which take instances of other classes
+/// For most of the APIs in this library which take instances of other classes
 /// from this library it is the assumption that the actual implementations
 /// provided here are used.
 library;
@@ -260,7 +260,7 @@ abstract class AclScope {
   /// are set in the different subclasses.
   final String _id;
 
-  /// The type of this acope this ACL scope represents.
+  /// The type of this scope this ACL scope represents.
   final int _type;
 
   /// ACL scope for all authenticated users.
@@ -561,7 +561,9 @@ abstract class Storage {
   /// Copy object [src] to object [dest].
   ///
   /// The names of [src] and [dest] must be absolute.
-  Future copyObject(String src, String dest);
+  ///
+  /// [metadata] can be used to overwrite metadata properties.
+  Future copyObject(String src, String dest, {ObjectMetadata? metadata});
 }
 
 /// Information on a specific object.
@@ -666,23 +668,38 @@ abstract class ObjectMetadata {
 /// Listing operate like a directory listing, despite the object
 /// namespace being flat.
 ///
+/// Instances of [BucketEntry] are either instances of [BucketDirectoryEntry]
+/// or [BucketObjectEntry]. Casting to [BucketObjectEntry] will give access to
+/// object metadata.
+///
 /// See [Bucket.list] for information on how the hierarchical structure
 /// is determined.
-class BucketEntry {
+sealed class BucketEntry {
   /// Whether this is information on an object.
-  final bool isObject;
+  bool get isObject;
 
   /// Name of object or directory.
-  final String name;
-
-  BucketEntry._object(this.name) : isObject = true;
-
-  BucketEntry._directory(this.name) : isObject = false;
+  String get name;
 
   /// Whether this is a prefix.
   bool get isDirectory => !isObject;
 }
 
+/// Entry in [Bucket.list] representing a directory given the `delimiter`
+/// passed.
+class BucketDirectoryEntry extends BucketEntry {
+  @override
+  final String name;
+
+  BucketDirectoryEntry._(this.name);
+
+  @override
+  bool get isObject => false;
+}
+
+/// Entry in [Bucket.list] representing an object.
+abstract class BucketObjectEntry implements BucketEntry, ObjectInfo {}
+
 /// Access to operations on a specific cloud storage bucket.
 abstract class Bucket {
   /// Name of this bucket.
