@@ -13,6 +13,12 @@ import 'text_field.dart';
 
 export 'package:flutter/services.dart' show SmartDashesType, SmartQuotesType;
 
+// The fraction of the height of the search text field after which its contents
+// completely fade out when resized on scroll.
+//
+// Eyeballed on an iPhone 15 simulator running iOS 17.5.
+const double _kMinHeightBeforeTotalTransparency = 4 / 5;
+
 /// A [CupertinoTextField] that mimics the look and behavior of UIKit's
 /// `UISearchTextField`.
 ///
@@ -112,9 +118,9 @@ class CupertinoSearchTextField extends StatefulWidget {
     this.padding = const EdgeInsetsDirectional.fromSTEB(5.5, 8, 5.5, 8),
     this.itemColor = CupertinoColors.secondaryLabel,
     this.itemSize = 20.0,
-    this.prefixInsets = const EdgeInsetsDirectional.fromSTEB(6, 0, 0, 3),
+    this.prefixInsets = const EdgeInsetsDirectional.fromSTEB(6, 8, 0, 8),
     this.prefixIcon = const Icon(CupertinoIcons.search),
-    this.suffixInsets = const EdgeInsetsDirectional.fromSTEB(0, 0, 5, 2),
+    this.suffixInsets = const EdgeInsetsDirectional.fromSTEB(0, 8, 5, 8),
     this.suffixIcon = const Icon(CupertinoIcons.xmark_circle_fill),
     this.suffixMode = OverlayVisibilityMode.editing,
     this.onSuffixTap,
@@ -127,18 +133,23 @@ class CupertinoSearchTextField extends StatefulWidget {
     this.onTap,
     this.autocorrect = true,
     this.enabled,
-  })  : assert(
-          !((decoration != null) && (backgroundColor != null)),
-          'Cannot provide both a background color and a decoration\n'
-          'To provide both, use "decoration: BoxDecoration(color: '
-          'backgroundColor)"',
-        ),
-        assert(
-          !((decoration != null) && (borderRadius != null)),
-          'Cannot provide both a border radius and a decoration\n'
-          'To provide both, use "decoration: BoxDecoration(borderRadius: '
-          'borderRadius)"',
-        );
+    this.cursorWidth = 2.0,
+    this.cursorHeight,
+    this.cursorRadius = const Radius.circular(2.0),
+    this.cursorOpacityAnimates = true,
+    this.cursorColor,
+  }) : assert(
+         !((decoration != null) && (backgroundColor != null)),
+         'Cannot provide both a background color and a decoration\n'
+         'To provide both, use "decoration: BoxDecoration(color: '
+         'backgroundColor)"',
+       ),
+       assert(
+         !((decoration != null) && (borderRadius != null)),
+         'Cannot provide both a border radius and a decoration\n'
+         'To provide both, use "decoration: BoxDecoration(borderRadius: '
+         'borderRadius)"',
+       );
 
   /// Controls the text being edited.
   ///
@@ -321,21 +332,37 @@ class CupertinoSearchTextField extends StatefulWidget {
   /// respond to touch events including the [prefixIcon] and [suffixIcon] button.
   final bool? enabled;
 
+  /// {@macro flutter.widgets.editableText.cursorWidth}
+  final double cursorWidth;
+
+  /// {@macro flutter.widgets.editableText.cursorHeight}
+  final double? cursorHeight;
+
+  /// {@macro flutter.widgets.editableText.cursorRadius}
+  final Radius cursorRadius;
+
+  /// {@macro flutter.widgets.editableText.cursorOpacityAnimates}
+  final bool cursorOpacityAnimates;
+
+  /// The color to use when painting the cursor.
+  final Color? cursorColor;
+
   @override
   State<StatefulWidget> createState() => _CupertinoSearchTextFieldState();
 }
 
-class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
-    with RestorationMixin {
+class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField> with RestorationMixin {
   /// Default value for the border radius. Radius value was determined using the
   /// comparison tool in https://github.com/flutter/platform_tests/.
-  final BorderRadius _kDefaultBorderRadius =
-      const BorderRadius.all(Radius.circular(9.0));
+  final BorderRadius _kDefaultBorderRadius = const BorderRadius.all(Radius.circular(9.0));
 
   RestorableTextEditingController? _controller;
 
-  TextEditingController get _effectiveController =>
-      widget.controller ?? _controller!.value;
+  TextEditingController get _effectiveController => widget.controller ?? _controller!.value;
+
+  ScrollNotificationObserverState? _scrollNotificationObserver;
+  double _fadeExtent = 0.0;
+  double? _maxHeight;
 
   @override
   void initState() {
@@ -345,6 +372,14 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
     }
   }
 
+  @override
+  void didChangeDependencies() {
+    super.didChangeDependencies();
+    _scrollNotificationObserver?.removeListener(_handleScrollNotification);
+    _scrollNotificationObserver = ScrollNotificationObserver.maybeOf(context);
+    _scrollNotificationObserver?.addListener(_handleScrollNotification);
+  }
+
   @override
   void didUpdateWidget(CupertinoSearchTextField oldWidget) {
     super.didUpdateWidget(oldWidget);
@@ -366,6 +401,10 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
 
   @override
   void dispose() {
+    if (_scrollNotificationObserver != null) {
+      _scrollNotificationObserver!.removeListener(_handleScrollNotification);
+      _scrollNotificationObserver = null;
+    }
     super.dispose();
     if (widget.controller == null) {
       _controller?.dispose();
@@ -379,9 +418,10 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
 
   void _createLocalController([TextEditingValue? value]) {
     assert(_controller == null);
-    _controller = value == null
-        ? RestorableTextEditingController()
-        : RestorableTextEditingController.fromValue(value);
+    _controller =
+        value == null
+            ? RestorableTextEditingController()
+            : RestorableTextEditingController.fromValue(value);
     if (!restorePending) {
       _registerController();
     }
@@ -398,13 +438,50 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
     }
   }
 
+  void _handleScrollNotification(ScrollNotification notification) {
+    if (_maxHeight == null) {
+      _maxHeight ??= context.size?.height;
+    } else if (notification is ScrollUpdateNotification) {
+      final double currentHeight = context.size?.height ?? 0.0;
+      setState(() {
+        _fadeExtent = _calculateScrollOpacity(currentHeight, _maxHeight!);
+      });
+    }
+  }
+
+  static double _calculateScrollOpacity(double currentHeight, double maxHeight) {
+    final double thresholdHeight = maxHeight * _kMinHeightBeforeTotalTransparency;
+    if (currentHeight >= maxHeight) {
+      return 0.0;
+    } else if (currentHeight <= thresholdHeight) {
+      return 1.0;
+    } else {
+      final double range = maxHeight - thresholdHeight;
+      final double progress = (currentHeight - thresholdHeight) / range;
+      return 1.0 - progress;
+    }
+  }
+
+  // Animate the top padding so that the contents of the search field
+  // move upwards when the search text field is resized on scroll.
+  EdgeInsetsGeometry _animatedInsets(BuildContext context, EdgeInsetsGeometry insets) {
+    final EdgeInsets currentInsets = insets.resolve(Directionality.of(context));
+    final EdgeInsetsGeometry? animatedInsets = EdgeInsetsGeometry.lerp(
+      insets,
+      currentInsets.copyWith(top: currentInsets.top / 2),
+      _fadeExtent,
+    );
+    return animatedInsets ?? insets;
+  }
+
   @override
   Widget build(BuildContext context) {
-    final String placeholder = widget.placeholder ??
-        CupertinoLocalizations.of(context).searchTextFieldPlaceholderLabel;
+    final String placeholder =
+        widget.placeholder ?? CupertinoLocalizations.of(context).searchTextFieldPlaceholderLabel;
 
-    final TextStyle placeholderStyle = widget.placeholderStyle ??
-        const TextStyle(color: CupertinoColors.systemGrey);
+    final TextStyle placeholderStyle =
+        widget.placeholderStyle ??
+        TextStyle(color: CupertinoColors.systemGrey.withOpacity(1.0 - _fadeExtent));
 
     // The icon size will be scaled by a factor of the accessibility text scale,
     // to follow the behavior of `UISearchTextField`.
@@ -412,7 +489,8 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
 
     // If decoration was not provided, create a decoration with the provided
     // background color and border radius.
-    final BoxDecoration decoration = widget.decoration ??
+    final BoxDecoration decoration =
+        widget.decoration ??
         BoxDecoration(
           color: widget.backgroundColor ?? CupertinoColors.tertiarySystemFill,
           borderRadius: widget.borderRadius ?? _kDefaultBorderRadius,
@@ -423,23 +501,23 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
       size: scaledIconSize,
     );
 
-    final Widget prefix = Padding(
-      padding: widget.prefixInsets,
-      child: IconTheme(
-        data: iconThemeData,
-        child: widget.prefixIcon,
+    final Widget prefix = Opacity(
+      opacity: 1.0 - _fadeExtent,
+      child: Padding(
+        padding: _animatedInsets(context, widget.prefixInsets),
+        child: IconTheme(data: iconThemeData, child: widget.prefixIcon),
       ),
     );
 
-    final Widget suffix = Padding(
-      padding: widget.suffixInsets,
-      child: CupertinoButton(
-        onPressed: widget.onSuffixTap ?? _defaultOnSuffixTap,
-        minSize: 0,
-        padding: EdgeInsets.zero,
-        child: IconTheme(
-          data: iconThemeData,
-          child: widget.suffixIcon,
+    final Widget suffix = Opacity(
+      opacity: 1.0 - _fadeExtent,
+      child: Padding(
+        padding: _animatedInsets(context, widget.suffixInsets),
+        child: CupertinoButton(
+          onPressed: widget.onSuffixTap ?? _defaultOnSuffixTap,
+          minSize: 0,
+          padding: EdgeInsets.zero,
+          child: IconTheme(data: iconThemeData, child: widget.suffixIcon),
         ),
       ),
     );
@@ -453,10 +531,15 @@ class _CupertinoSearchTextFieldState extends State<CupertinoSearchTextField>
       keyboardType: widget.keyboardType,
       onTap: widget.onTap,
       enabled: widget.enabled ?? true,
+      cursorWidth: widget.cursorWidth,
+      cursorHeight: widget.cursorHeight,
+      cursorRadius: widget.cursorRadius,
+      cursorOpacityAnimates: widget.cursorOpacityAnimates,
+      cursorColor: widget.cursorColor,
       suffixMode: widget.suffixMode,
       placeholder: placeholder,
       placeholderStyle: placeholderStyle,
-      padding: widget.padding,
+      padding: _animatedInsets(context, widget.padding),
       onChanged: widget.onChanged,
       onSubmitted: widget.onSubmitted,
       focusNode: widget.focusNode,
