@@ -29,7 +29,7 @@ import 'dart:collection';
 ///
 /// The default value is [debugPrintThrottled]. For a version that acts
 /// identically but does not throttle, use [debugPrintSynchronously].
-typedef DebugPrintCallback = void Function(String? message, { int? wrapWidth });
+typedef DebugPrintCallback = void Function(String? message, {int? wrapWidth});
 
 /// Prints a message to the console, which you can access using the "flutter"
 /// tool's "logs" command ("flutter logs").
@@ -50,9 +50,14 @@ DebugPrintCallback debugPrint = debugPrintThrottled;
 
 /// Alternative implementation of [debugPrint] that does not throttle.
 /// Used by tests.
-void debugPrintSynchronously(String? message, { int? wrapWidth }) {
+void debugPrintSynchronously(String? message, {int? wrapWidth}) {
   if (message != null && wrapWidth != null) {
-    print(message.split('\n').expand<String>((String line) => debugWordWrap(line, wrapWidth)).join('\n'));
+    print(
+      message
+          .split('\n')
+          .expand<String>((String line) => debugWordWrap(line, wrapWidth))
+          .join('\n'),
+    );
   } else {
     print(message);
   }
@@ -62,10 +67,12 @@ void debugPrintSynchronously(String? message, { int? wrapWidth }) {
 /// messages on platforms that rate-limit their logging (for example, Android).
 ///
 /// If `wrapWidth` is not null, the message is wrapped using [debugWordWrap].
-void debugPrintThrottled(String? message, { int? wrapWidth }) {
+void debugPrintThrottled(String? message, {int? wrapWidth}) {
   final List<String> messageLines = message?.split('\n') ?? <String>['null'];
   if (wrapWidth != null) {
-    _debugPrintBuffer.addAll(messageLines.expand<String>((String line) => debugWordWrap(line, wrapWidth)));
+    _debugPrintBuffer.addAll(
+      messageLines.expand<String>((String line) => debugWordWrap(line, wrapWidth)),
+    );
   } else {
     _debugPrintBuffer.addAll(messageLines);
   }
@@ -73,6 +80,7 @@ void debugPrintThrottled(String? message, { int? wrapWidth }) {
     _debugPrintTask();
   }
 }
+
 int _debugPrintedCharacters = 0;
 const int _kDebugPrintCapacity = 12 * 1024;
 const Duration _kDebugPrintPauseTime = Duration(seconds: 1);
@@ -111,6 +119,7 @@ void _debugPrintTask() {
 Future<void> get debugPrintDone => _debugPrintCompleter?.future ?? Future<void>.value();
 
 final RegExp _indentPattern = RegExp('^ *(?:[-+*] |[0-9]+[.):] )?');
+
 enum _WordWrapParseMode { inSpace, inWord, atBreak }
 
 /// Wraps the given string at the given width.
@@ -132,7 +141,7 @@ enum _WordWrapParseMode { inSpace, inWord, atBreak }
 /// and so forth. It is only intended for formatting error messages.
 ///
 /// The default [debugPrint] implementation uses this for its line wrapping.
-Iterable<String> debugWordWrap(String message, int width, { String wrapIndent = '' }) {
+Iterable<String> debugWordWrap(String message, int width, {String wrapIndent = ''}) {
   if (message.length < width || message.trimLeft()[0] == '#') {
     return <String>[message];
   }
@@ -148,7 +157,8 @@ Iterable<String> debugWordWrap(String message, int width, { String wrapIndent =
   int? lastWordEnd;
   while (true) {
     switch (mode) {
-      case _WordWrapParseMode.inSpace: // at start of break point (or start of line); can't break until next break
+      case _WordWrapParseMode
+          .inSpace: // at start of break point (or start of line); can't break until next break
         while ((index < message.length) && (message[index] == ' ')) {
           index += 1;
         }
