@@ -608,7 +608,10 @@ abstract class PointerEvent with Diagnosticable {
     // start and end point of the delta separately and calculate the delta in
     // the new space for greater accuracy.
     transformedEndPosition ??= transformPosition(transform, untransformedEndPosition);
-    final Offset transformedStartPosition = transformPosition(transform, untransformedEndPosition - untransformedDelta);
+    final Offset transformedStartPosition = transformPosition(
+      transform,
+      untransformedEndPosition - untransformedDelta,
+    );
     return transformedEndPosition - transformedStartPosition;
   }
 
@@ -635,32 +638,95 @@ mixin _PointerEventDescription on PointerEvent {
   void debugFillProperties(DiagnosticPropertiesBuilder properties) {
     super.debugFillProperties(properties);
     properties.add(DiagnosticsProperty<Offset>('position', position));
-    properties.add(DiagnosticsProperty<Offset>('localPosition', localPosition, defaultValue: position, level: DiagnosticLevel.debug));
-    properties.add(DiagnosticsProperty<Offset>('delta', delta, defaultValue: Offset.zero, level: DiagnosticLevel.debug));
-    properties.add(DiagnosticsProperty<Offset>('localDelta', localDelta, defaultValue: delta, level: DiagnosticLevel.debug));
-    properties.add(DiagnosticsProperty<Duration>('timeStamp', timeStamp, defaultValue: Duration.zero, level: DiagnosticLevel.debug));
+    properties.add(
+      DiagnosticsProperty<Offset>(
+        'localPosition',
+        localPosition,
+        defaultValue: position,
+        level: DiagnosticLevel.debug,
+      ),
+    );
+    properties.add(
+      DiagnosticsProperty<Offset>(
+        'delta',
+        delta,
+        defaultValue: Offset.zero,
+        level: DiagnosticLevel.debug,
+      ),
+    );
+    properties.add(
+      DiagnosticsProperty<Offset>(
+        'localDelta',
+        localDelta,
+        defaultValue: delta,
+        level: DiagnosticLevel.debug,
+      ),
+    );
+    properties.add(
+      DiagnosticsProperty<Duration>(
+        'timeStamp',
+        timeStamp,
+        defaultValue: Duration.zero,
+        level: DiagnosticLevel.debug,
+      ),
+    );
     properties.add(IntProperty('pointer', pointer, level: DiagnosticLevel.debug));
     properties.add(EnumProperty<PointerDeviceKind>('kind', kind, level: DiagnosticLevel.debug));
     properties.add(IntProperty('device', device, defaultValue: 0, level: DiagnosticLevel.debug));
     properties.add(IntProperty('buttons', buttons, defaultValue: 0, level: DiagnosticLevel.debug));
     properties.add(DiagnosticsProperty<bool>('down', down, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('pressure', pressure, defaultValue: 1.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('pressureMin', pressureMin, defaultValue: 1.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('pressureMax', pressureMax, defaultValue: 1.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('distance', distance, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('distanceMin', distanceMin, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('distanceMax', distanceMax, defaultValue: 0.0, level: DiagnosticLevel.debug));
+    properties.add(
+      DoubleProperty('pressure', pressure, defaultValue: 1.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('pressureMin', pressureMin, defaultValue: 1.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('pressureMax', pressureMax, defaultValue: 1.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('distance', distance, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('distanceMin', distanceMin, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('distanceMax', distanceMax, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
     properties.add(DoubleProperty('size', size, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('radiusMajor', radiusMajor, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('radiusMinor', radiusMinor, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('radiusMin', radiusMin, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('radiusMax', radiusMax, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(DoubleProperty('orientation', orientation, defaultValue: 0.0, level: DiagnosticLevel.debug));
+    properties.add(
+      DoubleProperty('radiusMajor', radiusMajor, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('radiusMinor', radiusMinor, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('radiusMin', radiusMin, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('radiusMax', radiusMax, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      DoubleProperty('orientation', orientation, defaultValue: 0.0, level: DiagnosticLevel.debug),
+    );
     properties.add(DoubleProperty('tilt', tilt, defaultValue: 0.0, level: DiagnosticLevel.debug));
-    properties.add(IntProperty('platformData', platformData, defaultValue: 0, level: DiagnosticLevel.debug));
-    properties.add(FlagProperty('obscured', value: obscured, ifTrue: 'obscured', level: DiagnosticLevel.debug));
-    properties.add(FlagProperty('synthesized', value: synthesized, ifTrue: 'synthesized', level: DiagnosticLevel.debug));
-    properties.add(IntProperty('embedderId', embedderId, defaultValue: 0, level: DiagnosticLevel.debug));
+    properties.add(
+      IntProperty('platformData', platformData, defaultValue: 0, level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      FlagProperty('obscured', value: obscured, ifTrue: 'obscured', level: DiagnosticLevel.debug),
+    );
+    properties.add(
+      FlagProperty(
+        'synthesized',
+        value: synthesized,
+        ifTrue: 'synthesized',
+        level: DiagnosticLevel.debug,
+      ),
+    );
+    properties.add(
+      IntProperty('embedderId', embedderId, defaultValue: 0, level: DiagnosticLevel.debug),
+    );
     properties.add(IntProperty('viewId', viewId, defaultValue: 0, level: DiagnosticLevel.debug));
   }
 
@@ -670,14 +736,15 @@ mixin _PointerEventDescription on PointerEvent {
   }
 }
 
-abstract class _AbstractPointerEvent implements PointerEvent { }
+abstract class _AbstractPointerEvent implements PointerEvent {}
 
 // The base class for transformed pointer event classes.
 //
 // A _TransformedPointerEvent stores an [original] event and the [transform]
 // matrix. It defers all field getters to the original event, except for
 // [localPosition] and [localDelta], which are calculated when first used.
-abstract class _TransformedPointerEvent extends _AbstractPointerEvent with Diagnosticable, _PointerEventDescription {
+abstract class _TransformedPointerEvent extends _AbstractPointerEvent
+    with Diagnosticable, _PointerEventDescription {
   @override
   PointerEvent get original;
 
@@ -844,9 +911,7 @@ class PointerAddedEvent extends PointerEvent with _PointerEventDescription, _Cop
     super.orientation,
     super.tilt,
     super.embedderId,
-  }) : super(
-         pressure: 0.0,
-       );
+  }) : super(pressure: 0.0);
 
   @override
   PointerAddedEvent transformed(Matrix4? transform) {
@@ -857,7 +922,9 @@ class PointerAddedEvent extends PointerEvent with _PointerEventDescription, _Cop
   }
 }
 
-class _TransformedPointerAddedEvent extends _TransformedPointerEvent with _CopyPointerAddedEvent implements PointerAddedEvent {
+class _TransformedPointerAddedEvent extends _TransformedPointerEvent
+    with _CopyPointerAddedEvent
+    implements PointerAddedEvent {
   _TransformedPointerAddedEvent(this.original, this.transform);
 
   @override
@@ -918,7 +985,8 @@ mixin _CopyPointerRemovedEvent on PointerEvent {
 ///
 /// For example, the pointer might have drifted out of the device's hover
 /// detection range or might have been disconnected from the system entirely.
-class PointerRemovedEvent extends PointerEvent with _PointerEventDescription, _CopyPointerRemovedEvent {
+class PointerRemovedEvent extends PointerEvent
+    with _PointerEventDescription, _CopyPointerRemovedEvent {
   /// Creates a pointer removed event.
   const PointerRemovedEvent({
     super.viewId,
@@ -935,9 +1003,7 @@ class PointerRemovedEvent extends PointerEvent with _PointerEventDescription, _C
     super.radiusMax,
     PointerRemovedEvent? super.original,
     super.embedderId,
-  }) : super(
-         pressure: 0.0,
-       );
+  }) : super(pressure: 0.0);
 
   @override
   PointerRemovedEvent transformed(Matrix4? transform) {
@@ -948,7 +1014,9 @@ class PointerRemovedEvent extends PointerEvent with _PointerEventDescription, _C
   }
 }
 
-class _TransformedPointerRemovedEvent extends _TransformedPointerEvent with _CopyPointerRemovedEvent implements PointerRemovedEvent {
+class _TransformedPointerRemovedEvent extends _TransformedPointerEvent
+    with _CopyPointerRemovedEvent
+    implements PointerRemovedEvent {
   _TransformedPointerRemovedEvent(this.original, this.transform);
 
   @override
@@ -1051,10 +1119,7 @@ class PointerHoverEvent extends PointerEvent with _PointerEventDescription, _Cop
     super.tilt,
     super.synthesized,
     super.embedderId,
-  }) : super(
-         down: false,
-         pressure: 0.0,
-       );
+  }) : super(down: false, pressure: 0.0);
 
   @override
   PointerHoverEvent transformed(Matrix4? transform) {
@@ -1065,7 +1130,9 @@ class PointerHoverEvent extends PointerEvent with _PointerEventDescription, _Cop
   }
 }
 
-class _TransformedPointerHoverEvent extends _TransformedPointerEvent with _CopyPointerHoverEvent implements PointerHoverEvent {
+class _TransformedPointerHoverEvent extends _TransformedPointerEvent
+    with _CopyPointerHoverEvent
+    implements PointerHoverEvent {
   _TransformedPointerHoverEvent(this.original, this.transform);
 
   @override
@@ -1172,9 +1239,7 @@ class PointerEnterEvent extends PointerEvent with _PointerEventDescription, _Cop
   }) : // Dart doesn't support comparing enums with == in const contexts yet.
        // https://github.com/dart-lang/language/issues/1811
        assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         pressure: 0.0,
-       );
+       super(pressure: 0.0);
 
   /// Creates an enter event from a [PointerEvent].
   ///
@@ -1213,7 +1278,9 @@ class PointerEnterEvent extends PointerEvent with _PointerEventDescription, _Cop
   }
 }
 
-class _TransformedPointerEnterEvent extends _TransformedPointerEvent with _CopyPointerEnterEvent implements PointerEnterEvent {
+class _TransformedPointerEnterEvent extends _TransformedPointerEvent
+    with _CopyPointerEnterEvent
+    implements PointerEnterEvent {
   _TransformedPointerEnterEvent(this.original, this.transform);
 
   @override
@@ -1318,9 +1385,7 @@ class PointerExitEvent extends PointerEvent with _PointerEventDescription, _Copy
     super.synthesized,
     super.embedderId,
   }) : assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         pressure: 0.0,
-       );
+       super(pressure: 0.0);
 
   /// Creates an exit event from a [PointerEvent].
   ///
@@ -1357,10 +1422,11 @@ class PointerExitEvent extends PointerEvent with _PointerEventDescription, _Copy
     }
     return _TransformedPointerExitEvent(original as PointerExitEvent? ?? this, transform);
   }
-
 }
 
-class _TransformedPointerExitEvent extends _TransformedPointerEvent with _CopyPointerExitEvent implements PointerExitEvent {
+class _TransformedPointerExitEvent extends _TransformedPointerEvent
+    with _CopyPointerExitEvent
+    implements PointerExitEvent {
   _TransformedPointerExitEvent(this.original, this.transform);
 
   @override
@@ -1455,10 +1521,7 @@ class PointerDownEvent extends PointerEvent with _PointerEventDescription, _Copy
     super.tilt,
     super.embedderId,
   }) : assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         down: true,
-         distance: 0.0,
-       );
+       super(down: true, distance: 0.0);
 
   @override
   PointerDownEvent transformed(Matrix4? transform) {
@@ -1469,7 +1532,9 @@ class PointerDownEvent extends PointerEvent with _PointerEventDescription, _Copy
   }
 }
 
-class _TransformedPointerDownEvent extends _TransformedPointerEvent with _CopyPointerDownEvent implements PointerDownEvent {
+class _TransformedPointerDownEvent extends _TransformedPointerEvent
+    with _CopyPointerDownEvent
+    implements PointerDownEvent {
   _TransformedPointerDownEvent(this.original, this.transform);
 
   @override
@@ -1572,10 +1637,7 @@ class PointerMoveEvent extends PointerEvent with _PointerEventDescription, _Copy
     super.synthesized,
     super.embedderId,
   }) : assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         down: true,
-         distance: 0.0,
-       );
+       super(down: true, distance: 0.0);
 
   @override
   PointerMoveEvent transformed(Matrix4? transform) {
@@ -1587,7 +1649,9 @@ class PointerMoveEvent extends PointerEvent with _PointerEventDescription, _Copy
   }
 }
 
-class _TransformedPointerMoveEvent extends _TransformedPointerEvent with _CopyPointerMoveEvent implements PointerMoveEvent {
+class _TransformedPointerMoveEvent extends _TransformedPointerEvent
+    with _CopyPointerMoveEvent
+    implements PointerMoveEvent {
   _TransformedPointerMoveEvent(this.original, this.transform);
 
   @override
@@ -1687,9 +1751,7 @@ class PointerUpEvent extends PointerEvent with _PointerEventDescription, _CopyPo
     super.tilt,
     super.embedderId,
   }) : assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         down: false,
-       );
+       super(down: false);
 
   @override
   PointerUpEvent transformed(Matrix4? transform) {
@@ -1700,7 +1762,9 @@ class PointerUpEvent extends PointerEvent with _PointerEventDescription, _CopyPo
   }
 }
 
-class _TransformedPointerUpEvent extends _TransformedPointerEvent with _CopyPointerUpEvent implements PointerUpEvent {
+class _TransformedPointerUpEvent extends _TransformedPointerEvent
+    with _CopyPointerUpEvent
+    implements PointerUpEvent {
   _TransformedPointerUpEvent(this.original, this.transform);
 
   @override
@@ -1755,9 +1819,7 @@ mixin _RespondablePointerEvent on PointerEvent {
   /// parameter of the [PointerSignalEvent] constructor.
   ///
   /// See also [RespondPointerEventCallback].
-  void respond({
-    required bool allowPlatformDefault,
-  }) {}
+  void respond({required bool allowPlatformDefault}) {}
 }
 
 mixin _CopyPointerScrollEvent on PointerEvent {
@@ -1815,7 +1877,8 @@ mixin _CopyPointerScrollEvent on PointerEvent {
 ///    events in a widget tree.
 ///  * [PointerSignalResolver], which provides an opt-in mechanism whereby
 ///    participating agents may disambiguate an event's target.
-class PointerScrollEvent extends PointerSignalEvent with _PointerEventDescription, _CopyPointerScrollEvent {
+class PointerScrollEvent extends PointerSignalEvent
+    with _PointerEventDescription, _CopyPointerScrollEvent {
   /// Creates a pointer scroll event.
   const PointerScrollEvent({
     super.viewId,
@@ -1849,13 +1912,13 @@ class PointerScrollEvent extends PointerSignalEvent with _PointerEventDescriptio
 
   @override
   void respond({required bool allowPlatformDefault}) {
-    if (_onRespond != null) {
-      _onRespond!(allowPlatformDefault: allowPlatformDefault);
-    }
+    _onRespond?.call(allowPlatformDefault: allowPlatformDefault);
   }
 }
 
-class _TransformedPointerScrollEvent extends _TransformedPointerEvent with _CopyPointerScrollEvent implements PointerScrollEvent {
+class _TransformedPointerScrollEvent extends _TransformedPointerEvent
+    with _CopyPointerScrollEvent
+    implements PointerScrollEvent {
   _TransformedPointerScrollEvent(this.original, this.transform);
 
   @override
@@ -1934,7 +1997,8 @@ mixin _CopyPointerScrollInertiaCancelEvent on PointerEvent {
 ///    events in a widget tree.
 ///  * [PointerSignalResolver], which provides an opt-in mechanism whereby
 ///    participating agents may disambiguate an event's target.
-class PointerScrollInertiaCancelEvent extends PointerSignalEvent with _PointerEventDescription, _CopyPointerScrollInertiaCancelEvent {
+class PointerScrollInertiaCancelEvent extends PointerSignalEvent
+    with _PointerEventDescription, _CopyPointerScrollInertiaCancelEvent {
   /// Creates a pointer scroll-inertia cancel event.
   const PointerScrollInertiaCancelEvent({
     super.viewId,
@@ -1950,11 +2014,16 @@ class PointerScrollInertiaCancelEvent extends PointerSignalEvent with _PointerEv
     if (transform == null || transform == this.transform) {
       return this;
     }
-    return _TransformedPointerScrollInertiaCancelEvent(original as PointerScrollInertiaCancelEvent? ?? this, transform);
+    return _TransformedPointerScrollInertiaCancelEvent(
+      original as PointerScrollInertiaCancelEvent? ?? this,
+      transform,
+    );
   }
 }
 
-class _TransformedPointerScrollInertiaCancelEvent extends _TransformedPointerEvent with _CopyPointerScrollInertiaCancelEvent, _RespondablePointerEvent implements PointerScrollInertiaCancelEvent {
+class _TransformedPointerScrollInertiaCancelEvent extends _TransformedPointerEvent
+    with _CopyPointerScrollInertiaCancelEvent, _RespondablePointerEvent
+    implements PointerScrollInertiaCancelEvent {
   _TransformedPointerScrollInertiaCancelEvent(this.original, this.transform);
 
   @override
@@ -1964,7 +2033,8 @@ class _TransformedPointerScrollInertiaCancelEvent extends _TransformedPointerEve
   final Matrix4 transform;
 
   @override
-  PointerScrollInertiaCancelEvent transformed(Matrix4? transform) => original.transformed(transform);
+  PointerScrollInertiaCancelEvent transformed(Matrix4? transform) =>
+      original.transformed(transform);
 }
 
 mixin _CopyPointerScaleEvent on PointerEvent {
@@ -2021,7 +2091,8 @@ mixin _CopyPointerScaleEvent on PointerEvent {
 ///    events in a widget tree.
 ///  * [PointerSignalResolver], which provides an opt-in mechanism whereby
 ///    participating agents may disambiguate an event's target.
-class PointerScaleEvent extends PointerSignalEvent with _PointerEventDescription, _CopyPointerScaleEvent {
+class PointerScaleEvent extends PointerSignalEvent
+    with _PointerEventDescription, _CopyPointerScaleEvent {
   /// Creates a pointer scale event.
   const PointerScaleEvent({
     super.viewId,
@@ -2045,7 +2116,9 @@ class PointerScaleEvent extends PointerSignalEvent with _PointerEventDescription
   }
 }
 
-class _TransformedPointerScaleEvent extends _TransformedPointerEvent with _CopyPointerScaleEvent, _RespondablePointerEvent implements PointerScaleEvent {
+class _TransformedPointerScaleEvent extends _TransformedPointerEvent
+    with _CopyPointerScaleEvent, _RespondablePointerEvent
+    implements PointerScaleEvent {
   _TransformedPointerScaleEvent(this.original, this.transform);
 
   @override
@@ -2105,7 +2178,8 @@ mixin _CopyPointerPanZoomStartEvent on PointerEvent {
 ///
 ///  * [Listener.onPointerPanZoomStart], which allows callers to be notified of these
 ///    events in a widget tree.
-class PointerPanZoomStartEvent extends PointerEvent with _PointerEventDescription, _CopyPointerPanZoomStartEvent {
+class PointerPanZoomStartEvent extends PointerEvent
+    with _PointerEventDescription, _CopyPointerPanZoomStartEvent {
   /// Creates a pointer pan/zoom start event.
   const PointerPanZoomStartEvent({
     super.viewId,
@@ -2122,11 +2196,16 @@ class PointerPanZoomStartEvent extends PointerEvent with _PointerEventDescriptio
     if (transform == null || transform == this.transform) {
       return this;
     }
-    return _TransformedPointerPanZoomStartEvent(original as PointerPanZoomStartEvent? ?? this, transform);
+    return _TransformedPointerPanZoomStartEvent(
+      original as PointerPanZoomStartEvent? ?? this,
+      transform,
+    );
   }
 }
 
-class _TransformedPointerPanZoomStartEvent extends _TransformedPointerEvent with _CopyPointerPanZoomStartEvent implements PointerPanZoomStartEvent {
+class _TransformedPointerPanZoomStartEvent extends _TransformedPointerEvent
+    with _CopyPointerPanZoomStartEvent
+    implements PointerPanZoomStartEvent {
   _TransformedPointerPanZoomStartEvent(this.original, this.transform);
 
   @override
@@ -2142,14 +2221,19 @@ class _TransformedPointerPanZoomStartEvent extends _TransformedPointerEvent with
 mixin _CopyPointerPanZoomUpdateEvent on PointerEvent {
   /// The total pan offset of the pan/zoom.
   Offset get pan;
+
   /// The total pan offset of the pan/zoom, transformed into local coordinates.
   Offset get localPan;
+
   /// The amount the pan offset changed since the last event.
   Offset get panDelta;
+
   /// The amount the pan offset changed since the last event, transformed into local coordinates.
   Offset get localPanDelta;
+
   /// The scale (zoom factor) of the pan/zoom.
   double get scale;
+
   /// The amount the pan/zoom has rotated in radians so far.
   double get rotation;
 
@@ -2206,7 +2290,8 @@ mixin _CopyPointerPanZoomUpdateEvent on PointerEvent {
 ///
 ///  * [Listener.onPointerPanZoomUpdate], which allows callers to be notified of these
 ///    events in a widget tree.
-class PointerPanZoomUpdateEvent extends PointerEvent with _PointerEventDescription, _CopyPointerPanZoomUpdateEvent {
+class PointerPanZoomUpdateEvent extends PointerEvent
+    with _PointerEventDescription, _CopyPointerPanZoomUpdateEvent {
   /// Creates a pointer pan/zoom update event.
   const PointerPanZoomUpdateEvent({
     super.viewId,
@@ -2240,11 +2325,16 @@ class PointerPanZoomUpdateEvent extends PointerEvent with _PointerEventDescripti
     if (transform == null || transform == this.transform) {
       return this;
     }
-    return _TransformedPointerPanZoomUpdateEvent(original as PointerPanZoomUpdateEvent? ?? this, transform);
+    return _TransformedPointerPanZoomUpdateEvent(
+      original as PointerPanZoomUpdateEvent? ?? this,
+      transform,
+    );
   }
 }
 
-class _TransformedPointerPanZoomUpdateEvent extends _TransformedPointerEvent with _CopyPointerPanZoomUpdateEvent implements PointerPanZoomUpdateEvent {
+class _TransformedPointerPanZoomUpdateEvent extends _TransformedPointerEvent
+    with _CopyPointerPanZoomUpdateEvent
+    implements PointerPanZoomUpdateEvent {
   _TransformedPointerPanZoomUpdateEvent(this.original, this.transform);
 
   @override
@@ -2324,7 +2414,8 @@ mixin _CopyPointerPanZoomEndEvent on PointerEvent {
 ///
 ///  * [Listener.onPointerPanZoomEnd], which allows callers to be notified of these
 ///    events in a widget tree.
-class PointerPanZoomEndEvent extends PointerEvent with _PointerEventDescription, _CopyPointerPanZoomEndEvent {
+class PointerPanZoomEndEvent extends PointerEvent
+    with _PointerEventDescription, _CopyPointerPanZoomEndEvent {
   /// Creates a pointer pan/zoom end event.
   const PointerPanZoomEndEvent({
     super.viewId,
@@ -2341,11 +2432,16 @@ class PointerPanZoomEndEvent extends PointerEvent with _PointerEventDescription,
     if (transform == null || transform == this.transform) {
       return this;
     }
-    return _TransformedPointerPanZoomEndEvent(original as PointerPanZoomEndEvent? ?? this, transform);
+    return _TransformedPointerPanZoomEndEvent(
+      original as PointerPanZoomEndEvent? ?? this,
+      transform,
+    );
   }
 }
 
-class _TransformedPointerPanZoomEndEvent extends _TransformedPointerEvent with _CopyPointerPanZoomEndEvent implements PointerPanZoomEndEvent {
+class _TransformedPointerPanZoomEndEvent extends _TransformedPointerEvent
+    with _CopyPointerPanZoomEndEvent
+    implements PointerPanZoomEndEvent {
   _TransformedPointerPanZoomEndEvent(this.original, this.transform);
 
   @override
@@ -2416,7 +2512,8 @@ mixin _CopyPointerCancelEvent on PointerEvent {
 ///
 ///  * [Listener.onPointerCancel], which allows callers to be notified of these
 ///    events in a widget tree.
-class PointerCancelEvent extends PointerEvent with _PointerEventDescription, _CopyPointerCancelEvent {
+class PointerCancelEvent extends PointerEvent
+    with _PointerEventDescription, _CopyPointerCancelEvent {
   /// Creates a pointer cancel event.
   const PointerCancelEvent({
     super.viewId,
@@ -2440,10 +2537,7 @@ class PointerCancelEvent extends PointerEvent with _PointerEventDescription, _Co
     super.tilt,
     super.embedderId,
   }) : assert(!identical(kind, PointerDeviceKind.trackpad)),
-       super(
-         down: false,
-         pressure: 0.0,
-       );
+       super(down: false, pressure: 0.0);
 
   @override
   PointerCancelEvent transformed(Matrix4? transform) {
@@ -2496,7 +2590,9 @@ double computeScaleSlop(PointerDeviceKind kind) {
   }
 }
 
-class _TransformedPointerCancelEvent extends _TransformedPointerEvent with _CopyPointerCancelEvent implements PointerCancelEvent {
+class _TransformedPointerCancelEvent extends _TransformedPointerEvent
+    with _CopyPointerCancelEvent
+    implements PointerCancelEvent {
   _TransformedPointerCancelEvent(this.original, this.transform);
 
   @override
