@@ -2,13 +2,20 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/widgets.dart';
+library;
 
-import 'arena.dart';
 import 'constants.dart';
 import 'events.dart';
 import 'recognizer.dart';
 import 'velocity_tracker.dart';
 
+export 'dart:ui' show Offset, PointerDeviceKind;
+
+export 'arena.dart' show GestureDisposition;
+export 'events.dart' show PointerDownEvent, PointerEvent;
+export 'velocity_tracker.dart' show Velocity;
+
 /// Callback signature for [LongPressGestureRecognizer.onLongPressDown].
 ///
 /// Called when a pointer that might cause a long-press has contacted the
@@ -103,16 +110,10 @@ typedef GestureLongPressEndCallback = void Function(LongPressEndDetails details)
 class LongPressDownDetails {
   /// Creates the details for a [GestureLongPressDownCallback].
   ///
-  /// The `globalPosition` argument must not be null.
-  ///
   /// If the `localPosition` argument is not specified, it will default to the
   /// global position.
-  const LongPressDownDetails({
-    this.globalPosition = Offset.zero,
-    Offset? localPosition,
-    this.kind,
-  }) : assert(globalPosition != null),
-       localPosition = localPosition ?? globalPosition;
+  const LongPressDownDetails({this.globalPosition = Offset.zero, Offset? localPosition, this.kind})
+    : localPosition = localPosition ?? globalPosition;
 
   /// The global position at which the pointer contacted the screen.
   final Offset globalPosition;
@@ -133,13 +134,8 @@ class LongPressDownDetails {
 ///  * [LongPressEndDetails], the details for [GestureLongPressEndCallback].
 class LongPressStartDetails {
   /// Creates the details for a [GestureLongPressStartCallback].
-  ///
-  /// The [globalPosition] argument must not be null.
-  const LongPressStartDetails({
-    this.globalPosition = Offset.zero,
-    Offset? localPosition,
-  }) : assert(globalPosition != null),
-       localPosition = localPosition ?? globalPosition;
+  const LongPressStartDetails({this.globalPosition = Offset.zero, Offset? localPosition})
+    : localPosition = localPosition ?? globalPosition;
 
   /// The global position at which the pointer initially contacted the screen.
   final Offset globalPosition;
@@ -157,16 +153,12 @@ class LongPressStartDetails {
 ///  * [LongPressStartDetails], the details for [GestureLongPressStartCallback].
 class LongPressMoveUpdateDetails {
   /// Creates the details for a [GestureLongPressMoveUpdateCallback].
-  ///
-  /// The [globalPosition] and [offsetFromOrigin] arguments must not be null.
   const LongPressMoveUpdateDetails({
     this.globalPosition = Offset.zero,
     Offset? localPosition,
     this.offsetFromOrigin = Offset.zero,
     Offset? localOffsetFromOrigin,
-  }) : assert(globalPosition != null),
-       assert(offsetFromOrigin != null),
-       localPosition = localPosition ?? globalPosition,
+  }) : localPosition = localPosition ?? globalPosition,
        localOffsetFromOrigin = localOffsetFromOrigin ?? offsetFromOrigin;
 
   /// The global position of the pointer when it triggered this update.
@@ -195,14 +187,11 @@ class LongPressMoveUpdateDetails {
 ///  * [LongPressStartDetails], the details for [GestureLongPressStartCallback].
 class LongPressEndDetails {
   /// Creates the details for a [GestureLongPressEndCallback].
-  ///
-  /// The [globalPosition] argument must not be null.
   const LongPressEndDetails({
     this.globalPosition = Offset.zero,
     Offset? localPosition,
     this.velocity = Velocity.zero,
-  }) : assert(globalPosition != null),
-       localPosition = localPosition ?? globalPosition;
+  }) : localPosition = localPosition ?? globalPosition;
 
   /// The global position at which the pointer lifted from the screen.
   final Offset globalPosition;
@@ -243,23 +232,18 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
   /// The [duration] argument can be used to overwrite the default duration
   /// after which the long press will be recognized.
   ///
+  /// {@macro flutter.gestures.tap.TapGestureRecognizer.allowedButtonsFilter}
+  ///
   /// {@macro flutter.gestures.GestureRecognizer.supportedDevices}
   LongPressGestureRecognizer({
     Duration? duration,
-    double? postAcceptSlopTolerance,
-    @Deprecated(
-      'Migrate to supportedDevices. '
-      'This feature was deprecated after v2.3.0-1.0.pre.',
-    )
-    PointerDeviceKind? kind,
-    Set<PointerDeviceKind>? supportedDevices,
-    Object? debugOwner,
+    super.postAcceptSlopTolerance = null,
+    super.supportedDevices,
+    super.debugOwner,
+    AllowedButtonsFilter? allowedButtonsFilter,
   }) : super(
          deadline: duration ?? kLongPressTimeout,
-         postAcceptSlopTolerance: postAcceptSlopTolerance,
-         kind: kind,
-         supportedDevices: supportedDevices,
-         debugOwner: debugOwner,
+         allowedButtonsFilter: allowedButtonsFilter ?? _defaultButtonAcceptBehavior,
        );
 
   bool _longPressAccepted = false;
@@ -268,6 +252,10 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
   // different set of buttons, the gesture is canceled.
   int? _initialButtons;
 
+  // Accept the input if, and only if, a single button is pressed.
+  static bool _defaultButtonAcceptBehavior(int buttons) =>
+      buttons == kPrimaryButton || buttons == kSecondaryButton || buttons == kTertiaryButton;
+
   /// Called when a pointer has contacted the screen at a particular location
   /// with a primary button, which might be the start of a long-press.
   ///
@@ -577,9 +565,9 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
             onLongPress == null &&
             onLongPressMoveUpdate == null &&
             onLongPressEnd == null &&
-            onLongPressUp == null)
+            onLongPressUp == null) {
           return false;
-        break;
+        }
       case kSecondaryButton:
         if (onSecondaryLongPressDown == null &&
             onSecondaryLongPressCancel == null &&
@@ -587,9 +575,9 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
             onSecondaryLongPress == null &&
             onSecondaryLongPressMoveUpdate == null &&
             onSecondaryLongPressEnd == null &&
-            onSecondaryLongPressUp == null)
+            onSecondaryLongPressUp == null) {
           return false;
-        break;
+        }
       case kTertiaryButton:
         if (onTertiaryLongPressDown == null &&
             onTertiaryLongPressCancel == null &&
@@ -597,9 +585,9 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
             onTertiaryLongPress == null &&
             onTertiaryLongPressMoveUpdate == null &&
             onTertiaryLongPressEnd == null &&
-            onTertiaryLongPressUp == null)
+            onTertiaryLongPressUp == null) {
           return false;
-        break;
+        }
       default:
         return false;
     }
@@ -629,7 +617,7 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
     }
 
     if (event is PointerUpEvent) {
-      if (_longPressAccepted == true) {
+      if (_longPressAccepted) {
         _checkLongPressEnd(event);
       } else {
         // Pointer is lifted before timeout.
@@ -645,7 +633,7 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
       _initialButtons = event.buttons;
       _checkLongPressDown(event);
     } else if (event is PointerMoveEvent) {
-      if (event.buttons != _initialButtons) {
+      if (event.buttons != _initialButtons && !_longPressAccepted) {
         resolve(GestureDisposition.rejected);
         stopTrackingPointer(primaryPointer!);
       } else if (_longPressAccepted) {
@@ -663,17 +651,20 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
     );
     switch (_initialButtons) {
       case kPrimaryButton:
-        if (onLongPressDown != null)
+        if (onLongPressDown != null) {
           invokeCallback<void>('onLongPressDown', () => onLongPressDown!(details));
-        break;
+        }
       case kSecondaryButton:
-        if (onSecondaryLongPressDown != null)
-          invokeCallback<void>('onSecondaryLongPressDown', () => onSecondaryLongPressDown!(details));
-        break;
+        if (onSecondaryLongPressDown != null) {
+          invokeCallback<void>(
+            'onSecondaryLongPressDown',
+            () => onSecondaryLongPressDown!(details),
+          );
+        }
       case kTertiaryButton:
-        if (onTertiaryLongPressDown != null)
+        if (onTertiaryLongPressDown != null) {
           invokeCallback<void>('onTertiaryLongPressDown', () => onTertiaryLongPressDown!(details));
-        break;
+        }
       default:
         assert(false, 'Unhandled button $_initialButtons');
     }
@@ -683,17 +674,17 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
     if (state == GestureRecognizerState.possible) {
       switch (_initialButtons) {
         case kPrimaryButton:
-          if (onLongPressCancel != null)
+          if (onLongPressCancel != null) {
             invokeCallback<void>('onLongPressCancel', onLongPressCancel!);
-          break;
+          }
         case kSecondaryButton:
-          if (onSecondaryLongPressCancel != null)
+          if (onSecondaryLongPressCancel != null) {
             invokeCallback<void>('onSecondaryLongPressCancel', onSecondaryLongPressCancel!);
-          break;
+          }
         case kTertiaryButton:
-          if (onTertiaryLongPressCancel != null)
+          if (onTertiaryLongPressCancel != null) {
             invokeCallback<void>('onTertiaryLongPressCancel', onTertiaryLongPressCancel!);
-          break;
+          }
         default:
           assert(false, 'Unhandled button $_initialButtons');
       }
@@ -713,31 +704,34 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
         if (onLongPress != null) {
           invokeCallback<void>('onLongPress', onLongPress!);
         }
-        break;
       case kSecondaryButton:
         if (onSecondaryLongPressStart != null) {
           final LongPressStartDetails details = LongPressStartDetails(
             globalPosition: _longPressOrigin!.global,
             localPosition: _longPressOrigin!.local,
           );
-          invokeCallback<void>('onSecondaryLongPressStart', () => onSecondaryLongPressStart!(details));
+          invokeCallback<void>(
+            'onSecondaryLongPressStart',
+            () => onSecondaryLongPressStart!(details),
+          );
         }
         if (onSecondaryLongPress != null) {
           invokeCallback<void>('onSecondaryLongPress', onSecondaryLongPress!);
         }
-        break;
       case kTertiaryButton:
         if (onTertiaryLongPressStart != null) {
           final LongPressStartDetails details = LongPressStartDetails(
             globalPosition: _longPressOrigin!.global,
             localPosition: _longPressOrigin!.local,
           );
-          invokeCallback<void>('onTertiaryLongPressStart', () => onTertiaryLongPressStart!(details));
+          invokeCallback<void>(
+            'onTertiaryLongPressStart',
+            () => onTertiaryLongPressStart!(details),
+          );
         }
         if (onTertiaryLongPress != null) {
           invokeCallback<void>('onTertiaryLongPress', onTertiaryLongPress!);
         }
-        break;
       default:
         assert(false, 'Unhandled button $_initialButtons');
     }
@@ -755,17 +749,20 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
         if (onLongPressMoveUpdate != null) {
           invokeCallback<void>('onLongPressMoveUpdate', () => onLongPressMoveUpdate!(details));
         }
-        break;
       case kSecondaryButton:
         if (onSecondaryLongPressMoveUpdate != null) {
-          invokeCallback<void>('onSecondaryLongPressMoveUpdate', () => onSecondaryLongPressMoveUpdate!(details));
+          invokeCallback<void>(
+            'onSecondaryLongPressMoveUpdate',
+            () => onSecondaryLongPressMoveUpdate!(details),
+          );
         }
-        break;
       case kTertiaryButton:
         if (onTertiaryLongPressMoveUpdate != null) {
-          invokeCallback<void>('onTertiaryLongPressMoveUpdate', () => onTertiaryLongPressMoveUpdate!(details));
+          invokeCallback<void>(
+            'onTertiaryLongPressMoveUpdate',
+            () => onTertiaryLongPressMoveUpdate!(details),
+          );
         }
-        break;
       default:
         assert(false, 'Unhandled button $_initialButtons');
     }
@@ -773,9 +770,8 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
 
   void _checkLongPressEnd(PointerEvent event) {
     final VelocityEstimate? estimate = _velocityTracker!.getVelocityEstimate();
-    final Velocity velocity = estimate == null
-        ? Velocity.zero
-        : Velocity(pixelsPerSecond: estimate.pixelsPerSecond);
+    final Velocity velocity =
+        estimate == null ? Velocity.zero : Velocity(pixelsPerSecond: estimate.pixelsPerSecond);
     final LongPressEndDetails details = LongPressEndDetails(
       globalPosition: event.position,
       localPosition: event.localPosition,
@@ -791,7 +787,6 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
         if (onLongPressUp != null) {
           invokeCallback<void>('onLongPressUp', onLongPressUp!);
         }
-        break;
       case kSecondaryButton:
         if (onSecondaryLongPressEnd != null) {
           invokeCallback<void>('onSecondaryLongPressEnd', () => onSecondaryLongPressEnd!(details));
@@ -799,7 +794,6 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
         if (onSecondaryLongPressUp != null) {
           invokeCallback<void>('onSecondaryLongPressUp', onSecondaryLongPressUp!);
         }
-        break;
       case kTertiaryButton:
         if (onTertiaryLongPressEnd != null) {
           invokeCallback<void>('onTertiaryLongPressEnd', () => onTertiaryLongPressEnd!(details));
@@ -807,7 +801,6 @@ class LongPressGestureRecognizer extends PrimaryPointerGestureRecognizer {
         if (onTertiaryLongPressUp != null) {
           invokeCallback<void>('onTertiaryLongPressUp', onTertiaryLongPressUp!);
         }
-        break;
       default:
         assert(false, 'Unhandled button $_initialButtons');
     }
