@@ -2,6 +2,12 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'bottom_navigation_bar.dart';
+/// @docImport 'floating_action_button.dart';
+/// @docImport 'icons.dart';
+/// @docImport 'scaffold.dart';
+library;
+
 import 'dart:ui';
 
 import 'package:flutter/widgets.dart';
@@ -39,23 +45,14 @@ const double _kIndicatorHeight = 32;
 /// Adaptive layouts can build different instances of the [Scaffold] in order to
 /// have a navigation rail for more horizontal layouts and a bottom navigation
 /// bar for more vertical layouts. See
-/// [the adaptive_scaffold.dart sample](https://github.com/flutter/samples/blob/master/experimental/web_dashboard/lib/src/widgets/third_party/adaptive_scaffold.dart)
+/// [the adaptive_scaffold.dart sample](https://github.com/flutter/samples/blob/main/experimental/web_dashboard/lib/src/widgets/third_party/adaptive_scaffold.dart)
 /// for an example.
 ///
 /// {@tool dartpad}
-/// This example shows a [NavigationRail] used within a Scaffold with 3
-/// [NavigationRailDestination]s. The main content is separated by a divider
-/// (although elevation on the navigation rail can be used instead). The
-/// `_selectedIndex` is updated by the `onDestinationSelected` callback.
-///
-/// ** See code in examples/api/lib/material/navigation_rail/navigation_rail.0.dart **
-/// {@end-tool}
-///
-/// {@tool dartpad}
 /// This sample shows the creation of [NavigationRail] widget used within a Scaffold with 3
 /// [NavigationRailDestination]s, as described in: https://m3.material.io/components/navigation-rail/overview
 ///
-/// ** See code in examples/api/lib/material/navigation_rail/navigation_rail.1.dart **
+/// ** See code in examples/api/lib/material/navigation_rail/navigation_rail.0.dart **
 /// {@end-tool}
 ///
 /// See also:
@@ -71,7 +68,7 @@ const double _kIndicatorHeight = 32;
 class NavigationRail extends StatefulWidget {
   /// Creates a Material Design navigation rail.
   ///
-  /// The value of [destinations] must be a list of two or more
+  /// The value of [destinations] must be a list of zero or more
   /// [NavigationRailDestination] values.
   ///
   /// If [elevation] is specified, it must be non-negative.
@@ -80,8 +77,8 @@ class NavigationRail extends StatefulWidget {
   /// [minExtendedWidth] is specified, it must be non-negative and greater than
   /// [minWidth].
   ///
-  /// The argument [extended] must not be null. [extended] can only be set to
-  /// true when the [labelType] is null or [NavigationRailLabelType.none].
+  /// The [extended] argument can only be set to true when the [labelType] is
+  /// null or [NavigationRailLabelType.none].
   ///
   /// If [backgroundColor], [elevation], [groupAlignment], [labelType],
   /// [unselectedLabelTextStyle], [selectedLabelTextStyle],
@@ -112,13 +109,12 @@ class NavigationRail extends StatefulWidget {
     this.useIndicator,
     this.indicatorColor,
     this.indicatorShape,
-  }) :  assert(destinations.length >= 2),
-        assert(selectedIndex == null || (0 <= selectedIndex && selectedIndex < destinations.length)),
-        assert(elevation == null || elevation > 0),
-        assert(minWidth == null || minWidth > 0),
-        assert(minExtendedWidth == null || minExtendedWidth > 0),
-        assert((minWidth == null || minExtendedWidth == null) || minExtendedWidth >= minWidth),
-        assert(!extended || (labelType == null || labelType == NavigationRailLabelType.none));
+  }) : assert(selectedIndex == null || (0 <= selectedIndex && selectedIndex < destinations.length)),
+       assert(elevation == null || elevation > 0),
+       assert(minWidth == null || minWidth > 0),
+       assert(minExtendedWidth == null || minExtendedWidth > 0),
+       assert((minWidth == null || minExtendedWidth == null) || minExtendedWidth >= minWidth),
+       assert(!extended || (labelType == null || labelType == NavigationRailLabelType.none));
 
   /// Sets the color of the Container that holds all of the [NavigationRail]'s
   /// contents.
@@ -167,7 +163,7 @@ class NavigationRail extends StatefulWidget {
   /// Defines the appearance of the button items that are arrayed within the
   /// navigation rail.
   ///
-  /// The value must be a list of two or more [NavigationRailDestination]
+  /// The value must be a list of zero or more [NavigationRailDestination]
   /// values.
   final List<NavigationRailDestination> destinations;
 
@@ -184,8 +180,8 @@ class NavigationRail extends StatefulWidget {
 
   /// The rail's elevation or z-coordinate.
   ///
-  /// If [Directionality] is [intl.TextDirection.LTR], the inner side is the
-  /// right side, and if [Directionality] is [intl.TextDirection.RTL], it is
+  /// If [Directionality] is [TextDirection.ltr], the inner side is the
+  /// right side, and if [Directionality] is [TextDirection.rtl], it is
   /// the left side.
   ///
   /// The default value is 0.
@@ -335,7 +331,9 @@ class NavigationRail extends StatefulWidget {
   /// ** See code in examples/api/lib/material/navigation_rail/navigation_rail.extended_animation.0.dart **
   /// {@end-tool}
   static Animation<double> extendedAnimation(BuildContext context) {
-    return context.dependOnInheritedWidgetOfExactType<_ExtendedNavigationRailAnimation>()!.animation;
+    return context
+        .dependOnInheritedWidgetOfExactType<_ExtendedNavigationRailAnimation>()!
+        .animation;
   }
 
   @override
@@ -346,7 +344,7 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
   late List<AnimationController> _destinationControllers;
   late List<Animation<double>> _destinationAnimations;
   late AnimationController _extendedController;
-  late Animation<double> _extendedAnimation;
+  late CurvedAnimation _extendedAnimation;
 
   @override
   void initState() {
@@ -392,29 +390,57 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
   @override
   Widget build(BuildContext context) {
     final NavigationRailThemeData navigationRailTheme = NavigationRailTheme.of(context);
-    final NavigationRailThemeData defaults = Theme.of(context).useMaterial3 ? _NavigationRailDefaultsM3(context) : _NavigationRailDefaultsM2(context);
+    final NavigationRailThemeData defaults =
+        Theme.of(context).useMaterial3
+            ? _NavigationRailDefaultsM3(context)
+            : _NavigationRailDefaultsM2(context);
     final MaterialLocalizations localizations = MaterialLocalizations.of(context);
 
-    final Color backgroundColor = widget.backgroundColor ?? navigationRailTheme.backgroundColor ?? defaults.backgroundColor!;
-    final double elevation = widget.elevation ?? navigationRailTheme.elevation ?? defaults.elevation!;
+    final Color backgroundColor =
+        widget.backgroundColor ?? navigationRailTheme.backgroundColor ?? defaults.backgroundColor!;
+    final double elevation =
+        widget.elevation ?? navigationRailTheme.elevation ?? defaults.elevation!;
     final double minWidth = widget.minWidth ?? navigationRailTheme.minWidth ?? defaults.minWidth!;
-    final double minExtendedWidth = widget.minExtendedWidth ?? navigationRailTheme.minExtendedWidth ?? defaults.minExtendedWidth!;
-    final TextStyle unselectedLabelTextStyle = widget.unselectedLabelTextStyle ?? navigationRailTheme.unselectedLabelTextStyle ?? defaults.unselectedLabelTextStyle!;
-    final TextStyle selectedLabelTextStyle = widget.selectedLabelTextStyle ?? navigationRailTheme.selectedLabelTextStyle ?? defaults.selectedLabelTextStyle!;
-    final IconThemeData unselectedIconTheme = widget.unselectedIconTheme ?? navigationRailTheme.unselectedIconTheme ?? defaults.unselectedIconTheme!;
-    final IconThemeData selectedIconTheme = widget.selectedIconTheme ?? navigationRailTheme.selectedIconTheme ?? defaults.selectedIconTheme!;
-    final double groupAlignment = widget.groupAlignment ?? navigationRailTheme.groupAlignment ?? defaults.groupAlignment!;
-    final NavigationRailLabelType labelType = widget.labelType ?? navigationRailTheme.labelType ?? defaults.labelType!;
-    final bool useIndicator = widget.useIndicator ?? navigationRailTheme.useIndicator ?? defaults.useIndicator!;
-    final Color? indicatorColor = widget.indicatorColor ?? navigationRailTheme.indicatorColor ?? defaults.indicatorColor;
-    final ShapeBorder? indicatorShape = widget.indicatorShape ?? navigationRailTheme.indicatorShape ?? defaults.indicatorShape;
+    final double minExtendedWidth =
+        widget.minExtendedWidth ??
+        navigationRailTheme.minExtendedWidth ??
+        defaults.minExtendedWidth!;
+    final TextStyle unselectedLabelTextStyle =
+        widget.unselectedLabelTextStyle ??
+        navigationRailTheme.unselectedLabelTextStyle ??
+        defaults.unselectedLabelTextStyle!;
+    final TextStyle selectedLabelTextStyle =
+        widget.selectedLabelTextStyle ??
+        navigationRailTheme.selectedLabelTextStyle ??
+        defaults.selectedLabelTextStyle!;
+    final IconThemeData unselectedIconTheme =
+        widget.unselectedIconTheme ??
+        navigationRailTheme.unselectedIconTheme ??
+        defaults.unselectedIconTheme!;
+    final IconThemeData selectedIconTheme =
+        widget.selectedIconTheme ??
+        navigationRailTheme.selectedIconTheme ??
+        defaults.selectedIconTheme!;
+    final double groupAlignment =
+        widget.groupAlignment ?? navigationRailTheme.groupAlignment ?? defaults.groupAlignment!;
+    final NavigationRailLabelType labelType =
+        widget.labelType ?? navigationRailTheme.labelType ?? defaults.labelType!;
+    final bool useIndicator =
+        widget.useIndicator ?? navigationRailTheme.useIndicator ?? defaults.useIndicator!;
+    final Color? indicatorColor =
+        widget.indicatorColor ?? navigationRailTheme.indicatorColor ?? defaults.indicatorColor;
+    final ShapeBorder? indicatorShape =
+        widget.indicatorShape ?? navigationRailTheme.indicatorShape ?? defaults.indicatorShape;
 
     // For backwards compatibility, in M2 the opacity of the unselected icons needs
     // to be set to the default if it isn't in the given theme. This can be removed
     // when Material 3 is the default.
-    final IconThemeData effectiveUnselectedIconTheme = Theme.of(context).useMaterial3
-      ? unselectedIconTheme
-      : unselectedIconTheme.copyWith(opacity: unselectedIconTheme.opacity ?? defaults.unselectedIconTheme!.opacity);
+    final IconThemeData effectiveUnselectedIconTheme =
+        Theme.of(context).useMaterial3
+            ? unselectedIconTheme
+            : unselectedIconTheme.copyWith(
+              opacity: unselectedIconTheme.opacity ?? defaults.unselectedIconTheme!.opacity,
+            );
 
     final bool isRTLDirection = Directionality.of(context) == TextDirection.rtl;
 
@@ -431,11 +457,7 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
             child: Column(
               children: <Widget>[
                 _verticalSpacer,
-                if (widget.leading != null)
-                  ...<Widget>[
-                    widget.leading!,
-                    _verticalSpacer,
-                  ],
+                if (widget.leading != null) ...<Widget>[widget.leading!, _verticalSpacer],
                 Expanded(
                   child: Align(
                     alignment: Alignment(0, groupAlignment),
@@ -448,12 +470,21 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
                             minExtendedWidth: minExtendedWidth,
                             extendedTransitionAnimation: _extendedAnimation,
                             selected: widget.selectedIndex == i,
-                            icon: widget.selectedIndex == i ? widget.destinations[i].selectedIcon : widget.destinations[i].icon,
+                            icon:
+                                widget.selectedIndex == i
+                                    ? widget.destinations[i].selectedIcon
+                                    : widget.destinations[i].icon,
                             label: widget.destinations[i].label,
                             destinationAnimation: _destinationAnimations[i],
                             labelType: labelType,
-                            iconTheme: widget.selectedIndex == i ? selectedIconTheme : effectiveUnselectedIconTheme,
-                            labelTextStyle: widget.selectedIndex == i ? selectedLabelTextStyle : unselectedLabelTextStyle,
+                            iconTheme:
+                                widget.selectedIndex == i
+                                    ? selectedIconTheme
+                                    : effectiveUnselectedIconTheme,
+                            labelTextStyle:
+                                widget.selectedIndex == i
+                                    ? selectedLabelTextStyle
+                                    : unselectedLabelTextStyle,
                             padding: widget.destinations[i].padding,
                             useIndicator: useIndicator,
                             indicatorColor: useIndicator ? indicatorColor : null,
@@ -469,8 +500,7 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
                             ),
                             disabled: widget.destinations[i].disabled,
                           ),
-                        if (widget.trailing != null)
-                          widget.trailing!,
+                        if (widget.trailing != null) widget.trailing!,
                       ],
                     ),
                   ),
@@ -488,16 +518,18 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
       controller.dispose();
     }
     _extendedController.dispose();
+    _extendedAnimation.dispose();
   }
 
   void _initControllers() {
-    _destinationControllers = List<AnimationController>.generate(widget.destinations.length, (int index) {
-      return AnimationController(
-        duration: kThemeAnimationDuration,
-        vsync: this,
-      )..addListener(_rebuild);
+    _destinationControllers = List<AnimationController>.generate(widget.destinations.length, (
+      int index,
+    ) {
+      return AnimationController(duration: kThemeAnimationDuration, vsync: this)
+        ..addListener(_rebuild);
     });
-    _destinationAnimations = _destinationControllers.map((AnimationController controller) => controller.view).toList();
+    _destinationAnimations =
+        _destinationControllers.map((AnimationController controller) => controller.view).toList();
     if (widget.selectedIndex != null) {
       _destinationControllers[widget.selectedIndex!].value = 1.0;
     }
@@ -506,10 +538,7 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
       vsync: this,
       value: widget.extended ? 1.0 : 0.0,
     );
-    _extendedAnimation = CurvedAnimation(
-      parent: _extendedController,
-      curve: Curves.easeInOut,
-    );
+    _extendedAnimation = CurvedAnimation(parent: _extendedController, curve: Curves.easeInOut);
     _extendedController.addListener(() {
       _rebuild();
     });
@@ -528,8 +557,8 @@ class _NavigationRailState extends State<NavigationRail> with TickerProviderStat
   }
 }
 
-class _RailDestination extends StatelessWidget {
-  _RailDestination({
+class _RailDestination extends StatefulWidget {
+  const _RailDestination({
     required this.minWidth,
     required this.minExtendedWidth,
     required this.icon,
@@ -547,11 +576,7 @@ class _RailDestination extends StatelessWidget {
     this.indicatorColor,
     this.indicatorShape,
     this.disabled = false,
-  }) : _positionAnimation = CurvedAnimation(
-          parent: ReverseAnimation(destinationAnimation),
-          curve: Curves.easeInOut,
-          reverseCurve: Curves.easeInOut.flipped,
-       );
+  });
 
   final double minWidth;
   final double minExtendedWidth;
@@ -571,56 +596,105 @@ class _RailDestination extends StatelessWidget {
   final ShapeBorder? indicatorShape;
   final bool disabled;
 
-  final Animation<double> _positionAnimation;
+  @override
+  State<_RailDestination> createState() => _RailDestinationState();
+}
+
+class _RailDestinationState extends State<_RailDestination> {
+  late CurvedAnimation _positionAnimation;
+
+  @override
+  void initState() {
+    super.initState();
+    _setPositionAnimation();
+  }
+
+  @override
+  void didUpdateWidget(_RailDestination oldWidget) {
+    super.didUpdateWidget(oldWidget);
+    if (widget.destinationAnimation != oldWidget.destinationAnimation) {
+      _positionAnimation.dispose();
+      _setPositionAnimation();
+    }
+  }
+
+  void _setPositionAnimation() {
+    _positionAnimation = CurvedAnimation(
+      parent: ReverseAnimation(widget.destinationAnimation),
+      curve: Curves.easeInOut,
+      reverseCurve: Curves.easeInOut.flipped,
+    );
+  }
+
+  @override
+  void dispose() {
+    _positionAnimation.dispose();
+    super.dispose();
+  }
 
   @override
   Widget build(BuildContext context) {
     assert(
-      useIndicator || indicatorColor == null,
+      widget.useIndicator || widget.indicatorColor == null,
       '[NavigationRail.indicatorColor] does not have an effect when [NavigationRail.useIndicator] is false',
     );
 
     final ThemeData theme = Theme.of(context);
-
+    final TextDirection textDirection = Directionality.of(context);
     final bool material3 = theme.useMaterial3;
-    final EdgeInsets destinationPadding = (padding ?? EdgeInsets.zero).resolve(Directionality.of(context));
+    final EdgeInsets destinationPadding = (widget.padding ?? EdgeInsets.zero).resolve(
+      textDirection,
+    );
     Offset indicatorOffset;
     bool applyXOffset = false;
 
     final Widget themedIcon = IconTheme(
-      data: disabled
-        ? iconTheme.copyWith(color: theme.colorScheme.onSurface.withOpacity(0.38))
-        : iconTheme,
-      child: icon,
+      data:
+          widget.disabled
+              ? widget.iconTheme.copyWith(color: theme.colorScheme.onSurface.withOpacity(0.38))
+              : widget.iconTheme,
+      child: widget.icon,
     );
     final Widget styledLabel = DefaultTextStyle(
-      style: labelTextStyle,
-      child: label,
+      style:
+          widget.disabled
+              ? widget.labelTextStyle.copyWith(color: theme.colorScheme.onSurface.withOpacity(0.38))
+              : widget.labelTextStyle,
+      child: widget.label,
     );
 
     Widget content;
 
-    switch (labelType) {
+    // The indicator height is fixed and equal to _kIndicatorHeight.
+    // When the icon height is larger than the indicator height the indicator
+    // vertical offset is used to vertically center the indicator.
+    final bool isLargeIconSize =
+        widget.iconTheme.size != null && widget.iconTheme.size! > _kIndicatorHeight;
+    final double indicatorVerticalOffset =
+        isLargeIconSize ? (widget.iconTheme.size! - _kIndicatorHeight) / 2 : 0;
+
+    switch (widget.labelType) {
       case NavigationRailLabelType.none:
         // Split the destination spacing across the top and bottom to keep the icon centered.
-        final Widget? spacing = material3 ? const SizedBox(height: _verticalDestinationSpacingM3 / 2) : null;
+        final Widget? spacing =
+            material3 ? const SizedBox(height: _verticalDestinationSpacingM3 / 2) : null;
         indicatorOffset = Offset(
-          minWidth / 2 + destinationPadding.left,
-          _verticalDestinationSpacingM3 / 2 + destinationPadding.top,
+          widget.minWidth / 2 + destinationPadding.left,
+          _verticalDestinationSpacingM3 / 2 + destinationPadding.top + indicatorVerticalOffset,
         );
         final Widget iconPart = Column(
           children: <Widget>[
             if (spacing != null) spacing,
             SizedBox(
-              width: minWidth,
-              height: material3 ? null : minWidth,
+              width: widget.minWidth,
+              height: material3 ? null : widget.minWidth,
               child: Center(
                 child: _AddIndicator(
-                  addIndicator: useIndicator,
-                  indicatorColor: indicatorColor,
-                  indicatorShape: indicatorShape,
+                  addIndicator: widget.useIndicator,
+                  indicatorColor: widget.indicatorColor,
+                  indicatorShape: widget.indicatorShape,
                   isCircular: !material3,
-                  indicatorAnimation: destinationAnimation,
+                  indicatorAnimation: widget.destinationAnimation,
                   child: themedIcon,
                 ),
               ),
@@ -628,46 +702,54 @@ class _RailDestination extends StatelessWidget {
             if (spacing != null) spacing,
           ],
         );
-        if (extendedTransitionAnimation.value == 0) {
+        if (widget.extendedTransitionAnimation.value == 0) {
           content = Padding(
-            padding: padding ?? EdgeInsets.zero,
+            padding: widget.padding ?? EdgeInsets.zero,
             child: Stack(
               children: <Widget>[
                 iconPart,
                 // For semantics when label is not showing,
-                SizedBox.shrink(
-                  child: Visibility.maintain(
-                    visible: false,
-                    child: label,
-                  ),
-                ),
+                SizedBox.shrink(child: Visibility.maintain(visible: false, child: widget.label)),
               ],
             ),
           );
         } else {
-          final Animation<double> labelFadeAnimation = extendedTransitionAnimation.drive(CurveTween(curve: const Interval(0.0, 0.25)));
+          final Animation<double> labelFadeAnimation = widget.extendedTransitionAnimation.drive(
+            CurveTween(curve: const Interval(0.0, 0.25)),
+          );
           applyXOffset = true;
           content = Padding(
-            padding: padding ?? EdgeInsets.zero,
+            padding: widget.padding ?? EdgeInsets.zero,
             child: ConstrainedBox(
               constraints: BoxConstraints(
-                minWidth: lerpDouble(minWidth, minExtendedWidth, extendedTransitionAnimation.value)!,
+                minWidth:
+                    lerpDouble(
+                      widget.minWidth,
+                      widget.minExtendedWidth,
+                      widget.extendedTransitionAnimation.value,
+                    )!,
               ),
               child: ClipRect(
                 child: Row(
+                  mainAxisSize: MainAxisSize.min,
                   children: <Widget>[
                     iconPart,
-                    Align(
-                      heightFactor: 1.0,
-                      widthFactor: extendedTransitionAnimation.value,
-                      alignment: AlignmentDirectional.centerStart,
-                      child: FadeTransition(
-                        alwaysIncludeSemantics: true,
-                        opacity: labelFadeAnimation,
-                        child: styledLabel,
+                    Flexible(
+                      child: Align(
+                        heightFactor: 1.0,
+                        widthFactor: widget.extendedTransitionAnimation.value,
+                        alignment: AlignmentDirectional.centerStart,
+                        child: FadeTransition(
+                          alwaysIncludeSemantics: true,
+                          opacity: labelFadeAnimation,
+                          child: styledLabel,
+                        ),
                       ),
                     ),
-                    SizedBox(width: _horizontalDestinationPadding * extendedTransitionAnimation.value),
+                    SizedBox(
+                      width:
+                          _horizontalDestinationPadding * widget.extendedTransitionAnimation.value,
+                    ),
                   ],
                 ),
               ),
@@ -676,114 +758,151 @@ class _RailDestination extends StatelessWidget {
         }
       case NavigationRailLabelType.selected:
         final double appearingAnimationValue = 1 - _positionAnimation.value;
-        final double verticalPadding = lerpDouble(_verticalDestinationPaddingNoLabel, _verticalDestinationPaddingWithLabel, appearingAnimationValue)!;
-        final Interval interval = selected ? const Interval(0.25, 0.75) : const Interval(0.75, 1.0);
-        final Animation<double> labelFadeAnimation = destinationAnimation.drive(CurveTween(curve: interval));
-        final double minHeight = material3 ? 0 : minWidth;
+        final double verticalPadding =
+            lerpDouble(
+              _verticalDestinationPaddingNoLabel,
+              _verticalDestinationPaddingWithLabel,
+              appearingAnimationValue,
+            )!;
+        final Interval interval =
+            widget.selected ? const Interval(0.25, 0.75) : const Interval(0.75, 1.0);
+        final Animation<double> labelFadeAnimation = widget.destinationAnimation.drive(
+          CurveTween(curve: interval),
+        );
+        final double minHeight = material3 ? 0 : widget.minWidth;
         final Widget topSpacing = SizedBox(height: material3 ? 0 : verticalPadding);
-        final Widget labelSpacing = SizedBox(height: material3 ? lerpDouble(0, _verticalIconLabelSpacingM3, appearingAnimationValue)! : 0);
-        final Widget bottomSpacing = SizedBox(height: material3 ? _verticalDestinationSpacingM3 : verticalPadding);
-        final double indicatorHorizontalPadding = (destinationPadding.left / 2) - (destinationPadding.right / 2);
+        final Widget labelSpacing = SizedBox(
+          height:
+              material3 ? lerpDouble(0, _verticalIconLabelSpacingM3, appearingAnimationValue)! : 0,
+        );
+        final Widget bottomSpacing = SizedBox(
+          height: material3 ? _verticalDestinationSpacingM3 : verticalPadding,
+        );
+        final double indicatorHorizontalPadding =
+            (destinationPadding.left / 2) - (destinationPadding.right / 2);
         final double indicatorVerticalPadding = destinationPadding.top;
-        indicatorOffset = Offset(minWidth / 2 + indicatorHorizontalPadding, indicatorVerticalPadding);
-        if (minWidth < _NavigationRailDefaultsM2(context).minWidth!) {
-          indicatorOffset = Offset(minWidth / 2 + _horizontalDestinationSpacingM3, indicatorVerticalPadding);
+        indicatorOffset = Offset(
+          widget.minWidth / 2 + indicatorHorizontalPadding,
+          indicatorVerticalPadding + indicatorVerticalOffset,
+        );
+        if (widget.minWidth < _NavigationRailDefaultsM2(context).minWidth!) {
+          indicatorOffset = Offset(
+            widget.minWidth / 2 + _horizontalDestinationSpacingM3,
+            indicatorVerticalPadding + indicatorVerticalOffset,
+          );
         }
-        content = Container(
-          constraints: BoxConstraints(
-            minWidth: minWidth,
-            minHeight: minHeight,
+        content = ConstrainedBox(
+          constraints: BoxConstraints(minWidth: widget.minWidth, minHeight: minHeight),
+          child: Padding(
+            padding:
+                widget.padding ??
+                const EdgeInsets.symmetric(horizontal: _horizontalDestinationPadding),
+            child: ClipRect(
+              child: Column(
+                mainAxisSize: MainAxisSize.min,
+                mainAxisAlignment: MainAxisAlignment.center,
+                children: <Widget>[
+                  topSpacing,
+                  _AddIndicator(
+                    addIndicator: widget.useIndicator,
+                    indicatorColor: widget.indicatorColor,
+                    indicatorShape: widget.indicatorShape,
+                    isCircular: false,
+                    indicatorAnimation: widget.destinationAnimation,
+                    child: themedIcon,
+                  ),
+                  labelSpacing,
+                  Align(
+                    alignment: Alignment.topCenter,
+                    heightFactor: appearingAnimationValue,
+                    widthFactor: 1.0,
+                    child: FadeTransition(
+                      alwaysIncludeSemantics: true,
+                      opacity: labelFadeAnimation,
+                      child: styledLabel,
+                    ),
+                  ),
+                  bottomSpacing,
+                ],
+              ),
+            ),
           ),
-          padding: padding ?? const EdgeInsets.symmetric(horizontal: _horizontalDestinationPadding),
-          child: ClipRect(
+        );
+      case NavigationRailLabelType.all:
+        final double minHeight = material3 ? 0 : widget.minWidth;
+        final Widget topSpacing = SizedBox(
+          height: material3 ? 0 : _verticalDestinationPaddingWithLabel,
+        );
+        final Widget labelSpacing = SizedBox(height: material3 ? _verticalIconLabelSpacingM3 : 0);
+        final Widget bottomSpacing = SizedBox(
+          height: material3 ? _verticalDestinationSpacingM3 : _verticalDestinationPaddingWithLabel,
+        );
+        final double indicatorHorizontalPadding =
+            (destinationPadding.left / 2) - (destinationPadding.right / 2);
+        final double indicatorVerticalPadding = destinationPadding.top;
+        indicatorOffset = Offset(
+          widget.minWidth / 2 + indicatorHorizontalPadding,
+          indicatorVerticalPadding + indicatorVerticalOffset,
+        );
+        if (widget.minWidth < _NavigationRailDefaultsM2(context).minWidth!) {
+          indicatorOffset = Offset(
+            widget.minWidth / 2 + _horizontalDestinationSpacingM3,
+            indicatorVerticalPadding + indicatorVerticalOffset,
+          );
+        }
+        content = ConstrainedBox(
+          constraints: BoxConstraints(minWidth: widget.minWidth, minHeight: minHeight),
+          child: Padding(
+            padding:
+                widget.padding ??
+                const EdgeInsets.symmetric(horizontal: _horizontalDestinationPadding),
             child: Column(
-              mainAxisSize: MainAxisSize.min,
-              mainAxisAlignment: MainAxisAlignment.center,
               children: <Widget>[
                 topSpacing,
                 _AddIndicator(
-                  addIndicator: useIndicator,
-                  indicatorColor: indicatorColor,
-                  indicatorShape: indicatorShape,
+                  addIndicator: widget.useIndicator,
+                  indicatorColor: widget.indicatorColor,
+                  indicatorShape: widget.indicatorShape,
                   isCircular: false,
-                  indicatorAnimation: destinationAnimation,
+                  indicatorAnimation: widget.destinationAnimation,
                   child: themedIcon,
                 ),
                 labelSpacing,
-                Align(
-                  alignment: Alignment.topCenter,
-                  heightFactor: appearingAnimationValue,
-                  widthFactor: 1.0,
-                  child: FadeTransition(
-                    alwaysIncludeSemantics: true,
-                    opacity: labelFadeAnimation,
-                    child: styledLabel,
-                  ),
-                ),
+                styledLabel,
                 bottomSpacing,
               ],
             ),
           ),
         );
-      case NavigationRailLabelType.all:
-        final double minHeight = material3 ? 0 : minWidth;
-        final Widget topSpacing = SizedBox(height: material3 ? 0 : _verticalDestinationPaddingWithLabel);
-        final Widget labelSpacing = SizedBox(height: material3 ? _verticalIconLabelSpacingM3 : 0);
-        final Widget bottomSpacing = SizedBox(height: material3 ? _verticalDestinationSpacingM3 : _verticalDestinationPaddingWithLabel);
-        final double indicatorHorizontalPadding = (destinationPadding.left / 2) - (destinationPadding.right / 2);
-        final double indicatorVerticalPadding = destinationPadding.top;
-        indicatorOffset = Offset(minWidth / 2 + indicatorHorizontalPadding, indicatorVerticalPadding);
-        if (minWidth < _NavigationRailDefaultsM2(context).minWidth!) {
-          indicatorOffset = Offset(minWidth / 2 + _horizontalDestinationSpacingM3, indicatorVerticalPadding);
-        }
-        content = Container(
-          constraints: BoxConstraints(
-            minWidth: minWidth,
-            minHeight: minHeight,
-          ),
-          padding: padding ?? const EdgeInsets.symmetric(horizontal: _horizontalDestinationPadding),
-          child: Column(
-            children: <Widget>[
-              topSpacing,
-              _AddIndicator(
-                addIndicator: useIndicator,
-                indicatorColor: indicatorColor,
-                indicatorShape: indicatorShape,
-                isCircular: false,
-                indicatorAnimation: destinationAnimation,
-                child: themedIcon,
-              ),
-              labelSpacing,
-              styledLabel,
-              bottomSpacing,
-            ],
-          ),
-        );
     }
 
     final ColorScheme colors = Theme.of(context).colorScheme;
+    final bool primaryColorAlphaModified = colors.primary.alpha < 255.0;
+    final Color effectiveSplashColor =
+        primaryColorAlphaModified ? colors.primary : colors.primary.withOpacity(0.12);
+    final Color effectiveHoverColor =
+        primaryColorAlphaModified ? colors.primary : colors.primary.withOpacity(0.04);
     return Semantics(
       container: true,
-      selected: selected,
+      selected: widget.selected,
       child: Stack(
         children: <Widget>[
           Material(
             type: MaterialType.transparency,
             child: _IndicatorInkWell(
-              onTap: disabled ? null : onTap,
-              borderRadius: BorderRadius.all(Radius.circular(minWidth / 2.0)),
-              customBorder: indicatorShape,
-              splashColor: colors.primary.withOpacity(0.12),
-              hoverColor: colors.primary.withOpacity(0.04),
+              onTap: widget.disabled ? null : widget.onTap,
+              borderRadius: BorderRadius.all(Radius.circular(widget.minWidth / 2.0)),
+              customBorder: widget.indicatorShape,
+              splashColor: effectiveSplashColor,
+              hoverColor: effectiveHoverColor,
               useMaterial3: material3,
               indicatorOffset: indicatorOffset,
               applyXOffset: applyXOffset,
+              textDirection: textDirection,
               child: content,
             ),
           ),
-          Semantics(
-            label: indexLabel,
-          ),
+          Semantics(label: widget.indexLabel),
         ],
       ),
     );
@@ -801,24 +920,34 @@ class _IndicatorInkWell extends InkResponse {
     required this.useMaterial3,
     required this.indicatorOffset,
     required this.applyXOffset,
+    required this.textDirection,
   }) : super(
-    containedInkWell: true,
-    highlightShape: BoxShape.rectangle,
-    borderRadius: useMaterial3 ? null : borderRadius,
-    customBorder: useMaterial3 ? customBorder : null,
-  );
+         containedInkWell: true,
+         highlightShape: BoxShape.rectangle,
+         borderRadius: useMaterial3 ? null : borderRadius,
+         customBorder: useMaterial3 ? customBorder : null,
+       );
 
   final bool useMaterial3;
+
   // The offset used to position Ink highlight.
   final Offset indicatorOffset;
+
   // Whether the horizontal offset from indicatorOffset should be used to position Ink highlight.
   // If true, Ink highlight uses the indicator horizontal offset. If false, Ink highlight is centered horizontally.
   final bool applyXOffset;
 
+  // The text direction used to adjust the indicator horizontal offset.
+  final TextDirection textDirection;
+
   @override
   RectCallback? getRectCallback(RenderBox referenceBox) {
     if (useMaterial3) {
-      final double indicatorHorizontalCenter = applyXOffset ? indicatorOffset.dx : referenceBox.size.width / 2;
+      final double boxWidth = referenceBox.size.width;
+      double indicatorHorizontalCenter = applyXOffset ? indicatorOffset.dx : boxWidth / 2;
+      if (textDirection == TextDirection.rtl) {
+        indicatorHorizontalCenter = boxWidth - indicatorHorizontalCenter;
+      }
       return () {
         return Rect.fromLTWH(
           indicatorHorizontalCenter - (_kCircularIndicatorDiameter / 2),
@@ -877,17 +1006,10 @@ class _AddIndicator extends StatelessWidget {
       );
     }
 
-    return Stack(
-      alignment: Alignment.center,
-      children: <Widget>[
-        indicator,
-        child,
-      ],
-    );
+    return Stack(alignment: Alignment.center, children: <Widget>[indicator, child]);
   }
 }
 
-
 /// Defines the behavior of the labels of a [NavigationRail].
 ///
 /// See also:
@@ -915,9 +1037,9 @@ enum NavigationRailLabelType {
 class NavigationRailDestination {
   /// Creates a destination that is used with [NavigationRail.destinations].
   ///
-  /// [icon] and [label] must be non-null. When the [NavigationRail.labelType]
-  /// is [NavigationRailLabelType.none], the label is still used for semantics,
-  /// and may still be used if [NavigationRail.extended] is true.
+  /// When the [NavigationRail.labelType] is [NavigationRailLabelType.none], the
+  /// label is still used for semantics, and may still be used if
+  /// [NavigationRail.extended] is true.
   const NavigationRailDestination({
     required this.icon,
     Widget? selectedIcon,
@@ -977,10 +1099,7 @@ class NavigationRailDestination {
 }
 
 class _ExtendedNavigationRailAnimation extends InheritedWidget {
-  const _ExtendedNavigationRailAnimation({
-    required this.animation,
-    required super.child,
-  });
+  const _ExtendedNavigationRailAnimation({required this.animation, required super.child});
 
   final Animation<double> animation;
 
@@ -1015,30 +1134,27 @@ class _NavigationRailDefaultsM2 extends NavigationRailThemeData {
   final ThemeData _theme;
   final ColorScheme _colors;
 
-  @override Color? get backgroundColor => _colors.surface;
+  @override
+  Color? get backgroundColor => _colors.surface;
 
-  @override TextStyle? get unselectedLabelTextStyle {
+  @override
+  TextStyle? get unselectedLabelTextStyle {
     return _theme.textTheme.bodyLarge!.copyWith(color: _colors.onSurface.withOpacity(0.64));
   }
 
-  @override TextStyle? get selectedLabelTextStyle {
+  @override
+  TextStyle? get selectedLabelTextStyle {
     return _theme.textTheme.bodyLarge!.copyWith(color: _colors.primary);
   }
 
-  @override IconThemeData? get unselectedIconTheme {
-    return IconThemeData(
-      size: 24.0,
-      color: _colors.onSurface,
-      opacity: 0.64,
-    );
+  @override
+  IconThemeData? get unselectedIconTheme {
+    return IconThemeData(size: 24.0, color: _colors.onSurface, opacity: 0.64);
   }
 
-  @override IconThemeData? get selectedIconTheme {
-    return IconThemeData(
-      size: 24.0,
-      color: _colors.primary,
-      opacity: 1.0,
-    );
+  @override
+  IconThemeData? get selectedIconTheme {
+    return IconThemeData(size: 24.0, color: _colors.primary, opacity: 1.0);
   }
 }
 
@@ -1049,6 +1165,7 @@ class _NavigationRailDefaultsM2 extends NavigationRailThemeData {
 // Design token database by the script:
 //   dev/tools/gen_defaults/bin/gen_defaults.dart.
 
+// dart format off
 class _NavigationRailDefaultsM3 extends NavigationRailThemeData {
   _NavigationRailDefaultsM3(this.context)
     : super(
@@ -1092,5 +1209,6 @@ class _NavigationRailDefaultsM3 extends NavigationRailThemeData {
 
   @override ShapeBorder? get indicatorShape => const StadiumBorder();
 }
+// dart format on
 
 // END GENERATED TOKEN PROPERTIES - NavigationRail
