@@ -2,6 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/material.dart';
+///
+/// @docImport 'box_border.dart';
+library;
+
 import 'dart:math' as math;
 import 'dart:ui' as ui show lerpDouble;
 
@@ -21,37 +26,15 @@ enum BorderStyle {
   // if you add more, think about how they will lerp
 }
 
-/// The relative position of the stroke on a [BorderSide] in a [Border] or [OutlinedBorder].
-/// When set to [inside], the stroke is drawn completely inside the widget.
-/// For [center] and [outside], a property such as [Container.clipBehavior]
-/// can be used in an outside widget to clip it.
-/// If [Container.decoration] has a border, the container may incorporate
-/// [BorderSide.width] as additional padding:
-/// - [inside] provides padding with full [BorderSide.width].
-/// - [center] provides padding with half [BorderSide.width].
-/// - [outside] provides zero padding, as stroke is drawn entirely outside.
-enum StrokeAlign {
-  /// The border is drawn on the inside of the border path.
-  inside,
-
-  /// The border is drawn on the center of the border path, with half of the
-  /// [BorderSide.width] on the inside, and the other half on the outside of the path.
-  center,
-
-  /// The border is drawn on the outside of the border path.
-  outside,
-}
-
 /// A side of a border of a box.
 ///
 /// A [Border] consists of four [BorderSide] objects: [Border.top],
 /// [Border.left], [Border.right], and [Border.bottom].
 ///
-/// Note that setting [BorderSide.width] to 0.0 will result in hairline
-/// rendering. A more involved explanation is present in [BorderSide.width].
+/// Setting [BorderSide.width] to 0.0 will result in hairline rendering; see
+/// [BorderSide.width] for a more involved explanation.
 ///
 /// {@tool snippet}
-///
 /// This sample shows how [BorderSide] objects can be used in a [Container], via
 /// a [BoxDecoration] and a [Border], to decorate some [Text]. In this example,
 /// the text has a thick bar above it that is light blue, and a thick bar below
@@ -79,7 +62,7 @@ enum StrokeAlign {
 ///    ([TableBorder.horizontalInside] and [TableBorder.verticalInside]), both
 ///    of which are also [BorderSide] objects.
 @immutable
-class BorderSide {
+class BorderSide with Diagnosticable {
   /// Creates the side of a border.
   ///
   /// By default, the border is 1.0 logical pixels wide and solid black.
@@ -87,11 +70,8 @@ class BorderSide {
     this.color = const Color(0xFF000000),
     this.width = 1.0,
     this.style = BorderStyle.solid,
-    this.strokeAlign = StrokeAlign.inside,
-  }) : assert(color != null),
-       assert(width != null),
-       assert(width >= 0.0),
-       assert(style != null);
+    this.strokeAlign = strokeAlignInside,
+  }) : assert(width >= 0.0);
 
   /// Creates a [BorderSide] that represents the addition of the two given
   /// [BorderSide]s.
@@ -102,11 +82,7 @@ class BorderSide {
   /// If one of the sides is zero-width with [BorderStyle.none], then the other
   /// side is return as-is. If both of the sides are zero-width with
   /// [BorderStyle.none], then [BorderSide.none] is returned.
-  ///
-  /// The arguments must not be null.
   static BorderSide merge(BorderSide a, BorderSide b) {
-    assert(a != null);
-    assert(b != null);
     assert(canMerge(a, b));
     final bool aIsNone = a.style == BorderStyle.none && a.width == 0.0;
     final bool bIsNone = b.style == BorderStyle.none && b.width == 0.0;
@@ -124,6 +100,7 @@ class BorderSide {
     return BorderSide(
       color: a.color, // == b.color
       width: a.width + b.width,
+      strokeAlign: math.max(a.strokeAlign, b.strokeAlign),
       style: a.style, // == b.style
     );
   }
@@ -134,7 +111,7 @@ class BorderSide {
   /// The width of this side of the border, in logical pixels.
   ///
   /// Setting width to 0.0 will result in a hairline border. This means that
-  /// the border will have the width of one physical pixel. Also, hairline
+  /// the border will have the width of one physical pixel. Hairline
   /// rendering takes shortcuts when the path overlaps a pixel more than once.
   /// This means that it will render faster than otherwise, but it might
   /// double-hit pixels, giving it a slightly darker/lighter result.
@@ -151,20 +128,63 @@ class BorderSide {
   /// A hairline black border that is not rendered.
   static const BorderSide none = BorderSide(width: 0.0, style: BorderStyle.none);
 
-  /// The direction of where the border will be drawn relative to the container.
-  final StrokeAlign strokeAlign;
+  /// The relative position of the stroke on a [BorderSide] in an
+  /// [OutlinedBorder] or [Border].
+  ///
+  /// Values typically range from -1.0 ([strokeAlignInside], inside border,
+  /// default) to 1.0 ([strokeAlignOutside], outside border), without any
+  /// bound constraints (e.g., a value of -2.0 is not typical, but allowed).
+  /// A value of 0 ([strokeAlignCenter]) will center the border on the edge
+  /// of the widget.
+  ///
+  /// When set to [strokeAlignInside], the stroke is drawn completely inside
+  /// the widget. For [strokeAlignCenter] and [strokeAlignOutside], a property
+  /// such as [Container.clipBehavior] can be used in an outside widget to clip
+  /// it. If [Container.decoration] has a border, the container may incorporate
+  /// [width] as additional padding:
+  /// - [strokeAlignInside] provides padding with full [width].
+  /// - [strokeAlignCenter] provides padding with half [width].
+  /// - [strokeAlignOutside] provides zero padding, as stroke is drawn entirely outside.
+  ///
+  /// This property is not honored by [toPaint] (because the [Paint] object
+  /// cannot represent it); it is intended that classes that use [BorderSide]
+  /// objects implement this property when painting borders by suitably
+  /// inflating or deflating their regions.
+  ///
+  /// {@tool dartpad}
+  /// This example shows an animation of how [strokeAlign] affects the drawing
+  /// when applied to borders of various shapes.
+  ///
+  /// ** See code in examples/api/lib/painting/borders/border_side.stroke_align.0.dart **
+  /// {@end-tool}
+  final double strokeAlign;
+
+  /// The border is drawn fully inside of the border path.
+  ///
+  /// This is a constant for use with [strokeAlign].
+  ///
+  /// This is the default value for [strokeAlign].
+  static const double strokeAlignInside = -1.0;
+
+  /// The border is drawn on the center of the border path, with half of the
+  /// [BorderSide.width] on the inside, and the other half on the outside of
+  /// the path.
+  ///
+  /// This is a constant for use with [strokeAlign].
+  static const double strokeAlignCenter = 0.0;
+
+  /// The border is drawn on the outside of the border path.
+  ///
+  /// This is a constant for use with [strokeAlign].
+  static const double strokeAlignOutside = 1.0;
 
   /// Creates a copy of this border but with the given fields replaced with the new values.
-  BorderSide copyWith({
-    Color? color,
-    double? width,
-    BorderStyle? style,
-  }) {
-    assert(width == null || width >= 0.0);
+  BorderSide copyWith({Color? color, double? width, BorderStyle? style, double? strokeAlign}) {
     return BorderSide(
       color: color ?? this.color,
       width: width ?? this.width,
       style: style ?? this.style,
+      strokeAlign: strokeAlign ?? this.strokeAlign,
     );
   }
 
@@ -185,7 +205,6 @@ class BorderSide {
   /// Values for `t` are usually obtained from an [Animation<double>], such as
   /// an [AnimationController].
   BorderSide scale(double t) {
-    assert(t != null);
     return BorderSide(
       color: color,
       width: math.max(0.0, width * t),
@@ -196,6 +215,9 @@ class BorderSide {
   /// Create a [Paint] object that, if used to stroke a line, will draw the line
   /// in this border's style.
   ///
+  /// The [strokeAlign] property is not reflected in the [Paint]; consumers must
+  /// implement that directly by inflating or deflating their region appropriately.
+  ///
   /// Not all borders use this method to paint their border sides. For example,
   /// non-uniform rectangular [Border]s have beveled edges and so paint their
   /// border sides as filled shapes rather than using a stroke.
@@ -219,29 +241,21 @@ class BorderSide {
   ///
   /// Two sides can be merged if one or both are zero-width with
   /// [BorderStyle.none], or if they both have the same color and style.
-  ///
-  /// The arguments must not be null.
   static bool canMerge(BorderSide a, BorderSide b) {
-    assert(a != null);
-    assert(b != null);
     if ((a.style == BorderStyle.none && a.width == 0.0) ||
         (b.style == BorderStyle.none && b.width == 0.0)) {
       return true;
     }
-    return a.style == b.style
-        && a.color == b.color
-        && a.strokeAlign == b.strokeAlign;
+    return a.style == b.style && a.color == b.color;
   }
 
   /// Linearly interpolate between two border sides.
   ///
-  /// The arguments must not be null.
-  ///
   /// {@macro dart.ui.shadow.lerp}
   static BorderSide lerp(BorderSide a, BorderSide b, double t) {
-    assert(a != null);
-    assert(b != null);
-    assert(t != null);
+    if (identical(a, b)) {
+      return a;
+    }
     if (t == 0.0) {
       return a;
     }
@@ -260,31 +274,19 @@ class BorderSide {
         strokeAlign: a.strokeAlign, // == b.strokeAlign
       );
     }
-    final Color colorA, colorB;
-    switch (a.style) {
-      case BorderStyle.solid:
-        colorA = a.color;
-        break;
-      case BorderStyle.none:
-        colorA = a.color.withAlpha(0x00);
-        break;
-    }
-    switch (b.style) {
-      case BorderStyle.solid:
-        colorB = b.color;
-        break;
-      case BorderStyle.none:
-        colorB = b.color.withAlpha(0x00);
-        break;
-    }
+    final Color colorA = switch (a.style) {
+      BorderStyle.solid => a.color,
+      BorderStyle.none => a.color.withAlpha(0x00),
+    };
+    final Color colorB = switch (b.style) {
+      BorderStyle.solid => b.color,
+      BorderStyle.none => b.color.withAlpha(0x00),
+    };
     if (a.strokeAlign != b.strokeAlign) {
-      // When strokeAlign changes, lerp to 0, then from 0 to the target width.
-      // All StrokeAlign values share a common zero width state.
-      final StrokeAlign strokeAlign = t > 0.5 ? b.strokeAlign : a.strokeAlign;
       return BorderSide(
         color: Color.lerp(colorA, colorB, t)!,
-        width: t > 0.5 ? ui.lerpDouble(0, b.width, t * 2 - 1)! : ui.lerpDouble(a.width, 0, t * 2)!,
-        strokeAlign: strokeAlign,
+        width: width,
+        strokeAlign: ui.lerpDouble(a.strokeAlign, b.strokeAlign, t)!,
       );
     }
     return BorderSide(
@@ -294,6 +296,26 @@ class BorderSide {
     );
   }
 
+  /// Get the amount of the stroke width that lies inside of the [BorderSide].
+  ///
+  /// For example, this will return the [width] for a [strokeAlign] of -1, half
+  /// the [width] for a [strokeAlign] of 0, and 0 for a [strokeAlign] of 1.
+  double get strokeInset => width * (1 - (1 + strokeAlign) / 2);
+
+  /// Get the amount of the stroke width that lies outside of the [BorderSide].
+  ///
+  /// For example, this will return 0 for a [strokeAlign] of -1, half the
+  /// [width] for a [strokeAlign] of 0, and the [width] for a [strokeAlign]
+  /// of 1.
+  double get strokeOutset => width * (1 + strokeAlign) / 2;
+
+  /// The offset of the stroke, taking into account the stroke alignment.
+  ///
+  /// For example, this will return the negative [width] of the stroke
+  /// for a [strokeAlign] of -1, 0 for a [strokeAlign] of 0, and the
+  /// [width] for a [strokeAlign] of -1.
+  double get strokeOffset => width * strokeAlign;
+
   @override
   bool operator ==(Object other) {
     if (identical(this, other)) {
@@ -302,22 +324,28 @@ class BorderSide {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is BorderSide
-        && other.color == color
-        && other.width == width
-        && other.style == style
-        && other.strokeAlign == strokeAlign;
+    return other is BorderSide &&
+        other.color == color &&
+        other.width == width &&
+        other.style == style &&
+        other.strokeAlign == strokeAlign;
   }
 
   @override
   int get hashCode => Object.hash(color, width, style, strokeAlign);
 
   @override
-  String toString() {
-    if (strokeAlign == StrokeAlign.inside) {
-      return '${objectRuntimeType(this, 'BorderSide')}($color, ${width.toStringAsFixed(1)}, $style)';
-    }
-    return '${objectRuntimeType(this, 'BorderSide')}($color, ${width.toStringAsFixed(1)}, $style, $strokeAlign)';
+  String toStringShort() => 'BorderSide';
+
+  @override
+  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
+    super.debugFillProperties(properties);
+    properties.add(
+      DiagnosticsProperty<Color>('color', color, defaultValue: const Color(0xFF000000)),
+    );
+    properties.add(DoubleProperty('width', width, defaultValue: 1.0));
+    properties.add(DoubleProperty('strokeAlign', strokeAlign, defaultValue: strokeAlignInside));
+    properties.add(EnumProperty<BorderStyle>('style', style, defaultValue: BorderStyle.solid));
   }
 }
 
@@ -368,7 +396,7 @@ abstract class ShapeBorder {
   /// The `reversed` argument is true if this object was the right operand of
   /// the `+` operator, and false if it was the left operand.
   @protected
-  ShapeBorder? add(ShapeBorder other, { bool reversed = false }) => null;
+  ShapeBorder? add(ShapeBorder other, {bool reversed = false}) => null;
 
   /// Creates a new border consisting of the two borders on either side of the
   /// operator.
@@ -379,7 +407,9 @@ abstract class ShapeBorder {
   /// merely paints the two borders sequentially, with the left hand operand on
   /// the inside and the right hand operand on the outside.
   ShapeBorder operator +(ShapeBorder other) {
-    return add(other) ?? other.add(this, reversed: true) ?? _CompoundBorder(<ShapeBorder>[other, this]);
+    return add(other) ??
+        other.add(this, reversed: true) ??
+        _CompoundBorder(<ShapeBorder>[other, this]);
   }
 
   /// Creates a copy of this border, scaled by the factor `t`.
@@ -480,14 +510,10 @@ abstract class ShapeBorder {
   ///
   /// {@macro dart.ui.shadow.lerp}
   static ShapeBorder? lerp(ShapeBorder? a, ShapeBorder? b, double t) {
-    assert(t != null);
-    ShapeBorder? result;
-    if (b != null) {
-      result = b.lerpFrom(a, t);
-    }
-    if (result == null && a != null) {
-      result = a.lerpTo(b, t);
+    if (identical(a, b)) {
+      return a;
     }
+    final ShapeBorder? result = b?.lerpFrom(a, t) ?? a?.lerpTo(b, t);
     return result ?? (t < 0.5 ? a : b);
   }
 
@@ -510,7 +536,7 @@ abstract class ShapeBorder {
   ///
   ///  * [getInnerPath], which creates the path for the inner edge.
   ///  * [Path.contains], which can tell if an [Offset] is within a [Path].
-  Path getOuterPath(Rect rect, { TextDirection? textDirection });
+  Path getOuterPath(Rect rect, {TextDirection? textDirection});
 
   /// Create a [Path] that describes the inner edge of the border.
   ///
@@ -531,7 +557,85 @@ abstract class ShapeBorder {
   ///
   ///  * [getOuterPath], which creates the path for the outer edge.
   ///  * [Path.contains], which can tell if an [Offset] is within a [Path].
-  Path getInnerPath(Rect rect, { TextDirection? textDirection });
+  Path getInnerPath(Rect rect, {TextDirection? textDirection});
+
+  /// Paint a canvas with the appropriate shape.
+  ///
+  /// On [ShapeBorder] subclasses whose [preferPaintInterior] method returns
+  /// true, this should be faster than using [Canvas.drawPath] with the path
+  /// provided by [getOuterPath]. (If [preferPaintInterior] returns false,
+  /// then this method asserts in debug mode and does nothing in release mode.)
+  ///
+  /// Subclasses are expected to implement this method when the [Canvas] API
+  /// has a dedicated method to draw the relevant shape. For example,
+  /// [CircleBorder] uses this to call [Canvas.drawCircle], and
+  /// [RoundedRectangleBorder] uses this to call [Canvas.drawRRect].
+  ///
+  /// Subclasses that implement this must ensure that calling [paintInterior]
+  /// is semantically equivalent to (i.e. renders the same pixels as) calling
+  /// [Canvas.drawPath] with the same [Paint] and the [Path] returned from
+  /// [getOuterPath], and must also override [preferPaintInterior] to
+  /// return true.
+  ///
+  /// For example, a shape that draws a rectangle might implement
+  /// [getOuterPath], [paintInterior], and [preferPaintInterior] as follows:
+  ///
+  /// ```dart
+  /// class RectangleBorder extends OutlinedBorder {
+  ///   // ...
+  ///
+  ///   @override
+  ///   Path getOuterPath(Rect rect, { TextDirection? textDirection }) {
+  ///    return Path()
+  ///      ..addRect(rect);
+  ///   }
+  ///
+  ///   @override
+  ///   void paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) {
+  ///    canvas.drawRect(rect, paint);
+  ///   }
+  ///
+  ///   @override
+  ///   bool get preferPaintInterior => true;
+  ///
+  ///   // ...
+  /// }
+  /// ```
+  ///
+  /// When a shape can only be drawn using path, [preferPaintInterior] must
+  /// return false. In that case, classes such as [ShapeDecoration] will cache
+  /// the path from [getOuterPath] and call [Canvas.drawPath] directly.
+  void paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) {
+    assert(
+      !preferPaintInterior,
+      '$runtimeType.preferPaintInterior returns true but $runtimeType.paintInterior is not implemented.',
+    );
+    assert(
+      false,
+      '$runtimeType.preferPaintInterior returns false, so it is an error to call its paintInterior method.',
+    );
+  }
+
+  /// Reports whether [paintInterior] is implemented.
+  ///
+  /// Classes such as [ShapeDecoration] prefer to use [paintInterior] if this
+  /// getter returns true. This is intended to enable faster painting; instead
+  /// of computing a shape using [getOuterPath] and then drawing it using
+  /// [Canvas.drawPath], the path can be drawn directly to the [Canvas] using
+  /// dedicated methods such as [Canvas.drawRect] or [Canvas.drawCircle].
+  ///
+  /// By default, this getter returns false.
+  ///
+  /// Subclasses that implement [paintInterior] should override this to return
+  /// true. Subclasses should only override [paintInterior] if doing so enables
+  /// faster rendering than is possible with [Canvas.drawPath] (so, in
+  /// particular, subclasses should not call [Canvas.drawPath] in
+  /// [paintInterior]).
+  ///
+  /// See also:
+  ///
+  ///  * [paintInterior], whose API documentation has an example implementation.
+  bool get preferPaintInterior => false;
 
   /// Paints the border within the given [Rect] on the given [Canvas].
   ///
@@ -539,7 +643,7 @@ abstract class ShapeBorder {
   /// has a text direction dependency (for example if it is expressed in terms
   /// of "start" and "end" instead of "left" and "right"). It may be null if
   /// the border will not need the text direction to paint itself.
-  void paint(Canvas canvas, Rect rect, { TextDirection? textDirection });
+  void paint(Canvas canvas, Rect rect, {TextDirection? textDirection});
 
   @override
   String toString() {
@@ -553,9 +657,10 @@ abstract class ShapeBorder {
 abstract class OutlinedBorder extends ShapeBorder {
   /// Abstract const constructor. This constructor enables subclasses to provide
   /// const constructors so that they can be used in const expressions.
-  ///
-  /// The value of [side] must not be null.
-  const OutlinedBorder({ this.side = BorderSide.none }) : assert(side != null);
+  const OutlinedBorder({this.side = BorderSide.none});
+
+  @override
+  EdgeInsetsGeometry get dimensions => EdgeInsets.all(math.max(side.strokeInset, 0));
 
   /// The border outline's color and weight.
   ///
@@ -565,7 +670,7 @@ abstract class OutlinedBorder extends ShapeBorder {
 
   /// Returns a copy of this OutlinedBorder that draws its outline with the
   /// specified [side], if [side] is non-null.
-  OutlinedBorder copyWith({ BorderSide? side });
+  OutlinedBorder copyWith({BorderSide? side});
 
   @override
   ShapeBorder scale(double t);
@@ -595,14 +700,10 @@ abstract class OutlinedBorder extends ShapeBorder {
   ///
   /// {@macro dart.ui.shadow.lerp}
   static OutlinedBorder? lerp(OutlinedBorder? a, OutlinedBorder? b, double t) {
-    assert(t != null);
-    ShapeBorder? result;
-    if (b != null) {
-      result = b.lerpFrom(a, t);
-    }
-    if (result == null && a != null) {
-      result = a.lerpTo(b, t);
+    if (identical(a, b)) {
+      return a;
     }
+    final ShapeBorder? result = b?.lerpFrom(a, t) ?? a?.lerpTo(b, t);
     return result as OutlinedBorder? ?? (t < 0.5 ? a : b);
   }
 }
@@ -612,24 +713,23 @@ abstract class OutlinedBorder extends ShapeBorder {
 /// The borders are listed from the outside to the inside.
 class _CompoundBorder extends ShapeBorder {
   _CompoundBorder(this.borders)
-    : assert(borders != null),
-      assert(borders.length >= 2),
+    : assert(borders.length >= 2),
       assert(!borders.any((ShapeBorder border) => border is _CompoundBorder));
 
   final List<ShapeBorder> borders;
 
   @override
   EdgeInsetsGeometry get dimensions {
-    return borders.fold<EdgeInsetsGeometry>(
-      EdgeInsets.zero,
-      (EdgeInsetsGeometry previousValue, ShapeBorder border) {
-        return previousValue.add(border.dimensions);
-      },
-    );
+    return borders.fold<EdgeInsetsGeometry>(EdgeInsets.zero, (
+      EdgeInsetsGeometry previousValue,
+      ShapeBorder border,
+    ) {
+      return previousValue.add(border.dimensions);
+    });
   }
 
   @override
-  ShapeBorder add(ShapeBorder other, { bool reversed = false }) {
+  ShapeBorder add(ShapeBorder other, {bool reversed = false}) {
     // This wraps the list of borders with "other", or, if "reversed" is true,
     // wraps "other" with the list of borders.
     // If "reversed" is false, "other" should end up being at the start of the
@@ -640,8 +740,8 @@ class _CompoundBorder extends ShapeBorder {
       // border, and "merged" is the result of attempting to merge it with the
       // new border. If it's null, it couldn't be merged.
       final ShapeBorder ours = reversed ? borders.last : borders.first;
-      final ShapeBorder? merged = ours.add(other, reversed: reversed)
-                             ?? other.add(ours, reversed: !reversed);
+      final ShapeBorder? merged =
+          ours.add(other, reversed: reversed) ?? other.add(ours, reversed: !reversed);
       if (merged != null) {
         final List<ShapeBorder> result = <ShapeBorder>[...borders];
         result[reversed ? result.length - 1 : 0] = merged;
@@ -651,8 +751,7 @@ class _CompoundBorder extends ShapeBorder {
     // We can't, so fall back to just adding the new border to the list.
     final List<ShapeBorder> mergedBorders = <ShapeBorder>[
       if (reversed) ...borders,
-      if (other is _CompoundBorder) ...other.borders
-      else other,
+      if (other is _CompoundBorder) ...other.borders else other,
       if (!reversed) ...borders,
     ];
     return _CompoundBorder(mergedBorders);
@@ -676,8 +775,9 @@ class _CompoundBorder extends ShapeBorder {
   }
 
   static _CompoundBorder lerp(ShapeBorder? a, ShapeBorder? b, double t) {
-    assert(t != null);
-    assert(a is _CompoundBorder || b is _CompoundBorder); // Not really necessary, but all call sites currently intend this.
+    assert(
+      a is _CompoundBorder || b is _CompoundBorder,
+    ); // Not really necessary, but all call sites currently intend this.
     final List<ShapeBorder?> aList = a is _CompoundBorder ? a.borders : <ShapeBorder?>[a];
     final List<ShapeBorder?> bList = b is _CompoundBorder ? b.borders : <ShapeBorder?>[b];
     final List<ShapeBorder> results = <ShapeBorder>[];
@@ -707,7 +807,7 @@ class _CompoundBorder extends ShapeBorder {
   }
 
   @override
-  Path getInnerPath(Rect rect, { TextDirection? textDirection }) {
+  Path getInnerPath(Rect rect, {TextDirection? textDirection}) {
     for (int index = 0; index < borders.length - 1; index += 1) {
       rect = borders[index].dimensions.resolve(textDirection).deflateRect(rect);
     }
@@ -715,12 +815,20 @@ class _CompoundBorder extends ShapeBorder {
   }
 
   @override
-  Path getOuterPath(Rect rect, { TextDirection? textDirection }) {
+  Path getOuterPath(Rect rect, {TextDirection? textDirection}) {
     return borders.first.getOuterPath(rect, textDirection: textDirection);
   }
 
   @override
-  void paint(Canvas canvas, Rect rect, { TextDirection? textDirection }) {
+  void paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) {
+    borders.first.paintInterior(canvas, rect, paint, textDirection: textDirection);
+  }
+
+  @override
+  bool get preferPaintInterior => borders.every((ShapeBorder border) => border.preferPaintInterior);
+
+  @override
+  void paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) {
     for (final ShapeBorder border in borders) {
       border.paint(canvas, rect, textDirection: textDirection);
       rect = border.dimensions.resolve(textDirection).deflateRect(rect);
@@ -735,8 +843,7 @@ class _CompoundBorder extends ShapeBorder {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is _CompoundBorder
-        && listEquals<ShapeBorder>(other.borders, borders);
+    return other is _CompoundBorder && listEquals<ShapeBorder>(other.borders, borders);
   }
 
   @override
@@ -761,8 +868,6 @@ class _CompoundBorder extends ShapeBorder {
 /// borders (where all the borders have the same configuration); to render a
 /// uniform border, consider using [Canvas.drawRect] directly.
 ///
-/// The arguments must not be null.
-///
 /// See also:
 ///
 ///  * [paintImage], which paints an image in a rectangle on a canvas.
@@ -777,18 +882,10 @@ void paintBorder(
   BorderSide bottom = BorderSide.none,
   BorderSide left = BorderSide.none,
 }) {
-  assert(canvas != null);
-  assert(rect != null);
-  assert(top != null);
-  assert(right != null);
-  assert(bottom != null);
-  assert(left != null);
-
   // We draw the borders as filled shapes, unless the borders are hairline
   // borders, in which case we use PaintingStyle.stroke, with the stroke width
   // specified here.
-  final Paint paint = Paint()
-    ..strokeWidth = 0.0;
+  final Paint paint = Paint()..strokeWidth = 0.0;
 
   final Path path = Path();
 
@@ -806,7 +903,6 @@ void paintBorder(
         path.lineTo(rect.left + left.width, rect.top + top.width);
       }
       canvas.drawPath(path, paint);
-      break;
     case BorderStyle.none:
       break;
   }
@@ -825,7 +921,6 @@ void paintBorder(
         path.lineTo(rect.right - right.width, rect.top + top.width);
       }
       canvas.drawPath(path, paint);
-      break;
     case BorderStyle.none:
       break;
   }
@@ -844,7 +939,6 @@ void paintBorder(
         path.lineTo(rect.right - right.width, rect.bottom - bottom.width);
       }
       canvas.drawPath(path, paint);
-      break;
     case BorderStyle.none:
       break;
   }
@@ -863,7 +957,6 @@ void paintBorder(
         path.lineTo(rect.left + left.width, rect.bottom - bottom.width);
       }
       canvas.drawPath(path, paint);
-      break;
     case BorderStyle.none:
       break;
   }
