@@ -2,6 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/material.dart';
+///
+/// @docImport 'box_decoration.dart';
+library;
+
 import 'package:flutter/foundation.dart';
 
 import 'basic_types.dart';
@@ -19,9 +24,11 @@ import 'edge_insets.dart';
 /// interpolated or animated. The [Border] class cannot interpolate between
 /// different shapes.
 enum BoxShape {
-  /// An axis-aligned, 2D rectangle. May have rounded corners (described by a
-  /// [BorderRadius]). The edges of the rectangle will match the edges of the box
-  /// into which the [Border] or [BoxDecoration] is painted.
+  /// An axis-aligned rectangle, optionally with rounded corners.
+  ///
+  /// The amount of corner rounding, if any, is determined by the border radius
+  /// specified by classes such as [BoxDecoration] or [Border]. The rectangle's
+  /// edges match those of the box in which it is painted.
   ///
   /// See also:
   ///
@@ -62,6 +69,48 @@ abstract class BoxBorder extends ShapeBorder {
   /// const constructors so that they can be used in const expressions.
   const BoxBorder();
 
+  /// Creates a [Border].
+  ///
+  /// All the sides of the border default to [BorderSide.none].
+  factory BoxBorder.fromLTRB({
+    BorderSide top = BorderSide.none,
+    BorderSide right = BorderSide.none,
+    BorderSide bottom = BorderSide.none,
+    BorderSide left = BorderSide.none,
+  }) => Border(top: top, right: right, bottom: bottom, left: left);
+
+  /// A uniform [Border] with all sides the same color and width.
+  ///
+  /// The sides default to black solid borders, one logical pixel wide.
+  factory BoxBorder.all({Color color, double width, BorderStyle style, double strokeAlign}) =
+      Border.all;
+
+  /// Creates a [Border] whose sides are all the same.
+  const factory BoxBorder.fromBorderSide(BorderSide side) = Border.fromBorderSide;
+
+  /// Creates a [Border] with symmetrical vertical and horizontal sides.
+  ///
+  /// The `vertical` argument applies to the [left] and [right] sides, and the
+  /// `horizontal` argument applies to the [top] and [bottom] sides.
+  ///
+  /// All arguments default to [BorderSide.none].
+  const factory BoxBorder.symmetric({BorderSide vertical, BorderSide horizontal}) =
+      Border.symmetric;
+
+  /// Creates a [BorderDirectional].
+  ///
+  /// The [start] and [end] sides represent the horizontal sides; the start side
+  /// is on the leading edge given the reading direction, and the end side is on
+  /// the trailing edge. They are resolved during [paint].
+  ///
+  /// All the sides of the border default to [BorderSide.none].
+  factory BoxBorder.fromSTEB({
+    BorderSide top = BorderSide.none,
+    BorderSide start = BorderSide.none,
+    BorderSide end = BorderSide.none,
+    BorderSide bottom = BorderSide.none,
+  }) => BorderDirectional(top: top, start: start, end: end, bottom: bottom);
+
   /// The top side of this border.
   ///
   /// This getter is available on both [Border] and [BorderDirectional]. If
@@ -83,7 +132,7 @@ abstract class BoxBorder extends ShapeBorder {
   // We override this to tighten the return value, so that callers can assume
   // that we'll return a [BoxBorder].
   @override
-  BoxBorder? add(ShapeBorder other, { bool reversed = false }) => null;
+  BoxBorder? add(ShapeBorder other, {bool reversed = false}) => null;
 
   /// Linearly interpolate between two borders.
   ///
@@ -113,9 +162,7 @@ abstract class BoxBorder extends ShapeBorder {
       return BorderDirectional.lerp(a, b, t);
     }
     if (b is Border && a is BorderDirectional) {
-      final BoxBorder c = b;
-      b = a;
-      a = c;
+      (a, b) = (b, a);
       t = 1.0 - t;
       // fall through to next case
     }
@@ -164,26 +211,32 @@ abstract class BoxBorder extends ShapeBorder {
         '  $b\n'
         'However, only Border and BorderDirectional classes are supported by this method.',
       ),
-      ErrorHint('For a more general interpolation method, consider using ShapeBorder.lerp instead.'),
+      ErrorHint(
+        'For a more general interpolation method, consider using ShapeBorder.lerp instead.',
+      ),
     ]);
   }
 
   @override
-  Path getInnerPath(Rect rect, { TextDirection? textDirection }) {
-    assert(textDirection != null, 'The textDirection argument to $runtimeType.getInnerPath must not be null.');
-    return Path()
-      ..addRect(dimensions.resolve(textDirection).deflateRect(rect));
+  Path getInnerPath(Rect rect, {TextDirection? textDirection}) {
+    assert(
+      textDirection != null,
+      'The textDirection argument to $runtimeType.getInnerPath must not be null.',
+    );
+    return Path()..addRect(dimensions.resolve(textDirection).deflateRect(rect));
   }
 
   @override
-  Path getOuterPath(Rect rect, { TextDirection? textDirection }) {
-    assert(textDirection != null, 'The textDirection argument to $runtimeType.getOuterPath must not be null.');
-    return Path()
-      ..addRect(rect);
+  Path getOuterPath(Rect rect, {TextDirection? textDirection}) {
+    assert(
+      textDirection != null,
+      'The textDirection argument to $runtimeType.getOuterPath must not be null.',
+    );
+    return Path()..addRect(rect);
   }
 
   @override
-  void paintInterior(Canvas canvas, Rect rect, Paint paint, { TextDirection? textDirection }) {
+  void paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) {
     // For `ShapeDecoration(shape: Border.all())`, a rectangle with sharp edges
     // is always painted. There is no borderRadius parameter for
     // ShapeDecoration or Border, only for BoxDecoration, which doesn't call
@@ -224,10 +277,14 @@ abstract class BoxBorder extends ShapeBorder {
     BorderRadius? borderRadius,
   });
 
-  static void _paintUniformBorderWithRadius(Canvas canvas, Rect rect, BorderSide side, BorderRadius borderRadius) {
+  static void _paintUniformBorderWithRadius(
+    Canvas canvas,
+    Rect rect,
+    BorderSide side,
+    BorderRadius borderRadius,
+  ) {
     assert(side.style != BorderStyle.none);
-    final Paint paint = Paint()
-      ..color = side.color;
+    final Paint paint = Paint()..color = side.color;
     final double width = side.width;
     if (width == 0.0) {
       paint
@@ -242,33 +299,53 @@ abstract class BoxBorder extends ShapeBorder {
     }
   }
 
-  static void _paintNonUniformBorder(
+  /// Paints a Border with different widths, styles and strokeAligns, on any
+  /// borderRadius while using a single color.
+  ///
+  /// See also:
+  ///
+  ///  * [paintBorder], which supports multiple colors but not borderRadius.
+  ///  * [paint], which calls this method.
+  static void paintNonUniformBorder(
     Canvas canvas,
     Rect rect, {
     required BorderRadius? borderRadius,
-    required BoxShape shape,
     required TextDirection? textDirection,
-    required BorderSide left,
-    required BorderSide top,
-    required BorderSide right,
-    required BorderSide bottom,
+    BoxShape shape = BoxShape.rectangle,
+    BorderSide top = BorderSide.none,
+    BorderSide right = BorderSide.none,
+    BorderSide bottom = BorderSide.none,
+    BorderSide left = BorderSide.none,
+    required Color color,
   }) {
     final RRect borderRect;
     switch (shape) {
       case BoxShape.rectangle:
-        borderRect = (borderRadius ?? BorderRadius.zero)
-            .resolve(textDirection)
-            .toRRect(rect);
+        borderRect = (borderRadius ?? BorderRadius.zero).resolve(textDirection).toRRect(rect);
       case BoxShape.circle:
-        assert(borderRadius == null, 'A borderRadius cannot be given when shape is a BoxShape.circle.');
+        assert(
+          borderRadius == null,
+          'A borderRadius cannot be given when shape is a BoxShape.circle.',
+        );
         borderRect = RRect.fromRectAndRadius(
           Rect.fromCircle(center: rect.center, radius: rect.shortestSide / 2.0),
           Radius.circular(rect.width),
         );
     }
-    final Paint paint = Paint()..color = top.color;
-    final RRect inner = _deflateRRect(borderRect, EdgeInsets.fromLTRB(left.strokeInset, top.strokeInset, right.strokeInset, bottom.strokeInset));
-    final RRect outer = _inflateRRect(borderRect, EdgeInsets.fromLTRB(left.strokeOutset, top.strokeOutset, right.strokeOutset, bottom.strokeOutset));
+    final Paint paint = Paint()..color = color;
+    final RRect inner = _deflateRRect(
+      borderRect,
+      EdgeInsets.fromLTRB(left.strokeInset, top.strokeInset, right.strokeInset, bottom.strokeInset),
+    );
+    final RRect outer = _inflateRRect(
+      borderRect,
+      EdgeInsets.fromLTRB(
+        left.strokeOutset,
+        top.strokeOutset,
+        right.strokeOutset,
+        bottom.strokeOutset,
+      ),
+    );
     canvas.drawDRRect(outer, inner, paint);
   }
 
@@ -278,10 +355,18 @@ abstract class BoxBorder extends ShapeBorder {
       rect.top - insets.top,
       rect.right + insets.right,
       rect.bottom + insets.bottom,
-      topLeft: (rect.tlRadius + Radius.elliptical(insets.left, insets.top)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      topRight: (rect.trRadius + Radius.elliptical(insets.right, insets.top)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      bottomRight: (rect.brRadius + Radius.elliptical(insets.right, insets.bottom)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      bottomLeft: (rect.blRadius + Radius.elliptical(insets.left, insets.bottom)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
+      topLeft: (rect.tlRadius + Radius.elliptical(insets.left, insets.top)).clamp(
+        minimum: Radius.zero,
+      ),
+      topRight: (rect.trRadius + Radius.elliptical(insets.right, insets.top)).clamp(
+        minimum: Radius.zero,
+      ),
+      bottomRight: (rect.brRadius + Radius.elliptical(insets.right, insets.bottom)).clamp(
+        minimum: Radius.zero,
+      ),
+      bottomLeft: (rect.blRadius + Radius.elliptical(insets.left, insets.bottom)).clamp(
+        minimum: Radius.zero,
+      ),
     );
   }
 
@@ -291,10 +376,18 @@ abstract class BoxBorder extends ShapeBorder {
       rect.top + insets.top,
       rect.right - insets.right,
       rect.bottom - insets.bottom,
-      topLeft: (rect.tlRadius - Radius.elliptical(insets.left, insets.top)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      topRight: (rect.trRadius - Radius.elliptical(insets.right, insets.top)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      bottomRight: (rect.brRadius - Radius.elliptical(insets.right, insets.bottom)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
-      bottomLeft:(rect.blRadius - Radius.elliptical(insets.left, insets.bottom)).clamp(minimum: Radius.zero), // ignore_clamp_double_lint
+      topLeft: (rect.tlRadius - Radius.elliptical(insets.left, insets.top)).clamp(
+        minimum: Radius.zero,
+      ),
+      topRight: (rect.trRadius - Radius.elliptical(insets.right, insets.top)).clamp(
+        minimum: Radius.zero,
+      ),
+      bottomRight: (rect.brRadius - Radius.elliptical(insets.right, insets.bottom)).clamp(
+        minimum: Radius.zero,
+      ),
+      bottomLeft: (rect.blRadius - Radius.elliptical(insets.left, insets.bottom)).clamp(
+        minimum: Radius.zero,
+      ),
     );
   }
 
@@ -379,8 +472,6 @@ class Border extends BoxBorder {
   /// Creates a border.
   ///
   /// All the sides of the border default to [BorderSide.none].
-  ///
-  /// The arguments must not be null.
   const Border({
     this.top = BorderSide.none,
     this.right = BorderSide.none,
@@ -389,20 +480,18 @@ class Border extends BoxBorder {
   });
 
   /// Creates a border whose sides are all the same.
-  ///
-  /// The `side` argument must not be null.
   const Border.fromBorderSide(BorderSide side)
-      : top = side,
-        right = side,
-        bottom = side,
-        left = side;
+    : top = side,
+      right = side,
+      bottom = side,
+      left = side;
 
   /// Creates a border with symmetrical vertical and horizontal sides.
   ///
   /// The `vertical` argument applies to the [left] and [right] sides, and the
   /// `horizontal` argument applies to the [top] and [bottom] sides.
   ///
-  /// All arguments default to [BorderSide.none] and must not be null.
+  /// All arguments default to [BorderSide.none].
   const Border.symmetric({
     BorderSide vertical = BorderSide.none,
     BorderSide horizontal = BorderSide.none,
@@ -420,7 +509,12 @@ class Border extends BoxBorder {
     BorderStyle style = BorderStyle.solid,
     double strokeAlign = BorderSide.strokeAlignInside,
   }) {
-    final BorderSide side = BorderSide(color: color, width: width, style: style, strokeAlign: strokeAlign);
+    final BorderSide side = BorderSide(
+      color: color,
+      width: width,
+      style: style,
+      strokeAlign: strokeAlign,
+    );
     return Border.fromBorderSide(side);
   }
 
@@ -429,8 +523,6 @@ class Border extends BoxBorder {
   ///
   /// It is only valid to call this if [BorderSide.canMerge] returns true for
   /// the pairwise combination of each side on both [Border]s.
-  ///
-  /// The arguments must not be null.
   static Border merge(Border a, Border b) {
     assert(BorderSide.canMerge(a.top, b.top));
     assert(BorderSide.canMerge(a.right, b.right));
@@ -458,14 +550,17 @@ class Border extends BoxBorder {
 
   @override
   EdgeInsetsGeometry get dimensions {
-    if (_widthIsUniform) {
-      return EdgeInsets.all(top.strokeInset);
-    }
-    return EdgeInsets.fromLTRB(left.strokeInset, top.strokeInset, right.strokeInset, bottom.strokeInset);
+    return EdgeInsets.fromLTRB(
+      left.strokeInset,
+      top.strokeInset,
+      right.strokeInset,
+      bottom.strokeInset,
+    );
   }
 
   @override
-  bool get isUniform => _colorIsUniform && _widthIsUniform && _styleIsUniform && _strokeAlignIsUniform;
+  bool get isUniform =>
+      _colorIsUniform && _widthIsUniform && _styleIsUniform && _strokeAlignIsUniform;
 
   bool get _colorIsUniform {
     final Color topColor = top.color;
@@ -484,13 +579,31 @@ class Border extends BoxBorder {
 
   bool get _strokeAlignIsUniform {
     final double topStrokeAlign = top.strokeAlign;
-    return left.strokeAlign == topStrokeAlign
-        && bottom.strokeAlign == topStrokeAlign
-        && right.strokeAlign == topStrokeAlign;
+    return left.strokeAlign == topStrokeAlign &&
+        bottom.strokeAlign == topStrokeAlign &&
+        right.strokeAlign == topStrokeAlign;
   }
 
+  Set<Color> _distinctVisibleColors() {
+    return <Color>{
+      if (top.style != BorderStyle.none) top.color,
+      if (right.style != BorderStyle.none) right.color,
+      if (bottom.style != BorderStyle.none) bottom.color,
+      if (left.style != BorderStyle.none) left.color,
+    };
+  }
+
+  // [BoxBorder.paintNonUniformBorder] is about 20% faster than [paintBorder],
+  // but [paintBorder] is able to draw hairline borders when width is zero
+  // and style is [BorderStyle.solid].
+  bool get _hasHairlineBorder =>
+      (top.style == BorderStyle.solid && top.width == 0.0) ||
+      (right.style == BorderStyle.solid && right.width == 0.0) ||
+      (bottom.style == BorderStyle.solid && bottom.width == 0.0) ||
+      (left.style == BorderStyle.solid && left.width == 0.0);
+
   @override
-  Border? add(ShapeBorder other, { bool reversed = false }) {
+  Border? add(ShapeBorder other, {bool reversed = false}) {
     if (other is Border &&
         BorderSide.canMerge(top, other.top) &&
         BorderSide.canMerge(right, other.right) &&
@@ -590,7 +703,10 @@ class Border extends BoxBorder {
         case BorderStyle.solid:
           switch (shape) {
             case BoxShape.circle:
-              assert(borderRadius == null, 'A borderRadius cannot be given when shape is a BoxShape.circle.');
+              assert(
+                borderRadius == null,
+                'A borderRadius cannot be given when shape is a BoxShape.circle.',
+              );
               BoxBorder._paintUniformBorderWithCircle(canvas, rect, top);
             case BoxShape.rectangle:
               if (borderRadius != null && borderRadius != BorderRadius.zero) {
@@ -603,31 +719,45 @@ class Border extends BoxBorder {
       }
     }
 
-    // Allow painting non-uniform borders if the color and style are uniform.
-    if (_colorIsUniform && _styleIsUniform) {
-      switch (top.style) {
-        case BorderStyle.none:
-          return;
-        case BorderStyle.solid:
-          BoxBorder._paintNonUniformBorder(canvas, rect,
-              shape: shape,
-              borderRadius: borderRadius,
-              textDirection: textDirection,
-              left: left,
-              top: top,
-              right: right,
-              bottom: bottom);
-          return;
-      }
+    if (_styleIsUniform && top.style == BorderStyle.none) {
+      return;
+    }
+
+    // Allow painting non-uniform borders if the visible colors are uniform.
+    final Set<Color> visibleColors = _distinctVisibleColors();
+    final bool hasHairlineBorder = _hasHairlineBorder;
+    // Paint a non uniform border if a single color is visible
+    // and (borderRadius is present) or (border is visible and width != 0.0).
+    if (visibleColors.length == 1 &&
+        !hasHairlineBorder &&
+        (shape == BoxShape.circle || (borderRadius != null && borderRadius != BorderRadius.zero))) {
+      BoxBorder.paintNonUniformBorder(
+        canvas,
+        rect,
+        shape: shape,
+        borderRadius: borderRadius,
+        textDirection: textDirection,
+        top: top.style == BorderStyle.none ? BorderSide.none : top,
+        right: right.style == BorderStyle.none ? BorderSide.none : right,
+        bottom: bottom.style == BorderStyle.none ? BorderSide.none : bottom,
+        left: left.style == BorderStyle.none ? BorderSide.none : left,
+        color: visibleColors.first,
+      );
+      return;
     }
 
     assert(() {
-      if (borderRadius != null) {
+      if (hasHairlineBorder) {
+        assert(
+          borderRadius == null || borderRadius == BorderRadius.zero,
+          'A hairline border like `BorderSide(width: 0.0, style: BorderStyle.solid)` can only be drawn when BorderRadius is zero or null.',
+        );
+      }
+      if (borderRadius != null && borderRadius != BorderRadius.zero) {
         throw FlutterError.fromParts(<DiagnosticsNode>[
-          ErrorSummary('A borderRadius can only be given on borders with uniform colors and styles.'),
+          ErrorSummary('A borderRadius can only be given on borders with uniform colors.'),
           ErrorDescription('The following is not uniform:'),
           if (!_colorIsUniform) ErrorDescription('BorderSide.color'),
-          if (!_styleIsUniform) ErrorDescription('BorderSide.style'),
         ]);
       }
       return true;
@@ -635,10 +765,9 @@ class Border extends BoxBorder {
     assert(() {
       if (shape != BoxShape.rectangle) {
         throw FlutterError.fromParts(<DiagnosticsNode>[
-          ErrorSummary('A Border can only be drawn as a circle on borders with uniform colors and styles.'),
+          ErrorSummary('A Border can only be drawn as a circle on borders with uniform colors.'),
           ErrorDescription('The following is not uniform:'),
           if (!_colorIsUniform) ErrorDescription('BorderSide.color'),
-          if (!_styleIsUniform) ErrorDescription('BorderSide.style'),
         ]);
       }
       return true;
@@ -646,7 +775,9 @@ class Border extends BoxBorder {
     assert(() {
       if (!_strokeAlignIsUniform || top.strokeAlign != BorderSide.strokeAlignInside) {
         throw FlutterError.fromParts(<DiagnosticsNode>[
-          ErrorSummary('A Border can only draw strokeAlign different than BorderSide.strokeAlignInside on borders with uniform colors and styles.'),
+          ErrorSummary(
+            'A Border can only draw strokeAlign different than BorderSide.strokeAlignInside on borders with uniform colors.',
+          ),
         ]);
       }
       return true;
@@ -663,11 +794,11 @@ class Border extends BoxBorder {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is Border
-        && other.top == top
-        && other.right == right
-        && other.bottom == bottom
-        && other.left == left;
+    return other is Border &&
+        other.top == top &&
+        other.right == right &&
+        other.bottom == bottom &&
+        other.left == left;
   }
 
   @override
@@ -718,8 +849,6 @@ class BorderDirectional extends BoxBorder {
   /// the trailing edge. They are resolved during [paint].
   ///
   /// All the sides of the border default to [BorderSide.none].
-  ///
-  /// The arguments must not be null.
   const BorderDirectional({
     this.top = BorderSide.none,
     this.start = BorderSide.none,
@@ -732,8 +861,6 @@ class BorderDirectional extends BoxBorder {
   ///
   /// It is only valid to call this if [BorderSide.canMerge] returns true for
   /// the pairwise combination of each side on both [BorderDirectional]s.
-  ///
-  /// The arguments must not be null.
   static BorderDirectional merge(BorderDirectional a, BorderDirectional b) {
     assert(BorderSide.canMerge(a.top, b.top));
     assert(BorderSide.canMerge(a.start, b.start));
@@ -775,14 +902,17 @@ class BorderDirectional extends BoxBorder {
 
   @override
   EdgeInsetsGeometry get dimensions {
-    if (isUniform) {
-      return EdgeInsetsDirectional.all(top.strokeInset);
-    }
-    return EdgeInsetsDirectional.fromSTEB(start.strokeInset, top.strokeInset, end.strokeInset, bottom.strokeInset);
+    return EdgeInsetsDirectional.fromSTEB(
+      start.strokeInset,
+      top.strokeInset,
+      end.strokeInset,
+      bottom.strokeInset,
+    );
   }
 
   @override
-  bool get isUniform => _colorIsUniform && _widthIsUniform && _styleIsUniform && _strokeAlignIsUniform;
+  bool get isUniform =>
+      _colorIsUniform && _widthIsUniform && _styleIsUniform && _strokeAlignIsUniform;
 
   bool get _colorIsUniform {
     final Color topColor = top.color;
@@ -801,13 +931,28 @@ class BorderDirectional extends BoxBorder {
 
   bool get _strokeAlignIsUniform {
     final double topStrokeAlign = top.strokeAlign;
-    return start.strokeAlign == topStrokeAlign
-        && bottom.strokeAlign == topStrokeAlign
-        && end.strokeAlign == topStrokeAlign;
+    return start.strokeAlign == topStrokeAlign &&
+        bottom.strokeAlign == topStrokeAlign &&
+        end.strokeAlign == topStrokeAlign;
   }
 
+  Set<Color> _distinctVisibleColors() {
+    return <Color>{
+      if (top.style != BorderStyle.none) top.color,
+      if (end.style != BorderStyle.none) end.color,
+      if (bottom.style != BorderStyle.none) bottom.color,
+      if (start.style != BorderStyle.none) start.color,
+    };
+  }
+
+  bool get _hasHairlineBorder =>
+      (top.style == BorderStyle.solid && top.width == 0.0) ||
+      (end.style == BorderStyle.solid && end.width == 0.0) ||
+      (bottom.style == BorderStyle.solid && bottom.width == 0.0) ||
+      (start.style == BorderStyle.solid && start.width == 0.0);
+
   @override
-  BoxBorder? add(ShapeBorder other, { bool reversed = false }) {
+  BoxBorder? add(ShapeBorder other, {bool reversed = false}) {
     if (other is BorderDirectional) {
       final BorderDirectional typedOther = other;
       if (BorderSide.canMerge(top, typedOther.top) &&
@@ -824,10 +969,8 @@ class BorderDirectional extends BoxBorder {
           !BorderSide.canMerge(typedOther.bottom, bottom)) {
         return null;
       }
-      if (start != BorderSide.none ||
-          end != BorderSide.none) {
-        if (typedOther.left != BorderSide.none ||
-            typedOther.right != BorderSide.none) {
+      if (start != BorderSide.none || end != BorderSide.none) {
+        if (typedOther.left != BorderSide.none || typedOther.right != BorderSide.none) {
           return null;
         }
         assert(typedOther.left == BorderSide.none);
@@ -938,7 +1081,10 @@ class BorderDirectional extends BoxBorder {
         case BorderStyle.solid:
           switch (shape) {
             case BoxShape.circle:
-              assert(borderRadius == null, 'A borderRadius cannot be given when shape is a BoxShape.circle.');
+              assert(
+                borderRadius == null,
+                'A borderRadius cannot be given when shape is a BoxShape.circle.',
+              );
               BoxBorder._paintUniformBorderWithCircle(canvas, rect, top);
             case BoxShape.rectangle:
               if (borderRadius != null && borderRadius != BorderRadius.zero) {
@@ -951,38 +1097,58 @@ class BorderDirectional extends BoxBorder {
       }
     }
 
-    final BorderSide left, right;
-    assert(textDirection != null, 'Non-uniform BorderDirectional objects require a TextDirection when painting.');
-    switch (textDirection!) {
-      case TextDirection.rtl:
-        left = end;
-        right = start;
-      case TextDirection.ltr:
-        left = start;
-        right = end;
+    if (_styleIsUniform && top.style == BorderStyle.none) {
+      return;
     }
 
-    // Allow painting non-uniform borders if the color and style are uniform.
-    if (_colorIsUniform && _styleIsUniform) {
-      switch (top.style) {
-        case BorderStyle.none:
-          return;
-        case BorderStyle.solid:
-          BoxBorder._paintNonUniformBorder(canvas, rect,
-              shape: shape,
-              borderRadius: borderRadius,
-              textDirection: textDirection,
-              left: left,
-              top: top,
-              right: right,
-              bottom: bottom);
-          return;
-      }
+    assert(
+      textDirection != null,
+      'Non-uniform BorderDirectional objects require a TextDirection when painting.',
+    );
+    final (BorderSide left, BorderSide right) = switch (textDirection!) {
+      TextDirection.rtl => (end, start),
+      TextDirection.ltr => (start, end),
+    };
+
+    // Allow painting non-uniform borders if the visible colors are uniform.
+    final Set<Color> visibleColors = _distinctVisibleColors();
+    final bool hasHairlineBorder = _hasHairlineBorder;
+    if (visibleColors.length == 1 &&
+        !hasHairlineBorder &&
+        (shape == BoxShape.circle || (borderRadius != null && borderRadius != BorderRadius.zero))) {
+      BoxBorder.paintNonUniformBorder(
+        canvas,
+        rect,
+        shape: shape,
+        borderRadius: borderRadius,
+        textDirection: textDirection,
+        top: top.style == BorderStyle.none ? BorderSide.none : top,
+        right: right.style == BorderStyle.none ? BorderSide.none : right,
+        bottom: bottom.style == BorderStyle.none ? BorderSide.none : bottom,
+        left: left.style == BorderStyle.none ? BorderSide.none : left,
+        color: visibleColors.first,
+      );
+      return;
     }
 
-    assert(borderRadius == null, 'A borderRadius can only be given for borders with uniform colors and styles.');
-    assert(shape == BoxShape.rectangle, 'A Border can only be drawn as a circle on borders with uniform colors and styles.');
-    assert(_strokeAlignIsUniform && top.strokeAlign == BorderSide.strokeAlignInside, 'A Border can only draw strokeAlign different than strokeAlignInside on borders with uniform colors and styles.');
+    if (hasHairlineBorder) {
+      assert(
+        borderRadius == null || borderRadius == BorderRadius.zero,
+        'A side like `BorderSide(width: 0.0, style: BorderStyle.solid)` can only be drawn when BorderRadius is zero or null.',
+      );
+    }
+    assert(
+      borderRadius == null,
+      'A borderRadius can only be given for borders with uniform colors.',
+    );
+    assert(
+      shape == BoxShape.rectangle,
+      'A Border can only be drawn as a circle on borders with uniform colors.',
+    );
+    assert(
+      _strokeAlignIsUniform && top.strokeAlign == BorderSide.strokeAlignInside,
+      'A Border can only draw strokeAlign different than strokeAlignInside on borders with uniform colors.',
+    );
 
     paintBorder(canvas, rect, top: top, left: left, bottom: bottom, right: right);
   }
@@ -995,11 +1161,11 @@ class BorderDirectional extends BoxBorder {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is BorderDirectional
-        && other.top == top
-        && other.start == start
-        && other.end == end
-        && other.bottom == bottom;
+    return other is BorderDirectional &&
+        other.top == top &&
+        other.start == start &&
+        other.end == end &&
+        other.bottom == bottom;
   }
 
   @override
