@@ -17,23 +17,27 @@ abstract final class MatrixUtils {
   ///
   /// Otherwise, returns null.
   static Offset? getAsTranslation(Matrix4 transform) {
-    final Float64List values = transform.storage;
-    // Values are stored in column-major order.
-    if (values[0] == 1.0 && // col 1
-        values[1] == 0.0 &&
-        values[2] == 0.0 &&
-        values[3] == 0.0 &&
-        values[4] == 0.0 && // col 2
-        values[5] == 1.0 &&
-        values[6] == 0.0 &&
-        values[7] == 0.0 &&
-        values[8] == 0.0 && // col 3
-        values[9] == 0.0 &&
-        values[10] == 1.0 &&
-        values[11] == 0.0 &&
-        values[14] == 0.0 && // bottom of col 4 (values 12 and 13 are the x and y offsets)
-        values[15] == 1.0) {
-      return Offset(values[12], values[13]);
+    // Values are stored in column-major order, so the appearance
+    // of dx is transposed from the top-right to the bottom-left.
+    if (transform.storage case [
+      1.0,
+      0.0,
+      0.0,
+      0.0,
+      0.0,
+      1.0,
+      0.0,
+      0.0,
+      0.0,
+      0.0,
+      1.0,
+      0.0,
+      final double dx,
+      final double dy,
+      0.0,
+      1.0,
+    ]) {
+      return Offset(dx, dy);
     }
     return null;
   }
@@ -43,24 +47,27 @@ abstract final class MatrixUtils {
   ///
   /// Otherwise, returns null.
   static double? getAsScale(Matrix4 transform) {
-    final Float64List values = transform.storage;
-    // Values are stored in column-major order.
-    if (values[1] == 0.0 && // col 1 (value 0 is the scale)
-        values[2] == 0.0 &&
-        values[3] == 0.0 &&
-        values[4] == 0.0 && // col 2 (value 5 is the scale)
-        values[6] == 0.0 &&
-        values[7] == 0.0 &&
-        values[8] == 0.0 && // col 3
-        values[9] == 0.0 &&
-        values[10] == 1.0 &&
-        values[11] == 0.0 &&
-        values[12] == 0.0 && // col 4
-        values[13] == 0.0 &&
-        values[14] == 0.0 &&
-        values[15] == 1.0 &&
-        values[0] == values[5]) { // uniform scale
-      return values[0];
+    // Values are stored in column-major order
+    // (but this symmetric matrix is unaffected).
+    if (transform.storage case [
+      final double diagonal1,
+      0.0,
+      0.0,
+      0.0,
+      0.0,
+      final double diagonal2,
+      0.0,
+      0.0,
+      0.0,
+      0.0,
+      1.0,
+      0.0,
+      0.0,
+      0.0,
+      0.0,
+      1.0,
+    ] when diagonal1 == diagonal2) {
+      return diagonal1;
     }
     return null;
   }
@@ -78,42 +85,50 @@ abstract final class MatrixUtils {
     if (b == null) {
       return isIdentity(a);
     }
-    return a.storage[0] == b.storage[0]
-        && a.storage[1] == b.storage[1]
-        && a.storage[2] == b.storage[2]
-        && a.storage[3] == b.storage[3]
-        && a.storage[4] == b.storage[4]
-        && a.storage[5] == b.storage[5]
-        && a.storage[6] == b.storage[6]
-        && a.storage[7] == b.storage[7]
-        && a.storage[8] == b.storage[8]
-        && a.storage[9] == b.storage[9]
-        && a.storage[10] == b.storage[10]
-        && a.storage[11] == b.storage[11]
-        && a.storage[12] == b.storage[12]
-        && a.storage[13] == b.storage[13]
-        && a.storage[14] == b.storage[14]
-        && a.storage[15] == b.storage[15];
+    return a.storage[0] == b.storage[0] &&
+        a.storage[1] == b.storage[1] &&
+        a.storage[2] == b.storage[2] &&
+        a.storage[3] == b.storage[3] &&
+        a.storage[4] == b.storage[4] &&
+        a.storage[5] == b.storage[5] &&
+        a.storage[6] == b.storage[6] &&
+        a.storage[7] == b.storage[7] &&
+        a.storage[8] == b.storage[8] &&
+        a.storage[9] == b.storage[9] &&
+        a.storage[10] == b.storage[10] &&
+        a.storage[11] == b.storage[11] &&
+        a.storage[12] == b.storage[12] &&
+        a.storage[13] == b.storage[13] &&
+        a.storage[14] == b.storage[14] &&
+        a.storage[15] == b.storage[15];
   }
 
   /// Whether the given matrix is the identity matrix.
   static bool isIdentity(Matrix4 a) {
-    return a.storage[0] == 1.0 // col 1
-        && a.storage[1] == 0.0
-        && a.storage[2] == 0.0
-        && a.storage[3] == 0.0
-        && a.storage[4] == 0.0 // col 2
-        && a.storage[5] == 1.0
-        && a.storage[6] == 0.0
-        && a.storage[7] == 0.0
-        && a.storage[8] == 0.0 // col 3
-        && a.storage[9] == 0.0
-        && a.storage[10] == 1.0
-        && a.storage[11] == 0.0
-        && a.storage[12] == 0.0 // col 4
-        && a.storage[13] == 0.0
-        && a.storage[14] == 0.0
-        && a.storage[15] == 1.0;
+    return a.storage[0] ==
+            1.0 // col 1
+            &&
+        a.storage[1] == 0.0 &&
+        a.storage[2] == 0.0 &&
+        a.storage[3] == 0.0 &&
+        a.storage[4] ==
+            0.0 // col 2
+            &&
+        a.storage[5] == 1.0 &&
+        a.storage[6] == 0.0 &&
+        a.storage[7] == 0.0 &&
+        a.storage[8] ==
+            0.0 // col 3
+            &&
+        a.storage[9] == 0.0 &&
+        a.storage[10] == 1.0 &&
+        a.storage[11] == 0.0 &&
+        a.storage[12] ==
+            0.0 // col 4
+            &&
+        a.storage[13] == 0.0 &&
+        a.storage[14] == 0.0 &&
+        a.storage[15] == 1.0;
   }
 
   /// Applies the given matrix as a perspective transform to the given point.
@@ -154,13 +169,11 @@ abstract final class MatrixUtils {
   /// if it can.
   static Rect _safeTransformRect(Matrix4 transform, Rect rect) {
     final Float64List storage = transform.storage;
-    final bool isAffine = storage[3] == 0.0 &&
-        storage[7] == 0.0 &&
-        storage[15] == 1.0;
+    final bool isAffine = storage[3] == 0.0 && storage[7] == 0.0 && storage[15] == 1.0;
 
-    _accumulate(storage, rect.left,  rect.top,    true,  isAffine);
-    _accumulate(storage, rect.right, rect.top,    false, isAffine);
-    _accumulate(storage, rect.left,  rect.bottom, false, isAffine);
+    _accumulate(storage, rect.left, rect.top, true, isAffine);
+    _accumulate(storage, rect.right, rect.top, false, isAffine);
+    _accumulate(storage, rect.left, rect.bottom, false, isAffine);
     _accumulate(storage, rect.right, rect.bottom, false, isAffine);
 
     return Rect.fromLTRB(_minMax[0], _minMax[1], _minMax[2], _minMax[3]);
@@ -364,28 +377,28 @@ abstract final class MatrixUtils {
     final double ry = storage[1] * x + storage[5] * y + storage[13];
 
     if (storage[3] == 0.0 && storage[7] == 0.0 && storage[15] == 1.0) {
-      double left  = rx;
+      double left = rx;
       double right = rx;
       if (wx < 0) {
-        left  += wx;
+        left += wx;
       } else {
         right += wx;
       }
       if (hx < 0) {
-        left  += hx;
+        left += hx;
       } else {
         right += hx;
       }
 
-      double top    = ry;
+      double top = ry;
       double bottom = ry;
       if (wy < 0) {
-        top    += wy;
+        top += wy;
       } else {
         bottom += wy;
       }
       if (hy < 0) {
-        top    += hy;
+        top += hy;
       } else {
         bottom += hy;
       }
@@ -396,12 +409,12 @@ abstract final class MatrixUtils {
       final double hw = storage[7] * h;
       final double rw = storage[3] * x + storage[7] * y + storage[15];
 
-      final double ulx =  rx            /  rw;
-      final double uly =  ry            /  rw;
-      final double urx = (rx + wx)      / (rw + ww);
-      final double ury = (ry + wy)      / (rw + ww);
-      final double llx = (rx      + hx) / (rw      + hw);
-      final double lly = (ry      + hy) / (rw      + hw);
+      final double ulx = rx / rw;
+      final double uly = ry / rw;
+      final double urx = (rx + wx) / (rw + ww);
+      final double ury = (ry + wy) / (rw + ww);
+      final double llx = (rx + hx) / (rw + hw);
+      final double lly = (ry + hy) / (rw + hw);
       final double lrx = (rx + wx + hx) / (rw + ww + hw);
       final double lry = (ry + wy + hy) / (rw + ww + hw);
 
@@ -419,6 +432,7 @@ abstract final class MatrixUtils {
     final double f = (c < d) ? c : d;
     return (e < f) ? e : f;
   }
+
   static double _max4(double a, double b, double c, double d) {
     final double e = (a > b) ? a : b;
     final double f = (c > d) ? c : d;
@@ -500,17 +514,22 @@ abstract final class MatrixUtils {
     //  [0.0, 1.0, 0.0, 0.0],
     //  [0.0, 0.0, 1.0, -radius],
     //  [0.0, 0.0, 0.0, 1.0]]
-    Matrix4 result = Matrix4.identity()
-        ..setEntry(3, 2, -perspective)
-        ..setEntry(2, 3, -radius)
-        ..setEntry(3, 3, perspective * radius + 1.0);
+    Matrix4 result =
+        Matrix4.identity()
+          ..setEntry(3, 2, -perspective)
+          ..setEntry(2, 3, -radius)
+          ..setEntry(3, 3, perspective * radius + 1.0);
 
     // Model matrix by first translating the object from the origin of the world
     // by radius in the z axis and then rotating against the world.
-    result = result * (switch (orientation) {
-        Axis.horizontal => Matrix4.rotationY(angle),
-        Axis.vertical   => Matrix4.rotationX(angle),
-      } * Matrix4.translationValues(0.0, 0.0, radius)) as Matrix4;
+    result =
+        result *
+                (switch (orientation) {
+                      Axis.horizontal => Matrix4.rotationY(angle),
+                      Axis.vertical => Matrix4.rotationX(angle),
+                    } *
+                    Matrix4.translationValues(0.0, 0.0, radius))
+            as Matrix4;
 
     // Essentially perspective * view * model.
     return result;
@@ -552,7 +571,7 @@ class TransformProperty extends DiagnosticsProperty<Matrix4> {
   });
 
   @override
-  String valueToString({ TextTreeConfiguration? parentConfiguration }) {
+  String valueToString({TextTreeConfiguration? parentConfiguration}) {
     if (parentConfiguration != null && !parentConfiguration.lineBreakProperties) {
       // Format the value on a single line to be compatible with the parent's
       // style.
