@@ -2,12 +2,17 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/material.dart';
+library;
+
+import 'package:flutter/foundation.dart';
 import 'package:flutter/gestures.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter/scheduler.dart';
 
 import 'basic.dart';
 import 'debug.dart';
+import 'drag_boundary.dart';
 import 'framework.dart';
 import 'inherited_theme.dart';
 import 'localizations.dart';
@@ -77,7 +82,39 @@ typedef ReorderCallback = void Function(int oldIndex, int newIndex);
 /// like an elevation or border.
 ///
 /// The returned value will typically be the [child] wrapped in other widgets.
-typedef ReorderItemProxyDecorator = Widget Function(Widget child, int index, Animation<double> animation);
+typedef ReorderItemProxyDecorator =
+    Widget Function(Widget child, int index, Animation<double> animation);
+
+/// Used to provide drag boundaries during drag-and-drop reordering.
+///
+/// {@tool snippet}
+/// ```dart
+/// DragBoundary(
+///  child: CustomScrollView(
+///    slivers: <Widget>[
+///      SliverReorderableList(
+///        itemBuilder: (BuildContext context, int index) {
+///          return ReorderableDragStartListener(
+///            key: ValueKey<int>(index),
+///            index: index,
+///            child: Text('$index'),
+///          );
+///        },
+///        dragBoundaryProvider: (BuildContext context) {
+///          return DragBoundary.forRectOf(context);
+///        },
+///        itemCount: 5,
+///        onReorder: (int fromIndex, int toIndex) {},
+///      ),
+///    ],
+///  )
+/// )
+/// ```
+/// {@end-tool}
+///
+/// See also:
+/// * [DragBoundary], a widget that provides drag boundaries.
+typedef ReorderDragBoundaryProvider = DragBoundaryDelegate<Rect>? Function(BuildContext context);
 
 /// A scrolling container that allows the user to interactively reorder the
 /// list items.
@@ -118,6 +155,7 @@ class ReorderableList extends StatefulWidget {
     this.onReorderStart,
     this.onReorderEnd,
     this.itemExtent,
+    this.itemExtentBuilder,
     this.prototypeItem,
     this.proxyDecorator,
     this.padding,
@@ -130,14 +168,17 @@ class ReorderableList extends StatefulWidget {
     this.anchor = 0.0,
     this.cacheExtent,
     this.dragStartBehavior = DragStartBehavior.start,
-    this.keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual,
+    this.keyboardDismissBehavior,
     this.restorationId,
     this.clipBehavior = Clip.hardEdge,
     this.autoScrollerVelocityScalar,
+    this.dragBoundaryProvider,
   }) : assert(itemCount >= 0),
        assert(
-         itemExtent == null || prototypeItem == null,
-         'You can only pass itemExtent or prototypeItem, not both',
+         (itemExtent == null && prototypeItem == null) ||
+             (itemExtent == null && itemExtentBuilder == null) ||
+             (prototypeItem == null && itemExtentBuilder == null),
+         'You can only pass one of itemExtent, prototypeItem and itemExtentBuilder.',
        );
 
   /// {@template flutter.widgets.reorderable_list.itemBuilder}
@@ -239,8 +280,9 @@ class ReorderableList extends StatefulWidget {
 
   /// {@macro flutter.widgets.scroll_view.keyboardDismissBehavior}
   ///
-  /// The default is [ScrollViewKeyboardDismissBehavior.manual]
-  final ScrollViewKeyboardDismissBehavior keyboardDismissBehavior;
+  /// If [keyboardDismissBehavior] is null then it will fallback to the inherited
+  /// [ScrollBehavior.getKeyboardDismissBehavior].
+  final ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior;
 
   /// {@macro flutter.widgets.scrollable.restorationId}
   final String? restorationId;
@@ -253,6 +295,9 @@ class ReorderableList extends StatefulWidget {
   /// {@macro flutter.widgets.list_view.itemExtent}
   final double? itemExtent;
 
+  /// {@macro flutter.widgets.list_view.itemExtentBuilder}
+  final ItemExtentBuilder? itemExtentBuilder;
+
   /// {@macro flutter.widgets.list_view.prototypeItem}
   final Widget? prototypeItem;
 
@@ -261,6 +306,14 @@ class ReorderableList extends StatefulWidget {
   /// {@macro flutter.widgets.SliverReorderableList.autoScrollerVelocityScalar.default}
   final double? autoScrollerVelocityScalar;
 
+  /// {@template flutter.widgets.reorderable_list.dragBoundaryProvider}
+  /// A callback used to provide drag boundaries during drag-and-drop reordering.
+  ///
+  /// If null, the delegate returned by `DragBoundary.forRectMaybeOf` will be used.
+  /// Defaults to null.
+  /// {@endtemplate}
+  final ReorderDragBoundaryProvider? dragBoundaryProvider;
+
   /// The state from the closest instance of this class that encloses the given
   /// context.
   ///
@@ -281,7 +334,9 @@ class ReorderableList extends StatefulWidget {
     assert(() {
       if (result == null) {
         throw FlutterError.fromParts(<DiagnosticsNode>[
-          ErrorSummary('ReorderableList.of() called with a context that does not contain a ReorderableList.'),
+          ErrorSummary(
+            'ReorderableList.of() called with a context that does not contain a ReorderableList.',
+          ),
           ErrorDescription(
             'No ReorderableList ancestor could be found starting from the context that was passed to ReorderableList.of().',
           ),
@@ -364,7 +419,11 @@ class ReorderableListState extends State<ReorderableList> {
     required PointerDownEvent event,
     required MultiDragGestureRecognizer recognizer,
   }) {
-    _sliverReorderableListKey.currentState!.startItemDragReorder(index: index, event: event, recognizer: recognizer);
+    _sliverReorderableListKey.currentState!.startItemDragReorder(
+      index: index,
+      event: event,
+      recognizer: recognizer,
+    );
   }
 
   /// Cancel any item drag in progress.
@@ -378,6 +437,7 @@ class ReorderableListState extends State<ReorderableList> {
     _sliverReorderableListKey.currentState!.cancelReorder();
   }
 
+  @protected
   @override
   Widget build(BuildContext context) {
     return CustomScrollView(
@@ -401,12 +461,14 @@ class ReorderableListState extends State<ReorderableList> {
             itemExtent: widget.itemExtent,
             prototypeItem: widget.prototypeItem,
             itemBuilder: widget.itemBuilder,
+            itemExtentBuilder: widget.itemExtentBuilder,
             itemCount: widget.itemCount,
             onReorder: widget.onReorder,
             onReorderStart: widget.onReorderStart,
             onReorderEnd: widget.onReorderEnd,
             proxyDecorator: widget.proxyDecorator,
             autoScrollerVelocityScalar: widget.autoScrollerVelocityScalar,
+            dragBoundaryProvider: widget.dragBoundaryProvider,
           ),
         ),
       ],
@@ -450,14 +512,18 @@ class SliverReorderableList extends StatefulWidget {
     this.onReorderStart,
     this.onReorderEnd,
     this.itemExtent,
+    this.itemExtentBuilder,
     this.prototypeItem,
     this.proxyDecorator,
+    this.dragBoundaryProvider,
     double? autoScrollerVelocityScalar,
   }) : autoScrollerVelocityScalar = autoScrollerVelocityScalar ?? _kDefaultAutoScrollVelocityScalar,
        assert(itemCount >= 0),
        assert(
-         itemExtent == null || prototypeItem == null,
-         'You can only pass itemExtent or prototypeItem, not both',
+         (itemExtent == null && prototypeItem == null) ||
+             (itemExtent == null && itemExtentBuilder == null) ||
+             (prototypeItem == null && itemExtentBuilder == null),
+         'You can only pass one of itemExtent, prototypeItem and itemExtentBuilder.',
        );
 
   // An eyeballed value for a smooth scrolling experience.
@@ -487,6 +553,9 @@ class SliverReorderableList extends StatefulWidget {
   /// {@macro flutter.widgets.list_view.itemExtent}
   final double? itemExtent;
 
+  /// {@macro flutter.widgets.list_view.itemExtentBuilder}
+  final ItemExtentBuilder? itemExtentBuilder;
+
   /// {@macro flutter.widgets.list_view.prototypeItem}
   final Widget? prototypeItem;
 
@@ -497,6 +566,9 @@ class SliverReorderableList extends StatefulWidget {
   /// {@endtemplate}
   final double autoScrollerVelocityScalar;
 
+  /// {@macro flutter.widgets.reorderable_list.dragBoundaryProvider}
+  final ReorderDragBoundaryProvider? dragBoundaryProvider;
+
   @override
   SliverReorderableListState createState() => SliverReorderableListState();
 
@@ -516,7 +588,8 @@ class SliverReorderableList extends StatefulWidget {
   ///  * [maybeOf], a similar function that will return null if no
   ///    [SliverReorderableList] ancestor is found.
   static SliverReorderableListState of(BuildContext context) {
-    final SliverReorderableListState? result = context.findAncestorStateOfType<SliverReorderableListState>();
+    final SliverReorderableListState? result =
+        context.findAncestorStateOfType<SliverReorderableListState>();
     assert(() {
       if (result == null) {
         throw FlutterError.fromParts(<DiagnosticsNode>[
@@ -594,7 +667,8 @@ class SliverReorderableList extends StatefulWidget {
 /// [ReorderableDragStartListener] and [ReorderableDelayedDragStartListener]
 /// refer to their [SliverReorderableList] with the static
 /// [SliverReorderableList.of] method.
-class SliverReorderableListState extends State<SliverReorderableList> with TickerProviderStateMixin {
+class SliverReorderableListState extends State<SliverReorderableList>
+    with TickerProviderStateMixin {
   // Map of index -> child state used manage where the dragging item will need
   // to be inserted.
   final Map<int, _ReorderableItemState> _items = <int, _ReorderableItemState>{};
@@ -606,24 +680,14 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
   Offset? _finalDropPosition;
   MultiDragGestureRecognizer? _recognizer;
   int? _recognizerPointer;
-  // To implement the gap for the dragged item, we replace the dragged item
-  // with a zero sized box, and then translate all of the later items down
-  // by the size of the dragged item. This allows us to keep the order of the
-  // list, while still being able to animate the gap between the items. However
-  // for the first frame of the drag, the item has not yet been replaced, so
-  // the calculation for the gap is off by the size of the gap. This flag is
-  // used to determine if the transition to the zero sized box has completed,
-  // so the gap calculation can compensate for it.
-  bool _dragStartTransitionComplete = false;
 
   EdgeDraggingAutoScroller? _autoScroller;
 
   late ScrollableState _scrollable;
   Axis get _scrollDirection => axisDirectionToAxis(_scrollable.axisDirection);
-  bool get _reverse =>
-    _scrollable.axisDirection == AxisDirection.up ||
-    _scrollable.axisDirection == AxisDirection.left;
+  bool get _reverse => axisDirectionIsReversed(_scrollable.axisDirection);
 
+  @protected
   @override
   void didChangeDependencies() {
     super.didChangeDependencies();
@@ -638,6 +702,7 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     }
   }
 
+  @protected
   @override
   void didUpdateWidget(covariant SliverReorderableList oldWidget) {
     super.didUpdateWidget(oldWidget);
@@ -655,9 +720,11 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     }
   }
 
+  @protected
   @override
   void dispose() {
     _dragReset();
+    _recognizer?.dispose();
     super.dispose();
   }
 
@@ -689,9 +756,10 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
 
       if (_items.containsKey(index)) {
         _dragIndex = index;
-        _recognizer = recognizer
-          ..onStart = _dragStart
-          ..addPointer(event);
+        _recognizer =
+            recognizer
+              ..onStart = _dragStart
+              ..addPointer(event);
         _recognizerPointer = event.pointer;
       } else {
         // TODO(darrenaustin): Can we handle this better, maybe scroll to the item?
@@ -717,6 +785,9 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
   }
 
   void _registerItem(_ReorderableItemState item) {
+    if (_dragInfo != null && _items[item.index] != item) {
+      item.updateForGap(_dragInfo!.index, _dragInfo!.index, _dragInfo!.itemExtent, false, _reverse);
+    }
     _items[item.index] = item;
     if (item.index == _dragInfo?.index) {
       item.dragging = true;
@@ -737,10 +808,6 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     item.dragging = true;
     widget.onReorderStart?.call(_dragIndex!);
     item.rebuild();
-    _dragStartTransitionComplete = false;
-    SchedulerBinding.instance.addPostFrameCallback((Duration duration) {
-      _dragStartTransitionComplete = true;
-    });
 
     _insertIndex = item.index;
     _dragInfo = _DragInfo(
@@ -765,7 +832,7 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
       if (childItem == item || !childItem.mounted) {
         continue;
       }
-      childItem.updateForGap(_insertIndex!, _dragInfo!.itemExtent, false, _reverse);
+      childItem.updateForGap(_insertIndex!, _insertIndex!, _dragInfo!.itemExtent, false, _reverse);
     }
     return _dragInfo;
   }
@@ -787,19 +854,27 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
   void _dragEnd(_DragInfo item) {
     setState(() {
       if (_insertIndex == item.index) {
-        _finalDropPosition = _itemOffsetAt(_insertIndex! + (_reverse ? 1 : 0));
-      } else if (_insertIndex! < widget.itemCount - 1) {
-        // Find the location of the item we want to insert before
         _finalDropPosition = _itemOffsetAt(_insertIndex!);
-      } else {
-        // Inserting into the last spot on the list. If it's the only spot, put
-        // it back where it was. Otherwise, grab the second to last and move
-        // down by the gap.
-        final int itemIndex = _items.length > 1 ? _insertIndex! - 1 : _insertIndex!;
-        if (_reverse) {
-          _finalDropPosition = _itemOffsetAt(itemIndex) - _extentOffset(item.itemExtent, _scrollDirection);
+      } else if (_reverse) {
+        if (_insertIndex! >= _items.length) {
+          // Drop at the starting position of the last element and offset its own extent
+          _finalDropPosition =
+              _itemOffsetAt(_items.length - 1) - _extentOffset(item.itemExtent, _scrollDirection);
         } else {
-          _finalDropPosition = _itemOffsetAt(itemIndex) + _extentOffset(item.itemExtent, _scrollDirection);
+          // Drop at the end of the current element occupying the insert position
+          _finalDropPosition =
+              _itemOffsetAt(_insertIndex!) +
+              _extentOffset(_itemExtentAt(_insertIndex!), _scrollDirection);
+        }
+      } else {
+        if (_insertIndex! == 0) {
+          // Drop at the starting position of the first element and offset its own extent
+          _finalDropPosition = _itemOffsetAt(0) - _extentOffset(item.itemExtent, _scrollDirection);
+        } else {
+          // Drop at the end of the previous element occupying the insert position
+          final int atIndex = _insertIndex! - 1;
+          _finalDropPosition =
+              _itemOffsetAt(atIndex) + _extentOffset(_itemExtentAt(atIndex), _scrollDirection);
         }
       }
     });
@@ -832,6 +907,7 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
       _recognizer?.dispose();
       _recognizer = null;
       _overlayEntry?.remove();
+      _overlayEntry?.dispose();
       _overlayEntry = null;
       _finalDropPosition = null;
     }
@@ -855,26 +931,23 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
   void _dragUpdateItems() {
     assert(_dragInfo != null);
     final double gapExtent = _dragInfo!.itemExtent;
-    final double proxyItemStart = _offsetExtent(_dragInfo!.dragPosition - _dragInfo!.dragOffset, _scrollDirection);
+    final double proxyItemStart = _offsetExtent(
+      _dragInfo!.dragPosition - _dragInfo!.dragOffset,
+      _scrollDirection,
+    );
     final double proxyItemEnd = proxyItemStart + gapExtent;
 
     // Find the new index for inserting the item being dragged.
     int newIndex = _insertIndex!;
     for (final _ReorderableItemState item in _items.values) {
-      if (item.index == _dragIndex! || !item.mounted) {
+      if ((_reverse && item.index == _dragIndex!) || !item.mounted) {
         continue;
       }
 
-      Rect geometry = item.targetGeometry();
-      if (!_dragStartTransitionComplete && _dragIndex! <= item.index) {
-        // Transition is not complete, so each item after the dragged item is still
-        // in its normal location and not moved up for the zero sized box that will
-        // replace the dragged item.
-        final Offset transitionOffset = _extentOffset(_reverse ? -gapExtent : gapExtent, _scrollDirection);
-        geometry = (geometry.topLeft - transitionOffset) & geometry.size;
-      }
+      final Rect geometry = item.targetGeometry();
       final double itemStart = _scrollDirection == Axis.vertical ? geometry.top : geometry.left;
-      final double itemExtent = _scrollDirection == Axis.vertical ? geometry.height : geometry.width;
+      final double itemExtent =
+          _scrollDirection == Axis.vertical ? geometry.height : geometry.width;
       final double itemEnd = itemStart + itemExtent;
       final double itemMiddle = itemStart + itemExtent / 2;
 
@@ -885,34 +958,36 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
           // the new index.
           newIndex = item.index;
           break;
-
         } else if (itemMiddle >= proxyItemStart && proxyItemStart >= itemStart) {
           // The end of the proxy is in the ending half of the item, so
           // we should swap the item with the gap and we are done looking for
           // the new index.
           newIndex = item.index + 1;
           break;
-
         } else if (itemStart > proxyItemEnd && newIndex < (item.index + 1)) {
           newIndex = item.index + 1;
         } else if (proxyItemStart > itemEnd && newIndex > item.index) {
           newIndex = item.index;
         }
       } else {
-        if (itemStart <= proxyItemStart && proxyItemStart <= itemMiddle) {
+        if (item.index == _dragIndex!) {
+          // If end of the proxy is not in ending half of item,
+          // we don't process, because it's original dragged item.
+          if (itemMiddle <= proxyItemEnd && proxyItemEnd <= itemEnd) {
+            newIndex = _dragIndex!;
+          }
+        } else if (itemStart <= proxyItemStart && proxyItemStart <= itemMiddle) {
           // The start of the proxy is in the beginning half of the item, so
           // we should swap the item with the gap and we are done looking for
           // the new index.
           newIndex = item.index;
           break;
-
         } else if (itemMiddle <= proxyItemEnd && proxyItemEnd <= itemEnd) {
           // The end of the proxy is in the ending half of the item, so
           // we should swap the item with the gap and we are done looking for
           // the new index.
           newIndex = item.index + 1;
           break;
-
         } else if (itemEnd < proxyItemStart && newIndex < (item.index + 1)) {
           newIndex = item.index + 1;
         } else if (proxyItemEnd < itemStart && newIndex > item.index) {
@@ -927,29 +1002,35 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
         if (item.index == _dragIndex! || !item.mounted) {
           continue;
         }
-        item.updateForGap(newIndex, gapExtent, true, _reverse);
+        item.updateForGap(_dragIndex!, newIndex, gapExtent, true, _reverse);
       }
     }
   }
 
   Rect get _dragTargetRect {
     final Offset origin = _dragInfo!.dragPosition - _dragInfo!.dragOffset;
-    return Rect.fromLTWH(origin.dx, origin.dy, _dragInfo!.itemSize.width, _dragInfo!.itemSize.height);
+    return Rect.fromLTWH(
+      origin.dx,
+      origin.dy,
+      _dragInfo!.itemSize.width,
+      _dragInfo!.itemSize.height,
+    );
   }
 
   Offset _itemOffsetAt(int index) {
-    final RenderBox itemRenderBox =  _items[index]!.context.findRenderObject()! as RenderBox;
-    return itemRenderBox.localToGlobal(Offset.zero);
+    return _items[index]!.targetGeometry().topLeft;
+  }
+
+  double _itemExtentAt(int index) {
+    return _sizeExtent(_items[index]!.targetGeometry().size, _scrollDirection);
   }
 
   Widget _itemBuilder(BuildContext context, int index) {
     if (_dragInfo != null && index >= widget.itemCount) {
-      switch (_scrollDirection) {
-        case Axis.horizontal:
-          return SizedBox(width: _dragInfo!.itemExtent);
-        case Axis.vertical:
-          return SizedBox(height: _dragInfo!.itemExtent);
-      }
+      return switch (_scrollDirection) {
+        Axis.horizontal => SizedBox(width: _dragInfo!.itemExtent),
+        Axis.vertical => SizedBox(height: _dragInfo!.itemExtent),
+      };
     }
     final Widget child = widget.itemBuilder(context, index);
     assert(child.key != null, 'All list items must have a key');
@@ -970,7 +1051,8 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     }
 
     // First, determine which semantics actions apply.
-    final Map<CustomSemanticsAction, VoidCallback> semanticsActions = <CustomSemanticsAction, VoidCallback>{};
+    final Map<CustomSemanticsAction, VoidCallback> semanticsActions =
+        <CustomSemanticsAction, VoidCallback>{};
 
     // Create the appropriate semantics actions.
     void moveToStart() => reorder(index, 0);
@@ -984,12 +1066,14 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     final bool isHorizontal = _scrollDirection == Axis.horizontal;
     // If the item can move to before its current position in the list.
     if (index > 0) {
-      semanticsActions[CustomSemanticsAction(label: localizations.reorderItemToStart)] = moveToStart;
+      semanticsActions[CustomSemanticsAction(label: localizations.reorderItemToStart)] =
+          moveToStart;
       String reorderItemBefore = localizations.reorderItemUp;
       if (isHorizontal) {
-        reorderItemBefore = Directionality.of(context) == TextDirection.ltr
-            ? localizations.reorderItemLeft
-            : localizations.reorderItemRight;
+        reorderItemBefore =
+            Directionality.of(context) == TextDirection.ltr
+                ? localizations.reorderItemLeft
+                : localizations.reorderItemRight;
       }
       semanticsActions[CustomSemanticsAction(label: reorderItemBefore)] = moveBefore;
     }
@@ -998,9 +1082,10 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     if (index < widget.itemCount - 1) {
       String reorderItemAfter = localizations.reorderItemDown;
       if (isHorizontal) {
-        reorderItemAfter = Directionality.of(context) == TextDirection.ltr
-            ? localizations.reorderItemRight
-            : localizations.reorderItemLeft;
+        reorderItemAfter =
+            Directionality.of(context) == TextDirection.ltr
+                ? localizations.reorderItemRight
+                : localizations.reorderItemLeft;
       }
       semanticsActions[CustomSemanticsAction(label: reorderItemAfter)] = moveAfter;
       semanticsActions[CustomSemanticsAction(label: localizations.reorderItemToEnd)] = moveToEnd;
@@ -1012,28 +1097,24 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
     //
     // Also apply the relevant custom accessibility actions for moving the item
     // up, down, to the start, and to the end of the list.
-    return Semantics(
-      container: true,
-      customSemanticsActions: semanticsActions,
-      child: child,
-    );
+    return Semantics(container: true, customSemanticsActions: semanticsActions, child: child);
   }
 
+  @protected
   @override
   Widget build(BuildContext context) {
     assert(debugCheckHasOverlay(context));
     final SliverChildBuilderDelegate childrenDelegate = SliverChildBuilderDelegate(
       _itemBuilder,
-      // When dragging, the dragged item is still in the list but has been replaced
-      // by a zero height SizedBox, so that the gap can move around. To make the
-      // list extent stable we add a dummy entry to the end.
-      childCount: widget.itemCount + (_dragInfo != null ? 1 : 0),
+      childCount: widget.itemCount,
       findChildIndexCallback: widget.findChildIndexCallback,
     );
     if (widget.itemExtent != null) {
-      return SliverFixedExtentList(
+      return SliverFixedExtentList(delegate: childrenDelegate, itemExtent: widget.itemExtent!);
+    } else if (widget.itemExtentBuilder != null) {
+      return SliverVariedExtentList(
         delegate: childrenDelegate,
-        itemExtent: widget.itemExtent!,
+        itemExtentBuilder: widget.itemExtentBuilder!,
       );
     } else if (widget.prototypeItem != null) {
       return SliverPrototypeExtentList(
@@ -1047,11 +1128,11 @@ class SliverReorderableListState extends State<SliverReorderableList> with Ticke
 
 class _ReorderableItem extends StatefulWidget {
   const _ReorderableItem({
-    required Key key,
+    required Key super.key,
     required this.index,
     required this.child,
     required this.capturedThemes,
-  }) : super(key: key);
+  });
 
   final int index;
   final Widget child;
@@ -1079,6 +1160,7 @@ class _ReorderableItemState extends State<_ReorderableItem> {
       });
     }
   }
+
   bool _dragging = false;
 
   @override
@@ -1107,13 +1189,11 @@ class _ReorderableItemState extends State<_ReorderableItem> {
   @override
   Widget build(BuildContext context) {
     if (_dragging) {
-      return const SizedBox();
+      final Size size = _extentSize(_listState._dragInfo!.itemExtent, _listState._scrollDirection);
+      return SizedBox.fromSize(size: size);
     }
     _listState._registerItem(this);
-    return Transform(
-      transform: Matrix4.translationValues(offset.dx, offset.dy, 0.0),
-      child: widget.child,
-    );
+    return Transform.translate(offset: offset, child: widget.child);
   }
 
   @override
@@ -1130,27 +1210,39 @@ class _ReorderableItemState extends State<_ReorderableItem> {
     return _targetOffset;
   }
 
-  void updateForGap(int gapIndex, double gapExtent, bool animate, bool reverse) {
-    final Offset newTargetOffset = (gapIndex <= index)
-        ? _extentOffset(reverse ? -gapExtent : gapExtent, _listState._scrollDirection)
-        : Offset.zero;
+  void updateForGap(int dragIndex, int gapIndex, double gapExtent, bool animate, bool reverse) {
+    // An offset needs to be added to create a gap when we are between the
+    // moving element (dragIndex) and the current gap position (gapIndex).
+    // For how to update the gap position, refer to [_dragUpdateItems].
+    final Offset newTargetOffset;
+    if (gapIndex < dragIndex && index < dragIndex && index >= gapIndex) {
+      newTargetOffset = _extentOffset(
+        reverse ? -gapExtent : gapExtent,
+        _listState._scrollDirection,
+      );
+    } else if (gapIndex > dragIndex && index > dragIndex && index < gapIndex) {
+      newTargetOffset = _extentOffset(
+        reverse ? gapExtent : -gapExtent,
+        _listState._scrollDirection,
+      );
+    } else {
+      newTargetOffset = Offset.zero;
+    }
     if (newTargetOffset != _targetOffset) {
       _targetOffset = newTargetOffset;
       if (animate) {
         if (_offsetAnimation == null) {
-          _offsetAnimation = AnimationController(
-            vsync: _listState,
-            duration: const Duration(milliseconds: 250),
-          )
-            ..addListener(rebuild)
-            ..addStatusListener((AnimationStatus status) {
-              if (status == AnimationStatus.completed) {
-                _startOffset = _targetOffset;
-                _offsetAnimation!.dispose();
-                _offsetAnimation = null;
-              }
-            })
-            ..forward();
+          _offsetAnimation =
+              AnimationController(vsync: _listState, duration: const Duration(milliseconds: 250))
+                ..addListener(rebuild)
+                ..addStatusListener((AnimationStatus status) {
+                  if (status.isCompleted) {
+                    _startOffset = _targetOffset;
+                    _offsetAnimation!.dispose();
+                    _offsetAnimation = null;
+                  }
+                })
+                ..forward();
         } else {
           _startOffset = offset;
           _offsetAnimation!.forward(from: 0.0);
@@ -1253,8 +1345,7 @@ class ReorderableDragStartListener extends StatelessWidget {
     list?.startItemDragReorder(
       index: index,
       event: event,
-      recognizer: createRecognizer()
-        ..gestureSettings = gestureSettings,
+      recognizer: createRecognizer()..gestureSettings = gestureSettings,
     );
   }
 }
@@ -1307,15 +1398,23 @@ class _DragInfo extends Drag {
     this.proxyDecorator,
     required this.tickerProvider,
   }) {
+    assert(debugMaybeDispatchCreated('widgets', '_DragInfo', this));
     final RenderBox itemRenderBox = item.context.findRenderObject()! as RenderBox;
     listState = item._listState;
     index = item.index;
     child = item.widget.child;
     capturedThemes = item.widget.capturedThemes;
-    dragPosition = initialPosition;
     dragOffset = itemRenderBox.globalToLocal(initialPosition);
     itemSize = item.context.size!;
+    _rawDragPosition = initialPosition;
+    if (listState.widget.dragBoundaryProvider != null) {
+      boundary = listState.widget.dragBoundaryProvider!.call(listState.context);
+    } else {
+      boundary = DragBoundary.forRectMaybeOf(listState.context);
+    }
+    dragPosition = _adjustedDragOffset(initialPosition);
     itemExtent = _sizeExtent(itemSize, scrollDirection);
+    itemLayoutConstraints = itemRenderBox.constraints;
     scrollable = Scrollable.of(item.context);
   }
 
@@ -1327,38 +1426,41 @@ class _DragInfo extends Drag {
   final ReorderItemProxyDecorator? proxyDecorator;
   final TickerProvider tickerProvider;
 
+  late DragBoundaryDelegate<Rect>? boundary;
   late SliverReorderableListState listState;
   late int index;
   late Widget child;
   late Offset dragPosition;
   late Offset dragOffset;
   late Size itemSize;
+  late BoxConstraints itemLayoutConstraints;
   late double itemExtent;
   late CapturedThemes capturedThemes;
   ScrollableState? scrollable;
   AnimationController? _proxyAnimation;
+  late Offset _rawDragPosition;
 
   void dispose() {
+    assert(debugMaybeDispatchDisposed(this));
     _proxyAnimation?.dispose();
   }
 
   void startDrag() {
-    _proxyAnimation = AnimationController(
-      vsync: tickerProvider,
-      duration: const Duration(milliseconds: 250),
-    )
-    ..addStatusListener((AnimationStatus status) {
-      if (status == AnimationStatus.dismissed) {
-        _dropCompleted();
-      }
-    })
-    ..forward();
+    _proxyAnimation =
+        AnimationController(vsync: tickerProvider, duration: const Duration(milliseconds: 250))
+          ..addStatusListener((AnimationStatus status) {
+            if (status.isDismissed) {
+              _dropCompleted();
+            }
+          })
+          ..forward();
   }
 
   @override
   void update(DragUpdateDetails details) {
     final Offset delta = _restrictAxis(details.delta, scrollDirection);
-    dragPosition += delta;
+    _rawDragPosition += delta;
+    dragPosition = _adjustedDragOffset(_rawDragPosition);
     onUpdate?.call(this, dragPosition, details.delta);
   }
 
@@ -1375,6 +1477,18 @@ class _DragInfo extends Drag {
     onCancel?.call(this);
   }
 
+  Offset _adjustedDragOffset(Offset offset) {
+    if (boundary == null) {
+      return offset;
+    }
+    final Offset adjOffset =
+        boundary!
+            .nearestPositionWithinBoundary((offset - dragOffset) & itemSize)
+            .shift(dragOffset)
+            .topLeft;
+    return adjOffset;
+  }
+
   void _dropCompleted() {
     _proxyAnimation?.dispose();
     _proxyAnimation = null;
@@ -1387,6 +1501,7 @@ class _DragInfo extends Drag {
         listState: listState,
         index: index,
         size: itemSize,
+        constraints: itemLayoutConstraints,
         animation: _proxyAnimation!,
         position: dragPosition - dragOffset - _overlayOrigin(context),
         proxyDecorator: proxyDecorator,
@@ -1409,6 +1524,7 @@ class _DragItemProxy extends StatelessWidget {
     required this.child,
     required this.position,
     required this.size,
+    required this.constraints,
     required this.animation,
     required this.proxyDecorator,
   });
@@ -1418,6 +1534,7 @@ class _DragItemProxy extends StatelessWidget {
   final Widget child;
   final Offset position;
   final Size size;
+  final BoxConstraints constraints;
   final AnimationController animation;
   final ReorderItemProxyDecorator? proxyDecorator;
 
@@ -1436,7 +1553,12 @@ class _DragItemProxy extends StatelessWidget {
           Offset effectivePosition = position;
           final Offset? dropPosition = listState._finalDropPosition;
           if (dropPosition != null) {
-            effectivePosition = Offset.lerp(dropPosition - overlayOrigin, effectivePosition, Curves.easeOut.transform(animation.value))!;
+            effectivePosition =
+                Offset.lerp(
+                  dropPosition - overlayOrigin,
+                  effectivePosition,
+                  Curves.easeOut.transform(animation.value),
+                )!;
           }
           return Positioned(
             left: effectivePosition.dx,
@@ -1444,7 +1566,17 @@ class _DragItemProxy extends StatelessWidget {
             child: SizedBox(
               width: size.width,
               height: size.height,
-              child: child,
+              child: OverflowBox(
+                minWidth: constraints.minWidth,
+                minHeight: constraints.minHeight,
+                maxWidth: constraints.maxWidth,
+                maxHeight: constraints.maxHeight,
+                alignment:
+                    listState._scrollDirection == Axis.horizontal
+                        ? Alignment.centerLeft
+                        : Alignment.topCenter,
+                child: child,
+              ),
             ),
           );
         },
@@ -1455,39 +1587,38 @@ class _DragItemProxy extends StatelessWidget {
 }
 
 double _sizeExtent(Size size, Axis scrollDirection) {
-  switch (scrollDirection) {
-    case Axis.horizontal:
-      return size.width;
-    case Axis.vertical:
-      return size.height;
-  }
+  return switch (scrollDirection) {
+    Axis.horizontal => size.width,
+    Axis.vertical => size.height,
+  };
+}
+
+Size _extentSize(double extent, Axis scrollDirection) {
+  return switch (scrollDirection) {
+    Axis.horizontal => Size(extent, 0),
+    Axis.vertical => Size(0, extent),
+  };
 }
 
 double _offsetExtent(Offset offset, Axis scrollDirection) {
-  switch (scrollDirection) {
-    case Axis.horizontal:
-      return offset.dx;
-    case Axis.vertical:
-      return offset.dy;
-  }
+  return switch (scrollDirection) {
+    Axis.horizontal => offset.dx,
+    Axis.vertical => offset.dy,
+  };
 }
 
 Offset _extentOffset(double extent, Axis scrollDirection) {
-  switch (scrollDirection) {
-    case Axis.horizontal:
-      return Offset(extent, 0.0);
-    case Axis.vertical:
-      return Offset(0.0, extent);
-  }
+  return switch (scrollDirection) {
+    Axis.horizontal => Offset(extent, 0.0),
+    Axis.vertical => Offset(0.0, extent),
+  };
 }
 
 Offset _restrictAxis(Offset offset, Axis scrollDirection) {
-  switch (scrollDirection) {
-    case Axis.horizontal:
-      return Offset(offset.dx, 0.0);
-    case Axis.vertical:
-      return Offset(0.0, offset.dy);
-  }
+  return switch (scrollDirection) {
+    Axis.horizontal => Offset(offset.dx, 0.0),
+    Axis.vertical => Offset(0.0, offset.dy),
+  };
 }
 
 // A global key that takes its identity from the object and uses a value of a
@@ -1497,7 +1628,6 @@ Offset _restrictAxis(Offset offset, Axis scrollDirection) {
 // of the objects used to generate widgets.
 @optionalTypeArgs
 class _ReorderableItemGlobalKey extends GlobalObjectKey {
-
   const _ReorderableItemGlobalKey(this.subKey, this.index, this.state) : super(subKey);
 
   final Key subKey;
@@ -1509,10 +1639,10 @@ class _ReorderableItemGlobalKey extends GlobalObjectKey {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is _ReorderableItemGlobalKey
-        && other.subKey == subKey
-        && other.index == index
-        && other.state == state;
+    return other is _ReorderableItemGlobalKey &&
+        other.subKey == subKey &&
+        other.index == index &&
+        other.state == state;
   }
 
   @override
