@@ -2,6 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'scroll_view.dart';
+/// @docImport 'sliver.dart';
+library;
+
 import 'dart:collection';
 
 import 'package:flutter/foundation.dart';
@@ -12,16 +16,17 @@ import 'debug.dart';
 import 'framework.dart';
 import 'image.dart';
 
-export 'package:flutter/rendering.dart' show
-  FixedColumnWidth,
-  FlexColumnWidth,
-  FractionColumnWidth,
-  IntrinsicColumnWidth,
-  MaxColumnWidth,
-  MinColumnWidth,
-  TableBorder,
-  TableCellVerticalAlignment,
-  TableColumnWidth;
+export 'package:flutter/rendering.dart'
+    show
+        FixedColumnWidth,
+        FlexColumnWidth,
+        FractionColumnWidth,
+        IntrinsicColumnWidth,
+        MaxColumnWidth,
+        MinColumnWidth,
+        TableBorder,
+        TableCellVerticalAlignment,
+        TableColumnWidth;
 
 /// A horizontal group of cells in a [Table].
 ///
@@ -32,7 +37,7 @@ export 'package:flutter/rendering.dart' show
 @immutable
 class TableRow {
   /// Creates a row in a [Table].
-  const TableRow({ this.key, this.decoration, this.children = const <Widget>[]});
+  const TableRow({this.key, this.decoration, this.children = const <Widget>[]});
 
   /// An identifier for the row.
   final LocalKey? key;
@@ -72,7 +77,7 @@ class TableRow {
 }
 
 class _TableElementRow {
-  const _TableElementRow({ this.key, required this.children });
+  const _TableElementRow({this.key, required this.children});
   final LocalKey? key;
   final List<Element> children;
 }
@@ -121,9 +126,16 @@ class Table extends RenderObjectWidget {
     this.border,
     this.defaultVerticalAlignment = TableCellVerticalAlignment.top,
     this.textBaseline, // NO DEFAULT: we don't know what the text's baseline should be
-  }) : assert(defaultVerticalAlignment != TableCellVerticalAlignment.baseline || textBaseline != null, 'textBaseline is required if you specify the defaultVerticalAlignment with TableCellVerticalAlignment.baseline'),
+  }) : assert(
+         defaultVerticalAlignment != TableCellVerticalAlignment.baseline || textBaseline != null,
+         'textBaseline is required if you specify the defaultVerticalAlignment with TableCellVerticalAlignment.baseline',
+       ),
        assert(() {
-         if (children.any((TableRow row1) => row1.key != null && children.any((TableRow row2) => row1 != row2 && row1.key == row2.key))) {
+         if (children.any(
+           (TableRow row1) =>
+               row1.key != null &&
+               children.any((TableRow row2) => row1 != row2 && row1.key == row2.key),
+         )) {
            throw FlutterError(
              'Two or more TableRow children of this Table had the same key.\n'
              'All the keyed TableRow children of a Table must have different Keys.',
@@ -150,16 +162,22 @@ class Table extends RenderObjectWidget {
          }
          return true;
        }()),
-       _rowDecorations = children.any((TableRow row) => row.decoration != null)
-                              ? children.map<Decoration?>((TableRow row) => row.decoration).toList(growable: false)
-                              : null {
+       _rowDecorations =
+           children.any((TableRow row) => row.decoration != null)
+               ? children.map<Decoration?>((TableRow row) => row.decoration).toList(growable: false)
+               : null {
     assert(() {
-      final List<Widget> flatChildren = children.expand<Widget>((TableRow row) => row.children).toList(growable: false);
-      return !debugChildrenHaveDuplicateKeys(this, flatChildren, message:
-        'Two or more cells in this Table contain widgets with the same key.\n'
-        'Every widget child of every TableRow in a Table must have different keys. The cells of a Table are '
-        'flattened out for processing, so separate cells cannot have duplicate keys even if they are in '
-        'different rows.',
+      final List<Widget> flatChildren = children
+          .expand<Widget>((TableRow row) => row.children)
+          .toList(growable: false);
+      return !debugChildrenHaveDuplicateKeys(
+        this,
+        flatChildren,
+        message:
+            'Two or more cells in this Table contain widgets with the same key.\n'
+            'Every widget child of every TableRow in a Table must have different keys. The cells of a Table are '
+            'flattened out for processing, so separate cells cannot have duplicate keys even if they are in '
+            'different rows.',
       );
     }());
   }
@@ -265,7 +283,7 @@ class _TableElement extends RenderObjectElement {
   @override
   RenderTable get renderObject => super.renderObject as RenderTable;
 
-  List<_TableElementRow> _children = const<_TableElementRow>[];
+  List<_TableElementRow> _children = const <_TableElementRow>[];
 
   bool _doingMountOrUpdate = false;
 
@@ -275,16 +293,20 @@ class _TableElement extends RenderObjectElement {
     _doingMountOrUpdate = true;
     super.mount(parent, newSlot);
     int rowIndex = -1;
-    _children = (widget as Table).children.map<_TableElementRow>((TableRow row) {
-      int columnIndex = 0;
-      rowIndex += 1;
-      return _TableElementRow(
-        key: row.key,
-        children: row.children.map<Element>((Widget child) {
-          return inflateWidget(child, _TableSlot(columnIndex++, rowIndex));
-        }).toList(growable: false),
-      );
-    }).toList(growable: false);
+    _children = (widget as Table).children
+        .map<_TableElementRow>((TableRow row) {
+          int columnIndex = 0;
+          rowIndex += 1;
+          return _TableElementRow(
+            key: row.key,
+            children: row.children
+                .map<Element>((Widget child) {
+                  return inflateWidget(child, _TableSlot(columnIndex++, rowIndex));
+                })
+                .toList(growable: false),
+          );
+        })
+        .toList(growable: false);
     _updateRenderObjectChildren();
     assert(_doingMountOrUpdate);
     _doingMountOrUpdate = false;
@@ -323,7 +345,8 @@ class _TableElement extends RenderObjectElement {
         oldKeyedRows[row.key!] = row.children;
       }
     }
-    final Iterator<_TableElementRow> oldUnkeyedRows = _children.where((_TableElementRow row) => row.key == null).iterator;
+    final Iterator<_TableElementRow> oldUnkeyedRows =
+        _children.where((_TableElementRow row) => row.key == null).iterator;
     final List<_TableElementRow> newChildren = <_TableElementRow>[];
     final Set<List<Element>> taken = <List<Element>>{};
     for (int rowIndex = 0; rowIndex < newWidget.children.length; rowIndex++) {
@@ -341,15 +364,28 @@ class _TableElement extends RenderObjectElement {
         row.children.length,
         (int columnIndex) => _TableSlot(columnIndex, rowIndex),
       );
-      newChildren.add(_TableElementRow(
-        key: row.key,
-        children: updateChildren(oldChildren, row.children, forgottenChildren: _forgottenChildren, slots: slots),
-      ));
+      newChildren.add(
+        _TableElementRow(
+          key: row.key,
+          children: updateChildren(
+            oldChildren,
+            row.children,
+            forgottenChildren: _forgottenChildren,
+            slots: slots,
+          ),
+        ),
+      );
     }
     while (oldUnkeyedRows.moveNext()) {
-      updateChildren(oldUnkeyedRows.current.children, const <Widget>[], forgottenChildren: _forgottenChildren);
+      updateChildren(
+        oldUnkeyedRows.current.children,
+        const <Widget>[],
+        forgottenChildren: _forgottenChildren,
+      );
     }
-    for (final List<Element> oldChildren in oldKeyedRows.values.where((List<Element> list) => !taken.contains(list))) {
+    for (final List<Element> oldChildren in oldKeyedRows.values.where(
+      (List<Element> list) => !taken.contains(list),
+    )) {
       updateChildren(oldChildren, const <Widget>[], forgottenChildren: _forgottenChildren);
     }
 
@@ -400,26 +436,36 @@ class _TableElement extends RenderObjectElement {
 ///
 /// To create an empty [TableCell], provide a [SizedBox.shrink]
 /// as the [child].
-class TableCell extends ParentDataWidget<TableCellParentData> {
+class TableCell extends StatelessWidget {
   /// Creates a widget that controls how a child of a [Table] is aligned.
-  const TableCell({
-    super.key,
-    this.verticalAlignment,
-    required super.child,
-  });
+  const TableCell({super.key, this.verticalAlignment, required this.child});
 
   /// How this cell is aligned vertically.
   final TableCellVerticalAlignment? verticalAlignment;
 
+  /// The child of this cell.
+  final Widget child;
+
+  @override
+  Widget build(BuildContext context) {
+    return _TableCell(
+      verticalAlignment: verticalAlignment,
+      child: Semantics(role: SemanticsRole.cell, child: child),
+    );
+  }
+}
+
+class _TableCell extends ParentDataWidget<TableCellParentData> {
+  const _TableCell({this.verticalAlignment, required super.child});
+
+  final TableCellVerticalAlignment? verticalAlignment;
+
   @override
   void applyParentData(RenderObject renderObject) {
     final TableCellParentData parentData = renderObject.parentData! as TableCellParentData;
     if (parentData.verticalAlignment != verticalAlignment) {
       parentData.verticalAlignment = verticalAlignment;
-      final RenderObject? targetParent = renderObject.parent;
-      if (targetParent is RenderObject) {
-        targetParent.markNeedsLayout();
-      }
+      renderObject.parent?.markNeedsLayout();
     }
   }
 
@@ -429,7 +475,9 @@ class TableCell extends ParentDataWidget<TableCellParentData> {
   @override
   void debugFillProperties(DiagnosticPropertiesBuilder properties) {
     super.debugFillProperties(properties);
-    properties.add(EnumProperty<TableCellVerticalAlignment>('verticalAlignment', verticalAlignment));
+    properties.add(
+      EnumProperty<TableCellVerticalAlignment>('verticalAlignment', verticalAlignment),
+    );
   }
 }
 
@@ -445,9 +493,7 @@ class _TableSlot with Diagnosticable {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is _TableSlot
-        && column == other.column
-        && row == other.row;
+    return other is _TableSlot && column == other.column && row == other.row;
   }
 
   @override
