@@ -2,6 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/cupertino.dart';
+/// @docImport 'package:flutter/material.dart';
+library;
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/rendering.dart';
 
@@ -155,14 +159,8 @@ mixin ToggleableStateMixin<S extends StatefulWidget> on TickerProviderStateMixin
       curve: Curves.easeIn,
       reverseCurve: Curves.easeOut,
     );
-    _reactionController = AnimationController(
-      duration: _reactionAnimationDuration,
-      vsync: this,
-    );
-    _reaction = CurvedAnimation(
-      parent: _reactionController,
-      curve: Curves.fastOutSlowIn,
-    );
+    _reactionController = AnimationController(duration: _reactionAnimationDuration, vsync: this);
+    _reaction = CurvedAnimation(parent: _reactionController, curve: Curves.fastOutSlowIn);
     _reactionHoverFadeController = AnimationController(
       duration: _kReactionFadeDuration,
       value: _hovering || _focused ? 1.0 : 0.0,
@@ -253,7 +251,9 @@ mixin ToggleableStateMixin<S extends StatefulWidget> on TickerProviderStateMixin
 
   void _handleTapEnd([TapUpDetails? _]) {
     if (_downPosition != null) {
-      setState(() { _downPosition = null; });
+      setState(() {
+        _downPosition = null;
+      });
     }
     _reactionController.reverse();
   }
@@ -261,7 +261,9 @@ mixin ToggleableStateMixin<S extends StatefulWidget> on TickerProviderStateMixin
   bool _focused = false;
   void _handleFocusHighlightChanged(bool focused) {
     if (focused != _focused) {
-      setState(() { _focused = focused; });
+      setState(() {
+        _focused = focused;
+      });
       if (focused) {
         _reactionFocusFadeController.forward();
       } else {
@@ -273,7 +275,9 @@ mixin ToggleableStateMixin<S extends StatefulWidget> on TickerProviderStateMixin
   bool _hovering = false;
   void _handleHoverChanged(bool hovering) {
     if (hovering != _hovering) {
-      setState(() { _hovering = hovering; });
+      setState(() {
+        _hovering = hovering;
+      });
       if (hovering) {
         _reactionHoverFadeController.forward();
       } else {
@@ -342,13 +346,7 @@ mixin ToggleableStateMixin<S extends StatefulWidget> on TickerProviderStateMixin
         onTap: isInteractive ? _handleTap : null,
         onTapUp: isInteractive ? _handleTapEnd : null,
         onTapCancel: isInteractive ? _handleTapEnd : null,
-        child: Semantics(
-          enabled: isInteractive,
-          child: CustomPaint(
-            size: size,
-            painter: painter,
-          ),
-        ),
+        child: Semantics(enabled: isInteractive, child: CustomPaint(size: size, painter: painter)),
       ),
     );
   }
@@ -581,23 +579,24 @@ abstract class ToggleablePainter extends ChangeNotifier implements CustomPainter
     required Offset origin,
   }) {
     if (!reaction.isDismissed || !reactionFocusFade.isDismissed || !reactionHoverFade.isDismissed) {
-      final Paint reactionPaint = Paint()
-        ..color = Color.lerp(
-          Color.lerp(
-            Color.lerp(inactiveReactionColor, reactionColor, position.value),
-            hoverColor,
-            reactionHoverFade.value,
-          ),
-          focusColor,
-          reactionFocusFade.value,
-        )!;
+      final Paint reactionPaint =
+          Paint()
+            ..color =
+                Color.lerp(
+                  Color.lerp(
+                    Color.lerp(inactiveReactionColor, reactionColor, position.value),
+                    hoverColor,
+                    reactionHoverFade.value,
+                  ),
+                  focusColor,
+                  reactionFocusFade.value,
+                )!;
       final Animatable<double> radialReactionRadiusTween = Tween<double>(
         begin: 0.0,
         end: splashRadius,
       );
-      final double reactionRadius = isFocused || isHovered
-          ? splashRadius
-          : radialReactionRadiusTween.evaluate(reaction);
+      final double reactionRadius =
+          isFocused || isHovered ? splashRadius : radialReactionRadiusTween.evaluate(reaction);
       if (reactionRadius > 0.0) {
         canvas.drawCircle(origin + offset, reactionRadius, reactionPaint);
       }
