@@ -10,13 +10,7 @@ void main() {
     const Widget title = Text('CupertinoListTile');
 
     await tester.pumpWidget(
-      const CupertinoApp(
-        home: Center(
-          child: CupertinoListTile(
-            title: title,
-          ),
-        ),
-      ),
+      const CupertinoApp(home: Center(child: CupertinoListTile(title: title))),
     );
 
     expect(tester.widget<Text>(find.byType(Text)), title);
@@ -28,12 +22,7 @@ void main() {
 
     await tester.pumpWidget(
       const CupertinoApp(
-        home: Center(
-          child: CupertinoListTile(
-            title: Icon(CupertinoIcons.add),
-            subtitle: subtitle,
-          ),
-        ),
+        home: Center(child: CupertinoListTile(title: Icon(CupertinoIcons.add), subtitle: subtitle)),
       ),
     );
 
@@ -47,10 +36,7 @@ void main() {
     await tester.pumpWidget(
       const CupertinoApp(
         home: Center(
-          child: CupertinoListTile(
-            title: Icon(CupertinoIcons.add),
-            additionalInfo: additionalInfo,
-          ),
+          child: CupertinoListTile(title: Icon(CupertinoIcons.add), additionalInfo: additionalInfo),
         ),
       ),
     );
@@ -64,16 +50,14 @@ void main() {
 
     await tester.pumpWidget(
       const CupertinoApp(
-        home: Center(
-          child: CupertinoListTile(
-            title: Icon(CupertinoIcons.add),
-            trailing: trailing,
-          ),
-        ),
+        home: Center(child: CupertinoListTile(title: Icon(CupertinoIcons.add), trailing: trailing)),
       ),
     );
 
-    expect(tester.widget<CupertinoListTileChevron>(find.byType(CupertinoListTileChevron)), trailing);
+    expect(
+      tester.widget<CupertinoListTileChevron>(find.byType(CupertinoListTileChevron)),
+      trailing,
+    );
   });
 
   testWidgets('shows leading', (WidgetTester tester) async {
@@ -81,12 +65,7 @@ void main() {
 
     await tester.pumpWidget(
       const CupertinoApp(
-        home: Center(
-          child: CupertinoListTile(
-            leading: leading,
-            title: Text('CupertinoListTile'),
-          ),
-        ),
+        home: Center(child: CupertinoListTile(leading: leading, title: Text('CupertinoListTile'))),
       ),
     );
 
@@ -103,10 +82,7 @@ void main() {
           data: const MediaQueryData(),
           child: CupertinoListSection(
             children: const <Widget>[
-              CupertinoListTile(
-                title: Text('CupertinoListTile'),
-                backgroundColor: backgroundColor,
-              ),
+              CupertinoListTile(title: Text('CupertinoListTile'), backgroundColor: backgroundColor),
             ],
           ),
         ),
@@ -118,7 +94,9 @@ void main() {
     expect(container.color, backgroundColor);
   });
 
-  testWidgets('does not change backgroundColor when tapped if onTap is not provided', (WidgetTester tester) async {
+  testWidgets('does not change backgroundColor when tapped if onTap is not provided', (
+    WidgetTester tester,
+  ) async {
     const Color backgroundColor = CupertinoColors.systemBlue;
     const Color backgroundColorActivated = CupertinoColors.systemRed;
 
@@ -148,7 +126,9 @@ void main() {
     expect(container.color, backgroundColor);
   });
 
-  testWidgets('changes backgroundColor when tapped if onTap is provided', (WidgetTester tester) async {
+  testWidgets('changes backgroundColor when tapped if onTap is provided', (
+    WidgetTester tester,
+  ) async {
     const Color backgroundColor = CupertinoColors.systemBlue;
     const Color backgroundColorActivated = CupertinoColors.systemRed;
 
@@ -163,7 +143,9 @@ void main() {
                 title: const Text('CupertinoListTile'),
                 backgroundColor: backgroundColor,
                 backgroundColorActivated: backgroundColorActivated,
-                onTap: () async { await Future<void>.delayed(const Duration(milliseconds: 1), () {}); },
+                onTap: () async {
+                  await Future<void>.delayed(const Duration(milliseconds: 1), () {});
+                },
               ),
             ],
           ),
@@ -187,18 +169,16 @@ void main() {
     await tester.pumpAndSettle();
   });
 
-  testWidgets('does not contain GestureDetector if onTap is not provided', (WidgetTester tester) async {
+  testWidgets('does not contain GestureDetector if onTap is not provided', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
         child: MediaQuery(
           data: const MediaQueryData(),
           child: CupertinoListSection(
-            children: const <Widget>[
-              CupertinoListTile(
-                title: Text('CupertinoListTile'),
-              ),
-            ],
+            children: const <Widget>[CupertinoListTile(title: Text('CupertinoListTile'))],
           ),
         ),
       ),
@@ -216,10 +196,7 @@ void main() {
           data: const MediaQueryData(),
           child: CupertinoListSection(
             children: <Widget>[
-              CupertinoListTile(
-                title: const Text('CupertinoListTile'),
-                onTap: () async {},
-              ),
+              CupertinoListTile(title: const Text('CupertinoListTile'), onTap: () async {}),
             ],
           ),
         ),
@@ -238,7 +215,7 @@ void main() {
       CupertinoApp(
         home: Builder(
           builder: (BuildContext context) {
-             final Widget secondPage = Center(
+            final Widget secondPage = Center(
               child: CupertinoButton(
                 child: const Text('Go back'),
                 onPressed: () => Navigator.of(context).pop<void>(),
@@ -249,13 +226,14 @@ void main() {
                 textDirection: TextDirection.ltr,
                 child: MediaQuery(
                   data: const MediaQueryData(),
-                  child:CupertinoListTile(
+                  child: CupertinoListTile(
                     title: const Text('CupertinoListTile'),
                     backgroundColor: backgroundColor,
                     backgroundColorActivated: backgroundColorActivated,
-                    onTap: () => Navigator.of(context).push(CupertinoPageRoute<Widget>(
-                      builder: (BuildContext context) => secondPage,
-                    )),
+                    onTap:
+                        () => Navigator.of(context).push(
+                          CupertinoPageRoute<Widget>(builder: (BuildContext context) => secondPage),
+                        ),
                   ),
                 ),
               ),
@@ -288,10 +266,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.ltr,
-              child: CupertinoListTile(
-                title: title,
-                leading: leading,
-              ),
+              child: CupertinoListTile(title: title, leading: leading),
             ),
           ),
         ),
@@ -312,10 +287,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.ltr,
-              child: CupertinoListTile(
-                title: title,
-                subtitle: subtitle,
-              ),
+              child: CupertinoListTile(title: title, subtitle: subtitle),
             ),
           ),
         ),
@@ -337,10 +309,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.ltr,
-              child: CupertinoListTile(
-                title: title,
-                additionalInfo: additionalInfo,
-              ),
+              child: CupertinoListTile(title: title, additionalInfo: additionalInfo),
             ),
           ),
         ),
@@ -389,10 +358,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.rtl,
-              child: CupertinoListTile(
-                title: title,
-                leading: leading,
-              ),
+              child: CupertinoListTile(title: title, leading: leading),
             ),
           ),
         ),
@@ -413,10 +379,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.rtl,
-              child: CupertinoListTile(
-                title: title,
-                subtitle: subtitle,
-              ),
+              child: CupertinoListTile(title: title, subtitle: subtitle),
             ),
           ),
         ),
@@ -438,10 +401,7 @@ void main() {
           home: Center(
             child: Directionality(
               textDirection: TextDirection.rtl,
-              child: CupertinoListTile(
-                title: title,
-                additionalInfo: additionalInfo,
-              ),
+              child: CupertinoListTile(title: title, additionalInfo: additionalInfo),
             ),
           ),
         ),
@@ -486,10 +446,7 @@ void main() {
 
     Future<void> onTap() async {
       showTile = false;
-      await Future<void>.delayed(
-        const Duration(seconds: 1),
-        () => showTile = true,
-      );
+      await Future<void>.delayed(const Duration(seconds: 1), () => showTile = true);
     }
 
     Widget buildCupertinoListTile() {
@@ -498,13 +455,7 @@ void main() {
           child: Center(
             child: Column(
               mainAxisAlignment: MainAxisAlignment.center,
-              children: <Widget>[
-                if (showTile)
-                  CupertinoListTile(
-                    onTap: onTap,
-                    title: title,
-                  ),
-               ],
+              children: <Widget>[if (showTile) CupertinoListTile(onTap: onTap, title: title)],
             ),
           ),
         ),
@@ -524,9 +475,7 @@ void main() {
     await tester.pumpWidget(
       CupertinoApp(
         home: CupertinoPageScaffold(
-          child: CupertinoListTile(
-            title: Text('CupertinoListTile' * 10),
-          ),
+          child: CupertinoListTile(title: Text('CupertinoListTile' * 10)),
         ),
       ),
     );
@@ -538,10 +487,7 @@ void main() {
     await tester.pumpWidget(
       CupertinoApp(
         home: CupertinoPageScaffold(
-          child: CupertinoListTile(
-            title: const Text(''),
-            subtitle: Text('CupertinoListTile' * 10),
-          ),
+          child: CupertinoListTile(title: const Text(''), subtitle: Text('CupertinoListTile' * 10)),
         ),
       ),
     );
