@@ -461,8 +461,6 @@ void main() {
   testWidgets('Media padding is applied to CupertinoSliverNavigationBar', (
     WidgetTester tester,
   ) async {
-    final ScrollController scrollController = ScrollController();
-    addTearDown(scrollController.dispose);
     final Key leadingKey = GlobalKey();
     final Key middleKey = GlobalKey();
     final Key trailingKey = GlobalKey();
@@ -475,7 +473,6 @@ void main() {
           ),
           child: CupertinoPageScaffold(
             child: CustomScrollView(
-              controller: scrollController,
               slivers: <Widget>[
                 CupertinoSliverNavigationBar(
                   leading: Placeholder(key: leadingKey),
@@ -742,7 +739,7 @@ void main() {
     expect(tester.getBottomLeft(find.text('Title')).dy, 44.0); // Extension gone.
   });
 
-  testWidgets('Auto back/close button', (WidgetTester tester) async {
+  testWidgets('Auto back/cancel button', (WidgetTester tester) async {
     await tester.pumpWidget(
       const CupertinoApp(home: CupertinoNavigationBar(middle: Text('Home page'))),
     );
@@ -779,10 +776,10 @@ void main() {
     await tester.pump();
     await tester.pump(const Duration(milliseconds: 600));
 
-    expect(find.widgetWithText(CupertinoButton, 'Close'), findsOneWidget);
+    expect(find.widgetWithText(CupertinoButton, 'Cancel'), findsOneWidget);
 
     // Test popping goes back correctly.
-    await tester.tap(find.text('Close'));
+    await tester.tap(find.text('Cancel'));
 
     await tester.pump();
     await tester.pump(const Duration(milliseconds: 600));
@@ -797,6 +794,57 @@ void main() {
     expect(find.text('Home page'), findsOneWidget);
   });
 
+  testWidgets('Navigation bars in a CupertinoSheetRoute have no back button', (
+    WidgetTester tester,
+  ) async {
+    await tester.pumpWidget(
+      const CupertinoApp(home: CupertinoNavigationBar(middle: Text('Home page'))),
+    );
+
+    expect(find.byType(CupertinoButton), findsNothing);
+
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .push(
+          CupertinoSheetRoute<void>(
+            builder: (BuildContext context) {
+              return const CupertinoPageScaffold(
+                navigationBar: CupertinoNavigationBar(middle: Text('Page 2')),
+                child: Placeholder(),
+              );
+            },
+          ),
+        );
+
+    await tester.pump();
+    await tester.pump(const Duration(milliseconds: 600));
+
+    // No back button is found.
+    expect(find.byType(CupertinoButton), findsNothing);
+    expect(find.text(String.fromCharCode(CupertinoIcons.back.codePoint)), findsNothing);
+
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .push(
+          CupertinoSheetRoute<void>(
+            builder: (BuildContext context) {
+              return const CupertinoPageScaffold(
+                child: CustomScrollView(
+                  slivers: <Widget>[CupertinoSliverNavigationBar(largeTitle: Text('Page 3'))],
+                ),
+              );
+            },
+          ),
+        );
+
+    await tester.pump();
+    await tester.pump(const Duration(milliseconds: 600));
+
+    // No back button is found.
+    expect(find.byType(CupertinoButton), findsNothing);
+    expect(find.text(String.fromCharCode(CupertinoIcons.back.codePoint)), findsNothing);
+  });
+
   testWidgets('Long back label turns into "back"', (WidgetTester tester) async {
     await tester.pumpWidget(const CupertinoApp(home: Placeholder()));
 
@@ -2337,6 +2385,121 @@ void main() {
     },
   );
 
+  testWidgets(
+    'Large title and bottom snap up when partially scrolled over halfway up in always mode',
+    (WidgetTester tester) async {
+      final ScrollController scrollController = ScrollController();
+      addTearDown(scrollController.dispose);
+      const double largeTitleHeight = 52.0;
+      const double bottomHeight = 100.0;
+
+      await tester.pumpWidget(
+        CupertinoApp(
+          home: CustomScrollView(
+            controller: scrollController,
+            slivers: const <Widget>[
+              CupertinoSliverNavigationBar(
+                largeTitle: Text('Large title'),
+                middle: Text('middle'),
+                alwaysShowMiddle: false,
+                bottom: PreferredSize(
+                  preferredSize: Size.fromHeight(bottomHeight),
+                  child: Placeholder(),
+                ),
+                bottomMode: NavigationBarBottomMode.always,
+              ),
+              SliverFillRemaining(child: SizedBox(height: 1000.0)),
+            ],
+          ),
+        ),
+      );
+
+      final RenderAnimatedOpacity? renderOpacity =
+          tester
+              .element(find.text('middle'))
+              .findAncestorRenderObjectOfType<RenderAnimatedOpacity>();
+      final Finder bottomFinder = find.byType(Placeholder);
+
+      expect(renderOpacity?.opacity.value, 0.0);
+      expect(scrollController.position.pixels, 0.0);
+
+      // Scroll to just past the halfway point of the large title.
+      final TestGesture scrollGesture1 = await tester.startGesture(
+        tester.getCenter(find.byType(Scrollable)),
+      );
+      await scrollGesture1.moveBy(const Offset(0.0, -(largeTitleHeight / 2) - 1));
+      await scrollGesture1.up();
+      await tester.pumpAndSettle();
+
+      // Expect the large title to snap up to the persistent nav bar.
+      expect(scrollController.position.pixels, largeTitleHeight);
+      expect(renderOpacity?.opacity.value, 1.0);
+
+      // Scroll to just past the halfway point of the bottom widget.
+      final TestGesture scrollGesture2 = await tester.startGesture(
+        tester.getCenter(find.byType(Scrollable)),
+      );
+      await scrollGesture2.moveBy(const Offset(0.0, -(bottomHeight / 2) - 1));
+      await scrollGesture2.up();
+      await tester.pumpAndSettle();
+
+      // The bottom widget is still fully extended.
+      expect(scrollController.position.pixels, largeTitleHeight + (bottomHeight / 2) + 1);
+      expect(
+        tester.getBottomLeft(bottomFinder).dy - tester.getTopLeft(bottomFinder).dy,
+        bottomHeight,
+      );
+      expect(renderOpacity?.opacity.value, 1.0);
+    },
+  );
+
+  testWidgets(
+    'Large title and bottom snap down when partially scrolled halfway up or less in always mode',
+    (WidgetTester tester) async {
+      final ScrollController scrollController = ScrollController();
+      addTearDown(scrollController.dispose);
+      const double largeTitleHeight = 52.0;
+
+      await tester.pumpWidget(
+        CupertinoApp(
+          home: CustomScrollView(
+            controller: scrollController,
+            slivers: const <Widget>[
+              CupertinoSliverNavigationBar(
+                largeTitle: Text('Large title'),
+                middle: Text('middle'),
+                alwaysShowMiddle: false,
+                bottom: PreferredSize(preferredSize: Size.fromHeight(100.0), child: Placeholder()),
+                bottomMode: NavigationBarBottomMode.always,
+              ),
+              SliverFillRemaining(child: SizedBox(height: 1000.0)),
+            ],
+          ),
+        ),
+      );
+
+      final RenderAnimatedOpacity? renderOpacity =
+          tester
+              .element(find.text('middle'))
+              .findAncestorRenderObjectOfType<RenderAnimatedOpacity>();
+
+      expect(renderOpacity?.opacity.value, 0.0);
+      expect(scrollController.offset, 0.0);
+
+      // Scroll to the halfway point of the large title.
+      final TestGesture scrollGesture1 = await tester.startGesture(
+        tester.getCenter(find.byType(Scrollable)),
+      );
+      await scrollGesture1.moveBy(const Offset(0.0, -largeTitleHeight / 2));
+      await scrollGesture1.up();
+      await tester.pumpAndSettle();
+
+      // Expect the large title and bottom to snap back to their extended height.
+      expect(scrollController.position.pixels, 0.0);
+      expect(renderOpacity?.opacity.value, 0.0);
+    },
+  );
+
   testWidgets('CupertinoNavigationBar with bottom widget', (WidgetTester tester) async {
     const double persistentHeight = 44.0;
     const double bottomHeight = 10.0;
@@ -2445,6 +2608,69 @@ void main() {
     expect(find.widgetWithText(CupertinoButton, 'Cancel'), findsOneWidget);
   });
 
+  testWidgets('CupertinoSliverNavigationBar.search golden tests', (WidgetTester tester) async {
+    await tester.binding.setSurfaceSize(const Size(390, 850));
+    addTearDown(() => tester.binding.setSurfaceSize(null));
+    await tester.pumpWidget(
+      const CupertinoApp(
+        home: RepaintBoundary(
+          child: CustomScrollView(
+            slivers: <Widget>[
+              CupertinoSliverNavigationBar.search(
+                largeTitle: Text('Large title'),
+                searchField: CupertinoSearchTextField(),
+              ),
+              SliverFillRemaining(child: SizedBox(height: 300.0)),
+            ],
+          ),
+        ),
+      ),
+    );
+
+    await expectLater(
+      find.byType(CupertinoSliverNavigationBar),
+      matchesGoldenFile('nav_bar.search.inactive.png'),
+    );
+
+    // Tap the search field.
+    await tester.tap(find.byType(CupertinoSearchTextField), warnIfMissed: false);
+    await tester.pump();
+    // Pump halfway through the animation.
+    await tester.pump(const Duration(milliseconds: 150));
+
+    await expectLater(
+      find.byType(CupertinoSliverNavigationBar),
+      matchesGoldenFile('nav_bar.search.transition_forward.png'),
+    );
+
+    // Pump to the end of the animation.
+    await tester.pump(const Duration(milliseconds: 300));
+
+    await expectLater(
+      find.byType(CupertinoSliverNavigationBar),
+      matchesGoldenFile('nav_bar.search.active.png'),
+    );
+
+    // Tap the 'Cancel' button to exit the search view.
+    await tester.tap(find.widgetWithText(CupertinoButton, 'Cancel'));
+    await tester.pump();
+    // Pump halfway through the animation.
+    await tester.pump(const Duration(milliseconds: 150));
+
+    await expectLater(
+      find.byType(CupertinoSliverNavigationBar),
+      matchesGoldenFile('nav_bar.search.transition_backward.png'),
+    );
+
+    // Pump for the duration of the search field animation.
+    await tester.pump(const Duration(milliseconds: 300));
+
+    await expectLater(
+      find.byType(CupertinoSliverNavigationBar),
+      matchesGoldenFile('nav_bar.search.inactive.png'),
+    );
+  });
+
   testWidgets('onSearchableBottomTap callback', (WidgetTester tester) async {
     const Color activeSearchColor = Color(0x0000000A);
     const Color inactiveSearchColor = Color(0x0000000B);
