@@ -27,13 +27,9 @@ typedef GestureTest = void Function(GestureTester tester);
 
 @isTest
 void testGesture(String description, GestureTest callback, {LeakTesting? experimentalLeakTesting}) {
-  testWidgets(
-    description,
-    (_) async {
-      FakeAsync().run((FakeAsync async) {
-        callback(GestureTester._(async));
-      });
-    },
-    experimentalLeakTesting: experimentalLeakTesting,
-  );
+  testWidgets(description, (_) async {
+    FakeAsync().run((FakeAsync async) {
+      callback(GestureTester._(async));
+    });
+  }, experimentalLeakTesting: experimentalLeakTesting);
 }
