@@ -6,40 +6,23 @@ import 'dart:ui' show VoidCallback;
 
 import 'package:flutter/gestures.dart';
 import 'package:flutter_test/flutter_test.dart';
+import 'package:leak_tracker_flutter_testing/leak_tracker_flutter_testing.dart';
 
 import 'gesture_tester.dart';
 
 // Down/move/up pair 1: normal tap sequence
-const PointerDownEvent down = PointerDownEvent(
-  pointer: 5,
-  position: Offset(10, 10),
-);
+const PointerDownEvent down = PointerDownEvent(pointer: 5, position: Offset(10, 10));
 
-const PointerMoveEvent move = PointerMoveEvent(
-  pointer: 5,
-  position: Offset(15, 15),
-);
+const PointerMoveEvent move = PointerMoveEvent(pointer: 5, position: Offset(15, 15));
 
-const PointerUpEvent up = PointerUpEvent(
-  pointer: 5,
-  position: Offset(15, 15),
-);
+const PointerUpEvent up = PointerUpEvent(pointer: 5, position: Offset(15, 15));
 
 // Down/move/up pair 2: tap sequence with a large move in the middle
-const PointerDownEvent down2 = PointerDownEvent(
-  pointer: 6,
-  position: Offset(10, 10),
-);
+const PointerDownEvent down2 = PointerDownEvent(pointer: 6, position: Offset(10, 10));
 
-const PointerMoveEvent move2 = PointerMoveEvent(
-  pointer: 6,
-  position: Offset(100, 200),
-);
+const PointerMoveEvent move2 = PointerMoveEvent(pointer: 6, position: Offset(100, 200));
 
-const PointerUpEvent up2 = PointerUpEvent(
-  pointer: 6,
-  position: Offset(100, 200),
-);
+const PointerUpEvent up2 = PointerUpEvent(pointer: 6, position: Offset(100, 200));
 
 void main() {
   TestWidgetsFlutterBinding.ensureInitialized();
@@ -49,19 +32,20 @@ void main() {
     expect(recognizer, hasAGoodToStringDeep);
   });
 
-  test('OffsetPair', () {
-    const OffsetPair offset1 = OffsetPair(
-      local: Offset(10, 20),
-      global: Offset(30, 40),
+  test('GestureRecognizer dispatches memory events', () async {
+    await expectLater(
+      await memoryEvents(() => TestGestureRecognizer().dispose(), TestGestureRecognizer),
+      areCreateAndDispose,
     );
+  });
+
+  test('OffsetPair', () {
+    const OffsetPair offset1 = OffsetPair(local: Offset(10, 20), global: Offset(30, 40));
 
     expect(offset1.local, const Offset(10, 20));
     expect(offset1.global, const Offset(30, 40));
 
-    const OffsetPair offset2 = OffsetPair(
-      local: Offset(50, 60),
-      global: Offset(70, 80),
-    );
+    const OffsetPair offset2 = OffsetPair(local: Offset(50, 60), global: Offset(70, 80));
 
     final OffsetPair sum = offset2 + offset1;
     expect(sum.local, const Offset(60, 80));
@@ -72,30 +56,18 @@ void main() {
     expect(difference.global, const Offset(40, 40));
   });
 
-  testWidgets('EagerGestureRecognizer asserts when kind and supportedDevices are both set', (WidgetTester tester) async {
-    expect(
-      () {
-        EagerGestureRecognizer(
-            kind: PointerDeviceKind.touch,
-            supportedDevices: <PointerDeviceKind>{ PointerDeviceKind.touch },
-        );
-      },
-      throwsA(
-        isA<AssertionError>().having((AssertionError error) => error.toString(),
-        'description', contains('kind == null || supportedDevices == null')),
-      ),
-    );
-  });
-
   group('PrimaryPointerGestureRecognizer', () {
     testGesture('cleans up state after winning arena', (GestureTester tester) {
       final List<String> resolutions = <String>[];
       final IndefiniteGestureRecognizer indefinite = IndefiniteGestureRecognizer();
-      final TestPrimaryPointerGestureRecognizer<PointerUpEvent> accepting = TestPrimaryPointerGestureRecognizer<PointerUpEvent>(
-        GestureDisposition.accepted,
-        onAcceptGesture: () => resolutions.add('accepted'),
-        onRejectGesture: () => resolutions.add('rejected'),
-      );
+      addTearDown(indefinite.dispose);
+      final TestPrimaryPointerGestureRecognizer<PointerUpEvent> accepting =
+          TestPrimaryPointerGestureRecognizer<PointerUpEvent>(
+            GestureDisposition.accepted,
+            onAcceptGesture: () => resolutions.add('accepted'),
+            onRejectGesture: () => resolutions.add('rejected'),
+          );
+      addTearDown(accepting.dispose);
       expect(accepting.state, GestureRecognizerState.ready);
       expect(accepting.primaryPointer, isNull);
       expect(accepting.initialPosition, isNull);
@@ -122,11 +94,14 @@ void main() {
     testGesture('cleans up state after losing arena', (GestureTester tester) {
       final List<String> resolutions = <String>[];
       final IndefiniteGestureRecognizer indefinite = IndefiniteGestureRecognizer();
-      final TestPrimaryPointerGestureRecognizer<PointerMoveEvent> rejecting = TestPrimaryPointerGestureRecognizer<PointerMoveEvent>(
-        GestureDisposition.rejected,
-        onAcceptGesture: () => resolutions.add('accepted'),
-        onRejectGesture: () => resolutions.add('rejected'),
-      );
+      addTearDown(indefinite.dispose);
+      final TestPrimaryPointerGestureRecognizer<PointerMoveEvent> rejecting =
+          TestPrimaryPointerGestureRecognizer<PointerMoveEvent>(
+            GestureDisposition.rejected,
+            onAcceptGesture: () => resolutions.add('accepted'),
+            onRejectGesture: () => resolutions.add('rejected'),
+          );
+      addTearDown(rejecting.dispose);
       expect(rejecting.state, GestureRecognizerState.ready);
       expect(rejecting.primaryPointer, isNull);
       expect(rejecting.initialPosition, isNull);
@@ -160,13 +135,16 @@ void main() {
     testGesture('works properly when recycled', (GestureTester tester) {
       final List<String> resolutions = <String>[];
       final IndefiniteGestureRecognizer indefinite = IndefiniteGestureRecognizer();
-      final TestPrimaryPointerGestureRecognizer<PointerUpEvent> accepting = TestPrimaryPointerGestureRecognizer<PointerUpEvent>(
-        GestureDisposition.accepted,
-        preAcceptSlopTolerance: 15,
-        postAcceptSlopTolerance: 1000,
-        onAcceptGesture: () => resolutions.add('accepted'),
-        onRejectGesture: () => resolutions.add('rejected'),
-      );
+      addTearDown(indefinite.dispose);
+      final TestPrimaryPointerGestureRecognizer<PointerUpEvent> accepting =
+          TestPrimaryPointerGestureRecognizer<PointerUpEvent>(
+            GestureDisposition.accepted,
+            preAcceptSlopTolerance: 15,
+            postAcceptSlopTolerance: 1000,
+            onAcceptGesture: () => resolutions.add('accepted'),
+            onRejectGesture: () => resolutions.add('rejected'),
+          );
+      addTearDown(accepting.dispose);
 
       // Send one complete pointer sequence
       indefinite.addPointer(down);
@@ -193,19 +171,19 @@ void main() {
 }
 
 class TestGestureRecognizer extends GestureRecognizer {
-  TestGestureRecognizer({ super.debugOwner });
+  TestGestureRecognizer({super.debugOwner});
 
   @override
   String get debugDescription => 'debugDescription content';
 
   @override
-  void addPointer(PointerDownEvent event) { }
+  void addPointer(PointerDownEvent event) {}
 
   @override
-  void acceptGesture(int pointer) { }
+  void acceptGesture(int pointer) {}
 
   @override
-  void rejectGesture(int pointer) { }
+  void rejectGesture(int pointer) {}
 }
 
 /// Gesture recognizer that adds itself to the gesture arena but never
@@ -217,10 +195,10 @@ class IndefiniteGestureRecognizer extends GestureRecognizer {
   }
 
   @override
-  void acceptGesture(int pointer) { }
+  void acceptGesture(int pointer) {}
 
   @override
-  void rejectGesture(int pointer) { }
+  void rejectGesture(int pointer) {}
 
   @override
   String get debugDescription => 'Unresolving';
@@ -228,7 +206,8 @@ class IndefiniteGestureRecognizer extends GestureRecognizer {
 
 /// Gesture recognizer that resolves with [resolution] when it handles an event
 /// on the primary pointer of type [T]
-class TestPrimaryPointerGestureRecognizer<T extends PointerEvent> extends PrimaryPointerGestureRecognizer {
+class TestPrimaryPointerGestureRecognizer<T extends PointerEvent>
+    extends PrimaryPointerGestureRecognizer {
   TestPrimaryPointerGestureRecognizer(
     this.resolution, {
     this.onAcceptGesture,
@@ -244,17 +223,13 @@ class TestPrimaryPointerGestureRecognizer<T extends PointerEvent> extends Primar
   @override
   void acceptGesture(int pointer) {
     super.acceptGesture(pointer);
-    if (onAcceptGesture != null) {
-      onAcceptGesture!();
-    }
+    onAcceptGesture?.call();
   }
 
   @override
   void rejectGesture(int pointer) {
     super.rejectGesture(pointer);
-    if (onRejectGesture != null) {
-      onRejectGesture!();
-    }
+    onRejectGesture?.call();
   }
 
   @override
