@@ -43,10 +43,11 @@ void main() {
     final DiagnosticPropertiesBuilder builder = DiagnosticPropertiesBuilder();
     const CheckboxThemeData().debugFillProperties(builder);
 
-    final List<String> description = builder.properties
-      .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-      .map((DiagnosticsNode node) => node.toString())
-      .toList();
+    final List<String> description =
+        builder.properties
+            .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+            .map((DiagnosticsNode node) => node.toString())
+            .toList();
 
     expect(description, <String>[]);
   });
@@ -63,18 +64,19 @@ void main() {
       visualDensity: VisualDensity.standard,
     ).debugFillProperties(builder);
 
-    final List<String> description = builder.properties
-      .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-      .map((DiagnosticsNode node) => node.toString())
-      .toList();
+    final List<String> description =
+        builder.properties
+            .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+            .map((DiagnosticsNode node) => node.toString())
+            .toList();
 
     expect(
       description,
       equalsIgnoringHashCodes(<String>[
         'mouseCursor: WidgetStatePropertyAll(SystemMouseCursor(click))',
-        'fillColor: WidgetStatePropertyAll(Color(0xfffffff0))',
-        'checkColor: WidgetStatePropertyAll(Color(0xfffffff1))',
-        'overlayColor: WidgetStatePropertyAll(Color(0xfffffff2))',
+        'fillColor: WidgetStatePropertyAll(${const Color(0xfffffff0)})',
+        'checkColor: WidgetStatePropertyAll(${const Color(0xfffffff1)})',
+        'overlayColor: WidgetStatePropertyAll(${const Color(0xfffffff2)})',
         'splashRadius: 1.0',
         'materialTapTargetSize: MaterialTapTargetSize.shrinkWrap',
         'visualDensity: VisualDensity#00000(h: 0.0, v: 0.0)',
@@ -128,11 +130,7 @@ void main() {
           ),
         ),
         home: Scaffold(
-          body: Checkbox(
-            onChanged: (bool? value) {},
-            value: selected,
-            autofocus: autofocus,
-          ),
+          body: Checkbox(onChanged: (bool? value) {}, value: selected, autofocus: autofocus),
         ),
       );
     }
@@ -142,26 +140,45 @@ void main() {
     await tester.pumpAndSettle();
     expect(_getCheckboxMaterial(tester), paints..path(color: defaultFillColor));
     // Size from MaterialTapTargetSize.shrinkWrap with added VisualDensity.
-    expect(tester.getSize(find.byType(Checkbox)), const Size(40.0, 40.0) + visualDensity.baseSizeAdjustment);
+    expect(
+      tester.getSize(find.byType(Checkbox)),
+      const Size(40.0, 40.0) + visualDensity.baseSizeAdjustment,
+    );
 
     // Selected checkbox.
     await tester.pumpWidget(buildCheckbox(selected: true));
     await tester.pumpAndSettle();
     expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor));
-    expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor)..path(color: defaultCheckColor));
+    expect(
+      _getCheckboxMaterial(tester),
+      paints
+        ..path(color: selectedFillColor)
+        ..path(color: defaultCheckColor),
+    );
 
     // Checkbox with hover.
     await tester.pumpWidget(buildCheckbox());
     await _pointGestureToCheckbox(tester);
     await tester.pumpAndSettle();
-    expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.text);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.text,
+    );
     expect(_getCheckboxMaterial(tester), paints..circle(color: hoverOverlayColor));
 
     // Checkbox with focus.
     await tester.pumpWidget(buildCheckbox(autofocus: true, selected: true));
     await tester.pumpAndSettle();
-    expect(_getCheckboxMaterial(tester), paints..circle(color: focusOverlayColor, radius: splashRadius));
-    expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor)..path(color: focusedCheckColor));
+    expect(
+      _getCheckboxMaterial(tester),
+      paints..circle(color: focusOverlayColor, radius: splashRadius),
+    );
+    expect(
+      _getCheckboxMaterial(tester),
+      paints
+        ..path(color: selectedFillColor)
+        ..path(color: focusedCheckColor),
+    );
   });
 
   testWidgets('Checkbox properties are taken over the theme values', (WidgetTester tester) async {
@@ -188,52 +205,52 @@ void main() {
     const VisualDensity visualDensity = VisualDensity.standard;
 
     Widget buildCheckbox({bool selected = false, bool autofocus = false}) {
-        return MaterialApp(
-          theme: ThemeData(
-            checkboxTheme: CheckboxThemeData(
-              mouseCursor: const MaterialStatePropertyAll<MouseCursor?>(themeMouseCursor),
-              fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                if (states.contains(MaterialState.selected)) {
-                  return themeSelectedFillColor;
-                }
-                return themeDefaultFillColor;
-              }),
-              checkColor: const MaterialStatePropertyAll<Color?>(themeCheckColor),
-              overlayColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                if (states.contains(MaterialState.focused)) {
-                  return themeFocusOverlayColor;
-                }
-                if (states.contains(MaterialState.hovered)) {
-                  return themeHoverOverlayColor;
-                }
-                return null;
-              }),
-              splashRadius: themeSplashRadius,
-              materialTapTargetSize: themeMaterialTapTargetSize,
-              visualDensity: themeVisualDensity,
-            ),
+      return MaterialApp(
+        theme: ThemeData(
+          checkboxTheme: CheckboxThemeData(
+            mouseCursor: const MaterialStatePropertyAll<MouseCursor?>(themeMouseCursor),
+            fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
+              if (states.contains(MaterialState.selected)) {
+                return themeSelectedFillColor;
+              }
+              return themeDefaultFillColor;
+            }),
+            checkColor: const MaterialStatePropertyAll<Color?>(themeCheckColor),
+            overlayColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
+              if (states.contains(MaterialState.focused)) {
+                return themeFocusOverlayColor;
+              }
+              if (states.contains(MaterialState.hovered)) {
+                return themeHoverOverlayColor;
+              }
+              return null;
+            }),
+            splashRadius: themeSplashRadius,
+            materialTapTargetSize: themeMaterialTapTargetSize,
+            visualDensity: themeVisualDensity,
           ),
-          home: Scaffold(
-            body: Checkbox(
-              onChanged: (bool? value) { },
-              value: selected,
-              autofocus: autofocus,
-              mouseCursor: mouseCursor,
-              fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                if (states.contains(MaterialState.selected)) {
-                  return selectedFillColor;
-                }
-                return defaultFillColor;
-              }),
-              checkColor: checkColor,
-              focusColor: focusColor,
-              hoverColor: hoverColor,
-              splashRadius: splashRadius,
-              materialTapTargetSize: materialTapTargetSize,
-              visualDensity: visualDensity,
-            ),
+        ),
+        home: Scaffold(
+          body: Checkbox(
+            onChanged: (bool? value) {},
+            value: selected,
+            autofocus: autofocus,
+            mouseCursor: mouseCursor,
+            fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
+              if (states.contains(MaterialState.selected)) {
+                return selectedFillColor;
+              }
+              return defaultFillColor;
+            }),
+            checkColor: checkColor,
+            focusColor: focusColor,
+            hoverColor: hoverColor,
+            splashRadius: splashRadius,
+            materialTapTargetSize: materialTapTargetSize,
+            visualDensity: visualDensity,
           ),
-        );
+        ),
+      );
     }
 
     // Checkbox.
@@ -241,19 +258,30 @@ void main() {
     await tester.pumpAndSettle();
     expect(_getCheckboxMaterial(tester), paints..path(color: defaultFillColor));
     // Size from MaterialTapTargetSize.shrinkWrap with added VisualDensity.
-    expect(tester.getSize(find.byType(Checkbox)), const Size(40.0, 40.0) + visualDensity.baseSizeAdjustment);
+    expect(
+      tester.getSize(find.byType(Checkbox)),
+      const Size(40.0, 40.0) + visualDensity.baseSizeAdjustment,
+    );
 
     // Selected checkbox.
     await tester.pumpWidget(buildCheckbox(selected: true));
     await tester.pumpAndSettle();
     expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor));
-    expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor)..path(color: checkColor));
+    expect(
+      _getCheckboxMaterial(tester),
+      paints
+        ..path(color: selectedFillColor)
+        ..path(color: checkColor),
+    );
 
     // Checkbox with hover.
     await tester.pumpWidget(buildCheckbox());
     await _pointGestureToCheckbox(tester);
     await tester.pumpAndSettle();
-    expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.text);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.text,
+    );
     expect(_getCheckboxMaterial(tester), paints..circle(color: hoverColor));
 
     // Checkbox with focus.
@@ -268,25 +296,25 @@ void main() {
     const Color selectedFillColor = Color(0xfffffff6);
 
     Widget buildCheckbox({bool selected = false}) {
-        return MaterialApp(
-          theme: ThemeData(
-            checkboxTheme: CheckboxThemeData(
-              fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                if (states.contains(MaterialState.selected)) {
-                  return themeSelectedFillColor;
-                }
-                return themeDefaultFillColor;
-              }),
-            ),
+      return MaterialApp(
+        theme: ThemeData(
+          checkboxTheme: CheckboxThemeData(
+            fillColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
+              if (states.contains(MaterialState.selected)) {
+                return themeSelectedFillColor;
+              }
+              return themeDefaultFillColor;
+            }),
           ),
-          home: Scaffold(
-            body: Checkbox(
-              onChanged: (bool? value) { },
-              value: selected,
-              activeColor: selectedFillColor,
-            ),
+        ),
+        home: Scaffold(
+          body: Checkbox(
+            onChanged: (bool? value) {},
+            value: selected,
+            activeColor: selectedFillColor,
           ),
-        );
+        ),
+      );
     }
 
     // Unselected checkbox.
@@ -300,7 +328,9 @@ void main() {
     expect(_getCheckboxMaterial(tester), paints..path(color: selectedFillColor));
   });
 
-  testWidgets('Checkbox theme overlay color resolves in active/pressed states', (WidgetTester tester) async {
+  testWidgets('Checkbox theme overlay color resolves in active/pressed states', (
+    WidgetTester tester,
+  ) async {
     const Color activePressedOverlayColor = Color(0xFF000001);
     const Color inactivePressedOverlayColor = Color(0xFF000002);
 
@@ -313,6 +343,7 @@ void main() {
       }
       return null;
     }
+
     const double splashRadius = 24.0;
 
     Widget buildCheckbox({required bool active}) {
@@ -323,12 +354,7 @@ void main() {
             splashRadius: splashRadius,
           ),
         ),
-        home: Scaffold(
-          body: Checkbox(
-            value: active,
-            onChanged: (_) { },
-          ),
-        ),
+        home: Scaffold(body: Checkbox(value: active, onChanged: (_) {})),
       );
     }
 
@@ -338,11 +364,7 @@ void main() {
 
     expect(
       _getCheckboxMaterial(tester),
-      paints
-        ..circle(
-          color: inactivePressedOverlayColor,
-          radius: splashRadius,
-        ),
+      paints..circle(color: inactivePressedOverlayColor, radius: splashRadius),
       reason: 'Inactive pressed Checkbox should have overlay color: $inactivePressedOverlayColor',
     );
 
@@ -352,11 +374,7 @@ void main() {
 
     expect(
       _getCheckboxMaterial(tester),
-      paints
-        ..circle(
-          color: activePressedOverlayColor,
-          radius: splashRadius,
-        ),
+      paints..circle(color: activePressedOverlayColor, radius: splashRadius),
       reason: 'Active pressed Checkbox should have overlay color: $activePressedOverlayColor',
     );
 
@@ -386,10 +404,7 @@ void main() {
               fillColor: MaterialStatePropertyAll<Color>(localThemeFillColor),
               checkColor: MaterialStatePropertyAll<Color>(localThemeCheckColor),
             ),
-            child: Checkbox(
-              value: active,
-              onChanged: (_) { },
-            ),
+            child: Checkbox(value: active, onChanged: (_) {}),
           ),
         ),
       );
@@ -398,7 +413,12 @@ void main() {
     await tester.pumpWidget(buildCheckbox(active: true));
     await tester.pumpAndSettle();
     expect(_getCheckboxMaterial(tester), paints..path(color: localThemeFillColor));
-    expect(_getCheckboxMaterial(tester), paints..path(color: localThemeFillColor)..path(color: localThemeCheckColor));
+    expect(
+      _getCheckboxMaterial(tester),
+      paints
+        ..path(color: localThemeFillColor)
+        ..path(color: localThemeCheckColor),
+    );
   });
 
   test('CheckboxThemeData lerp with null parameters', () {
@@ -428,13 +448,16 @@ void main() {
     );
     final CheckboxThemeData lerped = CheckboxThemeData.lerp(theme, null, 0.5);
 
-    expect(lerped.fillColor!.resolve(<MaterialState>{}), const Color(0x80fffff0));
-    expect(lerped.checkColor!.resolve(<MaterialState>{}), const Color(0x80fffff1));
-    expect(lerped.overlayColor!.resolve(<MaterialState>{}), const Color(0x80fffff2));
+    expect(lerped.fillColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0x80fffff0)));
+    expect(lerped.checkColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0x80fffff1)));
+    expect(lerped.overlayColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0x80fffff2)));
     expect(lerped.splashRadius, 1.5);
     expect(lerped.materialTapTargetSize, null);
     expect(lerped.visualDensity, null);
-    expect(lerped.shape, const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(2.0))));
+    expect(
+      lerped.shape,
+      const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(2.0))),
+    );
     // Returns null if either lerp value is null.
     expect(lerped.side, null);
   });
@@ -462,55 +485,52 @@ void main() {
     );
     final CheckboxThemeData lerped = CheckboxThemeData.lerp(themeA, themeB, 0.5);
 
-    expect(lerped.fillColor!.resolve(<MaterialState>{}), const Color(0xfffffff1));
-    expect(lerped.checkColor!.resolve(<MaterialState>{}), const Color(0xfffffff2));
-    expect(lerped.overlayColor!.resolve(<MaterialState>{}), const Color(0xfffffff3));
+    expect(lerped.fillColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0xfffffff1)));
+    expect(lerped.checkColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0xfffffff2)));
+    expect(lerped.overlayColor!.resolve(<MaterialState>{}), isSameColorAs(const Color(0xfffffff3)));
     expect(lerped.splashRadius, 6);
     expect(lerped.materialTapTargetSize, MaterialTapTargetSize.shrinkWrap);
-    expect(lerped.visualDensity,  const VisualDensity(vertical: 2.0, horizontal: 2.0));
-    expect(lerped.shape, const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(2.5))));
+    expect(lerped.visualDensity, const VisualDensity(vertical: 2.0, horizontal: 2.0));
+    expect(
+      lerped.shape,
+      const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(2.5))),
+    );
     expect(lerped.side, const BorderSide(width: 3.5));
   });
 
-  testWidgets('MaterialStateBorderSide properly lerp in CheckboxThemeData.side', (WidgetTester tester) async {
+  testWidgets('MaterialStateBorderSide properly lerp in CheckboxThemeData.side', (
+    WidgetTester tester,
+  ) async {
     late ColorScheme colorScheme;
 
-    Widget buildCheckbox({ required  Color seedColor }) {
+    Widget buildCheckbox({required Color seedColor}) {
       colorScheme = ColorScheme.fromSeed(seedColor: seedColor);
       return MaterialApp(
         theme: ThemeData(
           colorScheme: colorScheme,
           checkboxTheme: CheckboxThemeData(
             side: MaterialStateBorderSide.resolveWith((Set<MaterialState> states) {
-              return BorderSide(
-                color: colorScheme.primary,
-                width: 4.0,
-              );
+              return BorderSide(color: colorScheme.primary, width: 4.0);
             }),
           ),
         ),
-        home: Scaffold(
-          body: Checkbox(
-            value: false,
-            onChanged: (_) { },
-          ),
-        ),
+        home: Scaffold(body: Checkbox(value: false, onChanged: (_) {})),
       );
     }
 
     await tester.pumpWidget(buildCheckbox(seedColor: Colors.red));
     await tester.pumpAndSettle();
 
-    RenderBox getCheckboxRendeBox() {
+    RenderBox getCheckboxRenderBox() {
       return tester.renderObject<RenderBox>(find.byType(Checkbox));
     }
 
-    expect(getCheckboxRendeBox(), paints..drrect(color: colorScheme.primary));
+    expect(getCheckboxRenderBox(), paints..drrect(color: colorScheme.primary));
 
     await tester.pumpWidget(buildCheckbox(seedColor: Colors.blue));
     await tester.pump(kPressTimeout);
 
-    expect(getCheckboxRendeBox(), paints..drrect(color: colorScheme.primary));
+    expect(getCheckboxRenderBox(), paints..drrect(color: colorScheme.primary));
   });
 }
 
