@@ -12,6 +12,7 @@ import 'dart:typed_data';
 import 'package:flutter/material.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter_test/flutter_test.dart';
+
 import '../image_data.dart';
 import '../painting/mocks_for_image_cache.dart';
 
@@ -20,11 +21,7 @@ void main() {
     final Color backgroundColor = Colors.blue.shade900;
     await tester.pumpWidget(
       wrap(
-        child: CircleAvatar(
-          backgroundColor: backgroundColor,
-          radius: 50.0,
-          child: const Text('Z'),
-        ),
+        child: CircleAvatar(backgroundColor: backgroundColor, radius: 50.0, child: const Text('Z')),
       ),
     );
 
@@ -42,11 +39,7 @@ void main() {
     final Color backgroundColor = Colors.blue.shade100;
     await tester.pumpWidget(
       wrap(
-        child: CircleAvatar(
-          backgroundColor: backgroundColor,
-          radius: 50.0,
-          child: const Text('Z'),
-        ),
+        child: CircleAvatar(backgroundColor: backgroundColor, radius: 50.0, child: const Text('Z')),
       ),
     );
 
@@ -94,17 +87,20 @@ void main() {
     expect(decoration.image!.fit, equals(BoxFit.cover));
   });
 
-  testWidgets('CircleAvatar backgroundImage is used as a fallback for foregroundImage', (WidgetTester tester) async {
+  testWidgets('CircleAvatar backgroundImage is used as a fallback for foregroundImage', (
+    WidgetTester tester,
+  ) async {
+    addTearDown(imageCache.clear);
     final ErrorImageProvider errorImage = ErrorImageProvider();
     bool caughtForegroundImageError = false;
     await tester.pumpWidget(
       wrap(
         child: RepaintBoundary(
           child: CircleAvatar(
-          foregroundImage: errorImage,
-          backgroundImage: MemoryImage(Uint8List.fromList(kBlueRectPng)),
-          radius: 50.0,
-          onForegroundImageError: (_,__) => caughtForegroundImageError = true,
+            foregroundImage: errorImage,
+            backgroundImage: MemoryImage(Uint8List.fromList(kBlueRectPng)),
+            radius: 50.0,
+            onForegroundImageError: (_, _) => caughtForegroundImageError = true,
           ),
         ),
       ),
@@ -116,21 +112,13 @@ void main() {
     final RenderDecoratedBox child = box.child! as RenderDecoratedBox;
     final BoxDecoration decoration = child.decoration as BoxDecoration;
     expect(decoration.image!.fit, equals(BoxFit.cover));
-    await expectLater(
-      find.byType(CircleAvatar),
-      matchesGoldenFile('circle_avatar.fallback.png'),
-    );
+    await expectLater(find.byType(CircleAvatar), matchesGoldenFile('circle_avatar.fallback.png'));
   });
 
   testWidgets('CircleAvatar with foreground color', (WidgetTester tester) async {
     final Color foregroundColor = Colors.red.shade100;
     await tester.pumpWidget(
-      wrap(
-        child: CircleAvatar(
-          foregroundColor: foregroundColor,
-          child: const Text('Z'),
-        ),
-      ),
+      wrap(child: CircleAvatar(foregroundColor: foregroundColor, child: const Text('Z'))),
     );
 
     final ThemeData fallback = ThemeData.fallback();
@@ -148,14 +136,7 @@ void main() {
   testWidgets('Material3 - CircleAvatar default colors', (WidgetTester tester) async {
     final ThemeData theme = ThemeData();
     await tester.pumpWidget(
-      wrap(
-        child: Theme(
-          data: theme,
-          child: const CircleAvatar(
-            child: Text('Z'),
-          ),
-        ),
-      ),
+      wrap(child: Theme(data: theme, child: const CircleAvatar(child: Text('Z')))),
     );
 
     final RenderConstrainedBox box = tester.renderObject(find.byType(CircleAvatar));
@@ -167,15 +148,10 @@ void main() {
     expect(paragraph.text.style!.color, equals(theme.colorScheme.onPrimaryContainer));
   });
 
-  testWidgets('CircleAvatar text does not expand with textScaleFactor', (WidgetTester tester) async {
+  testWidgets('CircleAvatar text does not expand with textScaler', (WidgetTester tester) async {
     final Color foregroundColor = Colors.red.shade100;
     await tester.pumpWidget(
-      wrap(
-        child: CircleAvatar(
-          foregroundColor: foregroundColor,
-          child: const Text('Z'),
-        ),
-      ),
+      wrap(child: CircleAvatar(foregroundColor: foregroundColor, child: const Text('Z'))),
     );
 
     expect(tester.getSize(find.text('Z')), equals(const Size(16.0, 16.0)));
@@ -184,7 +160,7 @@ void main() {
       wrap(
         child: MediaQuery(
           data: const MediaQueryData(
-            textScaleFactor: 2.0,
+            textScaler: TextScaler.linear(2.0),
             size: Size(111.0, 111.0),
             devicePixelRatio: 1.1,
             padding: EdgeInsets.all(11.0),
@@ -200,7 +176,7 @@ void main() {
                 expect(data.padding, equals(const EdgeInsets.all(11.0)));
 
                 // This should be overridden to 1.0.
-                expect(data.textScaleFactor, equals(1.0));
+                expect(data.textScaler, TextScaler.noScaling);
                 return const Text('Z');
               },
             ),
@@ -257,7 +233,9 @@ void main() {
     expect(paragraph.text.style!.color, equals(ThemeData.fallback().primaryColorLight));
   });
 
-  testWidgets('CircleAvatar respects setting both minRadius and maxRadius', (WidgetTester tester) async {
+  testWidgets('CircleAvatar respects setting both minRadius and maxRadius', (
+    WidgetTester tester,
+  ) async {
     final Color backgroundColor = Colors.blue.shade900;
     await tester.pumpWidget(
       wrap(
@@ -285,17 +263,12 @@ void main() {
     // support is deprecated and the APIs are removed, these tests
     // can be deleted.
 
-    testWidgets('Material2 - CircleAvatar default colors with light theme', (WidgetTester tester) async {
+    testWidgets('Material2 - CircleAvatar default colors with light theme', (
+      WidgetTester tester,
+    ) async {
       final ThemeData theme = ThemeData(useMaterial3: false, primaryColor: Colors.grey.shade100);
       await tester.pumpWidget(
-        wrap(
-          child: Theme(
-            data: theme,
-            child: const CircleAvatar(
-              child: Text('Z'),
-            ),
-          ),
-        ),
+        wrap(child: Theme(data: theme, child: const CircleAvatar(child: Text('Z')))),
       );
 
       final RenderConstrainedBox box = tester.renderObject(find.byType(CircleAvatar));
@@ -307,17 +280,12 @@ void main() {
       expect(paragraph.text.style!.color, equals(theme.primaryTextTheme.titleLarge!.color));
     });
 
-    testWidgets('Material2 - CircleAvatar default colors with dark theme', (WidgetTester tester) async {
+    testWidgets('Material2 - CircleAvatar default colors with dark theme', (
+      WidgetTester tester,
+    ) async {
       final ThemeData theme = ThemeData(useMaterial3: false, primaryColor: Colors.grey.shade800);
       await tester.pumpWidget(
-        wrap(
-          child: Theme(
-            data: theme,
-            child: const CircleAvatar(
-              child: Text('Z'),
-            ),
-          ),
-        ),
+        wrap(child: Theme(data: theme, child: const CircleAvatar(child: Text('Z')))),
       );
 
       final RenderConstrainedBox box = tester.renderObject(find.byType(CircleAvatar));
@@ -331,14 +299,12 @@ void main() {
   });
 }
 
-Widget wrap({ required Widget child }) {
+Widget wrap({required Widget child}) {
   return Directionality(
     textDirection: TextDirection.ltr,
     child: MediaQuery(
       data: const MediaQueryData(),
-      child: MaterialApp(
-        theme: ThemeData(useMaterial3: false),
-        home: Center(child: child)),
+      child: MaterialApp(theme: ThemeData(useMaterial3: false), home: Center(child: child)),
     ),
   );
 }
