@@ -33,10 +33,7 @@ void main() {
     await tester.pumpWidget(
       const MaterialApp(
         home: Center(
-          child: DesktopTextSelectionToolbarButton(
-            onPressed: null,
-            child: Text('Cannot tap me'),
-          ),
+          child: DesktopTextSelectionToolbarButton(onPressed: null, child: Text('Cannot tap me')),
         ),
       ),
     );
