@@ -5,47 +5,45 @@
 import 'package:flutter/material.dart';
 import 'package:flutter_test/flutter_test.dart';
 
-enum RadiusType {
-  Sharp,
-  Shifting,
-  Round
-}
+enum RadiusType { Sharp, Shifting, Round }
 
 void matches(BorderRadius? borderRadius, RadiusType top, RadiusType bottom) {
   final Radius cardRadius = kMaterialEdges[MaterialType.card]!.topLeft;
 
-  if (top == RadiusType.Sharp) {
-    expect(borderRadius?.topLeft, equals(Radius.zero));
-    expect(borderRadius?.topRight, equals(Radius.zero));
-  } else if (top == RadiusType.Shifting) {
-    expect(borderRadius?.topLeft.x, greaterThan(0.0));
-    expect(borderRadius?.topLeft.x, lessThan(cardRadius.x));
-    expect(borderRadius?.topLeft.y, greaterThan(0.0));
-    expect(borderRadius?.topLeft.y, lessThan(cardRadius.y));
-    expect(borderRadius?.topRight.x, greaterThan(0.0));
-    expect(borderRadius?.topRight.x, lessThan(cardRadius.x));
-    expect(borderRadius?.topRight.y, greaterThan(0.0));
-    expect(borderRadius?.topRight.y, lessThan(cardRadius.y));
-  } else {
-    expect(borderRadius?.topLeft, equals(cardRadius));
-    expect(borderRadius?.topRight, equals(cardRadius));
+  switch (top) {
+    case RadiusType.Sharp:
+      expect(borderRadius?.topLeft, equals(Radius.zero));
+      expect(borderRadius?.topRight, equals(Radius.zero));
+    case RadiusType.Shifting:
+      expect(borderRadius?.topLeft.x, greaterThan(0.0));
+      expect(borderRadius?.topLeft.x, lessThan(cardRadius.x));
+      expect(borderRadius?.topLeft.y, greaterThan(0.0));
+      expect(borderRadius?.topLeft.y, lessThan(cardRadius.y));
+      expect(borderRadius?.topRight.x, greaterThan(0.0));
+      expect(borderRadius?.topRight.x, lessThan(cardRadius.x));
+      expect(borderRadius?.topRight.y, greaterThan(0.0));
+      expect(borderRadius?.topRight.y, lessThan(cardRadius.y));
+    case RadiusType.Round:
+      expect(borderRadius?.topLeft, equals(cardRadius));
+      expect(borderRadius?.topRight, equals(cardRadius));
   }
 
-  if (bottom == RadiusType.Sharp) {
-    expect(borderRadius?.bottomLeft, equals(Radius.zero));
-    expect(borderRadius?.bottomRight, equals(Radius.zero));
-  } else if (bottom == RadiusType.Shifting) {
-    expect(borderRadius?.bottomLeft.x, greaterThan(0.0));
-    expect(borderRadius?.bottomLeft.x, lessThan(cardRadius.x));
-    expect(borderRadius?.bottomLeft.y, greaterThan(0.0));
-    expect(borderRadius?.bottomLeft.y, lessThan(cardRadius.y));
-    expect(borderRadius?.bottomRight.x, greaterThan(0.0));
-    expect(borderRadius?.bottomRight.x, lessThan(cardRadius.x));
-    expect(borderRadius?.bottomRight.y, greaterThan(0.0));
-    expect(borderRadius?.bottomRight.y, lessThan(cardRadius.y));
-  } else {
-    expect(borderRadius?.bottomLeft, equals(cardRadius));
-    expect(borderRadius?.bottomRight, equals(cardRadius));
+  switch (bottom) {
+    case RadiusType.Sharp:
+      expect(borderRadius?.bottomLeft, equals(Radius.zero));
+      expect(borderRadius?.bottomRight, equals(Radius.zero));
+    case RadiusType.Shifting:
+      expect(borderRadius?.bottomLeft.x, greaterThan(0.0));
+      expect(borderRadius?.bottomLeft.x, lessThan(cardRadius.x));
+      expect(borderRadius?.bottomLeft.y, greaterThan(0.0));
+      expect(borderRadius?.bottomLeft.y, lessThan(cardRadius.y));
+      expect(borderRadius?.bottomRight.x, greaterThan(0.0));
+      expect(borderRadius?.bottomRight.x, lessThan(cardRadius.x));
+      expect(borderRadius?.bottomRight.y, greaterThan(0.0));
+      expect(borderRadius?.bottomRight.y, lessThan(cardRadius.y));
+    case RadiusType.Round:
+      expect(borderRadius?.bottomLeft, equals(cardRadius));
+      expect(borderRadius?.bottomRight, equals(cardRadius));
   }
 }
 
@@ -53,8 +51,7 @@ void matches(BorderRadius? borderRadius, RadiusType top, RadiusType bottom) {
 // This depends on the exact structure of objects built by the Material and
 // MergeableMaterial widgets.
 BorderRadius? getBorderRadius(WidgetTester tester, int index) {
-  final List<Element> containers = tester.elementList(find.byType(Container))
-                                   .toList();
+  final List<Element> containers = tester.elementList(find.byType(Container)).toList();
 
   final Container container = containers[index].widget as Container;
   final BoxDecoration? boxDecoration = container.decoration as BoxDecoration?;
@@ -65,13 +62,7 @@ BorderRadius? getBorderRadius(WidgetTester tester, int index) {
 void main() {
   testWidgets('MergeableMaterial empty', (WidgetTester tester) async {
     await tester.pumpWidget(
-      const MaterialApp(
-        home: Scaffold(
-          body: SingleChildScrollView(
-            child: MergeableMaterial(),
-          ),
-        ),
-      ),
+      const MaterialApp(home: Scaffold(body: SingleChildScrollView(child: MergeableMaterial()))),
     );
 
     final RenderBox box = tester.renderObject(find.byType(MergeableMaterial));
@@ -87,10 +78,7 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -110,10 +98,7 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 200.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 200.0),
                 ),
               ],
             ),
@@ -135,17 +120,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -168,17 +147,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -208,10 +181,7 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -243,10 +213,7 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -255,10 +222,7 @@ void main() {
       ),
     );
 
-    expect(
-      find.byType(MergeableMaterial),
-      isNot(paints..shadow(elevation: 0.0)),
-    );
+    expect(find.byType(MergeableMaterial), isNot(paints..shadow(elevation: 0.0)));
     debugDisableShadows = true;
   });
 
@@ -271,20 +235,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -307,17 +263,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -348,17 +298,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -381,20 +325,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -425,17 +361,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -450,7 +380,6 @@ void main() {
     matches(getBorderRadius(tester, 0), RadiusType.Round, RadiusType.Sharp);
     matches(getBorderRadius(tester, 1), RadiusType.Sharp, RadiusType.Round);
 
-
     await tester.pumpWidget(
       const MaterialApp(
         home: Scaffold(
@@ -459,20 +388,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -501,17 +422,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -540,20 +455,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -584,17 +491,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -617,24 +518,15 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -659,24 +551,15 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -700,17 +583,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -735,17 +612,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -768,30 +639,17 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('y'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('y')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -824,30 +682,17 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('y'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('y')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -871,17 +716,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -912,20 +751,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -948,30 +779,17 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('y'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('y')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('z'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('z')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1004,30 +822,17 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('y'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('y')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1051,20 +856,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('z'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('z')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1095,10 +892,7 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1120,20 +914,12 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1158,12 +944,13 @@ void main() {
   bool isDivider(BoxDecoration decoration, bool top, bool bottom) {
     const BorderSide side = BorderSide(color: Color(0x1F000000), width: 0.5);
 
-    return decoration == BoxDecoration(
-      border: Border(
-        top: top ? side : BorderSide.none,
-        bottom: bottom ? side : BorderSide.none,
-      ),
-    );
+    return decoration ==
+        BoxDecoration(
+          border: Border(
+            top: top ? side : BorderSide.none,
+            bottom: bottom ? side : BorderSide.none,
+          ),
+        );
   }
 
   testWidgets('MergeableMaterial dividers', (WidgetTester tester) async {
@@ -1177,31 +964,19 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('D'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1210,9 +985,7 @@ void main() {
       ),
     );
 
-    List<Widget> animatedContainers = tester.widgetList(
-      find.byType(AnimatedContainer),
-    ).toList();
+    List<Widget> animatedContainers = tester.widgetList(find.byType(AnimatedContainer)).toList();
     List<BoxDecoration> boxes = <BoxDecoration>[];
     for (final Widget container in animatedContainers) {
       boxes.add((container as AnimatedContainer).decoration! as BoxDecoration);
@@ -1235,34 +1008,20 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('x'),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
+                MaterialGap(key: ValueKey<String>('x')),
                 MaterialSlice(
                   key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('D'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1274,9 +1033,7 @@ void main() {
     // Wait for dividers to shrink.
     await tester.pump(const Duration(milliseconds: 200));
 
-    animatedContainers = tester.widgetList(
-      find.byType(AnimatedContainer),
-    ).toList();
+    animatedContainers = tester.widgetList(find.byType(AnimatedContainer)).toList();
     boxes = <BoxDecoration>[];
 
     for (final Widget container in animatedContainers) {
@@ -1303,17 +1060,11 @@ void main() {
               children: <MergeableMaterialItem>[
                 MaterialSlice(
                   key: ValueKey<String>('A'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
                 MaterialSlice(
                   key: ValueKey<String>('B'),
-                  child: SizedBox(
-                    width: 100.0,
-                    height: 100.0,
-                  ),
+                  child: SizedBox(width: 100.0, height: 100.0),
                 ),
               ],
             ),
@@ -1334,9 +1085,7 @@ void main() {
 
     await tester.pumpWidget(
       MaterialApp(
-        theme: ThemeData(
-          cardColor: themeCardColor,
-        ),
+        theme: ThemeData(cardColor: themeCardColor),
         home: const Scaffold(
           body: SingleChildScrollView(
             child: MergeableMaterial(
@@ -1344,21 +1093,10 @@ void main() {
                 MaterialSlice(
                   key: ValueKey<String>('A'),
                   color: materialSliceColor,
-                  child: SizedBox(
-                    height: 100,
-                    width: 100,
-                  ),
-                ),
-                MaterialGap(
-                  key: ValueKey<String>('B'),
-                ),
-                MaterialSlice(
-                  key: ValueKey<String>('C'),
-                  child: SizedBox(
-                    height: 100,
-                    width: 100,
-                  ),
+                  child: SizedBox(height: 100, width: 100),
                 ),
+                MaterialGap(key: ValueKey<String>('B')),
+                MaterialSlice(key: ValueKey<String>('C'), child: SizedBox(height: 100, width: 100)),
               ],
             ),
           ),
@@ -1366,10 +1104,12 @@ void main() {
       ),
     );
 
-    BoxDecoration boxDecoration = tester.widget<Container>(find.byType(Container).first).decoration! as BoxDecoration;
+    BoxDecoration boxDecoration =
+        tester.widget<Container>(find.byType(Container).first).decoration! as BoxDecoration;
     expect(boxDecoration.color, materialSliceColor);
 
-    boxDecoration = tester.widget<Container>(find.byType(Container).last).decoration! as BoxDecoration;
+    boxDecoration =
+        tester.widget<Container>(find.byType(Container).last).decoration! as BoxDecoration;
     expect(boxDecoration.color, themeCardColor);
   });
 }
