@@ -77,17 +77,18 @@ void main() {
     final DiagnosticPropertiesBuilder builder = DiagnosticPropertiesBuilder();
     const PopupMenuThemeData().debugFillProperties(builder);
 
-    final List<String> description = builder.properties
-        .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-        .map((DiagnosticsNode node) => node.toString())
-        .toList();
+    final List<String> description =
+        builder.properties
+            .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+            .map((DiagnosticsNode node) => node.toString())
+            .toList();
 
     expect(description, <String>[]);
   });
 
   testWidgets('PopupMenuThemeData implements debugFillProperties', (WidgetTester tester) async {
     final DiagnosticPropertiesBuilder builder = DiagnosticPropertiesBuilder();
-     PopupMenuThemeData(
+    PopupMenuThemeData(
       color: const Color(0xfffffff1),
       shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(2.0))),
       menuPadding: const EdgeInsets.symmetric(vertical: 12.0),
@@ -108,25 +109,26 @@ void main() {
       iconSize: 31.0,
     ).debugFillProperties(builder);
 
-    final List<String> description = builder.properties
-        .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-        .map((DiagnosticsNode node) => node.toString())
-        .toList();
+    final List<String> description =
+        builder.properties
+            .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+            .map((DiagnosticsNode node) => node.toString())
+            .toList();
 
     expect(description, <String>[
-      'color: Color(0xfffffff1)',
+      'color: ${const Color(0xfffffff1)}',
       'shape: RoundedRectangleBorder(BorderSide(width: 0.0, style: none), BorderRadius.circular(2.0))',
       'menuPadding: EdgeInsets(0.0, 12.0, 0.0, 12.0)',
       'elevation: 2.0',
-      'shadowColor: Color(0xfffffff2)',
-      'surfaceTintColor: Color(0xfffffff3)',
-      'text style: TextStyle(inherit: true, color: Color(0xfffffff4))',
+      'shadowColor: ${const Color(0xfffffff2)}',
+      'surfaceTintColor: ${const Color(0xfffffff3)}',
+      'text style: TextStyle(inherit: true, color: ${const Color(0xfffffff4)})',
       "labelTextStyle: Instance of '_WidgetStatePropertyWith<TextStyle?>'",
       'enableFeedback: false',
       'mouseCursor: WidgetStateMouseCursor(clickable)',
       'position: over',
-      'iconColor: Color(0xfffffff8)',
-      'iconSize: 31.0'
+      'iconColor: ${const Color(0xfffffff8)}',
+      'iconSize: 31.0',
     ]);
   });
 
@@ -135,47 +137,44 @@ void main() {
     final Key popupButtonApp = UniqueKey();
     final Key enabledPopupItemKey = UniqueKey();
     final Key disabledPopupItemKey = UniqueKey();
-    final ThemeData theme = ThemeData(useMaterial3: true);
+    final ThemeData theme = ThemeData();
 
-    await tester.pumpWidget(MaterialApp(
-      theme: theme,
-      key: popupButtonApp,
-      home: Material(
-        child: Column(
-          children: <Widget>[
-            Padding(
-              // The padding makes sure the menu has enough space around it to
-              // get properly aligned when displayed (`_kMenuScreenPadding`).
-              padding: const EdgeInsets.all(8.0),
-              child: PopupMenuButton<void>(
-                key: popupButtonKey,
-                itemBuilder: (BuildContext context) {
-                  return <PopupMenuEntry<void>>[
-                    PopupMenuItem<void>(
-                      key: enabledPopupItemKey,
-                      child: const Text('Enabled PopupMenuItem'),
-                    ),
-                    const PopupMenuDivider(),
-                    PopupMenuItem<void>(
-                      key: disabledPopupItemKey,
-                      enabled: false,
-                      child: const Text('Disabled PopupMenuItem'),
-                    ),
-                    const CheckedPopupMenuItem<void>(
-                      child: Text('Unchecked item'),
-                    ),
-                    const CheckedPopupMenuItem<void>(
-                      checked: true,
-                      child: Text('Checked item'),
-                    ),
-                  ];
-                },
+    await tester.pumpWidget(
+      MaterialApp(
+        theme: theme,
+        key: popupButtonApp,
+        home: Material(
+          child: Column(
+            children: <Widget>[
+              Padding(
+                // The padding makes sure the menu has enough space around it to
+                // get properly aligned when displayed (`_kMenuScreenPadding`).
+                padding: const EdgeInsets.all(8.0),
+                child: PopupMenuButton<void>(
+                  key: popupButtonKey,
+                  itemBuilder: (BuildContext context) {
+                    return <PopupMenuEntry<void>>[
+                      PopupMenuItem<void>(
+                        key: enabledPopupItemKey,
+                        child: const Text('Enabled PopupMenuItem'),
+                      ),
+                      const PopupMenuDivider(),
+                      PopupMenuItem<void>(
+                        key: disabledPopupItemKey,
+                        enabled: false,
+                        child: const Text('Disabled PopupMenuItem'),
+                      ),
+                      const CheckedPopupMenuItem<void>(child: Text('Unchecked item')),
+                      const CheckedPopupMenuItem<void>(checked: true, child: Text('Checked item')),
+                    ];
+                  },
+                ),
               ),
-            ),
-          ],
+            ],
+          ),
         ),
       ),
-    ));
+    );
 
     // Test default button icon color.
     expect(_iconStyle(tester, Icons.adaptive.more)?.color, theme.iconTheme.color);
@@ -188,10 +187,7 @@ void main() {
     /// that is of type Material, this code retrieves the built
     /// [PopupMenuButton].
     final Material button = tester.widget<Material>(
-      find.descendant(
-        of: find.byKey(popupButtonApp),
-        matching: find.byType(Material),
-      ).last,
+      find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
     );
     expect(button.color, theme.colorScheme.surfaceContainer);
     expect(button.shadowColor, theme.colorScheme.shadow);
@@ -204,20 +200,18 @@ void main() {
     /// popupItemKey that is of type DefaultTextStyle, this code retrieves the
     /// built [PopupMenuItem].
     DefaultTextStyle popupMenuItemLabel = tester.widget<DefaultTextStyle>(
-      find.descendant(
-        of: find.byKey(enabledPopupItemKey),
-        matching: find.byType(DefaultTextStyle),
-      ).last,
+      find
+          .descendant(of: find.byKey(enabledPopupItemKey), matching: find.byType(DefaultTextStyle))
+          .last,
     );
     expect(popupMenuItemLabel.style.fontFamily, 'Roboto');
     expect(popupMenuItemLabel.style.color, theme.colorScheme.onSurface);
 
     /// Test disabled text color
     popupMenuItemLabel = tester.widget<DefaultTextStyle>(
-      find.descendant(
-        of: find.byKey(disabledPopupItemKey),
-        matching: find.byType(DefaultTextStyle),
-      ).last,
+      find
+          .descendant(of: find.byKey(disabledPopupItemKey), matching: find.byType(DefaultTextStyle))
+          .last,
     );
     expect(popupMenuItemLabel.style.color, theme.colorScheme.onSurface.withOpacity(0.38));
 
@@ -250,7 +244,9 @@ void main() {
     expect(listTile.titleTextStyle?.color, theme.colorScheme.onSurface);
 
     // Check popup menu padding.
-    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(find.byType(SingleChildScrollView));
+    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(
+      find.byType(SingleChildScrollView),
+    );
     expect(popupMenu.padding, const EdgeInsets.symmetric(vertical: 8.0));
   });
 
@@ -261,48 +257,48 @@ void main() {
     final Key enabledPopupItemKey = UniqueKey();
     final Key disabledPopupItemKey = UniqueKey();
 
-    await tester.pumpWidget(MaterialApp(
-      theme: ThemeData(useMaterial3: true, popupMenuTheme: popupMenuTheme),
-      key: popupButtonApp,
-      home: Material(
-        child: Column(
-          children: <Widget>[
-            PopupMenuButton<void>(
-              // The padding is used in the positioning of the menu when the
-              // position is `PopupMenuPosition.under`. Setting it to zero makes
-              // it easier to test.
-              padding: EdgeInsets.zero,
-              key: popupButtonKey,
-              itemBuilder: (BuildContext context) {
-                return <PopupMenuEntry<Object>>[
-                  PopupMenuItem<Object>(
-                    key: disabledPopupItemKey,
-                    enabled: false,
-                    child: const Text('disabled'),
-                  ),
-                  const PopupMenuDivider(),
-                  PopupMenuItem<Object>(
-                    key: enabledPopupItemKey,
-                    onTap: () { },
-                    child: const Text('enabled'),
-                  ),
-                  const CheckedPopupMenuItem<Object>(
-                    child: Text('Unchecked item'),
-                  ),
-                  const CheckedPopupMenuItem<Object>(
-                    checked: true,
-                    child: Text('Checked item'),
-                  ),
-                ];
-              },
-            ),
-          ],
+    await tester.pumpWidget(
+      MaterialApp(
+        theme: ThemeData(popupMenuTheme: popupMenuTheme),
+        key: popupButtonApp,
+        home: Material(
+          child: Column(
+            children: <Widget>[
+              PopupMenuButton<void>(
+                // The padding is used in the positioning of the menu when the
+                // position is `PopupMenuPosition.under`. Setting it to zero makes
+                // it easier to test.
+                padding: EdgeInsets.zero,
+                key: popupButtonKey,
+                itemBuilder: (BuildContext context) {
+                  return <PopupMenuEntry<Object>>[
+                    PopupMenuItem<Object>(
+                      key: disabledPopupItemKey,
+                      enabled: false,
+                      child: const Text('disabled'),
+                    ),
+                    const PopupMenuDivider(),
+                    PopupMenuItem<Object>(
+                      key: enabledPopupItemKey,
+                      onTap: () {},
+                      child: const Text('enabled'),
+                    ),
+                    const CheckedPopupMenuItem<Object>(child: Text('Unchecked item')),
+                    const CheckedPopupMenuItem<Object>(checked: true, child: Text('Checked item')),
+                  ];
+                },
+              ),
+            ],
+          ),
         ),
       ),
-    ));
+    );
 
     expect(_iconStyle(tester, Icons.adaptive.more)?.color, popupMenuTheme.iconColor);
-    expect(tester.getSize(find.byIcon(Icons.adaptive.more)), Size(popupMenuTheme.iconSize!, popupMenuTheme.iconSize!));
+    expect(
+      tester.getSize(find.byIcon(Icons.adaptive.more)),
+      Size(popupMenuTheme.iconSize!, popupMenuTheme.iconSize!),
+    );
 
     await tester.tap(find.byKey(popupButtonKey));
     await tester.pumpAndSettle();
@@ -312,38 +308,31 @@ void main() {
     /// that is of type Material, this code retrieves the built
     /// [PopupMenuButton].
     final Material button = tester.widget<Material>(
-      find.descendant(
-        of: find.byKey(popupButtonApp),
-        matching: find.byType(Material),
-      ).last,
+      find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
     );
     expect(button.color, Colors.orange);
     expect(button.surfaceTintColor, const Color(0xff00ff00));
     expect(button.shadowColor, const Color(0xff00ff00));
-    expect(button.shape, const BeveledRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))));
+    expect(
+      button.shape,
+      const BeveledRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(12))),
+    );
     expect(button.elevation, 12.0);
 
     DefaultTextStyle popupMenuItemLabel = tester.widget<DefaultTextStyle>(
-      find.descendant(
-        of: find.byKey(enabledPopupItemKey),
-        matching: find.byType(DefaultTextStyle),
-      ).last,
-    );
-    expect(
-      popupMenuItemLabel.style,
-      popupMenuTheme.labelTextStyle?.resolve(enabled),
+      find
+          .descendant(of: find.byKey(enabledPopupItemKey), matching: find.byType(DefaultTextStyle))
+          .last,
     );
+    expect(popupMenuItemLabel.style, popupMenuTheme.labelTextStyle?.resolve(enabled));
+
     /// Test disabled text color
     popupMenuItemLabel = tester.widget<DefaultTextStyle>(
-      find.descendant(
-        of: find.byKey(disabledPopupItemKey),
-        matching: find.byType(DefaultTextStyle),
-      ).last,
-    );
-    expect(
-      popupMenuItemLabel.style,
-      popupMenuTheme.labelTextStyle?.resolve(disabled),
+      find
+          .descendant(of: find.byKey(disabledPopupItemKey), matching: find.byType(DefaultTextStyle))
+          .last,
     );
+    expect(popupMenuItemLabel.style, popupMenuTheme.labelTextStyle?.resolve(disabled));
 
     final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
     await gesture.addPointer();
@@ -370,7 +359,9 @@ void main() {
     expect(listTile.titleTextStyle, popupMenuTheme.labelTextStyle?.resolve(enabled));
 
     // Check popup menu padding.
-    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(find.byType(SingleChildScrollView));
+    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(
+      find.byType(SingleChildScrollView),
+    );
     expect(popupMenu.padding, popupMenuTheme.menuPadding);
   });
 
@@ -389,46 +380,48 @@ void main() {
     const EdgeInsets menuPadding = EdgeInsets.zero;
     const double elevation = 7.0;
     const TextStyle textStyle = TextStyle(color: Color(0xfff14fff), fontSize: 19.0);
-    const MouseCursor cursor =  SystemMouseCursors.forbidden;
+    const MouseCursor cursor = SystemMouseCursors.forbidden;
     const Color iconColor = Color(0xfff15fff);
     const double iconSize = 21.5;
 
-    await tester.pumpWidget(MaterialApp(
-      theme: ThemeData(useMaterial3: true, popupMenuTheme: popupMenuTheme),
-      key: popupButtonApp,
-      home: Material(
-        child: Column(
-          children: <Widget>[
-            PopupMenuButton<void>(
-              key: popupButtonKey,
-              elevation: elevation,
-              shadowColor: shadowColor,
-              surfaceTintColor: surfaceTintColor,
-              color: color,
-              shape: shape,
-              menuPadding: menuPadding,
-              iconColor: iconColor,
-              iconSize: iconSize,
-              itemBuilder: (BuildContext context) {
-                return <PopupMenuEntry<void>>[
-                  PopupMenuItem<void>(
-                    key: popupItemKey,
-                    labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
-                    mouseCursor: cursor,
-                    child: const Text('Example'),
-                  ),
-                  CheckedPopupMenuItem<void>(
-                    checked: true,
-                    labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
-                    child: const Text('Checked item'),
-                  )
-                ];
-              },
-            ),
-          ],
+    await tester.pumpWidget(
+      MaterialApp(
+        theme: ThemeData(popupMenuTheme: popupMenuTheme),
+        key: popupButtonApp,
+        home: Material(
+          child: Column(
+            children: <Widget>[
+              PopupMenuButton<void>(
+                key: popupButtonKey,
+                elevation: elevation,
+                shadowColor: shadowColor,
+                surfaceTintColor: surfaceTintColor,
+                color: color,
+                shape: shape,
+                menuPadding: menuPadding,
+                iconColor: iconColor,
+                iconSize: iconSize,
+                itemBuilder: (BuildContext context) {
+                  return <PopupMenuEntry<void>>[
+                    PopupMenuItem<void>(
+                      key: popupItemKey,
+                      labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
+                      mouseCursor: cursor,
+                      child: const Text('Example'),
+                    ),
+                    CheckedPopupMenuItem<void>(
+                      checked: true,
+                      labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
+                      child: const Text('Checked item'),
+                    ),
+                  ];
+                },
+              ),
+            ],
+          ),
         ),
       ),
-    ));
+    );
 
     expect(_iconStyle(tester, Icons.adaptive.more)?.color, iconColor);
     expect(tester.getSize(find.byIcon(Icons.adaptive.more)), const Size(iconSize, iconSize));
@@ -441,10 +434,7 @@ void main() {
     /// that is of type Material, this code retrieves the built
     /// [PopupMenuButton].
     final Material button = tester.widget<Material>(
-      find.descendant(
-        of: find.byKey(popupButtonApp),
-        matching: find.byType(Material),
-      ).last,
+      find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
     );
     expect(button.color, color);
     expect(button.shape, shape);
@@ -457,10 +447,7 @@ void main() {
     /// popupItemKey that is of type DefaultTextStyle, this code retrieves the
     /// built [PopupMenuItem].
     final DefaultTextStyle text = tester.widget<DefaultTextStyle>(
-      find.descendant(
-        of: find.byKey(popupItemKey),
-        matching: find.byType(DefaultTextStyle),
-      ).last,
+      find.descendant(of: find.byKey(popupItemKey), matching: find.byType(DefaultTextStyle)).last,
     );
     expect(text.style, textStyle);
 
@@ -476,7 +463,9 @@ void main() {
     expect(listTile.titleTextStyle, textStyle);
 
     // Check popup menu padding.
-    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(find.byType(SingleChildScrollView));
+    final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(
+      find.byType(SingleChildScrollView),
+    );
     expect(popupMenu.padding, EdgeInsets.zero);
   });
 
@@ -486,44 +475,46 @@ void main() {
     // can be deleted.
 
     testWidgets('Passing no PopupMenuThemeData returns defaults', (WidgetTester tester) async {
-     final Key popupButtonKey = UniqueKey();
+      final Key popupButtonKey = UniqueKey();
       final Key popupButtonApp = UniqueKey();
       final Key enabledPopupItemKey = UniqueKey();
       final Key disabledPopupItemKey = UniqueKey();
       final ThemeData theme = ThemeData(useMaterial3: false);
 
-      await tester.pumpWidget(MaterialApp(
-        theme: theme,
-        key: popupButtonApp,
-        home: Material(
-          child: Column(
-            children: <Widget>[
-              Padding(
-              // The padding makes sure the menu has enough space around it to
-              // get properly aligned when displayed (`_kMenuScreenPadding`).
-              padding: const EdgeInsets.all(8.0),
-                child: PopupMenuButton<void>(
-                  key: popupButtonKey,
-                  itemBuilder: (BuildContext context) {
-                    return <PopupMenuEntry<void>>[
-                      PopupMenuItem<void>(
-                        key: enabledPopupItemKey,
-                        child: const Text('Enabled PopupMenuItem'),
-                      ),
-                      const PopupMenuDivider(),
-                      PopupMenuItem<void>(
-                        key: disabledPopupItemKey,
-                        enabled: false,
-                        child: const Text('Disabled PopupMenuItem'),
-                      ),
-                    ];
-                  },
+      await tester.pumpWidget(
+        MaterialApp(
+          theme: theme,
+          key: popupButtonApp,
+          home: Material(
+            child: Column(
+              children: <Widget>[
+                Padding(
+                  // The padding makes sure the menu has enough space around it to
+                  // get properly aligned when displayed (`_kMenuScreenPadding`).
+                  padding: const EdgeInsets.all(8.0),
+                  child: PopupMenuButton<void>(
+                    key: popupButtonKey,
+                    itemBuilder: (BuildContext context) {
+                      return <PopupMenuEntry<void>>[
+                        PopupMenuItem<void>(
+                          key: enabledPopupItemKey,
+                          child: const Text('Enabled PopupMenuItem'),
+                        ),
+                        const PopupMenuDivider(),
+                        PopupMenuItem<void>(
+                          key: disabledPopupItemKey,
+                          enabled: false,
+                          child: const Text('Disabled PopupMenuItem'),
+                        ),
+                      ];
+                    },
+                  ),
                 ),
-              ),
-            ],
+              ],
+            ),
           ),
         ),
-      ));
+      );
 
       await tester.tap(find.byKey(popupButtonKey));
       await tester.pumpAndSettle();
@@ -533,10 +524,7 @@ void main() {
       /// that is of type Material, this code retrieves the built
       /// [PopupMenuButton].
       final Material button = tester.widget<Material>(
-        find.descendant(
-          of: find.byKey(popupButtonApp),
-          matching: find.byType(Material),
-        ).last,
+        find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
       );
       expect(button.color, null);
       expect(button.shape, null);
@@ -547,19 +535,24 @@ void main() {
       /// popupItemKey that is of type DefaultTextStyle, this code retrieves the
       /// built [PopupMenuItem].
       final DefaultTextStyle enabledText = tester.widget<DefaultTextStyle>(
-        find.descendant(
-          of: find.byKey(enabledPopupItemKey),
-          matching: find.byType(DefaultTextStyle),
-        ).last,
+        find
+            .descendant(
+              of: find.byKey(enabledPopupItemKey),
+              matching: find.byType(DefaultTextStyle),
+            )
+            .last,
       );
       expect(enabledText.style.fontFamily, 'Roboto');
       expect(enabledText.style.color, const Color(0xdd000000));
+
       /// Test disabled text color
       final DefaultTextStyle disabledText = tester.widget<DefaultTextStyle>(
-        find.descendant(
-          of: find.byKey(disabledPopupItemKey),
-          matching: find.byType(DefaultTextStyle),
-        ).last,
+        find
+            .descendant(
+              of: find.byKey(disabledPopupItemKey),
+              matching: find.byType(DefaultTextStyle),
+            )
+            .last,
       );
       expect(disabledText.style.color, theme.disabledColor);
 
@@ -584,7 +577,9 @@ void main() {
       );
 
       // Check popup menu padding.
-      final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(find.byType(SingleChildScrollView));
+      final SingleChildScrollView popupMenu = tester.widget<SingleChildScrollView>(
+        find.byType(SingleChildScrollView),
+      );
       expect(popupMenu.padding, const EdgeInsets.symmetric(vertical: 8.0));
     });
 
@@ -595,38 +590,40 @@ void main() {
       final Key enabledPopupItemKey = UniqueKey();
       final Key disabledPopupItemKey = UniqueKey();
 
-      await tester.pumpWidget(MaterialApp(
-        theme: ThemeData(popupMenuTheme: popupMenuTheme, useMaterial3: false),
-        key: popupButtonApp,
-        home: Material(
-          child: Column(
-            children: <Widget>[
-              PopupMenuButton<void>(
-                // The padding is used in the positioning of the menu when the
-                // position is `PopupMenuPosition.under`. Setting it to zero makes
-                // it easier to test.
-                padding: EdgeInsets.zero,
-                key: popupButtonKey,
-                itemBuilder: (BuildContext context) {
-                  return <PopupMenuEntry<Object>>[
-                    PopupMenuItem<Object>(
-                      key: disabledPopupItemKey,
-                      enabled: false,
-                      child: const Text('disabled'),
-                    ),
-                    const PopupMenuDivider(),
-                    PopupMenuItem<Object>(
-                      key: enabledPopupItemKey,
-                      onTap: () { },
-                      child: const Text('enabled'),
-                    ),
-                  ];
-                },
-              ),
-            ],
+      await tester.pumpWidget(
+        MaterialApp(
+          theme: ThemeData(popupMenuTheme: popupMenuTheme, useMaterial3: false),
+          key: popupButtonApp,
+          home: Material(
+            child: Column(
+              children: <Widget>[
+                PopupMenuButton<void>(
+                  // The padding is used in the positioning of the menu when the
+                  // position is `PopupMenuPosition.under`. Setting it to zero makes
+                  // it easier to test.
+                  padding: EdgeInsets.zero,
+                  key: popupButtonKey,
+                  itemBuilder: (BuildContext context) {
+                    return <PopupMenuEntry<Object>>[
+                      PopupMenuItem<Object>(
+                        key: disabledPopupItemKey,
+                        enabled: false,
+                        child: const Text('disabled'),
+                      ),
+                      const PopupMenuDivider(),
+                      PopupMenuItem<Object>(
+                        key: enabledPopupItemKey,
+                        onTap: () {},
+                        child: const Text('enabled'),
+                      ),
+                    ];
+                  },
+                ),
+              ],
+            ),
           ),
         ),
-      ));
+      );
 
       await tester.tap(find.byKey(popupButtonKey));
       await tester.pumpAndSettle();
@@ -636,10 +633,7 @@ void main() {
       /// that is of type Material, this code retrieves the built
       /// [PopupMenuButton].
       final Material button = tester.widget<Material>(
-        find.descendant(
-          of: find.byKey(popupButtonApp),
-          matching: find.byType(Material),
-        ).last,
+        find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
       );
       expect(button.color, popupMenuTheme.color);
       expect(button.shape, popupMenuTheme.shape);
@@ -650,10 +644,12 @@ void main() {
       /// popupItemKey that is of type DefaultTextStyle, this code retrieves the
       /// built [PopupMenuItem].
       final DefaultTextStyle text = tester.widget<DefaultTextStyle>(
-        find.descendant(
-          of: find.byKey(enabledPopupItemKey),
-          matching: find.byType(DefaultTextStyle),
-        ).last,
+        find
+            .descendant(
+              of: find.byKey(enabledPopupItemKey),
+              matching: find.byType(DefaultTextStyle),
+            )
+            .last,
       );
       expect(text.style, popupMenuTheme.textStyle);
 
@@ -674,7 +670,9 @@ void main() {
       );
     });
 
-    testWidgets('Popup menu widget properties take priority over theme', (WidgetTester tester) async {
+    testWidgets('Popup menu widget properties take priority over theme', (
+      WidgetTester tester,
+    ) async {
       final PopupMenuThemeData popupMenuTheme = _popupMenuThemeM2();
       final Key popupButtonKey = UniqueKey();
       final Key popupButtonApp = UniqueKey();
@@ -688,36 +686,38 @@ void main() {
       );
       const double elevation = 7.0;
       const TextStyle textStyle = TextStyle(color: Color(0xffffffef), fontSize: 19.0);
-      const MouseCursor cursor =  SystemMouseCursors.forbidden;
+      const MouseCursor cursor = SystemMouseCursors.forbidden;
 
-      await tester.pumpWidget(MaterialApp(
-        theme: ThemeData(useMaterial3: true, popupMenuTheme: popupMenuTheme),
-        key: popupButtonApp,
-        home: Material(
-          child: Column(
-            children: <Widget>[
-              PopupMenuButton<void>(
-                key: popupButtonKey,
-                elevation: elevation,
-                shadowColor: shadowColor,
-                surfaceTintColor: surfaceTintColor,
-                color: color,
-                shape: shape,
-                itemBuilder: (BuildContext context) {
-                  return <PopupMenuEntry<void>>[
-                    PopupMenuItem<void>(
-                      key: popupItemKey,
-                      labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
-                      mouseCursor: cursor,
-                      child: const Text('Example'),
-                    ),
-                  ];
-                },
-              ),
-            ],
+      await tester.pumpWidget(
+        MaterialApp(
+          theme: ThemeData(popupMenuTheme: popupMenuTheme),
+          key: popupButtonApp,
+          home: Material(
+            child: Column(
+              children: <Widget>[
+                PopupMenuButton<void>(
+                  key: popupButtonKey,
+                  elevation: elevation,
+                  shadowColor: shadowColor,
+                  surfaceTintColor: surfaceTintColor,
+                  color: color,
+                  shape: shape,
+                  itemBuilder: (BuildContext context) {
+                    return <PopupMenuEntry<void>>[
+                      PopupMenuItem<void>(
+                        key: popupItemKey,
+                        labelTextStyle: MaterialStateProperty.all<TextStyle>(textStyle),
+                        mouseCursor: cursor,
+                        child: const Text('Example'),
+                      ),
+                    ];
+                  },
+                ),
+              ],
+            ),
           ),
         ),
-      ));
+      );
 
       await tester.tap(find.byKey(popupButtonKey));
       await tester.pumpAndSettle();
@@ -727,10 +727,7 @@ void main() {
       /// that is of type Material, this code retrieves the built
       /// [PopupMenuButton].
       final Material button = tester.widget<Material>(
-        find.descendant(
-          of: find.byKey(popupButtonApp),
-          matching: find.byType(Material),
-        ).last,
+        find.descendant(of: find.byKey(popupButtonApp), matching: find.byType(Material)).last,
       );
       expect(button.color, color);
       expect(button.shape, shape);
@@ -743,10 +740,7 @@ void main() {
       /// popupItemKey that is of type DefaultTextStyle, this code retrieves the
       /// built [PopupMenuItem].
       final DefaultTextStyle text = tester.widget<DefaultTextStyle>(
-        find.descendant(
-          of: find.byKey(popupItemKey),
-          matching: find.byType(DefaultTextStyle),
-        ).last,
+        find.descendant(of: find.byKey(popupItemKey), matching: find.byType(DefaultTextStyle)).last,
       );
       expect(text.style, textStyle);
 
@@ -764,8 +758,8 @@ Set<MaterialState> enabled = <MaterialState>{};
 Set<MaterialState> disabled = <MaterialState>{MaterialState.disabled};
 
 TextStyle? _iconStyle(WidgetTester tester, IconData icon) {
-  return tester.widget<RichText>(find.descendant(
-    of: find.byIcon(icon),
-    matching: find.byType(RichText),
-  )).text.style;
+  return tester
+      .widget<RichText>(find.descendant(of: find.byIcon(icon), matching: find.byType(RichText)))
+      .text
+      .style;
 }
