@@ -23,18 +23,42 @@ void main() {
 
   test('Typography on non-Apple platforms defaults to the correct font', () {
     expect(Typography.material2018().black.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.fuchsia).black.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.linux).black.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.linux).black.titleLarge!.fontFamilyFallback, <String>['Ubuntu', 'Cantarell', 'DejaVu Sans', 'Liberation Sans', 'Arial']);
-    expect(Typography.material2018(platform: TargetPlatform.windows).black.titleLarge!.fontFamily, 'Segoe UI');
+    expect(
+      Typography.material2018(platform: TargetPlatform.fuchsia).black.titleLarge!.fontFamily,
+      'Roboto',
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.linux).black.titleLarge!.fontFamily,
+      'Roboto',
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.linux).black.titleLarge!.fontFamilyFallback,
+      <String>['Ubuntu', 'Cantarell', 'DejaVu Sans', 'Liberation Sans', 'Arial'],
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.windows).black.titleLarge!.fontFamily,
+      'Segoe UI',
+    );
     expect(Typography.material2018().white.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.fuchsia).white.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.linux).white.titleLarge!.fontFamily, 'Roboto');
-    expect(Typography.material2018(platform: TargetPlatform.linux).white.titleLarge!.fontFamilyFallback, <String>['Ubuntu', 'Cantarell', 'DejaVu Sans', 'Liberation Sans', 'Arial']);
-    expect(Typography.material2018(platform: TargetPlatform.windows).white.titleLarge!.fontFamily, 'Segoe UI');
+    expect(
+      Typography.material2018(platform: TargetPlatform.fuchsia).white.titleLarge!.fontFamily,
+      'Roboto',
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.linux).white.titleLarge!.fontFamily,
+      'Roboto',
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.linux).white.titleLarge!.fontFamilyFallback,
+      <String>['Ubuntu', 'Cantarell', 'DejaVu Sans', 'Liberation Sans', 'Arial'],
+    );
+    expect(
+      Typography.material2018(platform: TargetPlatform.windows).white.titleLarge!.fontFamily,
+      'Segoe UI',
+    );
   });
 
-  // Ref: https://developer.apple.com/ios/human-interface-guidelines/visual-design/typography/
+  // Ref: https://developer.apple.com/design/human-interface-guidelines/typography/
   final Matcher isSanFranciscoDisplayFont = predicate((TextStyle s) {
     return s.fontFamily == 'CupertinoSystemDisplay';
   }, 'Uses SF Display font');
@@ -99,18 +123,23 @@ void main() {
       tall: Typography.tall2018,
     ).debugFillProperties(builder);
 
-    final List<String> nonDefaultPropertyNames = builder.properties
-      .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-      .map((DiagnosticsNode node) => node.name!).toList();
+    final List<String> nonDefaultPropertyNames =
+        builder.properties
+            .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+            .map((DiagnosticsNode node) => node.name!)
+            .toList();
 
     expect(nonDefaultPropertyNames, <String>['black', 'white', 'englishLike', 'dense', 'tall']);
   });
 
   test('Can lerp between different typographies', () {
     final List<Typography> all = <Typography>[
-      for (final TargetPlatform platform in TargetPlatform.values) Typography.material2014(platform: platform),
-      for (final TargetPlatform platform in TargetPlatform.values) Typography.material2018(platform: platform),
-      for (final TargetPlatform platform in TargetPlatform.values) Typography.material2021(platform: platform),
+      for (final TargetPlatform platform in TargetPlatform.values)
+        Typography.material2014(platform: platform),
+      for (final TargetPlatform platform in TargetPlatform.values)
+        Typography.material2018(platform: platform),
+      for (final TargetPlatform platform in TargetPlatform.values)
+        Typography.material2021(platform: platform),
     ];
 
     for (final Typography fromTypography in all) {
@@ -135,19 +164,19 @@ void main() {
     const FontWeight regular = FontWeight.w400;
     const FontWeight medium = FontWeight.w500;
 
-    // H1 Roboto light 96 -1.5
+    // Display Large Roboto light 96 -1.5
     expect(theme.displayLarge!.fontFamily, 'Roboto');
     expect(theme.displayLarge!.fontWeight, light);
     expect(theme.displayLarge!.fontSize, 96);
     expect(theme.displayLarge!.letterSpacing, -1.5);
 
-    // H2 Roboto light 60 -0.5
+    // Display Medium Roboto light 60 -0.5
     expect(theme.displayMedium!.fontFamily, 'Roboto');
     expect(theme.displayMedium!.fontWeight, light);
     expect(theme.displayMedium!.fontSize, 60);
     expect(theme.displayMedium!.letterSpacing, -0.5);
 
-    // H3 Roboto regular 48 0
+    // Display Small Roboto regular 48 0
     expect(theme.displaySmall!.fontFamily, 'Roboto');
     expect(theme.displaySmall!.fontWeight, regular);
     expect(theme.displaySmall!.fontSize, 48);
@@ -159,55 +188,55 @@ void main() {
     expect(theme.headlineLarge!.fontSize, 40);
     expect(theme.headlineLarge!.letterSpacing, 0.25);
 
-    // H4 Roboto regular 34 0.25
+    // Headline Medium Roboto regular 34 0.25
     expect(theme.headlineMedium!.fontFamily, 'Roboto');
     expect(theme.headlineMedium!.fontWeight, regular);
     expect(theme.headlineMedium!.fontSize, 34);
     expect(theme.headlineMedium!.letterSpacing, 0.25);
 
-    // H5 Roboto regular 24 0
+    // Headline Small Roboto regular 24 0
     expect(theme.headlineSmall!.fontFamily, 'Roboto');
     expect(theme.headlineSmall!.fontWeight, regular);
     expect(theme.headlineSmall!.fontSize, 24);
     expect(theme.headlineSmall!.letterSpacing, 0);
 
-    // H6 Roboto medium 20 0.15
+    // Title Large Roboto medium 20 0.15
     expect(theme.titleLarge!.fontFamily, 'Roboto');
     expect(theme.titleLarge!.fontWeight, medium);
     expect(theme.titleLarge!.fontSize, 20);
     expect(theme.titleLarge!.letterSpacing, 0.15);
 
-    // Subtitle1 Roboto regular 16 0.15
+    // Title Medium Roboto regular 16 0.15
     expect(theme.titleMedium!.fontFamily, 'Roboto');
     expect(theme.titleMedium!.fontWeight, regular);
     expect(theme.titleMedium!.fontSize, 16);
     expect(theme.titleMedium!.letterSpacing, 0.15);
 
-    // Subtitle2 Roboto medium 14 0.1
+    // Title Small Roboto medium 14 0.1
     expect(theme.titleSmall!.fontFamily, 'Roboto');
     expect(theme.titleSmall!.fontWeight, medium);
     expect(theme.titleSmall!.fontSize, 14);
     expect(theme.titleSmall!.letterSpacing, 0.1);
 
-    // Body1 Roboto regular 16 0.5
+    // Body Large Roboto regular 16 0.5
     expect(theme.bodyLarge!.fontFamily, 'Roboto');
     expect(theme.bodyLarge!.fontWeight, regular);
     expect(theme.bodyLarge!.fontSize, 16);
     expect(theme.bodyLarge!.letterSpacing, 0.5);
 
-    // Body2 Roboto regular 14 0.25
+    // Body Medium Roboto regular 14 0.25
     expect(theme.bodyMedium!.fontFamily, 'Roboto');
     expect(theme.bodyMedium!.fontWeight, regular);
     expect(theme.bodyMedium!.fontSize, 14);
     expect(theme.bodyMedium!.letterSpacing, 0.25);
 
-    // Caption Roboto regular 12 0.4
+    // Body Small Roboto regular 12 0.4
     expect(theme.bodySmall!.fontFamily, 'Roboto');
     expect(theme.bodySmall!.fontWeight, regular);
     expect(theme.bodySmall!.fontSize, 12);
     expect(theme.bodySmall!.letterSpacing, 0.4);
 
-    // BUTTON Roboto medium 14 1.25
+    // Label Large Roboto medium 14 1.25
     expect(theme.labelLarge!.fontFamily, 'Roboto');
     expect(theme.labelLarge!.fontWeight, medium);
     expect(theme.labelLarge!.fontSize, 14);
@@ -219,7 +248,7 @@ void main() {
     expect(theme.labelMedium!.fontSize, 11);
     expect(theme.labelMedium!.letterSpacing, 1.5);
 
-    // OVERLINE Roboto regular 10 1.5
+    // Label Small Roboto regular 10 1.5
     expect(theme.labelSmall!.fontFamily, 'Roboto');
     expect(theme.labelSmall!.fontWeight, regular);
     expect(theme.labelSmall!.fontSize, 10);
@@ -370,7 +399,7 @@ void main() {
   });
 
   test('Default M3 light textTheme styles all use onSurface', () {
-    final ThemeData theme = ThemeData(useMaterial3: true);
+    final ThemeData theme = ThemeData();
     final TextTheme textTheme = theme.textTheme;
     final Color dark = theme.colorScheme.onSurface;
     expect(textTheme.displayLarge!.color, dark);
@@ -391,7 +420,7 @@ void main() {
   });
 
   test('Default M3 dark textTheme styles all use onSurface', () {
-    final ThemeData theme = ThemeData(useMaterial3: true, brightness: Brightness.dark);
+    final ThemeData theme = ThemeData(brightness: Brightness.dark);
     final TextTheme textTheme = theme.textTheme;
     final Color light = theme.colorScheme.onSurface;
     expect(textTheme.displayLarge!.color, light);
