@@ -38,9 +38,7 @@ void main() {
   // `logEvents`.
   // This annotation also contains a cursor with a value of `testCursor`.
   // The mouse tracker records the cursor requests it receives to `logCursors`.
-  TestAnnotationTarget setUpWithOneAnnotation({
-    required List<PointerEvent> logEvents,
-  }) {
+  TestAnnotationTarget setUpWithOneAnnotation({required List<PointerEvent> logEvents}) {
     final TestAnnotationTarget oneAnnotation = TestAnnotationTarget(
       onEnter: (PointerEnterEvent event) {
         logEvents.add(event);
@@ -52,18 +50,18 @@ void main() {
         logEvents.add(event);
       },
     );
-    setUpMouseAnnotationFinder(
-      (Offset position) sync* {
-        yield TestAnnotationEntry(oneAnnotation);
-      },
-    );
+    setUpMouseAnnotationFinder((Offset position) sync* {
+      yield TestAnnotationEntry(oneAnnotation);
+    });
     return oneAnnotation;
   }
 
   void dispatchRemoveDevice([int device = 0]) {
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, Offset.zero, device: device),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.remove, Offset.zero, device: device)],
+      ),
+    );
   }
 
   setUp(() {
@@ -72,71 +70,107 @@ void main() {
 
   final Matrix4 translate10by20 = Matrix4.translationValues(10, 20, 0);
 
-  test('should detect enter, hover, and exit from Added, Hover, and Removed events', () {
-    final List<PointerEvent> events = <PointerEvent>[];
-    setUpWithOneAnnotation(logEvents: events);
+  for (final ui.PointerDeviceKind pointerDeviceKind in <ui.PointerDeviceKind>[
+    ui.PointerDeviceKind.mouse,
+    ui.PointerDeviceKind.stylus,
+  ]) {
+    test(
+      'should detect enter, hover, and exit from Added, Hover, and Removed events for stylus',
+      () {
+        final List<PointerEvent> events = <PointerEvent>[];
+        setUpWithOneAnnotation(logEvents: events);
 
-    final List<bool> listenerLogs = <bool>[];
-    _mouseTracker.addListener(() {
-      listenerLogs.add(_mouseTracker.mouseIsConnected);
-    });
+        final List<bool> listenerLogs = <bool>[];
+        _mouseTracker.addListener(() {
+          listenerLogs.add(_mouseTracker.mouseIsConnected);
+        });
 
-    expect(_mouseTracker.mouseIsConnected, isFalse);
+        expect(_mouseTracker.mouseIsConnected, isFalse);
 
-    // Pointer enters the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, Offset.zero),
-    ]));
-    addTearDown(() => dispatchRemoveDevice());
+        // Pointer enters the annotation.
+        RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+          ui.PointerDataPacket(
+            data: <ui.PointerData>[
+              _pointerData(PointerChange.add, Offset.zero, kind: pointerDeviceKind),
+            ],
+          ),
+        );
+        addTearDown(() => dispatchRemoveDevice());
 
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent()),
-    ]));
-    expect(listenerLogs, <bool>[true]);
-    events.clear();
-    listenerLogs.clear();
+        expect(
+          events,
+          _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+            EventMatcher<PointerEnterEvent>(const PointerEnterEvent()),
+          ]),
+        );
+        expect(listenerLogs, <bool>[true]);
+        events.clear();
+        listenerLogs.clear();
 
-    // Pointer hovers the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(1.0, 101.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(1.0, 101.0))),
-    ]));
-    expect(_mouseTracker.mouseIsConnected, isTrue);
-    expect(listenerLogs, isEmpty);
-    events.clear();
+        // Pointer hovers the annotation.
+        RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+          ui.PointerDataPacket(
+            data: <ui.PointerData>[
+              _pointerData(PointerChange.hover, const Offset(1.0, 101.0), kind: pointerDeviceKind),
+            ],
+          ),
+        );
+        expect(
+          events,
+          _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+            EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(1.0, 101.0))),
+          ]),
+        );
+        expect(_mouseTracker.mouseIsConnected, isTrue);
+        expect(listenerLogs, isEmpty);
+        events.clear();
 
-    // Pointer is removed while on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, const Offset(1.0, 101.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(1.0, 101.0))),
-    ]));
-    expect(listenerLogs, <bool>[false]);
-    events.clear();
-    listenerLogs.clear();
+        // Pointer is removed while on the annotation.
+        RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+          ui.PointerDataPacket(
+            data: <ui.PointerData>[
+              _pointerData(PointerChange.remove, const Offset(1.0, 101.0), kind: pointerDeviceKind),
+            ],
+          ),
+        );
+        expect(
+          events,
+          _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+            EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(1.0, 101.0))),
+          ]),
+        );
+        expect(listenerLogs, <bool>[false]);
+        events.clear();
+        listenerLogs.clear();
 
-    // Pointer is added on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 301.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 301.0))),
-    ]));
-    expect(listenerLogs, <bool>[true]);
-    events.clear();
-    listenerLogs.clear();
-  });
+        // Pointer is added on the annotation.
+        RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+          ui.PointerDataPacket(
+            data: <ui.PointerData>[
+              _pointerData(PointerChange.add, const Offset(0.0, 301.0), kind: pointerDeviceKind),
+            ],
+          ),
+        );
+        expect(
+          events,
+          _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+            EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 301.0))),
+          ]),
+        );
+        expect(listenerLogs, <bool>[true]);
+        events.clear();
+        listenerLogs.clear();
+      },
+    );
+  }
 
   // Regression test for https://github.com/flutter/flutter/issues/90838
   test('should not crash if the first event is a Removed event', () {
     final List<PointerEvent> events = <PointerEvent>[];
     setUpWithOneAnnotation(logEvents: events);
-    binding.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, Offset.zero),
-    ]));
+    binding.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(data: <ui.PointerData>[_pointerData(PointerChange.remove, Offset.zero)]),
+    );
     events.clear();
   });
 
@@ -147,76 +181,131 @@ void main() {
     expect(_mouseTracker.mouseIsConnected, isFalse);
 
     // The first mouse is added on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, Offset.zero),
-      _pointerData(PointerChange.hover, const Offset(0.0, 1.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent()),
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(0.0, 1.0))),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.add, Offset.zero),
+          _pointerData(PointerChange.hover, const Offset(0.0, 1.0)),
+        ],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(const PointerEnterEvent()),
+        EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(0.0, 1.0))),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The second mouse is added on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 401.0), device: 1),
-      _pointerData(PointerChange.hover, const Offset(1.0, 401.0), device: 1),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 401.0), device: 1)),
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(1.0, 401.0), device: 1)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.add, const Offset(0.0, 401.0), device: 1),
+          _pointerData(PointerChange.hover, const Offset(1.0, 401.0), device: 1),
+        ],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(
+          const PointerEnterEvent(position: Offset(0.0, 401.0), device: 1),
+        ),
+        EventMatcher<PointerHoverEvent>(
+          const PointerHoverEvent(position: Offset(1.0, 401.0), device: 1),
+        ),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The first mouse moves on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 101.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(0.0, 101.0))),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 101.0))],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(0.0, 101.0))),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The second mouse moves on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(1.0, 501.0), device: 1),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(1.0, 501.0), device: 1)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.hover, const Offset(1.0, 501.0), device: 1),
+        ],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerHoverEvent>(
+          const PointerHoverEvent(position: Offset(1.0, 501.0), device: 1),
+        ),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The first mouse is removed while on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, const Offset(0.0, 101.0)),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(0.0, 101.0))),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.remove, const Offset(0.0, 101.0))],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(0.0, 101.0))),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The second mouse still moves on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(1.0, 601.0), device: 1),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(1.0, 601.0), device: 1)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.hover, const Offset(1.0, 601.0), device: 1),
+        ],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerHoverEvent>(
+          const PointerHoverEvent(position: Offset(1.0, 601.0), device: 1),
+        ),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isTrue);
     events.clear();
 
     // The second mouse is removed while on the annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, const Offset(1.0, 601.0), device: 1),
-    ]));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(1.0, 601.0), device: 1)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.remove, const Offset(1.0, 601.0), device: 1),
+        ],
+      ),
+    );
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(
+          const PointerExitEvent(position: Offset(1.0, 601.0), device: 1),
+        ),
+      ]),
+    );
     expect(_mouseTracker.mouseIsConnected, isFalse);
     events.clear();
   });
@@ -225,27 +314,38 @@ void main() {
     final List<PointerEvent> events = <PointerEvent>[];
     setUpWithOneAnnotation(logEvents: events);
 
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 101.0)),
-      _pointerData(PointerChange.down, const Offset(0.0, 101.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.add, const Offset(0.0, 101.0)),
+          _pointerData(PointerChange.down, const Offset(0.0, 101.0)),
+        ],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      // This Enter event is triggered by the [PointerAddedEvent] The
-      // [PointerDownEvent] is ignored by [MouseTracker].
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 101.0))),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        // This Enter event is triggered by the [PointerAddedEvent] The
+        // [PointerDownEvent] is ignored by [MouseTracker].
+        EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 101.0))),
+      ]),
+    );
     events.clear();
 
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.move, const Offset(0.0, 201.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.move, const Offset(0.0, 201.0))],
+      ),
+    );
     expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[]));
     events.clear();
 
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.up, const Offset(0.0, 301.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.up, const Offset(0.0, 301.0))],
+      ),
+    );
     expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[]));
     events.clear();
   });
@@ -267,9 +367,11 @@ void main() {
     isInHitRegion = false;
 
     // Connect a mouse when there is no annotation.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(0.0, 100.0))],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
     expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[]));
     expect(_mouseTracker.mouseIsConnected, isTrue);
@@ -281,9 +383,14 @@ void main() {
     expect(binding.postFrameCallbacks, hasLength(1));
 
     binding.flushPostFrameCallbacks(Duration.zero);
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0, 100)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(
+          const PointerEnterEvent(position: Offset(0, 100)).transformed(translate10by20),
+        ),
+      ]),
+    );
     events.clear();
 
     // Removing an annotation should trigger events.
@@ -292,9 +399,14 @@ void main() {
     expect(binding.postFrameCallbacks, hasLength(1));
 
     binding.flushPostFrameCallbacks(Duration.zero);
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(
+          const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
     expect(binding.postFrameCallbacks, hasLength(0));
   });
 
@@ -315,9 +427,11 @@ void main() {
     isInHitRegion = false;
 
     // Connect a mouse.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(0.0, 100.0))],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
     events.clear();
 
@@ -328,9 +442,14 @@ void main() {
     expect(binding.postFrameCallbacks, hasLength(1));
 
     binding.flushPostFrameCallbacks(Duration.zero);
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(
+          const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
     events.clear();
 
     expect(binding.postFrameCallbacks, hasLength(0));
@@ -342,9 +461,14 @@ void main() {
     expect(binding.postFrameCallbacks, hasLength(1));
 
     binding.flushPostFrameCallbacks(Duration.zero);
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(
+          const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
     expect(binding.postFrameCallbacks, hasLength(0));
   });
 
@@ -366,24 +490,38 @@ void main() {
 
     // Connect a mouse in the region. Should trigger Enter.
     isInHitRegion = true;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(0.0, 100.0))],
+      ),
+    );
 
     expect(binding.postFrameCallbacks, hasLength(0));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(
+          const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
     events.clear();
 
     // Disconnect the mouse from the region. Should trigger Exit.
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.remove, const Offset(0.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.remove, const Offset(0.0, 100.0))],
+      ),
+    );
     expect(binding.postFrameCallbacks, hasLength(0));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(
+          const PointerExitEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
   });
 
   test('should correctly handle when the pointer moves in or out of the annotation', () {
@@ -401,9 +539,11 @@ void main() {
     });
 
     isInHitRegion = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(200.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(200.0, 100.0))],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
 
     expect(binding.postFrameCallbacks, hasLength(0));
@@ -411,35 +551,54 @@ void main() {
 
     // Moves the mouse into the region. Should trigger Enter.
     isInHitRegion = true;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 100.0))],
+      ),
+    );
     expect(binding.postFrameCallbacks, hasLength(0));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerEnterEvent>(const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-      EventMatcher<PointerHoverEvent>(const PointerHoverEvent(position: Offset(0.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerEnterEvent>(
+          const PointerEnterEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+        EventMatcher<PointerHoverEvent>(
+          const PointerHoverEvent(position: Offset(0.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
     events.clear();
 
     // Moves the mouse out of the region. Should trigger Exit.
     isInHitRegion = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(200.0, 100.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(200.0, 100.0))],
+      ),
+    );
     expect(binding.postFrameCallbacks, hasLength(0));
-    expect(events, _equalToEventsOnCriticalFields(<BaseEventMatcher>[
-      EventMatcher<PointerExitEvent>(const PointerExitEvent(position: Offset(200.0, 100.0)).transformed(translate10by20)),
-    ]));
+    expect(
+      events,
+      _equalToEventsOnCriticalFields(<BaseEventMatcher>[
+        EventMatcher<PointerExitEvent>(
+          const PointerExitEvent(position: Offset(200.0, 100.0)).transformed(translate10by20),
+        ),
+      ]),
+    );
   });
 
   test('should not schedule post-frame callbacks when no mouse is connected', () {
-    setUpMouseAnnotationFinder((Offset position) sync* {
-    });
+    setUpMouseAnnotationFinder((Offset position) sync* {});
 
     // Connect a touch device, which should not be recognized by MouseTracker
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 100.0), kind: PointerDeviceKind.touch),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.add, const Offset(0.0, 100.0), kind: PointerDeviceKind.touch),
+        ],
+      ),
+    );
     expect(_mouseTracker.mouseIsConnected, isFalse);
 
     expect(binding.postFrameCallbacks, hasLength(0));
@@ -464,10 +623,14 @@ void main() {
 
     isInHitRegionOne = false;
     isInHitRegionTwo = true;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 101.0)),
-      _pointerData(PointerChange.hover, const Offset(1.0, 101.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[
+          _pointerData(PointerChange.add, const Offset(0.0, 101.0)),
+          _pointerData(PointerChange.hover, const Offset(1.0, 101.0)),
+        ],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
 
     // Passes if no errors are thrown.
@@ -505,25 +668,31 @@ void main() {
 
     // Starts out of A.
     isInB = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 1.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(0.0, 1.0))],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
     expect(logs, <String>[]);
 
     // Moves into B within one frame.
     isInB = true;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 10.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 10.0))],
+      ),
+    );
     expect(logs, <String>['enterA', 'enterB', 'hoverB', 'hoverA']);
     logs.clear();
 
     // Moves out of A within one frame.
     isInB = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 20.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 20.0))],
+      ),
+    );
     expect(logs, <String>['exitB', 'exitA']);
   });
 
@@ -560,9 +729,11 @@ void main() {
     // Starts within A.
     isInA = true;
     isInB = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.add, const Offset(0.0, 1.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.add, const Offset(0.0, 1.0))],
+      ),
+    );
     addTearDown(() => dispatchRemoveDevice());
     expect(logs, <String>['enterA']);
     logs.clear();
@@ -570,18 +741,22 @@ void main() {
     // Moves into B within one frame.
     isInA = false;
     isInB = true;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 10.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 10.0))],
+      ),
+    );
     expect(logs, <String>['exitA', 'enterB', 'hoverB']);
     logs.clear();
 
     // Moves into A within one frame.
     isInA = true;
     isInB = false;
-    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(ui.PointerDataPacket(data: <ui.PointerData>[
-      _pointerData(PointerChange.hover, const Offset(0.0, 1.0)),
-    ]));
+    RendererBinding.instance.platformDispatcher.onPointerDataPacket!(
+      ui.PointerDataPacket(
+        data: <ui.PointerData>[_pointerData(PointerChange.hover, const Offset(0.0, 1.0))],
+      ),
+    );
     expect(logs, <String>['exitB', 'enterA', 'hoverA']);
   });
 }
@@ -592,7 +767,8 @@ ui.PointerData _pointerData(
   int device = 0,
   PointerDeviceKind kind = PointerDeviceKind.mouse,
 }) {
-  final double devicePixelRatio = RendererBinding.instance.platformDispatcher.implicitView!.devicePixelRatio;
+  final double devicePixelRatio =
+      RendererBinding.instance.platformDispatcher.implicitView!.devicePixelRatio;
   return ui.PointerData(
     change: change,
     physicalX: logicalPosition.dx * devicePixelRatio,
@@ -607,7 +783,12 @@ class BaseEventMatcher extends Matcher {
 
   final PointerEvent expected;
 
-  bool _matchesField(Map<dynamic, dynamic> matchState, String field, dynamic actual, dynamic expected) {
+  bool _matchesField(
+    Map<dynamic, dynamic> matchState,
+    String field,
+    dynamic actual,
+    dynamic expected,
+  ) {
     if (actual != expected) {
       addStateInfo(matchState, <dynamic, dynamic>{
         'field': field,
@@ -622,12 +803,11 @@ class BaseEventMatcher extends Matcher {
   @override
   bool matches(dynamic untypedItem, Map<dynamic, dynamic> matchState) {
     final PointerEvent actual = untypedItem as PointerEvent;
-    if (!(
-      _matchesField(matchState, 'kind', actual.kind, PointerDeviceKind.mouse) &&
-      _matchesField(matchState, 'position', actual.position, expected.position) &&
-      _matchesField(matchState, 'device', actual.device, expected.device) &&
-      _matchesField(matchState, 'localPosition', actual.localPosition, expected.localPosition)
-    )) {
+    if (!((_matchesField(matchState, 'kind', actual.kind, PointerDeviceKind.mouse) ||
+            _matchesField(matchState, 'kind', actual.kind, PointerDeviceKind.stylus)) &&
+        _matchesField(matchState, 'position', actual.position, expected.position) &&
+        _matchesField(matchState, 'device', actual.device, expected.device) &&
+        _matchesField(matchState, 'localPosition', actual.localPosition, expected.localPosition))) {
       return false;
     }
     return true;
@@ -635,9 +815,7 @@ class BaseEventMatcher extends Matcher {
 
   @override
   Description describe(Description description) {
-    return description
-      .add('event (critical fields only) ')
-      .addDescriptionOf(expected);
+    return description.add('event (critical fields only) ').addDescriptionOf(expected);
   }
 
   @override
@@ -648,10 +826,10 @@ class BaseEventMatcher extends Matcher {
     bool verbose,
   ) {
     return mismatchDescription
-      .add('has ')
-      .addDescriptionOf(matchState['actual'])
-      .add(" at field `${matchState['field']}`, which doesn't match the expected ")
-      .addDescriptionOf(matchState['expected']);
+        .add('has ')
+        .addDescriptionOf(matchState['actual'])
+        .add(" at field `${matchState['field']}`, which doesn't match the expected ")
+        .addDescriptionOf(matchState['expected']);
   }
 }
 
@@ -676,10 +854,10 @@ class EventMatcher<T extends PointerEvent> extends BaseEventMatcher {
   ) {
     if (item is! T) {
       return mismatchDescription
-        .add('is ')
-        .addDescriptionOf(item.runtimeType)
-        .add(' and is not a subtype of ')
-        .addDescriptionOf(T);
+          .add('is ')
+          .addDescriptionOf(item.runtimeType)
+          .add(' and is not a subtype of ')
+          .addDescriptionOf(T);
     }
     return super.describeMismatch(item, mismatchDescription, matchState, verbose);
   }
@@ -722,9 +900,7 @@ class _EventListCriticalFieldsMatcher extends Matcher {
 
   @override
   Description describe(Description description) {
-    return description
-      .add('event list (critical fields only) ')
-      .addDescriptionOf(_expected);
+    return description.add('event list (critical fields only) ').addDescriptionOf(_expected);
   }
 
   @override
@@ -735,21 +911,20 @@ class _EventListCriticalFieldsMatcher extends Matcher {
     bool verbose,
   ) {
     if (item is! Iterable<PointerEvent>) {
-      return mismatchDescription
-        .add('is type ${item.runtimeType} instead of Iterable<PointerEvent>');
+      return mismatchDescription.add(
+        'is type ${item.runtimeType} instead of Iterable<PointerEvent>',
+      );
     } else if (item.length != _expected.length) {
-      return mismatchDescription
-        .add('has length ${item.length} instead of ${_expected.length}');
+      return mismatchDescription.add('has length ${item.length} instead of ${_expected.length}');
     } else if (matchState['matcher'] == null) {
-      return mismatchDescription
-        .add('met unexpected fatal error');
+      return mismatchDescription.add('met unexpected fatal error');
     } else {
       mismatchDescription
-        .add('has\n  ')
-        .addDescriptionOf(matchState['actual'])
-        .add("\nat index ${matchState['index']}, which doesn't match\n  ")
-        .addDescriptionOf(matchState['expected'])
-        .add('\nsince it ');
+          .add('has\n  ')
+          .addDescriptionOf(matchState['actual'])
+          .add("\nat index ${matchState['index']}, which doesn't match\n  ")
+          .addDescriptionOf(matchState['expected'])
+          .add('\nsince it ');
       final Description subDescription = StringDescription();
       final Matcher matcher = matchState['matcher'] as Matcher;
       matcher.describeMismatch(
