@@ -42,12 +42,18 @@ void main() {
     );
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pump(const Duration(seconds: 1));
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pumpWidget(
       Stack(
@@ -126,12 +132,18 @@ void main() {
     );
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pump(const Duration(seconds: 1));
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(50.0 + 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pumpWidget(
       Directionality(
@@ -212,12 +224,18 @@ void main() {
     );
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(800.0 - 50.0 - 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(800.0 - 50.0 - 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pump(const Duration(seconds: 1));
 
     box = key.currentContext!.findRenderObject()! as RenderBox;
-    expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(800.0 - 50.0 - 70.0 / 2.0, 30.0 + 110.0 / 2.0)));
+    expect(
+      box.localToGlobal(box.size.center(Offset.zero)),
+      equals(const Offset(800.0 - 50.0 - 70.0 / 2.0, 30.0 + 110.0 / 2.0)),
+    );
 
     await tester.pumpWidget(
       Directionality(
@@ -416,7 +434,9 @@ void main() {
     expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(350.0, 150.0)));
   });
 
-  testWidgets('AnimatedPositionedDirectional - interrupted animation (LTR)', (WidgetTester tester) async {
+  testWidgets('AnimatedPositionedDirectional - interrupted animation (LTR)', (
+    WidgetTester tester,
+  ) async {
     final GlobalKey key = GlobalKey();
 
     RenderBox box;
@@ -505,7 +525,9 @@ void main() {
     expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(200.0, 200.0)));
   });
 
-  testWidgets('AnimatedPositionedDirectional - switching variables (LTR)', (WidgetTester tester) async {
+  testWidgets('AnimatedPositionedDirectional - switching variables (LTR)', (
+    WidgetTester tester,
+  ) async {
     final GlobalKey key = GlobalKey();
 
     RenderBox box;
@@ -568,7 +590,9 @@ void main() {
     expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(350.0, 150.0)));
   });
 
-  testWidgets('AnimatedPositionedDirectional - interrupted animation (RTL)', (WidgetTester tester) async {
+  testWidgets('AnimatedPositionedDirectional - interrupted animation (RTL)', (
+    WidgetTester tester,
+  ) async {
     final GlobalKey key = GlobalKey();
 
     RenderBox box;
@@ -657,7 +681,9 @@ void main() {
     expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(600.0, 200.0)));
   });
 
-  testWidgets('AnimatedPositionedDirectional - switching variables (RTL)', (WidgetTester tester) async {
+  testWidgets('AnimatedPositionedDirectional - switching variables (RTL)', (
+    WidgetTester tester,
+  ) async {
     final GlobalKey key = GlobalKey();
 
     RenderBox box;
@@ -719,5 +745,4 @@ void main() {
     box = key.currentContext!.findRenderObject()! as RenderBox;
     expect(box.localToGlobal(box.size.center(Offset.zero)), equals(const Offset(450.0, 150.0)));
   });
-
 }
