@@ -17,15 +17,14 @@ class TestPaintingContext implements PaintingContext {
 
 void main() {
   group('AnimatedSize', () {
-    testWidgets('animates forwards then backwards with stable-sized children', (WidgetTester tester) async {
+    testWidgets('animates forwards then backwards with stable-sized children', (
+      WidgetTester tester,
+    ) async {
       await tester.pumpWidget(
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -38,10 +37,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 200.0,
-              height: 200.0,
-            ),
+            child: SizedBox(width: 200.0, height: 200.0),
           ),
         ),
       );
@@ -64,10 +60,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -98,10 +91,7 @@ void main() {
           child: AnimatedSize(
             onEnd: handleEnd,
             duration: const Duration(milliseconds: 200),
-            child: const SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: const SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -113,10 +103,7 @@ void main() {
           child: AnimatedSize(
             onEnd: handleEnd,
             duration: const Duration(milliseconds: 200),
-            child: const SizedBox(
-              width: 200.0,
-              height: 200.0,
-            ),
+            child: const SizedBox(width: 200.0, height: 200.0),
           ),
         ),
       );
@@ -130,10 +117,7 @@ void main() {
           child: AnimatedSize(
             onEnd: handleEnd,
             duration: const Duration(milliseconds: 200),
-            child: const SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: const SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -145,15 +129,12 @@ void main() {
     testWidgets('clamps animated size to constraints', (WidgetTester tester) async {
       await tester.pumpWidget(
         const Center(
-          child: SizedBox (
+          child: SizedBox(
             width: 100.0,
             height: 100.0,
             child: AnimatedSize(
               duration: Duration(milliseconds: 200),
-              child: SizedBox(
-                width: 100.0,
-                height: 100.0,
-              ),
+              child: SizedBox(width: 100.0, height: 100.0),
             ),
           ),
         ),
@@ -166,15 +147,12 @@ void main() {
       // Attempt to animate beyond the outer SizedBox.
       await tester.pumpWidget(
         const Center(
-          child: SizedBox (
+          child: SizedBox(
             width: 100.0,
             height: 100.0,
             child: AnimatedSize(
               duration: Duration(milliseconds: 200),
-              child: SizedBox(
-                width: 200.0,
-                height: 200.0,
-              ),
+              child: SizedBox(width: 200.0, height: 200.0),
             ),
           ),
         ),
@@ -187,12 +165,14 @@ void main() {
       expect(box.size.height, equals(100.0));
     });
 
-    testWidgets('tracks unstable child, then resumes animation when child stabilizes', (WidgetTester tester) async {
+    testWidgets('tracks unstable child, then resumes animation when child stabilizes', (
+      WidgetTester tester,
+    ) async {
       Future<void> pumpMillis(int millis) async {
         await tester.pump(Duration(milliseconds: millis));
       }
 
-      void verify({ double? size, RenderAnimatedSizeState? state }) {
+      void verify({double? size, RenderAnimatedSizeState? state}) {
         assert(size != null || state != null);
         final RenderAnimatedSize box = tester.renderObject(find.byType(AnimatedSize));
         if (size != null) {
@@ -275,10 +255,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -287,10 +264,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 200.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 200.0, height: 100.0),
           ),
         ),
       );
@@ -306,10 +280,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -329,10 +300,7 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
@@ -347,10 +315,7 @@ void main() {
             child: AnimatedSize(
               duration: const Duration(milliseconds: 200),
               clipBehavior: clip,
-              child: const SizedBox(
-                width: 100.0,
-                height: 100.0,
-              ),
+              child: const SizedBox(width: 100.0, height: 100.0),
             ),
           ),
         );
@@ -369,40 +334,55 @@ void main() {
                   AnimatedSize(
                     duration: const Duration(milliseconds: 200),
                     curve: Curves.easeInOutBack,
-                    child: SizedBox(
-                      width: size.width,
-                      height: size.height,
-                    ),
+                    child: SizedBox(width: size.width, height: size.height),
                   ),
                 ],
               ),
             ),
           ),
-          duration,
+          duration: duration,
         );
       }
 
       await pumpWidget(const Size(100, 100));
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(100, 100));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(100, 100),
+      );
 
       await pumpWidget(const Size(150, 200));
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(100, 100));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(100, 100),
+      );
 
       // Each pump triggers verification of dry layout.
       for (int total = 0; total < 200; total += 10) {
         await tester.pump(const Duration(milliseconds: 10));
       }
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(150, 200));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(150, 200),
+      );
 
       // Change every pump
       await pumpWidget(const Size(100, 100));
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(150, 200));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(150, 200),
+      );
 
       await pumpWidget(const Size(111, 111), const Duration(milliseconds: 10));
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(111, 111));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(111, 111),
+      );
 
       await pumpWidget(const Size(222, 222), const Duration(milliseconds: 10));
-      expect(tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size, const Size(222, 222));
+      expect(
+        tester.renderObject<RenderBox>(find.byType(IntrinsicHeight)).size,
+        const Size(222, 222),
+      );
     });
 
     testWidgets('re-attach with interrupted animation', (WidgetTester tester) async {
@@ -436,18 +416,11 @@ void main() {
           textDirection: TextDirection.ltr,
           child: Row(
             children: <Widget>[
-              SizedBox(
-                key: key1,
-                height: 200,
-                child: animatedSize,
-              ),
-              const SizedBox(
-                key: key2,
-                height: 200,
-              ),
+              SizedBox(key: key1, height: 200, child: animatedSize),
+              const SizedBox(key: key2, height: 200),
             ],
           ),
-        )
+        ),
       );
 
       setState(() {
@@ -463,15 +436,8 @@ void main() {
           textDirection: TextDirection.ltr,
           child: Row(
             children: <Widget>[
-              const SizedBox(
-                key: key1,
-                height: 200,
-              ),
-              SizedBox(
-                key: key2,
-                height: 200,
-                child: animatedSize,
-              ),
+              const SizedBox(key: key1, height: 200),
+              SizedBox(key: key2, height: 200, child: animatedSize),
             ],
           ),
         ),
@@ -494,35 +460,32 @@ void main() {
         const Center(
           child: AnimatedSize(
             duration: Duration(milliseconds: 200),
-            child: SizedBox(
-              width: 100.0,
-              height: 100.0,
-            ),
+            child: SizedBox(width: 100.0, height: 100.0),
           ),
         ),
       );
 
       final RenderAnimatedSize box = tester.renderObject(find.byType(AnimatedSize));
 
-      await tester.pumpWidget(
-        const Center(),
-      );
+      await tester.pumpWidget(const Center());
 
       expect(box.debugAnimation, isNotNull);
       expect(box.debugAnimation!.isDisposed, isTrue);
       expect(box.debugController, isNotNull);
       expect(
         () => box.debugController!.dispose(),
-        throwsA(isA<AssertionError>().having(
-          (AssertionError error) => error.message,
-          'message',
-          equalsIgnoringHashCodes(
-            'AnimationController.dispose() called more than once.\n'
-            'A given AnimationController cannot be disposed more than once.\n'
-            'The following AnimationController object was disposed multiple times:\n'
-            '  AnimationController#00000(⏮ 0.000; paused; DISPOSED)',
+        throwsA(
+          isA<AssertionError>().having(
+            (AssertionError error) => error.message,
+            'message',
+            equalsIgnoringHashCodes(
+              'AnimationController.dispose() called more than once.\n'
+              'A given AnimationController cannot be disposed more than once.\n'
+              'The following AnimationController object was disposed multiple times:\n'
+              '  AnimationController#00000(⏮ 0.000; paused; DISPOSED)',
+            ),
           ),
-        )),
+        ),
       );
     });
   });
