@@ -9,7 +9,7 @@ import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 class Leaf extends StatefulWidget {
-  const Leaf({ required Key key, required this.child }) : super(key: key);
+  const Leaf({required Key super.key, required this.child});
   final Widget child;
   @override
   State<Leaf> createState() => _LeafState();
@@ -49,24 +49,17 @@ class _LeafState extends State<Leaf> {
   }
 }
 
-List<Widget> generateList(Widget child, { required bool impliedMode }) {
-  return List<Widget>.generate(
-    100,
-    (int index) {
-      final Widget result = Leaf(
-        key: GlobalObjectKey<_LeafState>(index),
-        child: child,
-      );
-      if (impliedMode) {
-        return result;
-      }
-      return AutomaticKeepAlive(child: result);
-    },
-    growable: false,
-  );
+List<Widget> generateList(Widget child, {required bool impliedMode}) {
+  return List<Widget>.generate(100, (int index) {
+    final Widget result = Leaf(key: GlobalObjectKey<_LeafState>(index), child: child);
+    if (impliedMode) {
+      return result;
+    }
+    return AutomaticKeepAlive(child: result);
+  }, growable: false);
 }
 
-void tests({ required bool impliedMode }) {
+void tests({required bool impliedMode}) {
   testWidgets('AutomaticKeepAlive with ListView with itemExtent', (WidgetTester tester) async {
     await tester.pumpWidget(
       Directionality(
@@ -176,10 +169,7 @@ void tests({ required bool impliedMode }) {
           crossAxisCount: 2,
           childAspectRatio: 400.0 / 24.6, // about 50 widgets visible
           cacheExtent: 0.0,
-          children: generateList(
-            const Placeholder(),
-            impliedMode: impliedMode,
-          ),
+          children: generateList(const Placeholder(), impliedMode: impliedMode),
         ),
       ),
     );
@@ -219,8 +209,12 @@ void tests({ required bool impliedMode }) {
 }
 
 void main() {
-  group('Explicit automatic keep-alive', () { tests(impliedMode: false); });
-  group('Implied automatic keep-alive', () { tests(impliedMode: true); });
+  group('Explicit automatic keep-alive', () {
+    tests(impliedMode: false);
+  });
+  group('Implied automatic keep-alive', () {
+    tests(impliedMode: true);
+  });
 
   testWidgets('AutomaticKeepAlive double', (WidgetTester tester) async {
     await tester.pumpWidget(
@@ -235,24 +229,16 @@ void main() {
             AutomaticKeepAlive(
               child: SizedBox(
                 height: 400.0,
-                child: Stack(children: <Widget>[
-                  Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
-                  Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
-                ]),
-              ),
-            ),
-            AutomaticKeepAlive(
-              child: SizedBox(
-                key: GlobalObjectKey<_LeafState>(2),
-                height: 400.0,
-              ),
-            ),
-            AutomaticKeepAlive(
-              child: SizedBox(
-                key: GlobalObjectKey<_LeafState>(3),
-                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
+                  ],
+                ),
               ),
             ),
+            AutomaticKeepAlive(child: SizedBox(key: GlobalObjectKey<_LeafState>(2), height: 400.0)),
+            AutomaticKeepAlive(child: SizedBox(key: GlobalObjectKey<_LeafState>(3), height: 400.0)),
           ],
         ),
       ),
@@ -319,28 +305,34 @@ void main() {
             AutomaticKeepAlive(
               child: SizedBox(
                 height: 400.0,
-                child: Stack(children: <Widget>[
-                  Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
-                  Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
-                ]),
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
+                  ],
+                ),
               ),
             ),
             AutomaticKeepAlive(
               child: SizedBox(
                 height: 400.0,
-                child: Stack(children: <Widget>[
-                  Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
-                  Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
-                ]),
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
+                  ],
+                ),
               ),
             ),
             AutomaticKeepAlive(
               child: SizedBox(
                 height: 400.0,
-                child: Stack(children: <Widget>[
-                  Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
-                  Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
-                ]),
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
+                  ],
+                ),
               ),
             ),
           ],
@@ -364,44 +356,52 @@ void main() {
     expect(find.byKey(const GlobalObjectKey<_LeafState>(3)), findsOneWidget);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(4)), findsOneWidget);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(5)), findsOneWidget);
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: ListView(
-        addAutomaticKeepAlives: false,
-        addRepaintBoundaries: false,
-        addSemanticIndexes: false,
-        cacheExtent: 0.0,
-        children: const <Widget>[
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(children: <Widget>[
-                Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
-              ]),
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView(
+          addAutomaticKeepAlives: false,
+          addRepaintBoundaries: false,
+          addSemanticIndexes: false,
+          cacheExtent: 0.0,
+          children: const <Widget>[
+            AutomaticKeepAlive(
+              child: SizedBox(
+                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
+                  ],
+                ),
+              ),
             ),
-          ),
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(children: <Widget>[
-                Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
-              ]),
+            AutomaticKeepAlive(
+              child: SizedBox(
+                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
+                  ],
+                ),
+              ),
             ),
-          ),
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(children: <Widget>[
-                Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
-              ]),
+            AutomaticKeepAlive(
+              child: SizedBox(
+                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
+                  ],
+                ),
+              ),
             ),
-          ),
-        ],
+          ],
+        ),
       ),
-    ));
+    );
     await tester.pump(); // Sometimes AutomaticKeepAlive needs an extra pump to clean things up.
     expect(find.byKey(const GlobalObjectKey<_LeafState>(1), skipOffstage: false), findsNothing);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(2)), findsOneWidget);
@@ -428,43 +428,44 @@ void main() {
     expect(find.byKey(const GlobalObjectKey<_LeafState>(4), skipOffstage: false), findsNothing);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(5), skipOffstage: false), findsNothing);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(0), skipOffstage: false), findsNothing);
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: ListView(
-        addAutomaticKeepAlives: false,
-        addRepaintBoundaries: false,
-        addSemanticIndexes: false,
-        cacheExtent: 0.0,
-        children: const <Widget>[
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(children: <Widget>[
-                Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
-              ]),
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView(
+          addAutomaticKeepAlives: false,
+          addRepaintBoundaries: false,
+          addSemanticIndexes: false,
+          cacheExtent: 0.0,
+          children: const <Widget>[
+            AutomaticKeepAlive(
+              child: SizedBox(
+                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(1), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(2), child: Placeholder()),
+                  ],
+                ),
+              ),
             ),
-          ),
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(),
+            AutomaticKeepAlive(child: SizedBox(height: 400.0, child: Stack())),
+            AutomaticKeepAlive(
+              child: SizedBox(
+                height: 400.0,
+                child: Stack(
+                  children: <Widget>[
+                    Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
+                    Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
+                  ],
+                ),
+              ),
             ),
-          ),
-          AutomaticKeepAlive(
-            child: SizedBox(
-              height: 400.0,
-              child: Stack(children: <Widget>[
-                Leaf(key: GlobalObjectKey<_LeafState>(3), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(4), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(5), child: Placeholder()),
-                Leaf(key: GlobalObjectKey<_LeafState>(0), child: Placeholder()),
-              ]),
-            ),
-          ),
-        ],
+          ],
+        ),
       ),
-    ));
+    );
     await tester.pump(); // Sometimes AutomaticKeepAlive needs an extra pump to clean things up.
     expect(find.byKey(const GlobalObjectKey<_LeafState>(1)), findsOneWidget);
     expect(find.byKey(const GlobalObjectKey<_LeafState>(2)), findsOneWidget);
@@ -474,26 +475,25 @@ void main() {
     expect(find.byKey(const GlobalObjectKey<_LeafState>(0), skipOffstage: false), findsNothing);
   });
 
-  testWidgets('AutomaticKeepAlive with keepAlive set to true before initState', (WidgetTester tester) async {
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: ListView.builder(
-        dragStartBehavior: DragStartBehavior.down,
-        addSemanticIndexes: false,
-        itemCount: 50,
-        itemBuilder: (BuildContext context, int index) {
-          if (index == 0) {
-            return const _AlwaysKeepAlive(
-              key: GlobalObjectKey<_AlwaysKeepAliveState>(0),
-            );
-          }
-          return SizedBox(
-            height: 44.0,
-            child: Text('FooBar $index'),
-          );
-        },
+  testWidgets('AutomaticKeepAlive with keepAlive set to true before initState', (
+    WidgetTester tester,
+  ) async {
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          dragStartBehavior: DragStartBehavior.down,
+          addSemanticIndexes: false,
+          itemCount: 50,
+          itemBuilder: (BuildContext context, int index) {
+            if (index == 0) {
+              return const _AlwaysKeepAlive(key: GlobalObjectKey<_AlwaysKeepAliveState>(0));
+            }
+            return SizedBox(height: 44.0, child: Text('FooBar $index'));
+          },
+        ),
       ),
-    ));
+    );
 
     expect(find.text('keep me alive'), findsOneWidget);
     expect(find.text('FooBar 1'), findsOneWidget);
@@ -502,51 +502,57 @@ void main() {
     expect(find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0)), findsOneWidget);
     await tester.drag(find.byType(ListView), const Offset(0.0, -1000.0)); // move to bottom
     await tester.pump();
-    expect(find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0), skipOffstage: false), findsOneWidget);
+    expect(
+      find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0), skipOffstage: false),
+      findsOneWidget,
+    );
 
     expect(find.text('keep me alive', skipOffstage: false), findsOneWidget);
     expect(find.text('FooBar 1'), findsNothing);
     expect(find.text('FooBar 2'), findsNothing);
   });
 
-  testWidgets('AutomaticKeepAlive with keepAlive set to true before initState and widget goes out of scope', (WidgetTester tester) async {
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: ListView.builder(
-        addSemanticIndexes: false,
-        itemCount: 250,
-        itemBuilder: (BuildContext context, int index) {
-          if (index.isEven) {
-            return _AlwaysKeepAlive(
-              key: GlobalObjectKey<_AlwaysKeepAliveState>(index),
-            );
-          }
-          return SizedBox(
-            height: 44.0,
-            child: Text('FooBar $index'),
-          );
-        },
-      ),
-    ));
+  testWidgets(
+    'AutomaticKeepAlive with keepAlive set to true before initState and widget goes out of scope',
+    (WidgetTester tester) async {
+      await tester.pumpWidget(
+        Directionality(
+          textDirection: TextDirection.ltr,
+          child: ListView.builder(
+            addSemanticIndexes: false,
+            itemCount: 250,
+            itemBuilder: (BuildContext context, int index) {
+              if (index.isEven) {
+                return _AlwaysKeepAlive(key: GlobalObjectKey<_AlwaysKeepAliveState>(index));
+              }
+              return SizedBox(height: 44.0, child: Text('FooBar $index'));
+            },
+          ),
+        ),
+      );
 
-    expect(find.text('keep me alive'), findsNWidgets(7));
-    expect(find.text('FooBar 1'), findsOneWidget);
-    expect(find.text('FooBar 3'), findsOneWidget);
+      expect(find.text('keep me alive'), findsNWidgets(7));
+      expect(find.text('FooBar 1'), findsOneWidget);
+      expect(find.text('FooBar 3'), findsOneWidget);
 
-    expect(find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0)), findsOneWidget);
+      expect(find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0)), findsOneWidget);
 
-    final ScrollableState state = tester.state(find.byType(Scrollable));
-    final ScrollPosition position = state.position;
-    position.jumpTo(3025.0);
+      final ScrollableState state = tester.state(find.byType(Scrollable));
+      final ScrollPosition position = state.position;
+      position.jumpTo(3025.0);
 
-    await tester.pump();
-    expect(find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0), skipOffstage: false), findsOneWidget);
+      await tester.pump();
+      expect(
+        find.byKey(const GlobalObjectKey<_AlwaysKeepAliveState>(0), skipOffstage: false),
+        findsOneWidget,
+      );
 
-    expect(find.text('keep me alive', skipOffstage: false), findsNWidgets(23));
-    expect(find.text('FooBar 1'), findsNothing);
-    expect(find.text('FooBar 3'), findsNothing);
-    expect(find.text('FooBar 73'), findsOneWidget);
-  });
+      expect(find.text('keep me alive', skipOffstage: false), findsNWidgets(23));
+      expect(find.text('FooBar 1'), findsNothing);
+      expect(find.text('FooBar 3'), findsNothing);
+      expect(find.text('FooBar 73'), findsOneWidget);
+    },
+  );
 
   testWidgets('AutomaticKeepAlive with SliverKeepAliveWidget', (WidgetTester tester) async {
     // We're just doing a basic test here to make sure that the functionality of
@@ -561,19 +567,26 @@ void main() {
     expect(alternate.children.length, 1);
   });
 
-  testWidgets('Keep alive Listenable has its listener removed once called', (WidgetTester tester) async {
+  testWidgets('Keep alive Listenable has its listener removed once called', (
+    WidgetTester tester,
+  ) async {
     final LeakCheckerHandle handle = LeakCheckerHandle();
     addTearDown(handle.dispose);
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: ListView.builder(
-        itemCount: 1,
-        itemBuilder: (BuildContext context, int index) {
-          return const KeepAliveListenableLeakChecker(key: GlobalObjectKey<_KeepAliveListenableLeakCheckerState>(0));
-        },
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          itemCount: 1,
+          itemBuilder: (BuildContext context, int index) {
+            return const KeepAliveListenableLeakChecker(
+              key: GlobalObjectKey<_KeepAliveListenableLeakCheckerState>(0),
+            );
+          },
+        ),
       ),
-    ));
-    final _KeepAliveListenableLeakCheckerState state = const GlobalObjectKey<_KeepAliveListenableLeakCheckerState>(0).currentState!;
+    );
+    final _KeepAliveListenableLeakCheckerState state =
+        const GlobalObjectKey<_KeepAliveListenableLeakCheckerState>(0).currentState!;
 
     expect(handle.hasListeners, false);
     state.dispatch(handle);
@@ -584,27 +597,25 @@ void main() {
 }
 
 class _AlwaysKeepAlive extends StatefulWidget {
-  const _AlwaysKeepAlive({ required Key key }) : super(key: key);
+  const _AlwaysKeepAlive({required Key super.key});
 
   @override
   State<StatefulWidget> createState() => _AlwaysKeepAliveState();
 }
 
-class _AlwaysKeepAliveState extends State<_AlwaysKeepAlive> with AutomaticKeepAliveClientMixin<_AlwaysKeepAlive> {
+class _AlwaysKeepAliveState extends State<_AlwaysKeepAlive>
+    with AutomaticKeepAliveClientMixin<_AlwaysKeepAlive> {
   @override
   bool get wantKeepAlive => true;
 
   @override
   Widget build(BuildContext context) {
     super.build(context);
-    return const SizedBox(
-      height: 48.0,
-      child: Text('keep me alive'),
-    );
+    return const SizedBox(height: 48.0, child: Text('keep me alive'));
   }
 }
 
-class RenderBoxKeepAlive extends RenderBox { }
+class RenderBoxKeepAlive extends RenderBox {}
 
 mixin KeepAliveParentDataMixinAlt implements KeepAliveParentDataMixin {
   @override
@@ -614,14 +625,11 @@ mixin KeepAliveParentDataMixinAlt implements KeepAliveParentDataMixin {
   bool keepAlive = false;
 }
 
-class RenderSliverMultiBoxAdaptorAlt extends RenderSliver with
-    KeepAliveParentDataMixinAlt,
-    RenderSliverHelpers,
-    RenderSliverWithKeepAliveMixin {
-
+class RenderSliverMultiBoxAdaptorAlt extends RenderSliver
+    with KeepAliveParentDataMixinAlt, RenderSliverHelpers, RenderSliverWithKeepAliveMixin {
   final List<RenderBox> children = <RenderBox>[];
 
-  void insert(RenderBox child, { RenderBox? after }) {
+  void insert(RenderBox child, {RenderBox? after}) {
     children.add(child);
   }
 
@@ -631,7 +639,7 @@ class RenderSliverMultiBoxAdaptorAlt extends RenderSliver with
   }
 
   @override
-  void performLayout() { }
+  void performLayout() {}
 }
 
 class LeakCheckerHandle with ChangeNotifier {
