@@ -2,6 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'dart:ui';
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/services.dart';
 import 'package:flutter/widgets.dart';
@@ -25,6 +27,15 @@ class AppLifecycleStateObserver with WidgetsBindingObserver {
   }
 }
 
+class ViewFocusObserver with WidgetsBindingObserver {
+  List<ViewFocusEvent> accumulatedEvents = <ViewFocusEvent>[];
+
+  @override
+  void didChangeViewFocus(ViewFocusEvent state) {
+    accumulatedEvents.add(state);
+  }
+}
+
 class PushRouteObserver with WidgetsBindingObserver {
   late String pushedRoute;
 
@@ -45,19 +56,174 @@ class PushRouteInformationObserver with WidgetsBindingObserver {
   }
 }
 
+// Implements to make sure all methods get coverage.
+class RentrantObserver implements WidgetsBindingObserver {
+  RentrantObserver() {
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  bool active = true;
+
+  int removeSelf() {
+    active = false;
+    int count = 0;
+    while (WidgetsBinding.instance.removeObserver(this)) {
+      count += 1;
+    }
+    return count;
+  }
+
+  @override
+  void didChangeAccessibilityFeatures() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangeAppLifecycleState(AppLifecycleState state) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangeViewFocus(ViewFocusEvent event) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangeLocales(List<Locale>? locales) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangeMetrics() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangePlatformBrightness() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didChangeTextScaleFactor() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  void didHaveMemoryPressure() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+  }
+
+  @override
+  Future<bool> didPopRoute() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return Future<bool>.value(true);
+  }
+
+  @override
+  bool handleStartBackGesture(PredictiveBackEvent backEvent) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return true;
+  }
+
+  @override
+  bool handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return true;
+  }
+
+  @override
+  bool handleCommitBackGesture() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return true;
+  }
+
+  @override
+  bool handleCancelBackGesture() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return true;
+  }
+
+  @override
+  Future<bool> didPushRoute(String route) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return Future<bool>.value(true);
+  }
+
+  @override
+  Future<bool> didPushRouteInformation(RouteInformation routeInformation) {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return Future<bool>.value(true);
+  }
+
+  @override
+  Future<AppExitResponse> didRequestAppExit() {
+    assert(active);
+    WidgetsBinding.instance.addObserver(this);
+    return Future<AppExitResponse>.value(AppExitResponse.exit);
+  }
+}
+
 void main() {
   Future<void> setAppLifeCycleState(AppLifecycleState state) async {
-    final ByteData? message =
-        const StringCodec().encodeMessage(state.toString());
-    await TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
-        .handlePlatformMessage('flutter/lifecycle', message, (_) { });
+    final ByteData? message = const StringCodec().encodeMessage(state.toString());
+    await TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/lifecycle',
+      message,
+      (_) {},
+    );
   }
 
+  testWidgets('Rentrant observer callbacks do not result in exceptions', (
+    WidgetTester tester,
+  ) async {
+    final RentrantObserver observer = RentrantObserver();
+    WidgetsBinding.instance.handleAccessibilityFeaturesChanged();
+    WidgetsBinding.instance.handleAppLifecycleStateChanged(AppLifecycleState.resumed);
+    WidgetsBinding.instance.handleLocaleChanged();
+    WidgetsBinding.instance.handleMetricsChanged();
+    WidgetsBinding.instance.handlePlatformBrightnessChanged();
+    WidgetsBinding.instance.handleTextScaleFactorChanged();
+    WidgetsBinding.instance.handleMemoryPressure();
+    WidgetsBinding.instance.handlePopRoute();
+    WidgetsBinding.instance.handlePushRoute('/');
+    WidgetsBinding.instance.handleRequestAppExit();
+    WidgetsBinding.instance.handleViewFocusChanged(
+      const ViewFocusEvent(
+        viewId: 0,
+        state: ViewFocusState.focused,
+        direction: ViewFocusDirection.forward,
+      ),
+    );
+    await tester.idle();
+    expect(observer.removeSelf(), greaterThan(1));
+    expect(observer.removeSelf(), 0);
+  });
+
   testWidgets('didHaveMemoryPressure callback', (WidgetTester tester) async {
     final MemoryPressureObserver observer = MemoryPressureObserver();
     WidgetsBinding.instance.addObserver(observer);
-    final ByteData message = const JSONMessageCodec().encodeMessage(<String, dynamic>{'type': 'memoryPressure'})!;
-    await tester.binding.defaultBinaryMessenger.handlePlatformMessage('flutter/system', message, (_) { });
+    final ByteData message =
+        const JSONMessageCodec().encodeMessage(<String, dynamic>{'type': 'memoryPressure'})!;
+    await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/system',
+      message,
+      (_) {},
+    );
     expect(observer.sawMemoryPressure, true);
     WidgetsBinding.instance.removeObserver(observer);
   });
@@ -94,30 +260,45 @@ void main() {
 
     observer.accumulatedStates.clear();
     await setAppLifeCycleState(AppLifecycleState.hidden);
-    expect(observer.accumulatedStates, <AppLifecycleState>[
-      AppLifecycleState.hidden,
-    ]);
+    expect(observer.accumulatedStates, <AppLifecycleState>[AppLifecycleState.hidden]);
 
     observer.accumulatedStates.clear();
     await setAppLifeCycleState(AppLifecycleState.paused);
-    expect(observer.accumulatedStates, <AppLifecycleState>[
-      AppLifecycleState.paused,
-    ]);
+    expect(observer.accumulatedStates, <AppLifecycleState>[AppLifecycleState.paused]);
+
+    observer.accumulatedStates.clear();
+    await setAppLifeCycleState(AppLifecycleState.detached);
+    expect(observer.accumulatedStates, <AppLifecycleState>[AppLifecycleState.detached]);
+
+    observer.accumulatedStates.clear();
+    await setAppLifeCycleState(AppLifecycleState.resumed);
+    expect(observer.accumulatedStates, <AppLifecycleState>[AppLifecycleState.resumed]);
 
     observer.accumulatedStates.clear();
     await setAppLifeCycleState(AppLifecycleState.detached);
     expect(observer.accumulatedStates, <AppLifecycleState>[
+      AppLifecycleState.inactive,
+      AppLifecycleState.hidden,
+      AppLifecycleState.paused,
       AppLifecycleState.detached,
     ]);
+    WidgetsBinding.instance.removeObserver(observer);
+  });
 
-    observer.accumulatedStates.clear();
-    await setAppLifeCycleState(AppLifecycleState.resumed);
-    expect(observer.accumulatedStates, <AppLifecycleState>[
-      AppLifecycleState.resumed,
-    ]);
+  testWidgets('handleViewFocusChanged callback', (WidgetTester tester) async {
+    final ViewFocusObserver observer = ViewFocusObserver();
+    WidgetsBinding.instance.addObserver(observer);
 
-    observer.accumulatedStates.clear();
-    await expectLater(() async => setAppLifeCycleState(AppLifecycleState.detached), throwsAssertionError);
+    const ViewFocusEvent expectedEvent = ViewFocusEvent(
+      viewId: 0,
+      state: ViewFocusState.focused,
+      direction: ViewFocusDirection.forward,
+    );
+
+    PlatformDispatcher.instance.onViewFocusChange!(expectedEvent);
+    expect(observer.accumulatedEvents, <ViewFocusEvent>[expectedEvent]);
+
+    WidgetsBinding.instance.removeObserver(observer);
   });
 
   testWidgets('didPushRoute callback', (WidgetTester tester) async {
@@ -125,8 +306,18 @@ void main() {
     WidgetsBinding.instance.addObserver(observer);
 
     const String testRouteName = 'testRouteName';
-    final ByteData message = const JSONMethodCodec().encodeMethodCall(const MethodCall('pushRoute', testRouteName));
-    await tester.binding.defaultBinaryMessenger.handlePlatformMessage('flutter/navigation', message, (_) {});
+    final ByteData message = const JSONMethodCodec().encodeMethodCall(
+      const MethodCall('pushRoute', testRouteName),
+    );
+    final ByteData result =
+        (await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+          'flutter/navigation',
+          message,
+          (_) {},
+        ))!;
+    final bool decodedResult = const JSONMethodCodec().decodeEnvelope(result) as bool;
+
+    expect(decodedResult, true);
     expect(observer.pushedRoute, testRouteName);
 
     WidgetsBinding.instance.removeObserver(observer);
@@ -144,13 +335,22 @@ void main() {
     final ByteData message = const JSONMethodCodec().encodeMethodCall(
       const MethodCall('pushRouteInformation', testRouteInformation),
     );
-    await tester.binding.defaultBinaryMessenger
-        .handlePlatformMessage('flutter/navigation', message, (_) {});
+    final ByteData result =
+        (await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+          'flutter/navigation',
+          message,
+          (_) {},
+        ))!;
+    final bool decodedResult = const JSONMethodCodec().decodeEnvelope(result) as bool;
+
+    expect(decodedResult, true);
     expect(observer.pushedRoute, 'testRouteName');
     WidgetsBinding.instance.removeObserver(observer);
   });
 
-  testWidgets('didPushRouteInformation calls didPushRoute correctly when handling url', (WidgetTester tester) async {
+  testWidgets('didPushRouteInformation calls didPushRoute correctly when handling url', (
+    WidgetTester tester,
+  ) async {
     final PushRouteObserver observer = PushRouteObserver();
     WidgetsBinding.instance.addObserver(observer);
 
@@ -163,8 +363,11 @@ void main() {
     ByteData message = const JSONMethodCodec().encodeMethodCall(
       MethodCall('pushRouteInformation', testRouteInformation),
     );
-    await ServicesBinding.instance.defaultBinaryMessenger
-        .handlePlatformMessage('flutter/navigation', message, (_) {});
+    await ServicesBinding.instance.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     expect(observer.pushedRoute, '/');
 
     // A complex url.
@@ -176,8 +379,11 @@ void main() {
     message = const JSONMethodCodec().encodeMethodCall(
       MethodCall('pushRouteInformation', testRouteInformation),
     );
-    await ServicesBinding.instance.defaultBinaryMessenger
-        .handlePlatformMessage('flutter/navigation', message, (_) {});
+    await ServicesBinding.instance.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     expect(observer.pushedRoute, '/abc?def=123&def=456#789');
     WidgetsBinding.instance.removeObserver(observer);
   });
@@ -193,7 +399,11 @@ void main() {
     final ByteData message = const JSONMethodCodec().encodeMethodCall(
       const MethodCall('pushRouteInformation', testRouteInformation),
     );
-    await tester.binding.defaultBinaryMessenger.handlePlatformMessage('flutter/navigation', message, (_) { });
+    await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     expect(observer.pushedRouteInformation.uri.toString(), 'testRouteName');
     expect(observer.pushedRouteInformation.state, 'state');
     WidgetsBinding.instance.removeObserver(observer);
@@ -210,9 +420,16 @@ void main() {
     final ByteData message = const JSONMethodCodec().encodeMethodCall(
       const MethodCall('pushRouteInformation', testRouteInformation),
     );
-    await ServicesBinding.instance.defaultBinaryMessenger.handlePlatformMessage('flutter/navigation', message, (_) { });
+    await ServicesBinding.instance.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     expect(observer.pushedRouteInformation.location, '/abc?def=123&def=456#789');
-    expect(observer.pushedRouteInformation.uri.toString(), 'http://hostname/abc?def=123&def=456#789');
+    expect(
+      observer.pushedRouteInformation.uri.toString(),
+      'http://hostname/abc?def=123&def=456#789',
+    );
     expect(observer.pushedRouteInformation.state, 'state');
     WidgetsBinding.instance.removeObserver(observer);
   });
@@ -229,12 +446,68 @@ void main() {
       const MethodCall('pushRouteInformation', testRouteInformation),
     );
 
-    await tester.binding.defaultBinaryMessenger.handlePlatformMessage('flutter/navigation', message, (_) { });
+    await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     expect(observer.pushedRouteInformation.uri.toString(), 'testRouteName');
     expect(observer.pushedRouteInformation.state, null);
     WidgetsBinding.instance.removeObserver(observer);
   });
 
+  testWidgets('pushRouteInformation not handled by observer returns false', (
+    WidgetTester tester,
+  ) async {
+    const Map<String, dynamic> testRouteInformation = <String, dynamic>{
+      'location': 'testRouteName',
+      'state': null,
+    };
+    final ByteData message = const JSONMethodCodec().encodeMethodCall(
+      const MethodCall('pushRouteInformation', testRouteInformation),
+    );
+
+    final ByteData result =
+        (await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+          'flutter/navigation',
+          message,
+          (_) {},
+        ))!;
+    final bool decodedResult = const JSONMethodCodec().decodeEnvelope(result) as bool;
+
+    expect(decodedResult, false);
+  });
+
+  testWidgets('pushRoute not handled by observer returns false', (WidgetTester tester) async {
+    const String testRoute = 'testRouteName';
+    final ByteData message = const JSONMethodCodec().encodeMethodCall(
+      const MethodCall('pushRoute', testRoute),
+    );
+
+    final ByteData result =
+        (await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+          'flutter/navigation',
+          message,
+          (_) {},
+        ))!;
+    final bool decodedResult = const JSONMethodCodec().decodeEnvelope(result) as bool;
+
+    expect(decodedResult, false);
+  });
+
+  testWidgets('popRoute not handled by observer returns false', (WidgetTester tester) async {
+    final ByteData message = const JSONMethodCodec().encodeMethodCall(const MethodCall('popRoute'));
+
+    final ByteData result =
+        (await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+          'flutter/navigation',
+          message,
+          (_) {},
+        ))!;
+    final bool decodedResult = const JSONMethodCodec().decodeEnvelope(result) as bool;
+
+    expect(decodedResult, false);
+  });
   testWidgets('Application lifecycle affects frame scheduling', (WidgetTester tester) async {
     expect(tester.binding.hasScheduledFrame, isFalse);
 
@@ -289,10 +562,27 @@ void main() {
     await tester.pump();
   });
 
+  testWidgets('resetInternalState resets lifecycleState and framesEnabled to initial state', (
+    WidgetTester tester,
+  ) async {
+    // Initial state
+    expect(tester.binding.lifecycleState, isNull);
+    expect(tester.binding.framesEnabled, isTrue);
+
+    tester.binding.handleAppLifecycleStateChanged(AppLifecycleState.paused);
+    expect(tester.binding.lifecycleState, AppLifecycleState.paused);
+    expect(tester.binding.framesEnabled, isFalse);
+
+    tester.binding.resetInternalState();
+
+    expect(tester.binding.lifecycleState, isNull);
+    expect(tester.binding.framesEnabled, isTrue);
+  });
+
   testWidgets('scheduleFrameCallback error control test', (WidgetTester tester) async {
     late FlutterError error;
     try {
-      tester.binding.scheduleFrameCallback((Duration _) { }, rescheduling: true);
+      tester.binding.scheduleFrameCallback((Duration _) {}, rescheduling: true);
     } on FlutterError catch (e) {
       error = e;
     }
@@ -321,30 +611,34 @@ void main() {
     );
   });
 
-  testWidgets('defaultStackFilter elides framework Element mounting stacks', (WidgetTester tester) async {
+  testWidgets('defaultStackFilter elides framework Element mounting stacks', (
+    WidgetTester tester,
+  ) async {
     final FlutterExceptionHandler? oldHandler = FlutterError.onError;
     late FlutterErrorDetails errorDetails;
     FlutterError.onError = (FlutterErrorDetails details) {
       errorDetails = details;
     };
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: TestStatefulWidget(
-        child: Builder(
-          builder: (BuildContext context) {
-            return Opacity(
-              opacity: .5,
-              child: Builder(
-                builder: (BuildContext context) {
-                  assert(false);
-                  return const Text('');
-                },
-              ),
-            );
-          },
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: TestStatefulWidget(
+          child: Builder(
+            builder: (BuildContext context) {
+              return Opacity(
+                opacity: .5,
+                child: Builder(
+                  builder: (BuildContext context) {
+                    assert(false);
+                    return const Text('');
+                  },
+                ),
+              );
+            },
+          ),
         ),
       ),
-    ));
+    );
     FlutterError.onError = oldHandler;
     expect(errorDetails.exception, isAssertionError);
     const String toMatch = '...     Normal element mounting (';
