@@ -8,9 +8,11 @@ import 'package:flutter/rendering.dart';
 import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 
+import 'two_dimensional_utils.dart';
+
 Finder findKey(int i) => find.byKey(ValueKey<int>(i), skipOffstage: false);
 
-Widget buildSingleChildScrollView(Axis scrollDirection, { bool reverse = false }) {
+Widget buildSingleChildScrollView(Axis scrollDirection, {bool reverse = false}) {
   return Directionality(
     textDirection: TextDirection.ltr,
     child: Center(
@@ -38,7 +40,7 @@ Widget buildSingleChildScrollView(Axis scrollDirection, { bool reverse = false }
   );
 }
 
-Widget buildListView(Axis scrollDirection, { bool reverse = false, bool shrinkWrap = false }) {
+Widget buildListView(Axis scrollDirection, {bool reverse = false, bool shrinkWrap = false}) {
   return Directionality(
     textDirection: TextDirection.ltr,
     child: Center(
@@ -66,7 +68,6 @@ Widget buildListView(Axis scrollDirection, { bool reverse = false, bool shrinkWr
 }
 
 void main() {
-
   group('SingleChildScrollView', () {
     testWidgets('SingleChildScrollView ensureVisible Axis.vertical', (WidgetTester tester) async {
       BuildContext findContext(int i) => tester.element(findKey(i));
@@ -122,7 +123,9 @@ void main() {
       expect(tester.getTopLeft(findKey(3)).dx, equals(100.0));
     });
 
-    testWidgets('SingleChildScrollView ensureVisible Axis.vertical reverse', (WidgetTester tester) async {
+    testWidgets('SingleChildScrollView ensureVisible Axis.vertical reverse', (
+      WidgetTester tester,
+    ) async {
       BuildContext findContext(int i) => tester.element(findKey(i));
 
       await tester.pumpWidget(buildSingleChildScrollView(Axis.vertical, reverse: true));
@@ -190,7 +193,9 @@ void main() {
       expect(tester.getBottomLeft(findKey(6)).dy, equals(500.0));
     });
 
-    testWidgets('SingleChildScrollView ensureVisible Axis.horizontal reverse', (WidgetTester tester) async {
+    testWidgets('SingleChildScrollView ensureVisible Axis.horizontal reverse', (
+      WidgetTester tester,
+    ) async {
       BuildContext findContext(int i) => tester.element(findKey(i));
 
       await tester.pumpWidget(buildSingleChildScrollView(Axis.horizontal, reverse: true));
@@ -310,7 +315,9 @@ void main() {
       expect(tester.getTopLeft(findKey(0)).dy, moreOrLessEquals(500.0, epsilon: 0.1));
     });
 
-    testWidgets('Nested SingleChildScrollView ensureVisible behavior test', (WidgetTester tester) async {
+    testWidgets('Nested SingleChildScrollView ensureVisible behavior test', (
+      WidgetTester tester,
+    ) async {
       // Regressing test for https://github.com/flutter/flutter/issues/65100
       Finder findKey(String coordinate) => find.byKey(ValueKey<String>(coordinate));
       BuildContext findContext(String coordinate) => tester.element(findKey(coordinate));
@@ -333,11 +340,7 @@ void main() {
               height: 400.0,
               child: SingleChildScrollView(
                 scrollDirection: Axis.horizontal,
-                child: SingleChildScrollView(
-                  child: Column(
-                    children: rows,
-                  ),
-                ),
+                child: SingleChildScrollView(child: Column(children: rows)),
               ),
             ),
           ),
@@ -682,39 +685,41 @@ void main() {
         await tester.pump();
       }
 
-      await tester.pumpWidget(Directionality(
-        textDirection: TextDirection.ltr,
-        child: Center(
-          child: SizedBox(
-            width: 600.0,
-            height: 400.0,
-            child: ListView(
-              children: <Widget>[
-                const SizedBox(height: 200.0),
-                const SizedBox(height: 200.0),
-                const SizedBox(height: 200.0),
-                SizedBox(
-                  height: 200.0,
-                  child: Center(
-                    child: Transform(
-                      transform: Matrix4.rotationZ(math.pi),
-                      child: Container(
-                        key: const ValueKey<int>(0),
-                        width: 100.0,
-                        height: 100.0,
-                        color: const Color(0xFFFFFFFF),
+      await tester.pumpWidget(
+        Directionality(
+          textDirection: TextDirection.ltr,
+          child: Center(
+            child: SizedBox(
+              width: 600.0,
+              height: 400.0,
+              child: ListView(
+                children: <Widget>[
+                  const SizedBox(height: 200.0),
+                  const SizedBox(height: 200.0),
+                  const SizedBox(height: 200.0),
+                  SizedBox(
+                    height: 200.0,
+                    child: Center(
+                      child: Transform(
+                        transform: Matrix4.rotationZ(math.pi),
+                        child: Container(
+                          key: const ValueKey<int>(0),
+                          width: 100.0,
+                          height: 100.0,
+                          color: const Color(0xFFFFFFFF),
+                        ),
                       ),
                     ),
                   ),
-                ),
-                const SizedBox(height: 200.0),
-                const SizedBox(height: 200.0),
-                const SizedBox(height: 200.0),
-              ],
+                  const SizedBox(height: 200.0),
+                  const SizedBox(height: 200.0),
+                  const SizedBox(height: 200.0),
+                ],
+              ),
             ),
           ),
         ),
-      ));
+      );
 
       await prepare(321.0);
       Scrollable.ensureVisible(findContext(0));
@@ -979,19 +984,46 @@ void main() {
                     offset: offset,
                     center: const ValueKey<String>('center'),
                     slivers: const <Widget>[
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-6), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-5), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-4), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-3), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-2), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(-1), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(key: ValueKey<String>('center'), child: SizedBox(key: ValueKey<int>(0), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(1), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(2), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(3), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(4), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(5), width: 200.0, height: 200.0)),
-                      SliverToBoxAdapter(child: SizedBox(key: ValueKey<int>(6), width: 200.0, height: 200.0)),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-6), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-5), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-4), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-3), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-2), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(-1), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        key: ValueKey<String>('center'),
+                        child: SizedBox(key: ValueKey<int>(0), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(1), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(2), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(3), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(4), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(5), width: 200.0, height: 200.0),
+                      ),
+                      SliverToBoxAdapter(
+                        child: SizedBox(key: ValueKey<int>(6), width: 200.0, height: 200.0),
+                      ),
                     ],
                   );
                 },
@@ -1027,7 +1059,6 @@ void main() {
       await tester.pump(const Duration(milliseconds: 1020));
       expect(tester.getTopLeft(findKey(3)).dy, equals(100.0));
 
-
       await prepare(-480.0);
       Scrollable.ensureVisible(findContext(-3));
       await tester.pump();
@@ -1050,4 +1081,231 @@ void main() {
       expect(tester.getTopLeft(findKey(-3)).dy, equals(100.0));
     });
   });
+
+  group('TwoDimensionalViewport ensureVisible', () {
+    Finder findKey(ChildVicinity vicinity) {
+      return find.byKey(ValueKey<ChildVicinity>(vicinity));
+    }
+
+    BuildContext findContext(WidgetTester tester, ChildVicinity vicinity) {
+      return tester.element(findKey(vicinity));
+    }
+
+    testWidgets('Axis.vertical', (WidgetTester tester) async {
+      await tester.pumpWidget(simpleBuilderTest(useCacheExtent: true));
+
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 0)));
+      await tester.pump();
+      expect(tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 0))).dy, equals(0.0));
+      // (0, 3) is in the cache extent, and will be brought into view next
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy,
+        equals(600.0),
+      );
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 3)));
+      await tester.pump();
+      // Now in view at top edge of viewport
+      expect(tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy, equals(0.0));
+
+      // If already visible, no change
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 3)));
+      await tester.pump();
+      expect(tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy, equals(0.0));
+    });
+
+    testWidgets('Axis.horizontal', (WidgetTester tester) async {
+      await tester.pumpWidget(simpleBuilderTest(useCacheExtent: true));
+
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 1, yIndex: 0)));
+      await tester.pump();
+      expect(tester.getTopLeft(findKey(const ChildVicinity(xIndex: 1, yIndex: 0))).dx, equals(0.0));
+      // (5, 0) is now in the cache extent, and will be brought into view next
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 5, yIndex: 0))).dx,
+        equals(800.0),
+      );
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 0)),
+        alignmentPolicy: ScrollPositionAlignmentPolicy.keepVisibleAtEnd,
+      );
+      await tester.pump();
+      // Now in view at trailing edge of viewport
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 5, yIndex: 0))).dx,
+        equals(600.0),
+      );
+
+      // If already in position, no change
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 0)),
+        alignmentPolicy: ScrollPositionAlignmentPolicy.keepVisibleAtEnd,
+      );
+      await tester.pump();
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 5, yIndex: 0))).dx,
+        equals(600.0),
+      );
+    });
+
+    testWidgets('both axes', (WidgetTester tester) async {
+      await tester.pumpWidget(simpleBuilderTest(useCacheExtent: true));
+
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 1, yIndex: 1)));
+      await tester.pump();
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 1, yIndex: 1))),
+        const Rect.fromLTRB(0.0, 0.0, 200.0, 200.0),
+      );
+      // (5, 4) is in the cache extent, and will be brought into view next
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(800.0, 600.0, 1000.0, 800.0),
+      );
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 4)),
+        alignment: 1.0, // Same as ScrollAlignmentPolicy.keepVisibleAtEnd
+      );
+      await tester.pump();
+      // Now in view at bottom trailing corner of viewport
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(600.0, 400.0, 800.0, 600.0),
+      );
+
+      // If already visible, no change
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 4)),
+        alignment: 1.0,
+      );
+      await tester.pump();
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(600.0, 400.0, 800.0, 600.0),
+      );
+    });
+
+    testWidgets('Axis.vertical reverse', (WidgetTester tester) async {
+      await tester.pumpWidget(
+        simpleBuilderTest(
+          verticalDetails: const ScrollableDetails.vertical(reverse: true),
+          useCacheExtent: true,
+        ),
+      );
+
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 0))).dy,
+        equals(400.0),
+      );
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 0)));
+      await tester.pump();
+      // Already visible so no change.
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 0))).dy,
+        equals(400.0),
+      );
+      // (0, 3) is in the cache extent, and will be brought into view next
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy,
+        equals(-200.0),
+      );
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 3)));
+      await tester.pump();
+      // Now in view at bottom edge of viewport since we are reversed
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy,
+        equals(400.0),
+      );
+
+      // If already visible, no change
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 3)));
+      await tester.pump();
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 3))).dy,
+        equals(400.0),
+      );
+    });
+
+    testWidgets('Axis.horizontal reverse', (WidgetTester tester) async {
+      await tester.pumpWidget(
+        simpleBuilderTest(
+          horizontalDetails: const ScrollableDetails.horizontal(reverse: true),
+          useCacheExtent: true,
+        ),
+      );
+
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 0))).dx,
+        equals(600.0),
+      );
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 0, yIndex: 0)));
+      await tester.pump();
+      // Already visible so no change.
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 0, yIndex: 0))).dx,
+        equals(600.0),
+      );
+      // (4, 0) is in the cache extent, and will be brought into view next
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 4, yIndex: 0))).dx,
+        equals(-200.0),
+      );
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 4, yIndex: 0)));
+      await tester.pump();
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 4, yIndex: 0))).dx,
+        equals(200.0),
+      );
+
+      // If already visible, no change
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 4, yIndex: 0)));
+      await tester.pump();
+      expect(
+        tester.getTopLeft(findKey(const ChildVicinity(xIndex: 4, yIndex: 0))).dx,
+        equals(200.0),
+      );
+    });
+
+    testWidgets('both axes reverse', (WidgetTester tester) async {
+      await tester.pumpWidget(
+        simpleBuilderTest(
+          verticalDetails: const ScrollableDetails.vertical(reverse: true),
+          horizontalDetails: const ScrollableDetails.horizontal(reverse: true),
+          useCacheExtent: true,
+        ),
+      );
+
+      Scrollable.ensureVisible(findContext(tester, const ChildVicinity(xIndex: 1, yIndex: 1)));
+      await tester.pump();
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 1, yIndex: 1))),
+        const Rect.fromLTRB(600.0, 400.0, 800.0, 600.0),
+      );
+      // (5, 4) is in the cache extent, and will be brought into view next
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(-200.0, -200.0, 0.0, 0.0),
+      );
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 4)),
+        alignment: 1.0, // Same as ScrollAlignmentPolicy.keepVisibleAtEnd
+      );
+      await tester.pump();
+      // Now in view at trailing corner of viewport
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(0.0, 0.0, 200.0, 200.0),
+      );
+
+      // If already visible, no change
+      Scrollable.ensureVisible(
+        findContext(tester, const ChildVicinity(xIndex: 5, yIndex: 4)),
+        alignment: 1.0,
+      );
+      await tester.pump();
+      expect(
+        tester.getRect(findKey(const ChildVicinity(xIndex: 5, yIndex: 4))),
+        const Rect.fromLTRB(0.0, 0.0, 200.0, 200.0),
+      );
+    });
+  });
 }
