@@ -115,22 +115,27 @@ void main() {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        fadeOutCurve: Curves.linear,
-        fadeInCurve: Curves.linear,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          fadeOutCurve: Curves.linear,
+          fadeInCurve: Curves.linear,
+          excludeFromSemantics: true,
+        ),
+      );
 
       expect(findFadeInImage(tester).placeholder!.rawImage.image, null);
       expect(findFadeInImage(tester).target.rawImage.image, null);
 
       placeholderProvider.complete();
       await tester.pump();
-      expect(findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(placeholderImage), true);
+      expect(
+        findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(placeholderImage),
+        true,
+      );
       expect(findFadeInImage(tester).target.rawImage.image, null);
 
       imageProvider.complete();
@@ -153,10 +158,7 @@ void main() {
         await tester.pump(const Duration(milliseconds: 10));
       }
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-      ));
+      await tester.pumpWidget(FadeInImage(placeholder: placeholderProvider, image: imageProvider));
       expect(findFadeInImage(tester).target.rawImage.image!.isCloneOf(targetImage), true);
       expect(findFadeInImage(tester).target.opacity, 1);
     });
@@ -166,12 +168,14 @@ void main() {
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
       final TestImageProvider secondImageProvider = TestImageProvider(replacementImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+        ),
+      );
 
       imageProvider.complete();
       placeholderProvider.complete();
@@ -180,10 +184,9 @@ void main() {
       // Calls setState after the animation, which removes the placeholder image.
       await tester.pump(const Duration(milliseconds: 100));
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: secondImageProvider,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(placeholder: placeholderProvider, image: secondImageProvider),
+      );
       await tester.pump();
 
       FadeInImageParts parts = findFadeInImage(tester);
@@ -202,52 +205,49 @@ void main() {
     });
 
     // Regression test for https://github.com/flutter/flutter/issues/111011
-    testWidgets("FadeInImage's image obeys gapless playback when first image is cached but second isn't",
-            (WidgetTester tester) async {
-      final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
-      final TestImageProvider imageProvider = TestImageProvider(targetImage);
-      final TestImageProvider secondImageProvider = TestImageProvider(replacementImage);
+    testWidgets(
+      "FadeInImage's image obeys gapless playback when first image is cached but second isn't",
+      (WidgetTester tester) async {
+        final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
+        final TestImageProvider imageProvider = TestImageProvider(targetImage);
+        final TestImageProvider secondImageProvider = TestImageProvider(replacementImage);
 
-      // Pre-cache the initial image.
-      imageProvider.resolve(ImageConfiguration.empty);
-      imageProvider.complete();
-      placeholderProvider.complete();
+        // Pre-cache the initial image.
+        imageProvider.resolve(ImageConfiguration.empty);
+        imageProvider.complete();
+        placeholderProvider.complete();
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-      ));
-      await tester.pumpAndSettle();
+        await tester.pumpWidget(
+          FadeInImage(placeholder: placeholderProvider, image: imageProvider),
+        );
+        await tester.pumpAndSettle();
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: secondImageProvider,
-      ));
+        await tester.pumpWidget(
+          FadeInImage(placeholder: placeholderProvider, image: secondImageProvider),
+        );
 
-      FadeInImageParts parts = findFadeInImage(tester);
-      // Continually shows previously loaded image until the new image provider provides the image.
-      expect(parts.placeholder, isNull);
-      expect(parts.target.rawImage.image!.isCloneOf(targetImage), isTrue);
-      expect(parts.target.opacity, 1);
+        FadeInImageParts parts = findFadeInImage(tester);
+        // Continually shows previously loaded image until the new image provider provides the image.
+        expect(parts.placeholder, isNull);
+        expect(parts.target.rawImage.image!.isCloneOf(targetImage), isTrue);
+        expect(parts.target.opacity, 1);
 
-      // Now, provide the image.
-      secondImageProvider.complete();
-      await tester.pump();
+        // Now, provide the image.
+        secondImageProvider.complete();
+        await tester.pump();
 
-      parts = findFadeInImage(tester);
-      expect(parts.target.rawImage.image!.isCloneOf(replacementImage), isTrue);
-      expect(parts.target.opacity, 1);
-    });
+        parts = findFadeInImage(tester);
+        expect(parts.target.rawImage.image!.isCloneOf(replacementImage), isTrue);
+        expect(parts.target.opacity, 1);
+      },
+    );
 
     testWidgets("FadeInImage's placeholder obeys gapless playback", (WidgetTester tester) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider secondPlaceholderProvider = TestImageProvider(replacementImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-      ));
+      await tester.pumpWidget(FadeInImage(placeholder: placeholderProvider, image: imageProvider));
 
       placeholderProvider.complete();
       await tester.pump();
@@ -256,10 +256,9 @@ void main() {
       expect(parts.placeholder!.rawImage.image!.isCloneOf(placeholderImage), true);
       expect(parts.placeholder!.opacity, 1);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: secondPlaceholderProvider,
-        image: imageProvider,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(placeholder: secondPlaceholderProvider, image: imageProvider),
+      );
 
       parts = findFadeInImage(tester);
       // continually shows previously loaded image.
@@ -275,16 +274,15 @@ void main() {
       expect(parts.placeholder!.opacity, 1);
     });
 
-    testWidgets('shows a cached image immediately when skipFadeOnSynchronousLoad=true', (WidgetTester tester) async {
+    testWidgets('shows a cached image immediately when skipFadeOnSynchronousLoad=true', (
+      WidgetTester tester,
+    ) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
       imageProvider.resolve(ImageConfiguration.empty);
       imageProvider.complete();
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-      ));
+      await tester.pumpWidget(FadeInImage(placeholder: placeholderProvider, image: imageProvider));
 
       expect(findFadeInImage(tester).target.rawImage.image!.isCloneOf(targetImage), true);
       expect(findFadeInImage(tester).placeholder, isNull);
@@ -296,44 +294,58 @@ void main() {
       final TestImageProvider secondPlaceholderProvider = TestImageProvider(replacementImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          excludeFromSemantics: true,
+        ),
+      );
 
       final State? state = findFadeInImage(tester).state;
       placeholderProvider.complete();
       await tester.pump();
-      expect(findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(placeholderImage), true);
+      expect(
+        findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(placeholderImage),
+        true,
+      );
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: secondPlaceholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: secondPlaceholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          excludeFromSemantics: true,
+        ),
+      );
 
       secondPlaceholderProvider.complete();
       await tester.pump();
-      expect(findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(replacementImage), true);
+      expect(
+        findFadeInImage(tester).placeholder!.rawImage.image!.isCloneOf(replacementImage),
+        true,
+      );
       expect(findFadeInImage(tester).state, same(state));
     });
 
-    testWidgets('does not keep the placeholder in the tree if it is invisible', (WidgetTester tester) async {
+    testWidgets('does not keep the placeholder in the tree if it is invisible', (
+      WidgetTester tester,
+    ) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          excludeFromSemantics: true,
+        ),
+      );
 
       placeholderProvider.complete();
       await tester.pumpAndSettle();
@@ -345,17 +357,21 @@ void main() {
       expect(find.byType(Image), findsOneWidget);
     });
 
-    testWidgets("doesn't interrupt in-progress animation when animation values are updated", (WidgetTester tester) async {
+    testWidgets("doesn't interrupt in-progress animation when animation values are updated", (
+      WidgetTester tester,
+    ) async {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          excludeFromSemantics: true,
+        ),
+      );
 
       final State? state = findFadeInImage(tester).state;
       placeholderProvider.complete();
@@ -363,13 +379,15 @@ void main() {
       await tester.pump();
       await tester.pump(animationDuration);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        fadeOutDuration: animationDuration * 2,
-        fadeInDuration: animationDuration * 2,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          fadeOutDuration: animationDuration * 2,
+          fadeInDuration: animationDuration * 2,
+          excludeFromSemantics: true,
+        ),
+      );
 
       expect(findFadeInImage(tester).state, same(state));
       expect(findFadeInImage(tester).placeholder!.opacity, moreOrLessEquals(0));
@@ -383,17 +401,19 @@ void main() {
       final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
       final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-      await tester.pumpWidget(FadeInImage(
-        placeholder: placeholderProvider,
-        image: imageProvider,
-        color: const Color(0xFF00FF00),
-        colorBlendMode: BlendMode.clear,
-        placeholderColor: const Color(0xFF0000FF),
-        placeholderColorBlendMode: BlendMode.modulate,
-        fadeOutDuration: animationDuration,
-        fadeInDuration: animationDuration,
-        excludeFromSemantics: true,
-      ));
+      await tester.pumpWidget(
+        FadeInImage(
+          placeholder: placeholderProvider,
+          image: imageProvider,
+          color: const Color(0xFF00FF00),
+          colorBlendMode: BlendMode.clear,
+          placeholderColor: const Color(0xFF0000FF),
+          placeholderColorBlendMode: BlendMode.modulate,
+          fadeOutDuration: animationDuration,
+          fadeInDuration: animationDuration,
+          excludeFromSemantics: true,
+        ),
+      );
 
       expect(findFadeInImage(tester).placeholder?.color, const Color(0xFF0000FF));
       expect(findFadeInImage(tester).placeholder?.colorBlendMode, BlendMode.modulate);
@@ -403,7 +423,6 @@ void main() {
     });
 
     group('ImageProvider', () {
-
       test('memory placeholder cacheWidth and cacheHeight is passed through', () async {
         final Uint8List testBytes = Uint8List.fromList(kTransparentImage);
         final FadeInImage image = FadeInImage.memoryNetwork(
@@ -416,23 +435,39 @@ void main() {
         );
 
         bool called = false;
-        Future<ui.Codec> decode(ui.ImmutableBuffer buffer, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
+        Future<ui.Codec> decode(
+          ui.ImmutableBuffer buffer, {
+          int? cacheWidth,
+          int? cacheHeight,
+          bool allowUpscaling = false,
+        }) {
           expect(cacheWidth, 20);
           expect(cacheHeight, 30);
           expect(allowUpscaling, false);
           called = true;
-          return PaintingBinding.instance.instantiateImageCodecFromBuffer(buffer, cacheWidth: cacheWidth, cacheHeight: cacheHeight, allowUpscaling: allowUpscaling);
+          return PaintingBinding.instance.instantiateImageCodecFromBuffer(
+            buffer,
+            cacheWidth: cacheWidth,
+            cacheHeight: cacheHeight,
+            allowUpscaling: allowUpscaling,
+          );
         }
+
         final ImageProvider resizeImage = image.placeholder;
         expect(image.placeholder, isA<ResizeImage>());
         expect(called, false);
         final LoadTestImageProvider testProvider = LoadTestImageProvider(image.placeholder);
-        final ImageStreamCompleter streamCompleter = testProvider.testLoad(await resizeImage.obtainKey(ImageConfiguration.empty), decode);
+        final ImageStreamCompleter streamCompleter = testProvider.testLoad(
+          await resizeImage.obtainKey(ImageConfiguration.empty),
+          decode,
+        );
 
         final Completer<void> completer = Completer<void>();
-        streamCompleter.addListener(ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
-          completer.complete();
-        }));
+        streamCompleter.addListener(
+          ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
+            completer.complete();
+          }),
+        );
         await completer.future;
 
         expect(called, true);
@@ -446,24 +481,39 @@ void main() {
         );
 
         bool called = false;
-        Future<ui.Codec> decode(ui.ImmutableBuffer buffer, {int? cacheWidth, int? cacheHeight, bool allowUpscaling = false}) {
+        Future<ui.Codec> decode(
+          ui.ImmutableBuffer buffer, {
+          int? cacheWidth,
+          int? cacheHeight,
+          bool allowUpscaling = false,
+        }) {
           expect(cacheWidth, null);
           expect(cacheHeight, null);
           expect(allowUpscaling, false);
           called = true;
-          return PaintingBinding.instance.instantiateImageCodecFromBuffer(buffer, cacheWidth: cacheWidth, cacheHeight: cacheHeight);
+          return PaintingBinding.instance.instantiateImageCodecFromBuffer(
+            buffer,
+            cacheWidth: cacheWidth,
+            cacheHeight: cacheHeight,
+          );
         }
+
         // image.placeholder should be an instance of MemoryImage instead of ResizeImage
         final ImageProvider memoryImage = image.placeholder;
         expect(image.placeholder, isA<MemoryImage>());
         expect(called, false);
         final LoadTestImageProvider testProvider = LoadTestImageProvider(image.placeholder);
-        final ImageStreamCompleter streamCompleter = testProvider.testLoad(await memoryImage.obtainKey(ImageConfiguration.empty), decode);
+        final ImageStreamCompleter streamCompleter = testProvider.testLoad(
+          await memoryImage.obtainKey(ImageConfiguration.empty),
+          decode,
+        );
 
         final Completer<void> completer = Completer<void>();
-        streamCompleter.addListener(ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
-          completer.complete();
-        }));
+        streamCompleter.addListener(
+          ImageStreamListener((ImageInfo imageInfo, bool syncCall) {
+            completer.complete();
+          }),
+        );
         await completer.future;
 
         expect(called, true);
@@ -471,14 +521,15 @@ void main() {
     });
 
     group('semantics', () {
-      testWidgets('only one Semantics node appears within FadeInImage', (WidgetTester tester) async {
+      testWidgets('only one Semantics node appears within FadeInImage', (
+        WidgetTester tester,
+      ) async {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(placeholder: placeholderProvider, image: imageProvider),
+        );
 
         expect(find.byType(Semantics), findsOneWidget);
       });
@@ -487,11 +538,13 @@ void main() {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-          excludeFromSemantics: true,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(
+            placeholder: placeholderProvider,
+            image: imageProvider,
+            excludeFromSemantics: true,
+          ),
+        );
 
         expect(find.byType(Semantics), findsNothing);
       });
@@ -499,22 +552,26 @@ void main() {
       group('label', () {
         const String imageSemanticText = 'Test image semantic label';
 
-        testWidgets('defaults to image label if placeholder label is unspecified', (WidgetTester tester) async {
+        testWidgets('defaults to image label if placeholder label is unspecified', (
+          WidgetTester tester,
+        ) async {
           Semantics semanticsWidget() => tester.widget(find.byType(Semantics));
 
           final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
           final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-          await tester.pumpWidget(Directionality(
-            textDirection: TextDirection.ltr,
-            child: FadeInImage(
-              placeholder: placeholderProvider,
-              image: imageProvider,
-              fadeOutDuration: animationDuration,
-              fadeInDuration: animationDuration,
-              imageSemanticLabel: imageSemanticText,
+          await tester.pumpWidget(
+            Directionality(
+              textDirection: TextDirection.ltr,
+              child: FadeInImage(
+                placeholder: placeholderProvider,
+                image: imageProvider,
+                fadeOutDuration: animationDuration,
+                fadeInDuration: animationDuration,
+                imageSemanticLabel: imageSemanticText,
+              ),
             ),
-          ));
+          );
 
           placeholderProvider.complete();
           await tester.pump();
@@ -532,12 +589,14 @@ void main() {
           final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
           final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-          await tester.pumpWidget(FadeInImage(
+          await tester.pumpWidget(
+            FadeInImage(
               placeholder: placeholderProvider,
               image: imageProvider,
               fadeOutDuration: animationDuration,
               fadeInDuration: animationDuration,
-          ));
+            ),
+          );
 
           placeholderProvider.complete();
           await tester.pump();
@@ -556,13 +615,14 @@ void main() {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-          fit: BoxFit.cover,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(placeholder: placeholderProvider, image: imageProvider, fit: BoxFit.cover),
+        );
 
-        expect(findFadeInImage(tester).placeholder!.fit, equals(findFadeInImage(tester).target.fit));
+        expect(
+          findFadeInImage(tester).placeholder!.fit,
+          equals(findFadeInImage(tester).target.fit),
+        );
         expect(findFadeInImage(tester).placeholder!.fit, equals(BoxFit.cover));
       });
 
@@ -570,12 +630,14 @@ void main() {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-          fit: BoxFit.cover,
-          placeholderFit: BoxFit.fill,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(
+            placeholder: placeholderProvider,
+            image: imageProvider,
+            fit: BoxFit.cover,
+            placeholderFit: BoxFit.fill,
+          ),
+        );
 
         expect(findFadeInImage(tester).target.fit, equals(BoxFit.cover));
         expect(findFadeInImage(tester).placeholder!.fit, equals(BoxFit.fill));
@@ -587,13 +649,14 @@ void main() {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-          filterQuality: FilterQuality.medium,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(placeholder: placeholderProvider, image: imageProvider),
+        );
 
-        expect(findFadeInImage(tester).placeholder!.filterQuality, equals(findFadeInImage(tester).target.filterQuality));
+        expect(
+          findFadeInImage(tester).placeholder!.filterQuality,
+          equals(findFadeInImage(tester).target.filterQuality),
+        );
         expect(findFadeInImage(tester).placeholder!.filterQuality, equals(FilterQuality.medium));
       });
 
@@ -601,12 +664,13 @@ void main() {
         final TestImageProvider placeholderProvider = TestImageProvider(placeholderImage);
         final TestImageProvider imageProvider = TestImageProvider(targetImage);
 
-        await tester.pumpWidget(FadeInImage(
-          placeholder: placeholderProvider,
-          image: imageProvider,
-          filterQuality: FilterQuality.medium,
-          placeholderFilterQuality: FilterQuality.high,
-        ));
+        await tester.pumpWidget(
+          FadeInImage(
+            placeholder: placeholderProvider,
+            image: imageProvider,
+            placeholderFilterQuality: FilterQuality.high,
+          ),
+        );
 
         expect(findFadeInImage(tester).target.filterQuality, equals(FilterQuality.medium));
         expect(findFadeInImage(tester).placeholder!.filterQuality, equals(FilterQuality.high));
