@@ -7,10 +7,7 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   test('AssetImage from package', () {
-    const AssetImage image = AssetImage(
-      'assets/image.png',
-      package: 'test_package',
-    );
+    const AssetImage image = AssetImage('assets/image.png', package: 'test_package');
     expect(image.keyName, 'packages/test_package/assets/image.png');
   });
 
@@ -24,21 +21,14 @@ void main() {
   });
 
   test('Image.asset from package', () {
-    final Image imageWidget = Image.asset(
-      'assets/image.png',
-      package: 'test_package',
-    );
+    final Image imageWidget = Image.asset('assets/image.png', package: 'test_package');
     assert(imageWidget.image is AssetImage);
     final AssetImage assetImage = imageWidget.image as AssetImage;
     expect(assetImage.keyName, 'packages/test_package/assets/image.png');
   });
 
   test('Image.asset from package', () {
-    final Image imageWidget = Image.asset(
-      'assets/image.png',
-      scale: 1.5,
-      package: 'test_package',
-    );
+    final Image imageWidget = Image.asset('assets/image.png', scale: 1.5, package: 'test_package');
     assert(imageWidget.image is ExactAssetImage);
     final ExactAssetImage assetImage = imageWidget.image as ExactAssetImage;
     expect(assetImage.keyName, 'packages/test_package/assets/image.png');
