@@ -545,10 +545,7 @@ void main() {
       StatefulBuilder(
         builder: (BuildContext context, StateSetter stateSetter) {
           setState = stateSetter;
-          return Theme(
-            data: ThemeData(cardTheme: CardTheme(data: cardThemeData)),
-            child: const ThemedCard(),
-          );
+          return Theme(data: ThemeData(cardTheme: cardThemeData), child: const ThemedCard());
         },
       ),
     );
