@@ -2,11 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'package:collection/collection.dart';
 import 'package:flutter/material.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter_test/flutter_test.dart';
 
-import '../rendering/mock_canvas.dart';
 import '../rendering/rendering_tester.dart' show TestClipPaintingContext;
 
 class TestSliverChildListDelegate extends SliverChildListDelegate {
@@ -21,7 +21,7 @@ class TestSliverChildListDelegate extends SliverChildListDelegate {
 }
 
 class Alive extends StatefulWidget {
-  const Alive(this.alive, this.index, { super.key });
+  const Alive(this.alive, this.index, {super.key});
   final bool alive;
   final int index;
 
@@ -29,7 +29,7 @@ class Alive extends StatefulWidget {
   AliveState createState() => AliveState();
 
   @override
-  String toString({ DiagnosticLevel minLevel = DiagnosticLevel.info }) => '$index $alive';
+  String toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) => '$index $alive';
 }
 
 class AliveState extends State<Alive> with AutomaticKeepAliveClientMixin {
@@ -44,6 +44,7 @@ class AliveState extends State<Alive> with AutomaticKeepAliveClientMixin {
 }
 
 typedef WhetherToKeepAlive = bool Function(int);
+
 class _StatefulListView extends StatefulWidget {
   const _StatefulListView(this.aliveCallback);
 
@@ -90,10 +91,8 @@ void main() {
             stateSetter = setState;
             return ListView.builder(
               itemCount: itemCount,
-              itemBuilder: (BuildContext _, int index) => Container(
-                key: Key('$index'),
-                height: 2000.0,
-              ),
+              itemBuilder:
+                  (BuildContext _, int index) => Container(key: Key('$index'), height: 2000.0),
               findChildIndexCallback: (Key key) {
                 finderCalled = true;
                 return null;
@@ -101,7 +100,7 @@ void main() {
             );
           },
         ),
-      )
+      ),
     );
     expect(finderCalled, false);
 
@@ -126,19 +125,17 @@ void main() {
             stateSetter = setState;
             return ListView.separated(
               itemCount: itemCount,
-              itemBuilder: (BuildContext _, int index) => Container(
-                key: Key('$index'),
-                height: 2000.0,
-              ),
+              itemBuilder:
+                  (BuildContext _, int index) => Container(key: Key('$index'), height: 2000.0),
               findChildIndexCallback: (Key key) {
                 finderCalled = true;
                 return null;
               },
-              separatorBuilder: (BuildContext _, int __) => const Divider(),
+              separatorBuilder: (BuildContext _, int _) => const Divider(),
             );
           },
         ),
-      )
+      ),
     );
     expect(finderCalled, false);
 
@@ -153,9 +150,7 @@ void main() {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
-        child: Center(
-          child: ListView(itemExtent: 100.0),
-        ),
+        child: Center(child: ListView(itemExtent: 100.0)),
       ),
     );
   });
@@ -167,16 +162,13 @@ void main() {
         child: ListView(
           itemExtent: 200.0,
           children: List<Widget>.generate(20, (int i) {
-            return Container(
-              color: Colors.green,
-              child: Text('$i'),
-            );
+            return ColoredBox(color: Colors.green, child: Text('$i'));
           }),
         ),
       ),
     );
 
-    final RenderBox box = tester.renderObject<RenderBox>(find.byType(Container).first);
+    final RenderBox box = tester.renderObject<RenderBox>(find.byType(ColoredBox).first);
     expect(box.size.height, equals(200.0));
 
     expect(find.text('0'), findsOneWidget);
@@ -249,8 +241,10 @@ void main() {
     log.clear();
   });
 
-  testWidgets('ListView large scroll jump and keepAlive first child not keepAlive', (WidgetTester tester) async {
-    Future<void> checkAndScroll([ String zero = '0:false' ]) async {
+  testWidgets('ListView large scroll jump and keepAlive first child not keepAlive', (
+    WidgetTester tester,
+  ) async {
+    Future<void> checkAndScroll([String zero = '0:false']) async {
       expect(find.text(zero), findsOneWidget);
       expect(find.text('1:false'), findsOneWidget);
       expect(find.text('2:false'), findsOneWidget);
@@ -288,12 +282,7 @@ void main() {
 
   testWidgets('ListView can build out of underflow', (WidgetTester tester) async {
     await tester.pumpWidget(
-      Directionality(
-        textDirection: TextDirection.ltr,
-        child: ListView(
-          itemExtent: 100.0,
-        ),
-      ),
+      Directionality(textDirection: TextDirection.ltr, child: ListView(itemExtent: 100.0)),
     );
 
     expect(find.text('0'), findsNothing);
@@ -347,14 +336,10 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: Center(
-          child: SizedBox(
-            width: 0.0,
-            height: 0.0,
+          child: SizedBox.shrink(
             child: ListView(
               padding: const EdgeInsets.all(8.0),
-              children: const <Widget>[
-                Text('padded', textDirection: TextDirection.ltr),
-              ],
+              children: const <Widget>[Text('padded', textDirection: TextDirection.ltr)],
             ),
           ),
         ),
@@ -383,7 +368,9 @@ void main() {
     expect(find.text('19'), findsOneWidget);
   });
 
-  testWidgets('ListView with shrink wrap in bounded context correctly uses cache extent', (WidgetTester tester) async {
+  testWidgets('ListView with shrink wrap in bounded context correctly uses cache extent', (
+    WidgetTester tester,
+  ) async {
     final SemanticsHandle handle = tester.ensureSemantics();
     await tester.pumpWidget(
       Directionality(
@@ -401,13 +388,24 @@ void main() {
       ),
     );
     expect(tester.getSemantics(find.text('Text 5')), matchesSemantics());
-    expect(tester.getSemantics(find.text('Text 6', skipOffstage: false)), matchesSemantics(isHidden: true));
-    expect(tester.getSemantics(find.text('Text 7', skipOffstage: false)), matchesSemantics(isHidden: true));
-    expect(tester.getSemantics(find.text('Text 8', skipOffstage: false)), matchesSemantics(isHidden: true));
+    expect(
+      tester.getSemantics(find.text('Text 6', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
+    expect(
+      tester.getSemantics(find.text('Text 7', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
+    expect(
+      tester.getSemantics(find.text('Text 8', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
     handle.dispose();
   });
 
-  testWidgets('ListView hidden items should stay hidden if their semantics are updated', (WidgetTester tester) async {
+  testWidgets('ListView hidden items should stay hidden if their semantics are updated', (
+    WidgetTester tester,
+  ) async {
     final SemanticsHandle handle = tester.ensureSemantics();
     await tester.pumpWidget(
       Directionality(
@@ -427,9 +425,18 @@ void main() {
     // Scrollable maybe be marked dirty after layout.
     await tester.pumpAndSettle();
     expect(tester.getSemantics(find.text('Text 5')), matchesSemantics());
-    expect(tester.getSemantics(find.text('Text 6', skipOffstage: false)), matchesSemantics(isHidden: true));
-    expect(tester.getSemantics(find.text('Text 7', skipOffstage: false)), matchesSemantics(isHidden: true));
-    expect(tester.getSemantics(find.text('Text 8', skipOffstage: false)), matchesSemantics(isHidden: true));
+    expect(
+      tester.getSemantics(find.text('Text 6', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
+    expect(
+      tester.getSemantics(find.text('Text 7', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
+    expect(
+      tester.getSemantics(find.text('Text 8', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
 
     // Marks Text 6 semantics as dirty.
     final RenderObject text6 = tester.renderObject(find.text('Text 6', skipOffstage: false));
@@ -437,28 +444,25 @@ void main() {
 
     // Verify the semantics is still hidden.
     await tester.pump();
-    expect(tester.getSemantics(find.text('Text 6', skipOffstage: false)), matchesSemantics(isHidden: true));
+    expect(
+      tester.getSemantics(find.text('Text 6', skipOffstage: false)),
+      matchesSemantics(isHidden: true),
+    );
 
     handle.dispose();
   });
 
   testWidgets('didFinishLayout has correct indices', (WidgetTester tester) async {
     final TestSliverChildListDelegate delegate = TestSliverChildListDelegate(
-      List<Widget>.generate(
-        20,
-        (int i) {
-          return Text('$i', textDirection: TextDirection.ltr);
-        },
-      ),
+      List<Widget>.generate(20, (int i) {
+        return Text('$i', textDirection: TextDirection.ltr);
+      }),
     );
 
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
-        child: ListView.custom(
-          itemExtent: 110.0,
-          childrenDelegate: delegate,
-        ),
+        child: ListView.custom(itemExtent: 110.0, childrenDelegate: delegate),
       ),
     );
 
@@ -468,10 +472,7 @@ void main() {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
-        child: ListView.custom(
-          itemExtent: 210.0,
-          childrenDelegate: delegate,
-        ),
+        child: ListView.custom(itemExtent: 210.0, childrenDelegate: delegate),
       ),
     );
 
@@ -495,16 +496,16 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: MediaQuery(
-          data: const MediaQueryData(
-            padding: EdgeInsets.all(30.0),
-          ),
+          data: const MediaQueryData(padding: EdgeInsets.all(30.0)),
           child: ListView(
             children: <Widget>[
               const Text('top', textDirection: TextDirection.ltr),
-              Builder(builder: (BuildContext context) {
-                innerMediaQueryPadding = MediaQuery.of(context).padding;
-                return Container();
-              }),
+              Builder(
+                builder: (BuildContext context) {
+                  innerMediaQueryPadding = MediaQuery.paddingOf(context);
+                  return Container();
+                },
+              ),
             ],
           ),
         ),
@@ -516,7 +517,9 @@ void main() {
     expect(innerMediaQueryPadding, const EdgeInsets.symmetric(horizontal: 30.0));
   });
 
-  testWidgets('ListView clips if overflow is smaller than cacheExtent', (WidgetTester tester) async {
+  testWidgets('ListView clips if overflow is smaller than cacheExtent', (
+    WidgetTester tester,
+  ) async {
     // Regression test for https://github.com/flutter/flutter/issues/17426.
 
     await tester.pumpWidget(
@@ -528,15 +531,9 @@ void main() {
             child: ListView(
               cacheExtent: 500.0,
               children: <Widget>[
-                Container(
-                  height: 90.0,
-                ),
-                Container(
-                  height: 110.0,
-                ),
-                Container(
-                  height: 80.0,
-                ),
+                Container(height: 90.0),
+                Container(height: 110.0),
+                Container(height: 80.0),
               ],
             ),
           ),
@@ -547,6 +544,222 @@ void main() {
     expect(find.byType(Viewport), paints..clipRect());
   });
 
+  testWidgets(
+    'ListView allows touch on children when reaching an edge and over-scrolling / settling',
+    (WidgetTester tester) async {
+      bool tapped = false;
+      final ScrollController controller = ScrollController();
+      addTearDown(controller.dispose);
+
+      const Duration frame = Duration(milliseconds: 16);
+
+      await tester.pumpWidget(
+        Directionality(
+          textDirection: TextDirection.ltr,
+          child: ListView.builder(
+            controller: controller,
+            physics: const BouncingScrollPhysics(),
+            itemCount: 15,
+            itemBuilder: (BuildContext context, int index) {
+              return GestureDetector(
+                onTap: () {
+                  tapped = true;
+                },
+                child: SizedBox(height: 100.0, child: Text('Item $index')),
+              );
+            },
+          ),
+        ),
+      );
+
+      // Tapping on an item in an idle scrollable should register the tap
+      await tester.tap(find.text('Item 0'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      await tester.fling(find.byType(ListView), const Offset(0.0, 80.0), 1000.0);
+      // Pump a few frames to ensure the scrollable is in an over-scrolled state
+      for (int i = 0; i < 5; i++) {
+        await tester.pump(frame);
+      }
+
+      expect(controller.offset, lessThan(0.0));
+
+      // Tapping on an item in an over-scrolled state should register the tap
+      await tester.tap(find.text('Item 1'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      await tester.pumpAndSettle();
+      expect(controller.offset, 0.0);
+
+      // Tapping on an item in an idle scrollable should register the tap
+      await tester.tap(find.text('Item 2'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      // Jump somewhere in the middle of the list
+      controller.jumpTo(101.0);
+      expect(controller.offset, equals(101.0));
+
+      await tester.tap(find.text('Item 3'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      await tester.pumpAndSettle();
+
+      // Strong fling down, to over-scroll the list at the top
+      await tester.fling(find.byType(ListView), const Offset(0.0, 500.0), 5000.0);
+
+      for (int i = 0; i < 5; i++) {
+        await tester.pump(frame);
+      }
+
+      // Ensure the scrollable is over-scrolled
+      expect(controller.offset, lessThan(0.0));
+
+      // Now we are settling, all taps should be registered
+      await tester.tap(find.text('Item 2'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      await tester.pump(frame);
+
+      await tester.tap(find.text('Item 2'));
+      expect(tapped, isTrue);
+      tapped = false;
+
+      await tester.pumpAndSettle();
+
+      await tester.tap(find.text('Item 2'));
+      expect(tapped, isTrue);
+      tapped = false;
+    },
+  );
+
+  testWidgets('ListView absorbs touch to stop scrolling when not at the edge', (
+    WidgetTester tester,
+  ) async {
+    bool tapped = false;
+    final ScrollController controller = ScrollController();
+    addTearDown(controller.dispose);
+
+    const Duration frame = Duration(milliseconds: 16);
+
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          controller: controller,
+          physics: const BouncingScrollPhysics(),
+          itemCount: 15,
+          itemBuilder: (BuildContext context, int index) {
+            return GestureDetector(
+              onTap: () {
+                tapped = true;
+              },
+              child: SizedBox(height: 100.0, child: Text('Item $index')),
+            );
+          },
+        ),
+      ),
+    );
+
+    // Jump somewhere in the middle of the list
+    controller.jumpTo(101.0);
+    expect(controller.offset, equals(101.0));
+
+    // Tap on an item, it should register the tap
+    await tester.tap(find.text('Item 3'));
+    expect(tapped, isTrue);
+    tapped = false;
+
+    // Fling the list, it should start scrolling. Bot not to the edge
+    await tester.fling(find.byType(ListView), const Offset(0.0, 100.0), 1000.0);
+
+    await tester.pump(frame);
+
+    final double offset = controller.offset;
+
+    // Ensure we are somewhere between 0 and the starting offset
+    expect(controller.offset, lessThan(101.0));
+    expect(controller.offset, greaterThan(0.0));
+
+    await tester.tap(
+      find.text('Item 2'),
+      warnIfMissed: false,
+    ); // The tap should be absorbed by the ListView. Therefore warnIfMissed is set to false
+    expect(tapped, isFalse);
+
+    // Ensure the scrollable stops in place and doesn't scroll further
+    await tester.pump(frame);
+    expect(offset, equals(controller.offset));
+    await tester.pumpAndSettle();
+    expect(offset, equals(controller.offset));
+
+    // Tapping on an item should register the tap normally, as the scrollable is idle
+    await tester.tap(find.text('Item 2'));
+    expect(tapped, isTrue);
+    tapped = false;
+  });
+
+  testWidgets('Horizontal ListView, when over-scrolled at the end allows touches on children', (
+    WidgetTester tester,
+  ) async {
+    bool tapped = false;
+    final ScrollController controller = ScrollController();
+    addTearDown(controller.dispose);
+
+    const Duration frame = Duration(milliseconds: 16);
+
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          itemExtent: 100.0,
+          controller: controller,
+          physics: const BouncingScrollPhysics(),
+          scrollDirection: Axis.horizontal,
+          itemCount: 15,
+          itemBuilder: (BuildContext context, int index) {
+            return GestureDetector(
+              onTap: () {
+                tapped = true;
+              },
+              child: SizedBox(width: 100.0, child: Text('Item $index')),
+            );
+          },
+        ),
+      ),
+    );
+
+    // Tap on an item, it should register the tap
+    await tester.tap(find.text('Item 3'));
+    expect(tapped, isTrue);
+    tapped = false;
+
+    // Fling the list, it should start scrolling
+    await tester.fling(find.byType(ListView), const Offset(-500.0, 0.0), 10000.0);
+
+    for (int i = 0; i < 5; i++) {
+      await tester.pump(frame);
+    }
+
+    // Ensure the scrollable is over-scrolled at the end
+    expect(controller.offset, greaterThan(controller.position.maxScrollExtent));
+
+    // Tap on an item, it should register the tap
+    await tester.tap(find.text('Item 14'));
+    expect(tapped, isTrue);
+    tapped = false;
+
+    await tester.pumpAndSettle();
+
+    // Tap on an item, it should register the tap
+    await tester.tap(find.text('Item 14'));
+    expect(tapped, isTrue);
+  });
+
   testWidgets('ListView does not clips if no overflow', (WidgetTester tester) async {
     await tester.pumpWidget(
       Directionality(
@@ -554,14 +767,7 @@ void main() {
         child: Center(
           child: SizedBox(
             height: 200.0,
-            child: ListView(
-              cacheExtent: 500.0,
-              children: const <Widget>[
-                SizedBox(
-                  height: 100.0,
-                ),
-              ],
-            ),
+            child: ListView(cacheExtent: 500.0, children: const <Widget>[SizedBox(height: 100.0)]),
           ),
         ),
       ),
@@ -570,7 +776,9 @@ void main() {
     expect(find.byType(Viewport), isNot(paints..clipRect()));
   });
 
-  testWidgets('ListView (fixed extent) clips if overflow is smaller than cacheExtent', (WidgetTester tester) async {
+  testWidgets('ListView (fixed extent) clips if overflow is smaller than cacheExtent', (
+    WidgetTester tester,
+  ) async {
     // Regression test for https://github.com/flutter/flutter/issues/17426.
 
     await tester.pumpWidget(
@@ -583,15 +791,9 @@ void main() {
               itemExtent: 100.0,
               cacheExtent: 500.0,
               children: const <Widget>[
-                SizedBox(
-                  height: 100.0,
-                ),
-                SizedBox(
-                  height: 100.0,
-                ),
-                SizedBox(
-                  height: 100.0,
-                ),
+                SizedBox(height: 100.0),
+                SizedBox(height: 100.0),
+                SizedBox(height: 100.0),
               ],
             ),
           ),
@@ -612,11 +814,7 @@ void main() {
             child: ListView(
               itemExtent: 100.0,
               cacheExtent: 500.0,
-              children: const <Widget>[
-                SizedBox(
-                  height: 100.0,
-                ),
-              ],
+              children: const <Widget>[SizedBox(height: 100.0)],
             ),
           ),
         ),
@@ -637,34 +835,31 @@ void main() {
             child: ListView(
               scrollDirection: Axis.horizontal,
               itemExtent: 100.0,
-              children: const <Widget>[
-                SizedBox(
-                  height: 100.0,
-                ),
-              ],
+              children: const <Widget>[SizedBox(height: 100.0)],
             ),
           ),
         ),
       ),
     );
-    expect(tester.getSemantics(find.byType(Scrollable)), matchesSemantics(
-      children: <Matcher>[
-        matchesSemantics(
-          children: <Matcher>[
-            matchesSemantics(hasImplicitScrolling: true),
-          ],
-        ),
-      ],
-    ));
+    expect(
+      tester.getSemantics(find.byType(Scrollable)),
+      matchesSemantics(
+        children: <Matcher>[
+          matchesSemantics(children: <Matcher>[matchesSemantics(hasImplicitScrolling: true)]),
+        ],
+      ),
+    );
     handle.dispose();
   });
 
-  testWidgets('Updates viewport dimensions when scroll direction changes', (WidgetTester tester) async {
+  testWidgets('Updates viewport dimensions when scroll direction changes', (
+    WidgetTester tester,
+  ) async {
     // Regression test for https://github.com/flutter/flutter/issues/43380.
     final ScrollController controller = ScrollController();
+    addTearDown(controller.dispose);
 
-    Widget buildListView({ required Axis scrollDirection }) {
-      assert(scrollDirection != null);
+    Widget buildListView({required Axis scrollDirection}) {
       return Directionality(
         textDirection: TextDirection.ltr,
         child: Center(
@@ -675,12 +870,7 @@ void main() {
               controller: controller,
               scrollDirection: scrollDirection,
               itemExtent: 50.0,
-              children: const <Widget>[
-                SizedBox(
-                  height: 50.0,
-                  width: 50.0,
-                ),
-              ],
+              children: const <Widget>[SizedBox(height: 50.0, width: 50.0)],
             ),
           ),
         ),
@@ -701,9 +891,7 @@ void main() {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
-        child: ListView(
-          children: <Widget>[Container(height: 2000.0)],
-        ),
+        child: ListView(children: <Widget>[Container(height: 2000.0)]),
       ),
     );
 
@@ -731,6 +919,7 @@ void main() {
     // 4th, check that a non-default clip behavior can be sent to the painting context.
     renderObject.paint(context, Offset.zero);
     expect(context.clipBehavior, equals(Clip.antiAlias));
+    context.dispose();
   });
 
   testWidgets('ListView.builder respects clipBehavior', (WidgetTester tester) async {
@@ -739,7 +928,7 @@ void main() {
         textDirection: TextDirection.ltr,
         child: ListView.builder(
           itemCount: 10,
-          itemBuilder: (BuildContext _, int __) => Container(height: 2000.0),
+          itemBuilder: (BuildContext _, int _) => Container(height: 2000.0),
           clipBehavior: Clip.antiAlias,
         ),
       ),
@@ -771,8 +960,8 @@ void main() {
         textDirection: TextDirection.ltr,
         child: ListView.separated(
           itemCount: 10,
-          itemBuilder: (BuildContext _, int __) => Container(height: 2000.0),
-          separatorBuilder: (BuildContext _, int __) => const Divider(),
+          itemBuilder: (BuildContext _, int _) => Container(height: 2000.0),
+          separatorBuilder: (BuildContext _, int _) => const Divider(),
           clipBehavior: Clip.antiAlias,
         ),
       ),
@@ -780,4 +969,218 @@ void main() {
     final RenderViewport renderObject = tester.allRenderObjects.whereType<RenderViewport>().first;
     expect(renderObject.clipBehavior, equals(Clip.antiAlias));
   });
+
+  // Regression test for https://github.com/flutter/flutter/pull/138912
+  testWidgets('itemExtentBuilder should respect item count', (WidgetTester tester) async {
+    final ScrollController controller = ScrollController();
+    addTearDown(controller.dispose);
+    final List<double> numbers = <double>[10, 20, 30, 40, 50];
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          controller: controller,
+          itemCount: numbers.length,
+          itemExtentBuilder: (int index, SliverLayoutDimensions dimensions) {
+            return numbers[index];
+          },
+          itemBuilder: (BuildContext context, int index) {
+            return SizedBox(height: numbers[index], child: Text('Item $index'));
+          },
+        ),
+      ),
+    );
+
+    expect(find.text('Item 0'), findsOneWidget);
+    expect(find.text('Item 4'), findsOneWidget);
+    expect(find.text('Item 5'), findsNothing);
+  });
+
+  // Regression test for https://github.com/flutter/flutter/pull/131393
+  testWidgets('itemExtentBuilder test', (WidgetTester tester) async {
+    final ScrollController controller = ScrollController();
+    addTearDown(controller.dispose);
+    final List<int> buildLog = <int>[];
+    late SliverLayoutDimensions sliverLayoutDimensions;
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: ListView.builder(
+          controller: controller,
+          itemExtentBuilder: (int index, SliverLayoutDimensions dimensions) {
+            sliverLayoutDimensions = dimensions;
+            return 100.0;
+          },
+          itemBuilder: (BuildContext context, int index) {
+            buildLog.insert(0, index);
+            return Text('Item $index');
+          },
+        ),
+      ),
+    );
+
+    expect(find.text('Item 0'), findsOneWidget);
+    expect(find.text('Item 5'), findsOneWidget);
+    expect(find.text('Item 6'), findsNothing);
+    expect(
+      sliverLayoutDimensions,
+      const SliverLayoutDimensions(
+        scrollOffset: 0.0,
+        precedingScrollExtent: 0.0,
+        viewportMainAxisExtent: 600.0,
+        crossAxisExtent: 800.0,
+      ),
+    );
+    // viewport(600.0) + cache extent after(250.0)
+    expect(buildLog.length, 9);
+    expect(buildLog.min, 0);
+    expect(buildLog.max, 8);
+
+    buildLog.clear();
+
+    // Scrolling drastically.
+    controller.jumpTo(10000.0);
+    await tester.pump();
+
+    expect(find.text('Item 99'), findsNothing);
+    expect(find.text('Item 100'), findsOneWidget);
+    expect(find.text('Item 105'), findsOneWidget);
+    expect(find.text('Item 106'), findsNothing);
+    expect(
+      sliverLayoutDimensions,
+      const SliverLayoutDimensions(
+        scrollOffset: 10000.0,
+        precedingScrollExtent: 0.0,
+        viewportMainAxisExtent: 600.0,
+        crossAxisExtent: 800.0,
+      ),
+    );
+    // Scrolling drastically only loading the visible and cached area items.
+    // cache extent before(250.0) + viewport(600.0) + cache extent after(250.0)
+    expect(buildLog.length, 12);
+    expect(buildLog.min, 97);
+    expect(buildLog.max, 108);
+
+    buildLog.clear();
+    controller.jumpTo(5000.0);
+    await tester.pump();
+
+    expect(find.text('Item 49'), findsNothing);
+    expect(find.text('Item 50'), findsOneWidget);
+    expect(find.text('Item 55'), findsOneWidget);
+    expect(find.text('Item 56'), findsNothing);
+    expect(
+      sliverLayoutDimensions,
+      const SliverLayoutDimensions(
+        scrollOffset: 5000.0,
+        precedingScrollExtent: 0.0,
+        viewportMainAxisExtent: 600.0,
+        crossAxisExtent: 800.0,
+      ),
+    );
+    // cache extent before(250.0) + viewport(600.0) + cache extent after(250.0)
+    expect(buildLog.length, 12);
+    expect(buildLog.min, 47);
+    expect(buildLog.max, 58);
+
+    buildLog.clear();
+    controller.jumpTo(4700.0);
+    await tester.pump();
+
+    expect(find.text('Item 46'), findsNothing);
+    expect(find.text('Item 47'), findsOneWidget);
+    expect(find.text('Item 52'), findsOneWidget);
+    expect(find.text('Item 53'), findsNothing);
+    expect(
+      sliverLayoutDimensions,
+      const SliverLayoutDimensions(
+        scrollOffset: 4700.0,
+        precedingScrollExtent: 0.0,
+        viewportMainAxisExtent: 600.0,
+        crossAxisExtent: 800.0,
+      ),
+    );
+    // Only newly entered cached area items need to be loaded.
+    expect(buildLog.length, 3);
+    expect(buildLog.min, 44);
+    expect(buildLog.max, 46);
+
+    buildLog.clear();
+    controller.jumpTo(5300.0);
+    await tester.pump();
+
+    expect(find.text('Item 52'), findsNothing);
+    expect(find.text('Item 53'), findsOneWidget);
+    expect(find.text('Item 58'), findsOneWidget);
+    expect(find.text('Item 59'), findsNothing);
+    expect(
+      sliverLayoutDimensions,
+      const SliverLayoutDimensions(
+        scrollOffset: 5300.0,
+        precedingScrollExtent: 0.0,
+        viewportMainAxisExtent: 600.0,
+        crossAxisExtent: 800.0,
+      ),
+    );
+    // Only newly entered cached area items need to be loaded.
+    expect(buildLog.length, 6);
+    expect(buildLog.min, 56);
+    expect(buildLog.max, 61);
+  });
+
+  testWidgets('itemExtent, prototypeItem and itemExtentBuilder conflicts test', (
+    WidgetTester tester,
+  ) async {
+    Object? error;
+    try {
+      await tester.pumpWidget(
+        ListView.builder(
+          itemExtentBuilder: (int index, SliverLayoutDimensions dimensions) {
+            return 100.0;
+          },
+          itemExtent: 100.0,
+          itemBuilder: (BuildContext context, int index) {
+            return Text('Item $index');
+          },
+        ),
+      );
+    } catch (e) {
+      error = e;
+    }
+    expect(error, isNotNull);
+
+    error = null;
+    try {
+      await tester.pumpWidget(
+        ListView.builder(
+          itemExtentBuilder: (int index, SliverLayoutDimensions dimensions) {
+            return 100.0;
+          },
+          prototypeItem: Container(),
+          itemBuilder: (BuildContext context, int index) {
+            return Text('Item $index');
+          },
+        ),
+      );
+    } catch (e) {
+      error = e;
+    }
+    expect(error, isNotNull);
+
+    error = null;
+    try {
+      await tester.pumpWidget(
+        ListView.builder(
+          itemExtent: 100.0,
+          prototypeItem: Container(),
+          itemBuilder: (BuildContext context, int index) {
+            return Text('Item $index');
+          },
+        ),
+      );
+    } catch (e) {
+      error = e;
+    }
+    expect(error, isNotNull);
+  });
 }
