@@ -5,6 +5,7 @@
 import 'package:flutter/foundation.dart';
 import 'package:flutter/material.dart';
 import 'package:flutter_test/flutter_test.dart';
+import 'package:leak_tracker_flutter_testing/leak_tracker_flutter_testing.dart';
 
 void main() {
   testWidgets('Restoration Smoke Test', (WidgetTester tester) async {
@@ -70,7 +71,9 @@ void main() {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home'), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacementNamed('Foo', arguments: 3);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushReplacementNamed('Foo', arguments: 3);
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -103,7 +106,9 @@ void main() {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home'), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePopAndPushNamed('Foo', arguments: 3);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePopAndPushNamed('Foo', arguments: 3);
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -136,7 +141,9 @@ void main() {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home'), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushNamedAndRemoveUntil('Foo', (Route<dynamic> _) => false, arguments: 3);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushNamedAndRemoveUntil('Foo', (Route<dynamic> _) => false, arguments: 3);
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -170,7 +177,9 @@ void main() {
     await tapRouteCounter('home', tester);
     expect(findRoute('home', count: 1), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePush(_routeBuilder, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePush(_routeBuilder, arguments: 'Foo');
     await tester.pumpAndSettle();
 
     expect(findRoute('home'), findsNothing);
@@ -207,7 +216,9 @@ void main() {
     await tapRouteCounter('home', tester);
     expect(findRoute('home', count: 1), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePush(_routeBuilder, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePush(_routeBuilder, arguments: 'Foo');
     await tester.pumpAndSettle();
     expect(findRoute('Foo'), findsOneWidget);
   });
@@ -216,7 +227,9 @@ void main() {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home', count: 0), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacement(_routeBuilder, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushReplacement(_routeBuilder, arguments: 'Foo');
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -250,7 +263,9 @@ void main() {
     await tapRouteCounter('home', tester);
     expect(findRoute('home', count: 1), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacement(_routeBuilder, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushReplacement(_routeBuilder, arguments: 'Foo');
     await tester.pumpAndSettle();
     expect(findRoute('Foo'), findsOneWidget);
   });
@@ -259,7 +274,9 @@ void main() {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home', count: 0), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushAndRemoveUntil(_routeBuilder, (Route<dynamic> _) => false, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushAndRemoveUntil(_routeBuilder, (Route<dynamic> _) => false, arguments: 'Foo');
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -288,12 +305,16 @@ void main() {
     expect(findRoute('Bar'), findsNothing);
   }, skip: isBrowser); // https://github.com/flutter/flutter/issues/33615
 
-  testWidgets('restorablePushAndRemoveUntil adds route on all platforms', (WidgetTester tester) async {
+  testWidgets('restorablePushAndRemoveUntil adds route on all platforms', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(const TestWidget());
     await tapRouteCounter('home', tester);
     expect(findRoute('home', count: 1), findsOneWidget);
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePushAndRemoveUntil(_routeBuilder, (Route<dynamic> _) => false, arguments: 'Foo');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePushAndRemoveUntil(_routeBuilder, (Route<dynamic> _) => false, arguments: 'Foo');
     await tester.pumpAndSettle();
     expect(findRoute('Foo'), findsOneWidget);
   });
@@ -305,7 +326,9 @@ void main() {
     final Route<Object> oldRoute = ModalRoute.of(tester.element(find.text('Route: home')))!;
     expect(oldRoute.settings.name, 'home');
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorableReplace(newRouteBuilder: _routeBuilder, arguments: 'Foo', oldRoute: oldRoute);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorableReplace(newRouteBuilder: _routeBuilder, arguments: 'Foo', oldRoute: oldRoute);
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -341,7 +364,9 @@ void main() {
     final Route<Object> oldRoute = ModalRoute.of(tester.element(find.text('Route: home')))!;
     expect(oldRoute.settings.name, 'home');
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorableReplace(newRouteBuilder: _routeBuilder, arguments: 'Foo', oldRoute: oldRoute);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorableReplace(newRouteBuilder: _routeBuilder, arguments: 'Foo', oldRoute: oldRoute);
     await tester.pumpAndSettle();
     expect(findRoute('Foo'), findsOneWidget);
   });
@@ -361,7 +386,13 @@ void main() {
     final Route<Object> anchor = ModalRoute.of(tester.element(find.text('Route: Anchor')))!;
     expect(anchor.settings.name, 'Anchor');
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorableReplaceRouteBelow(newRouteBuilder: _routeBuilder, arguments: 'Foo', anchorRoute: anchor);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorableReplaceRouteBelow(
+          newRouteBuilder: _routeBuilder,
+          arguments: 'Foo',
+          anchorRoute: anchor,
+        );
     await tester.pumpAndSettle();
 
     expect(findRoute('home', skipOffstage: false), findsNothing);
@@ -392,7 +423,9 @@ void main() {
     expect(findRoute('Anchor', count: 2), findsOneWidget);
   }, skip: isBrowser); // https://github.com/flutter/flutter/issues/33615
 
-  testWidgets('restorableReplaceRouteBelow adds route on all platforms', (WidgetTester tester) async {
+  testWidgets('restorableReplaceRouteBelow adds route on all platforms', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(const TestWidget());
     expect(findRoute('home', count: 0), findsOneWidget);
 
@@ -407,7 +440,13 @@ void main() {
     final Route<Object> anchor = ModalRoute.of(tester.element(find.text('Route: Anchor')))!;
     expect(anchor.settings.name, 'Anchor');
 
-    tester.state<NavigatorState>(find.byType(Navigator)).restorableReplaceRouteBelow(newRouteBuilder: _routeBuilder, arguments: 'Foo', anchorRoute: anchor);
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorableReplaceRouteBelow(
+          newRouteBuilder: _routeBuilder,
+          arguments: 'Foo',
+          anchorRoute: anchor,
+        );
     await tester.pumpAndSettle();
     expect(findRoute('Foo', skipOffstage: false), findsOneWidget);
   });
@@ -494,7 +533,9 @@ void main() {
     expect(route2.isActive, isTrue);
   });
 
-  testWidgets('routes that are in the process of pop are not restored', (WidgetTester tester) async {
+  testWidgets('routes that are in the process of pop are not restored', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(const TestWidget());
     await tapRouteCounter('home', tester);
     expect(findRoute('home', count: 1), findsOneWidget);
@@ -584,7 +625,9 @@ void main() {
     tester.state<NavigatorState>(find.byType(Navigator)).restorablePushNamed('route4');
     await tester.pumpAndSettle();
     expect(findRoute('route4'), findsOneWidget);
-    tester.state<NavigatorState>(find.byType(Navigator)).restorablePush(_routeBuilder, arguments: 'route5');
+    tester
+        .state<NavigatorState>(find.byType(Navigator))
+        .restorablePush(_routeBuilder, arguments: 'route5');
     await tester.pumpAndSettle();
     expect(findRoute('route5'), findsOneWidget);
 
@@ -618,7 +661,8 @@ void main() {
     await tester.pumpAndSettle();
     expect(findRoute('route5'), findsOneWidget);
 
-    final Route<Object> route = ModalRoute.of(tester.element(find.text('Route: route3', skipOffstage: false)))!;
+    final Route<Object> route =
+        ModalRoute.of(tester.element(find.text('Route: route3', skipOffstage: false)))!;
     expect(route.settings.name, 'route3');
     tester.state<NavigatorState>(find.byType(Navigator)).removeRoute(route);
     await tester.pumpAndSettle();
@@ -641,9 +685,8 @@ void main() {
     await tester.pumpAndSettle();
     expect(find.text('Return value: null'), findsOneWidget);
 
-    final RestorableRouteFuture<int> routeFuture = tester
-        .state<RouteFutureWidgetState>(find.byType(RouteFutureWidget))
-        .routeFuture;
+    final RestorableRouteFuture<int> routeFuture =
+        tester.state<RouteFutureWidgetState>(find.byType(RouteFutureWidget)).routeFuture;
     expect(routeFuture.route, isNull);
     expect(routeFuture.isPresent, isFalse);
     expect(routeFuture.enabled, isFalse);
@@ -658,9 +701,10 @@ void main() {
     await tester.restartAndRestore();
 
     expect(find.text('Route: Foo'), findsOneWidget);
-    final RestorableRouteFuture<int> restoredRouteFuture = tester
-        .state<RouteFutureWidgetState>(find.byType(RouteFutureWidget, skipOffstage: false))
-        .routeFuture;
+    final RestorableRouteFuture<int> restoredRouteFuture =
+        tester
+            .state<RouteFutureWidgetState>(find.byType(RouteFutureWidget, skipOffstage: false))
+            .routeFuture;
     expect(restoredRouteFuture.route!.settings.name, 'Foo');
     expect(restoredRouteFuture.isPresent, isTrue);
     expect(restoredRouteFuture.enabled, isTrue);
@@ -685,9 +729,8 @@ void main() {
     await tester.pumpAndSettle();
     expect(find.text('Return value: null'), findsOneWidget);
 
-    final RestorableRouteFuture<int> routeFuture = tester
-        .state<RouteFutureWidgetState>(find.byType(RouteFutureWidget))
-        .routeFuture;
+    final RestorableRouteFuture<int> routeFuture =
+        tester.state<RouteFutureWidgetState>(find.byType(RouteFutureWidget)).routeFuture;
     expect(routeFuture.route, isNull);
     expect(routeFuture.isPresent, isFalse);
     expect(routeFuture.enabled, isFalse);
@@ -712,88 +755,142 @@ void main() {
     final Route<Object> oldRoute = ModalRoute.of(tester.element(find.text('Route: Bar')))!;
     expect(oldRoute.settings.name, 'Bar');
 
-    final Matcher throwsArgumentsAssertionError = throwsA(isAssertionError.having(
-      (AssertionError e) => e.message,
-      'message',
-      'The arguments object must be serializable via the StandardMessageCodec.',
-    ));
-    final Matcher throwsBuilderAssertionError = throwsA(isAssertionError.having(
-      (AssertionError e) => e.message,
-      'message',
-      'The provided routeBuilder must be a static function.',
-    ));
+    final Matcher throwsArgumentsAssertionError = throwsA(
+      isAssertionError.having(
+        (AssertionError e) => e.message,
+        'message',
+        'The arguments object must be serializable via the StandardMessageCodec.',
+      ),
+    );
+    final Matcher throwsBuilderAssertionError = throwsA(
+      isAssertionError.having(
+        (AssertionError e) => e.message,
+        'message',
+        'The provided routeBuilder must be a static function.',
+      ),
+    );
 
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushNamed('Foo', arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushNamed('Foo', arguments: Object()),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacementNamed('Foo', arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushReplacementNamed('Foo', arguments: Object()),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePopAndPushNamed('Foo', arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePopAndPushNamed('Foo', arguments: Object()),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushNamedAndRemoveUntil('Foo', (Route<Object?> _) => false, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushNamedAndRemoveUntil(
+            'Foo',
+            (Route<Object?> _) => false,
+            arguments: Object(),
+          ),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePush(_routeBuilder, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePush(_routeBuilder, arguments: Object()),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacement(_routeBuilder, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushReplacement(_routeBuilder, arguments: Object()),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushAndRemoveUntil(_routeBuilder, (Route<Object?> _) => false, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushAndRemoveUntil(
+            _routeBuilder,
+            (Route<Object?> _) => false,
+            arguments: Object(),
+          ),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorableReplace(newRouteBuilder: _routeBuilder, oldRoute: oldRoute, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorableReplace(
+            newRouteBuilder: _routeBuilder,
+            oldRoute: oldRoute,
+            arguments: Object(),
+          ),
       throwsArgumentsAssertionError,
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorableReplaceRouteBelow(newRouteBuilder: _routeBuilder, anchorRoute: oldRoute, arguments: Object()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorableReplaceRouteBelow(
+            newRouteBuilder: _routeBuilder,
+            anchorRoute: oldRoute,
+            arguments: Object(),
+          ),
       throwsArgumentsAssertionError,
     );
 
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePush((BuildContext _, Object? __) => FakeRoute()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePush((BuildContext _, Object? _) => FakeRoute()),
       throwsBuilderAssertionError,
       skip: isBrowser, // https://github.com/flutter/flutter/issues/33615
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushReplacement((BuildContext _, Object? __) => FakeRoute()),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushReplacement((BuildContext _, Object? _) => FakeRoute()),
       throwsBuilderAssertionError,
       skip: isBrowser, // https://github.com/flutter/flutter/issues/33615
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorablePushAndRemoveUntil((BuildContext _, Object? __) => FakeRoute(), (Route<Object?> _) => false),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorablePushAndRemoveUntil(
+            (BuildContext _, Object? _) => FakeRoute(),
+            (Route<Object?> _) => false,
+          ),
       throwsBuilderAssertionError,
       skip: isBrowser, // https://github.com/flutter/flutter/issues/33615
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorableReplace(newRouteBuilder: (BuildContext _, Object? __) => FakeRoute(), oldRoute: oldRoute),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorableReplace(
+            newRouteBuilder: (BuildContext _, Object? _) => FakeRoute(),
+            oldRoute: oldRoute,
+          ),
       throwsBuilderAssertionError,
       skip: isBrowser, // https://github.com/flutter/flutter/issues/33615
     );
     expect(
-      () => tester.state<NavigatorState>(find.byType(Navigator)).restorableReplaceRouteBelow(newRouteBuilder: (BuildContext _, Object? __) => FakeRoute(), anchorRoute: oldRoute),
+      () => tester
+          .state<NavigatorState>(find.byType(Navigator))
+          .restorableReplaceRouteBelow(
+            newRouteBuilder: (BuildContext _, Object? _) => FakeRoute(),
+            anchorRoute: oldRoute,
+          ),
       throwsBuilderAssertionError,
       skip: isBrowser, // https://github.com/flutter/flutter/issues/33615
     );
   });
 
   testWidgets('Moving scopes', (WidgetTester tester) async {
-    await tester.pumpWidget(const RootRestorationScope(
-      restorationId: 'root',
-      child: TestWidget(
-        restorationId: null,
-      ),
-    ));
+    await tester.pumpWidget(
+      const RootRestorationScope(restorationId: 'root', child: TestWidget(restorationId: null)),
+    );
     await tapRouteCounter('home', tester);
     tester.state<NavigatorState>(find.byType(Navigator)).restorablePushNamed('Foo');
     await tester.pumpAndSettle();
@@ -810,10 +907,7 @@ void main() {
     await tester.pumpAndSettle();
 
     // Move navigator into restoration scope.
-    await tester.pumpWidget(const RootRestorationScope(
-      restorationId: 'root',
-      child: TestWidget(),
-    ));
+    await tester.pumpWidget(const RootRestorationScope(restorationId: 'root', child: TestWidget()));
 
     expect(findRoute('Foo'), findsOneWidget);
     expect(findRoute('home', count: 1, skipOffstage: false), findsOneWidget);
@@ -824,12 +918,9 @@ void main() {
     expect(findRoute('home', count: 1, skipOffstage: false), findsOneWidget);
 
     // Move navigator out of restoration scope.
-    await tester.pumpWidget(const RootRestorationScope(
-      restorationId: 'root',
-      child: TestWidget(
-        restorationId: null,
-      ),
-    ));
+    await tester.pumpWidget(
+      const RootRestorationScope(restorationId: 'root', child: TestWidget(restorationId: null)),
+    );
 
     expect(findRoute('Foo'), findsOneWidget);
     expect(findRoute('home', count: 1, skipOffstage: false), findsOneWidget);
@@ -895,7 +986,9 @@ void main() {
     await tapRouteCounter('r1', tester);
     expect(findRoute('r1', count: 1), findsOneWidget);
 
-    tester.state<PagedTestNavigatorState>(find.byType(PagedTestNavigator)).addPage('p2', restoreState: false);
+    tester
+        .state<PagedTestNavigatorState>(find.byType(PagedTestNavigator))
+        .addPage('p2', restoreState: false);
     await tester.pumpAndSettle();
     await tapRouteCounter('p2', tester);
     expect(findRoute('p2', count: 1), findsOneWidget);
@@ -976,52 +1069,51 @@ void main() {
     expect(findRoute('p1', count: 0), findsOneWidget);
   });
 
-  testWidgets('Helpful assert thrown all routes in onGenerateInitialRoutes are not restorable', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      MaterialApp(
-        restorationScopeId: 'material_app',
-        initialRoute: '/',
-        routes: <String, WidgetBuilder>{
-          '/': (BuildContext context) => Container(),
-        },
-        onGenerateInitialRoutes: (String initialRoute) {
-          return <MaterialPageRoute<void>>[
-            MaterialPageRoute<void>(
-              builder: (BuildContext context) => Container(),
-            ),
-          ];
-        },
-      ),
-    );
-    await tester.restartAndRestore();
-    final dynamic exception = tester.takeException();
-    expect(exception, isAssertionError);
-    expect(
-      (exception as AssertionError).message,
-      contains('All routes returned by onGenerateInitialRoutes are not restorable.'),
-    );
+  testWidgets(
+    'Helpful assert thrown all routes in onGenerateInitialRoutes are not restorable',
+    experimentalLeakTesting:
+        LeakTesting.settings.withIgnoredAll(), // leaking by design because of exception
+    (WidgetTester tester) async {
+      await tester.pumpWidget(
+        MaterialApp(
+          restorationScopeId: 'material_app',
+          initialRoute: '/',
+          routes: <String, WidgetBuilder>{'/': (BuildContext context) => Container()},
+          onGenerateInitialRoutes: (String initialRoute) {
+            return <MaterialPageRoute<void>>[
+              MaterialPageRoute<void>(builder: (BuildContext context) => Container()),
+            ];
+          },
+        ),
+      );
+      await tester.restartAndRestore();
+      final dynamic exception = tester.takeException();
+      expect(exception, isAssertionError);
+      expect(
+        (exception as AssertionError).message,
+        contains('All routes returned by onGenerateInitialRoutes are not restorable.'),
+      );
 
-    // The previous assert leaves the widget tree in a broken state, so the
-    // following code catches any remaining exceptions from attempting to build
-    // new widget tree.
-    final FlutterExceptionHandler? oldHandler = FlutterError.onError;
-    dynamic remainingException;
-    FlutterError.onError = (FlutterErrorDetails details) {
-      remainingException ??= details.exception;
-    };
-    await tester.pumpWidget(Container(key: UniqueKey()));
-    FlutterError.onError = oldHandler;
-    expect(remainingException, isAssertionError);
-  });
+      // The previous assert leaves the widget tree in a broken state, so the
+      // following code catches any remaining exceptions from attempting to build
+      // new widget tree.
+      final FlutterExceptionHandler? oldHandler = FlutterError.onError;
+      dynamic remainingException;
+      FlutterError.onError = (FlutterErrorDetails details) {
+        remainingException ??= details.exception;
+      };
+      await tester.pumpWidget(Container(key: UniqueKey()));
+      FlutterError.onError = oldHandler;
+      expect(remainingException, isAssertionError);
+    },
+  );
 }
 
 @pragma('vm:entry-point')
 Route<void> _routeBuilder(BuildContext context, Object? arguments) {
   return MaterialPageRoute<void>(
     builder: (BuildContext context) {
-      return RouteWidget(
-        name: arguments! as String,
-      );
+      return RouteWidget(name: arguments! as String);
     },
   );
 }
@@ -1102,28 +1194,21 @@ class PagedTestNavigatorState extends State<PagedTestNavigator> with Restoration
         }
         return false;
       },
-      pages: _routes.value.isEmpty ? const <Page<Object?>>[] : _routes.value.split(',').map((String name) {
-        if (name.startsWith('r-')) {
-          name = name.substring(2);
-          return TestPage(
-            name: name,
-            restorationId: name,
-            key: ValueKey<String>(name),
-          );
-        }
-        return TestPage(
-          name: name,
-          key: ValueKey<String>(name),
-        );
-      }).toList(),
+      pages:
+          _routes.value.isEmpty
+              ? const <Page<Object?>>[]
+              : _routes.value.split(',').map((String name) {
+                if (name.startsWith('r-')) {
+                  name = name.substring(2);
+                  return TestPage(name: name, restorationId: name, key: ValueKey<String>(name));
+                }
+                return TestPage(name: name, key: ValueKey<String>(name));
+              }).toList(),
       onGenerateRoute: (RouteSettings settings) {
         return MaterialPageRoute<int>(
           settings: settings,
           builder: (BuildContext context) {
-            return RouteWidget(
-              name: settings.name!,
-              arguments: settings.arguments,
-            );
+            return RouteWidget(name: settings.name!, arguments: settings.arguments);
           },
         );
       },
@@ -1153,9 +1238,7 @@ class TestPage extends Page<void> {
     return MaterialPageRoute<void>(
       settings: this,
       builder: (BuildContext context) {
-        return RouteWidget(
-          name: name!,
-        );
+        return RouteWidget(name: name!);
       },
     );
   }
@@ -1181,10 +1264,7 @@ class TestWidget extends StatelessWidget {
               return MaterialPageRoute<int>(
                 settings: settings,
                 builder: (BuildContext context) {
-                  return RouteWidget(
-                    name: settings.name!,
-                    arguments: settings.arguments,
-                  );
+                  return RouteWidget(name: settings.name!, arguments: settings.arguments);
                 },
               );
             },
@@ -1235,8 +1315,7 @@ class RouteWidgetState extends State<RouteWidget> with RestorationMixin {
               });
             },
           ),
-          if (widget.arguments != null)
-            Text('Arguments(home): ${widget.arguments}'),
+          if (widget.arguments != null) Text('Arguments(home): ${widget.arguments}'),
           Text('Counter(${widget.name}): ${counter.value}'),
         ],
       ),
@@ -1286,13 +1365,12 @@ class RouteFutureWidgetState extends State<RouteFutureWidget> with RestorationMi
 
   @override
   Widget build(BuildContext context) {
-    return Center(
-      child: Text('Return value: $value'),
-    );
+    return Center(child: Text('Return value: $value'));
   }
 }
 
-Finder findRoute(String name, { Object? arguments, int? count, bool skipOffstage = true }) => _RouteFinder(name, arguments: arguments, count: count, skipOffstage: skipOffstage);
+Finder findRoute(String name, {Object? arguments, int? count, bool skipOffstage = true}) =>
+    _RouteFinder(name, arguments: arguments, count: count, skipOffstage: skipOffstage);
 
 Future<void> tapRouteCounter(String name, WidgetTester tester) async {
   await tester.tap(find.text('Route: $name'));
@@ -1300,7 +1378,7 @@ Future<void> tapRouteCounter(String name, WidgetTester tester) async {
 }
 
 class _RouteFinder extends MatchFinder {
-  _RouteFinder(this.name, { this.arguments, this.count, super.skipOffstage });
+  _RouteFinder(this.name, {this.arguments, this.count, super.skipOffstage});
 
   final String name;
   final Object? arguments;
@@ -1338,4 +1416,4 @@ class _RouteFinder extends MatchFinder {
   }
 }
 
-class FakeRoute extends Fake implements Route<void> { }
+class FakeRoute extends Fake implements Route<void> {}
