@@ -6,17 +6,12 @@ import 'package:flutter/rendering.dart';
 import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 
-import '../rendering/recording_canvas.dart';
-
 final BoxDecoration kBoxDecorationA = BoxDecoration(border: nonconst(null));
 final BoxDecoration kBoxDecorationB = BoxDecoration(border: nonconst(null));
 final BoxDecoration kBoxDecorationC = BoxDecoration(border: nonconst(null));
 
 class TestWidget extends StatelessWidget {
-  const TestWidget({
-    super.key,
-    required this.child,
-  });
+  const TestWidget({super.key, required this.child});
 
   final Widget child;
 
@@ -25,20 +20,18 @@ class TestWidget extends StatelessWidget {
 }
 
 class TestOrientedBox extends SingleChildRenderObjectWidget {
-  const TestOrientedBox({ super.key, super.child });
+  const TestOrientedBox({super.key, super.child});
 
   Decoration _getDecoration(BuildContext context) {
-    final Orientation orientation = MediaQuery.orientationOf(context);
-    switch (orientation) {
-      case Orientation.landscape:
-        return const BoxDecoration(color: Color(0xFF00FF00));
-      case Orientation.portrait:
-        return const BoxDecoration(color: Color(0xFF0000FF));
-    }
+    return switch (MediaQuery.orientationOf(context)) {
+      Orientation.landscape => const BoxDecoration(color: Color(0xFF00FF00)),
+      Orientation.portrait => const BoxDecoration(color: Color(0xFF0000FF)),
+    };
   }
 
   @override
-  RenderDecoratedBox createRenderObject(BuildContext context) => RenderDecoratedBox(decoration: _getDecoration(context));
+  RenderDecoratedBox createRenderObject(BuildContext context) =>
+      RenderDecoratedBox(decoration: _getDecoration(context));
 
   @override
   void updateRenderObject(BuildContext context, RenderDecoratedBox renderObject) {
@@ -47,7 +40,7 @@ class TestOrientedBox extends SingleChildRenderObjectWidget {
 }
 
 class TestNonVisitingWidget extends SingleChildRenderObjectWidget {
-  const TestNonVisitingWidget({ super.key, required Widget super.child });
+  const TestNonVisitingWidget({super.key, required Widget super.child});
 
   @override
   RenderObject createRenderObject(BuildContext context) => TestNonVisitingRenderObject();
@@ -79,8 +72,9 @@ class TestNonVisitingRenderObject extends RenderBox with RenderObjectWithChildMi
 void main() {
   testWidgets('RenderObjectWidget smoke test', (WidgetTester tester) async {
     await tester.pumpWidget(DecoratedBox(decoration: kBoxDecorationA));
-    SingleChildRenderObjectElement element =
-        tester.element(find.byElementType(SingleChildRenderObjectElement));
+    SingleChildRenderObjectElement element = tester.element(
+      find.byElementType(SingleChildRenderObjectElement),
+    );
     expect(element, isNotNull);
     expect(element.renderObject, isA<RenderDecoratedBox>());
     RenderDecoratedBox renderObject = element.renderObject as RenderDecoratedBox;
@@ -97,10 +91,10 @@ void main() {
   });
 
   testWidgets('RenderObjectWidget can add and remove children', (WidgetTester tester) async {
-
     void checkFullTree() {
-      final SingleChildRenderObjectElement element =
-          tester.firstElement(find.byElementType(SingleChildRenderObjectElement));
+      final SingleChildRenderObjectElement element = tester.firstElement(
+        find.byElementType(SingleChildRenderObjectElement),
+      );
       expect(element, isNotNull);
       expect(element.renderObject, isA<RenderDecoratedBox>());
       final RenderDecoratedBox renderObject = element.renderObject as RenderDecoratedBox;
@@ -115,8 +109,9 @@ void main() {
     }
 
     void childBareTree() {
-      final SingleChildRenderObjectElement element =
-          tester.element(find.byElementType(SingleChildRenderObjectElement));
+      final SingleChildRenderObjectElement element = tester.element(
+        find.byElementType(SingleChildRenderObjectElement),
+      );
       expect(element, isNotNull);
       expect(element.renderObject, isA<RenderDecoratedBox>());
       final RenderDecoratedBox renderObject = element.renderObject as RenderDecoratedBox;
@@ -125,75 +120,59 @@ void main() {
       expect(renderObject.child, isNull);
     }
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-      child: DecoratedBox(
-        decoration: kBoxDecorationB,
-      ),
-    ));
+    await tester.pumpWidget(
+      DecoratedBox(decoration: kBoxDecorationA, child: DecoratedBox(decoration: kBoxDecorationB)),
+    );
 
     checkFullTree();
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-      child: TestWidget(
-        child: DecoratedBox(
-          decoration: kBoxDecorationB,
-        ),
+    await tester.pumpWidget(
+      DecoratedBox(
+        decoration: kBoxDecorationA,
+        child: TestWidget(child: DecoratedBox(decoration: kBoxDecorationB)),
       ),
-    ));
+    );
 
     checkFullTree();
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-      child: DecoratedBox(
-        decoration: kBoxDecorationB,
-      ),
-    ));
+    await tester.pumpWidget(
+      DecoratedBox(decoration: kBoxDecorationA, child: DecoratedBox(decoration: kBoxDecorationB)),
+    );
 
     checkFullTree();
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-    ));
+    await tester.pumpWidget(DecoratedBox(decoration: kBoxDecorationA));
 
     childBareTree();
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-      child: TestWidget(
-        child: TestWidget(
-          child: DecoratedBox(
-            decoration: kBoxDecorationB,
-          ),
-        ),
+    await tester.pumpWidget(
+      DecoratedBox(
+        decoration: kBoxDecorationA,
+        child: TestWidget(child: TestWidget(child: DecoratedBox(decoration: kBoxDecorationB))),
       ),
-    ));
+    );
 
     checkFullTree();
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-    ));
+    await tester.pumpWidget(DecoratedBox(decoration: kBoxDecorationA));
 
     childBareTree();
   });
 
   testWidgets('Detached render tree is intact', (WidgetTester tester) async {
-
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-      child: DecoratedBox(
-        decoration: kBoxDecorationB,
+    await tester.pumpWidget(
+      DecoratedBox(
+        decoration: kBoxDecorationA,
         child: DecoratedBox(
-          decoration: kBoxDecorationC,
+          decoration: kBoxDecorationB,
+          child: DecoratedBox(decoration: kBoxDecorationC),
         ),
       ),
-    ));
+    );
 
-    SingleChildRenderObjectElement element =
-        tester.firstElement(find.byElementType(SingleChildRenderObjectElement));
+    SingleChildRenderObjectElement element = tester.firstElement(
+      find.byElementType(SingleChildRenderObjectElement),
+    );
     expect(element.renderObject, isA<RenderDecoratedBox>());
     final RenderDecoratedBox parent = element.renderObject as RenderDecoratedBox;
     expect(parent.child, isA<RenderDecoratedBox>());
@@ -204,12 +183,9 @@ void main() {
     expect(grandChild.decoration, equals(kBoxDecorationC));
     expect(grandChild.child, isNull);
 
-    await tester.pumpWidget(DecoratedBox(
-      decoration: kBoxDecorationA,
-    ));
+    await tester.pumpWidget(DecoratedBox(decoration: kBoxDecorationA));
 
-    element =
-        tester.element(find.byElementType(SingleChildRenderObjectElement));
+    element = tester.element(find.byElementType(SingleChildRenderObjectElement));
     expect(element.renderObject, isA<RenderDecoratedBox>());
     expect(element.renderObject, equals(parent));
     expect(parent.child, isNull);
@@ -226,29 +202,27 @@ void main() {
     final Key boxKey = UniqueKey();
     final TestOrientedBox box = TestOrientedBox(key: boxKey);
 
-    await tester.pumpWidget(MediaQuery(
-      data: const MediaQueryData(size: Size(400.0, 300.0)),
-      child: box,
-    ));
+    await tester.pumpWidget(
+      MediaQuery(data: const MediaQueryData(size: Size(400.0, 300.0)), child: box),
+    );
 
     final RenderDecoratedBox renderBox = tester.renderObject(find.byKey(boxKey));
     BoxDecoration decoration = renderBox.decoration as BoxDecoration;
     expect(decoration.color, equals(const Color(0xFF00FF00)));
 
-    await tester.pumpWidget(MediaQuery(
-      data: const MediaQueryData(size: Size(300.0, 400.0)),
-      child: box,
-    ));
+    await tester.pumpWidget(
+      MediaQuery(data: const MediaQueryData(size: Size(300.0, 400.0)), child: box),
+    );
 
     decoration = renderBox.decoration as BoxDecoration;
     expect(decoration.color, equals(const Color(0xFF0000FF)));
   });
 
-  testWidgets('RenderObject not visiting children provides helpful error message', (WidgetTester tester) async {
+  testWidgets('RenderObject not visiting children provides helpful error message', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
-      TestNonVisitingWidget(
-        child: Container(color: const Color(0xFFED1D7F)),
-      ),
+      TestNonVisitingWidget(child: Container(color: const Color(0xFFED1D7F))),
     );
 
     final RenderObject renderObject = tester.renderObject(find.byType(TestNonVisitingWidget));
@@ -262,6 +236,9 @@ void main() {
     final dynamic error = tester.takeException();
     expect(error, isNotNull, reason: 'RenderObject did not throw when painting');
     expect(error, isFlutterError);
-    expect(error.toString(), contains("A RenderObject was not visited by the parent's visitChildren"));
+    expect(
+      error.toString(),
+      contains("A RenderObject was not visited by the parent's visitChildren"),
+    );
   });
 }
