@@ -11,12 +11,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: false,
-          floating: false,
-          bottom: false,
-          controller: controller,
-        ),
+      _TestWidget(pinned: false, floating: false, bottom: false, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -33,12 +28,7 @@ void main() {
     await tester.pumpWidget(
       MediaQuery(
         data: const MediaQueryData(accessibleNavigation: true),
-        child:  _TestWidget(
-          pinned: false,
-          floating: false,
-          bottom: false,
-          controller: controller,
-        ),
+        child: _TestWidget(pinned: false, floating: false, bottom: false, controller: controller),
       ),
     );
 
@@ -62,12 +52,7 @@ void main() {
       ..accessibilityFeaturesTestValue = const FakeAccessibilityFeatures();
 
     await tester.pumpWidget(
-      _TestWidget(
-        pinned: false,
-        floating: false,
-        bottom: false,
-        controller: controller,
-      ),
+      _TestWidget(pinned: false, floating: false, bottom: false, controller: controller),
     );
 
     // AccessibleNavigation is off
@@ -77,14 +62,14 @@ void main() {
     expect(render.text.style!.color!.opacity < 1.0, true);
 
     // Turn on accessibleNavigation
-    tester.platformDispatcher.accessibilityFeaturesTestValue =
-        const FakeAccessibilityFeatures(accessibleNavigation: true);
+    tester.platformDispatcher.accessibilityFeaturesTestValue = const FakeAccessibilityFeatures(
+      accessibleNavigation: true,
+    );
     await tester.pumpAndSettle();
     expect(render.text.style!.color!.opacity, 1.0);
 
     // Turn off accessibleNavigation
-    tester.platformDispatcher.accessibilityFeaturesTestValue =
-        const FakeAccessibilityFeatures();
+    tester.platformDispatcher.accessibilityFeaturesTestValue = const FakeAccessibilityFeatures();
     await tester.pumpAndSettle();
     expect(render.text.style!.color!.opacity < 1.0, true);
   });
@@ -92,12 +77,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: false,
-          floating: false,
-          bottom: true,
-          controller: controller,
-        ),
+      _TestWidget(pinned: false, floating: false, bottom: true, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -112,12 +92,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: false,
-          floating: true,
-          bottom: false,
-          controller: controller,
-        ),
+      _TestWidget(pinned: false, floating: true, bottom: false, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -132,12 +107,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: false,
-          floating: true,
-          bottom: true,
-          controller: controller,
-        ),
+      _TestWidget(pinned: false, floating: true, bottom: true, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -152,12 +122,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: true,
-          floating: false,
-          bottom: false,
-          controller: controller,
-        ),
+      _TestWidget(pinned: true, floating: false, bottom: false, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -172,12 +137,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: true,
-          floating: false,
-          bottom: true,
-          controller: controller,
-        ),
+      _TestWidget(pinned: true, floating: false, bottom: true, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -194,12 +154,7 @@ void main() {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: true,
-          floating: true,
-          bottom: false,
-          controller: controller,
-        ),
+      _TestWidget(pinned: true, floating: true, bottom: false, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -210,18 +165,15 @@ void main() {
     expect(render.text.style!.color!.opacity, 1.0);
   });
 
-  testWidgets('pinned && floating && bottom && extraToolbarHeight == 0.0 ==> fade opacity', (WidgetTester tester) async {
+  testWidgets('pinned && floating && bottom && extraToolbarHeight == 0.0 ==> fade opacity', (
+    WidgetTester tester,
+  ) async {
     // Regression test for https://github.com/flutter/flutter/issues/25993.
 
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
-      _TestWidget(
-        pinned: true,
-        floating: true,
-        bottom: true,
-        controller: controller,
-      ),
+      _TestWidget(pinned: true, floating: true, bottom: true, controller: controller),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -232,7 +184,9 @@ void main() {
     expect(render.text.style!.color!.opacity, 0.0);
   });
 
-  testWidgets('pinned && floating && bottom && extraToolbarHeight != 0.0 ==> 1.0 opacity', (WidgetTester tester) async {
+  testWidgets('pinned && floating && bottom && extraToolbarHeight != 0.0 ==> 1.0 opacity', (
+    WidgetTester tester,
+  ) async {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     await tester.pumpWidget(
@@ -253,18 +207,20 @@ void main() {
     expect(render.text.style!.color!.opacity, 1.0);
   });
 
-  testWidgets('!pinned && !floating && !bottom && extraToolbarHeight != 0.0 ==> fade opacity', (WidgetTester tester) async {
+  testWidgets('!pinned && !floating && !bottom && extraToolbarHeight != 0.0 ==> fade opacity', (
+    WidgetTester tester,
+  ) async {
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
     const double collapsedHeight = 100.0;
     await tester.pumpWidget(
-        _TestWidget(
-          pinned: false,
-          floating: false,
-          bottom: false,
-          controller: controller,
-          collapsedHeight: collapsedHeight,
-        ),
+      _TestWidget(
+        pinned: false,
+        floating: false,
+        bottom: false,
+        controller: controller,
+        collapsedHeight: collapsedHeight,
+      ),
     );
 
     final RenderParagraph render = tester.renderObject(find.text('Hallo Welt!!1'));
@@ -277,7 +233,6 @@ void main() {
 }
 
 class _TestWidget extends StatelessWidget {
-
   const _TestWidget({
     required this.pinned,
     required this.floating,
@@ -304,22 +259,20 @@ class _TestWidget extends StatelessWidget {
             expandedHeight: 120.0,
             collapsedHeight: collapsedHeight,
             title: const Text('Hallo Welt!!1'),
-            bottom: !bottom ? null :  PreferredSize(
-              preferredSize: const Size.fromHeight(35.0),
-              child: Container(),
-            ),
+            bottom:
+                !bottom
+                    ? null
+                    : PreferredSize(preferredSize: const Size.fromHeight(35.0), child: Container()),
           ),
           SliverList(
-            delegate: SliverChildListDelegate(List<Widget>.generate(20, (int i) {
-              return SizedBox(
-                height: 100.0,
-                child: Text('Tile $i'),
-              );
-            })),
+            delegate: SliverChildListDelegate(
+              List<Widget>.generate(20, (int i) {
+                return SizedBox(height: 100.0, child: Text('Tile $i'));
+              }),
+            ),
           ),
         ],
       ),
     );
   }
-
 }
