@@ -6,8 +6,10 @@ import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
-  testWidgets('Sliver with keep alive without key - should dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver with keep alive without key - should dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       const WidgetTest0(text: 'child 0', keepAlive: true),
       const WidgetTest1(text: 'child 1', keepAlive: true),
       const WidgetTest2(text: 'child 2', keepAlive: true),
@@ -29,8 +31,10 @@ void main() {
     expect(state2.hasBeenDisposed, false);
   });
 
-  testWidgets('Sliver without keep alive without key - should dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver without keep alive without key - should dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       const WidgetTest0(text: 'child 0'),
       const WidgetTest1(text: 'child 1'),
       const WidgetTest2(text: 'child 2'),
@@ -52,8 +56,10 @@ void main() {
     expect(state2.hasBeenDisposed, false);
   });
 
-  testWidgets('Sliver without keep alive with key - should dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver without keep alive with key - should dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: GlobalKey()),
       WidgetTest1(text: 'child 1', key: GlobalKey()),
       WidgetTest2(text: 'child 2', key: GlobalKey()),
@@ -75,8 +81,10 @@ void main() {
     expect(state2.hasBeenDisposed, false);
   });
 
-  testWidgets('Sliver with keep alive with key - should not dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver with keep alive with key - should not dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: GlobalKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: GlobalKey(), keepAlive: true),
       WidgetTest2(text: 'child 2', key: GlobalKey(), keepAlive: true),
@@ -97,8 +105,10 @@ void main() {
     expect(state2.hasBeenDisposed, false);
   });
 
-  testWidgets('Sliver with keep alive with Unique key - should not dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver with keep alive with Unique key - should not dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: UniqueKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: UniqueKey(), keepAlive: true),
       WidgetTest2(text: 'child 2', key: UniqueKey(), keepAlive: true),
@@ -119,8 +129,10 @@ void main() {
     expect(state2.hasBeenDisposed, false);
   });
 
-  testWidgets('Sliver with keep alive with Value key - should not dispose after reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('Sliver with keep alive with Value key - should not dispose after reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       const WidgetTest0(text: 'child 0', key: ValueKey<int>(0), keepAlive: true),
       const WidgetTest1(text: 'child 1', key: ValueKey<int>(1), keepAlive: true),
       const WidgetTest2(text: 'child 2', key: ValueKey<int>(2), keepAlive: true),
@@ -142,7 +154,7 @@ void main() {
   });
 
   testWidgets('Sliver complex case 1', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: GlobalKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: GlobalKey(), keepAlive: true),
       const WidgetTest2(text: 'child 2', keepAlive: true),
@@ -186,7 +198,7 @@ void main() {
   });
 
   testWidgets('Sliver complex case 2', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: GlobalKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: UniqueKey()),
       const WidgetTest2(text: 'child 2', keepAlive: true),
@@ -229,7 +241,7 @@ void main() {
   });
 
   testWidgets('Sliver with SliverChildBuilderDelegate', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: UniqueKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: GlobalKey()),
       const WidgetTest2(text: 'child 2', keepAlive: true),
@@ -271,15 +283,15 @@ void main() {
     expect(state2.hasBeenDisposed, true);
   });
 
-  testWidgets('SliverFillViewport should not dispose widget with key during in screen reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('SliverFillViewport should not dispose widget with key during in screen reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: UniqueKey(), keepAlive: true),
       WidgetTest1(text: 'child 1', key: UniqueKey()),
       const WidgetTest2(text: 'child 2', keepAlive: true),
     ];
-    await tester.pumpWidget(
-        SwitchingChildListTest(viewportFraction: 0.1, children: childList),
-    );
+    await tester.pumpWidget(SwitchingChildListTest(viewportFraction: 0.1, children: childList));
     final _WidgetTest0State state0 = tester.state(find.byType(WidgetTest0));
     final _WidgetTest1State state1 = tester.state(find.byType(WidgetTest1));
     final _WidgetTest2State state2 = tester.state(find.byType(WidgetTest2));
@@ -288,39 +300,31 @@ void main() {
     expect(find.text('child 2'), findsOneWidget);
 
     childList = createSwitchedChildList(childList, 0, 2);
-    await tester.pumpWidget(
-        SwitchingChildListTest(viewportFraction: 0.1, children: childList),
-    );
+    await tester.pumpWidget(SwitchingChildListTest(viewportFraction: 0.1, children: childList));
 
     childList = createSwitchedChildList(childList, 0, 1);
-    await tester.pumpWidget(
-        SwitchingChildListTest(viewportFraction: 0.1, children: childList),
-    );
+    await tester.pumpWidget(SwitchingChildListTest(viewportFraction: 0.1, children: childList));
 
     childList = createSwitchedChildList(childList, 1, 2);
-    await tester.pumpWidget(
-        SwitchingChildListTest(viewportFraction: 0.1, children: childList),
-    );
+    await tester.pumpWidget(SwitchingChildListTest(viewportFraction: 0.1, children: childList));
 
     childList = createSwitchedChildList(childList, 0, 1);
-    await tester.pumpWidget(
-        SwitchingChildListTest(viewportFraction: 0.1, children: childList),
-    );
+    await tester.pumpWidget(SwitchingChildListTest(viewportFraction: 0.1, children: childList));
 
     expect(state0.hasBeenDisposed, false);
     expect(state1.hasBeenDisposed, false);
     expect(state2.hasBeenDisposed, true);
   });
 
-  testWidgets('SliverList should not dispose widget with key during in screen reordering', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+  testWidgets('SliverList should not dispose widget with key during in screen reordering', (
+    WidgetTester tester,
+  ) async {
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: UniqueKey(), keepAlive: true),
       const WidgetTest1(text: 'child 1', keepAlive: true),
       WidgetTest2(text: 'child 2', key: UniqueKey()),
     ];
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
     final _WidgetTest0State state0 = tester.state(find.byType(WidgetTest0));
     final _WidgetTest1State state1 = tester.state(find.byType(WidgetTest1));
     final _WidgetTest2State state2 = tester.state(find.byType(WidgetTest2));
@@ -329,48 +333,34 @@ void main() {
     expect(find.text('child 2'), findsOneWidget);
 
     childList = createSwitchedChildList(childList, 0, 2);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
 
     childList = createSwitchedChildList(childList, 1, 2);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
 
     childList = createSwitchedChildList(childList, 1, 2);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
 
     childList = createSwitchedChildList(childList, 0, 1);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
 
     childList = createSwitchedChildList(childList, 0, 2);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
 
     childList = createSwitchedChildList(childList, 0, 1);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
     expect(state0.hasBeenDisposed, false);
     expect(state1.hasBeenDisposed, true);
     expect(state2.hasBeenDisposed, false);
   });
 
   testWidgets('SliverList remove child from child list', (WidgetTester tester) async {
-    List<Widget> childList= <Widget>[
+    List<Widget> childList = <Widget>[
       WidgetTest0(text: 'child 0', key: UniqueKey(), keepAlive: true),
       const WidgetTest1(text: 'child 1', keepAlive: true),
       WidgetTest2(text: 'child 2', key: UniqueKey()),
     ];
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
     final _WidgetTest0State state0 = tester.state(find.byType(WidgetTest0));
     final _WidgetTest1State state1 = tester.state(find.byType(WidgetTest1));
     final _WidgetTest2State state2 = tester.state(find.byType(WidgetTest2));
@@ -380,9 +370,7 @@ void main() {
 
     childList = createSwitchedChildList(childList, 0, 1);
     childList.removeAt(2);
-    await tester.pumpWidget(
-        SwitchingSliverListTest(children: childList),
-    );
+    await tester.pumpWidget(SwitchingSliverListTest(children: childList));
     expect(find.text('child 0'), findsOneWidget);
     expect(find.text('child 1'), findsOneWidget);
     expect(find.text('child 2'), findsNothing);
@@ -400,10 +388,7 @@ List<Widget> createSwitchedChildList(List<Widget> childList, int i, int j) {
 }
 
 class SwitchingChildBuilderTest extends StatefulWidget {
-  const SwitchingChildBuilderTest({
-    required this.children,
-    super.key,
-  });
+  const SwitchingChildBuilderTest({required this.children, super.key});
 
   final List<Widget> children;
 
@@ -471,11 +456,7 @@ class _SwitchingChildBuilderTest extends State<SwitchingChildBuilderTest> {
 }
 
 class SwitchingChildListTest extends StatelessWidget {
-  const SwitchingChildListTest({
-    required this.children,
-    this.viewportFraction = 1.0,
-    super.key,
-  });
+  const SwitchingChildListTest({required this.children, this.viewportFraction = 1.0, super.key});
 
   final List<Widget> children;
   final double viewportFraction;
@@ -503,10 +484,7 @@ class SwitchingChildListTest extends StatelessWidget {
 }
 
 class SwitchingSliverListTest extends StatelessWidget {
-  const SwitchingSliverListTest({
-    required this.children,
-    super.key,
-  });
+  const SwitchingSliverListTest({required this.children, super.key});
 
   final List<Widget> children;
 
@@ -519,11 +497,7 @@ class SwitchingSliverListTest extends StatelessWidget {
           height: 100,
           child: CustomScrollView(
             cacheExtent: 0,
-            slivers: <Widget>[
-              SliverList(
-                delegate: SliverChildListDelegate(children),
-              ),
-            ],
+            slivers: <Widget>[SliverList(delegate: SliverChildListDelegate(children))],
           ),
         ),
       ),
@@ -532,11 +506,7 @@ class SwitchingSliverListTest extends StatelessWidget {
 }
 
 class WidgetTest0 extends StatefulWidget {
-  const WidgetTest0({
-    required this.text,
-    this.keepAlive = false,
-    super.key,
-  });
+  const WidgetTest0({required this.text, this.keepAlive = false, super.key});
 
   final String text;
   final bool keepAlive;
@@ -565,11 +535,7 @@ class _WidgetTest0State extends State<WidgetTest0> with AutomaticKeepAliveClient
 }
 
 class WidgetTest1 extends StatefulWidget {
-  const WidgetTest1({
-    required this.text,
-    this.keepAlive = false,
-    super.key,
-  });
+  const WidgetTest1({required this.text, this.keepAlive = false, super.key});
 
   final String text;
   final bool keepAlive;
@@ -598,11 +564,7 @@ class _WidgetTest1State extends State<WidgetTest1> with AutomaticKeepAliveClient
 }
 
 class WidgetTest2 extends StatefulWidget {
-  const WidgetTest2({
-    required this.text,
-    this.keepAlive = false,
-    super.key,
-  });
+  const WidgetTest2({required this.text, this.keepAlive = false, super.key});
 
   final String text;
   final bool keepAlive;
