@@ -5,6 +5,7 @@
 import 'package:flutter/rendering.dart';
 import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
+import 'package:leak_tracker_flutter_testing/leak_tracker_flutter_testing.dart';
 
 import '../rendering/rendering_tester.dart' show TestCallbackPainter;
 
@@ -19,20 +20,12 @@ class TestPaintingContext implements PaintingContext {
 
 void main() {
   testWidgets('Can construct an empty Stack', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const Directionality(
-        textDirection: TextDirection.ltr,
-        child: Stack(),
-      ),
-    );
+    await tester.pumpWidget(const Directionality(textDirection: TextDirection.ltr, child: Stack()));
   });
 
   testWidgets('Can construct an empty Centered Stack', (WidgetTester tester) async {
     await tester.pumpWidget(
-      const Directionality(
-        textDirection: TextDirection.ltr,
-        child: Center(child: Stack()),
-      ),
+      const Directionality(textDirection: TextDirection.ltr, child: Center(child: Stack())),
     );
   });
 
@@ -43,14 +36,7 @@ void main() {
       const Stack(
         alignment: Alignment.topLeft,
         children: <Widget>[
-          Positioned(
-            left: 10.0,
-            child: SizedBox(
-              key: key,
-              width: 10.0,
-              height: 10.0,
-            ),
-          ),
+          Positioned(left: 10.0, child: SizedBox(key: key, width: 10.0, height: 10.0)),
         ],
       ),
     );
@@ -71,14 +57,7 @@ void main() {
       const Stack(
         alignment: Alignment.topLeft,
         children: <Widget>[
-          Positioned(
-            right: 10.0,
-            child: SizedBox(
-              key: key,
-              width: 10.0,
-              height: 10.0,
-            ),
-          ),
+          Positioned(right: 10.0, child: SizedBox(key: key, width: 10.0, height: 10.0)),
         ],
       ),
     );
@@ -100,7 +79,7 @@ void main() {
     await tester.pumpWidget(
       const Stack(
         textDirection: TextDirection.ltr,
-        children: <Widget>[ Positioned(left: 10.0, child: sizedBox) ],
+        children: <Widget>[Positioned(left: 10.0, child: sizedBox)],
       ),
     );
     Element containerElement = tester.element(find.byKey(key));
@@ -115,10 +94,7 @@ void main() {
     expect(parentData.height, isNull);
 
     await tester.pumpWidget(
-      const Stack(
-        textDirection: TextDirection.ltr,
-        children: <Widget>[ sizedBox ],
-      ),
+      const Stack(textDirection: TextDirection.ltr, children: <Widget>[sizedBox]),
     );
     containerElement = tester.element(find.byKey(key));
 
@@ -151,11 +127,13 @@ void main() {
     );
 
     final Element child0 = tester.element(find.byKey(child0Key));
-    final StackParentData child0RenderObjectParentData = child0.renderObject!.parentData! as StackParentData;
+    final StackParentData child0RenderObjectParentData =
+        child0.renderObject!.parentData! as StackParentData;
     expect(child0RenderObjectParentData.offset, equals(Offset.zero));
 
     final Element child1 = tester.element(find.byKey(child1Key));
-    final StackParentData child1RenderObjectParentData = child1.renderObject!.parentData! as StackParentData;
+    final StackParentData child1RenderObjectParentData =
+        child1.renderObject!.parentData! as StackParentData;
     expect(child1RenderObjectParentData.offset, equals(const Offset(5.0, 5.0)));
 
     await tester.pumpWidget(
@@ -197,11 +175,13 @@ void main() {
     );
 
     final Element child0 = tester.element(find.byKey(child0Key));
-    final StackParentData child0RenderObjectParentData = child0.renderObject!.parentData! as StackParentData;
+    final StackParentData child0RenderObjectParentData =
+        child0.renderObject!.parentData! as StackParentData;
     expect(child0RenderObjectParentData.offset, equals(Offset.zero));
 
     final Element child1 = tester.element(find.byKey(child1Key));
-    final StackParentData child1RenderObjectParentData = child1.renderObject!.parentData! as StackParentData;
+    final StackParentData child1RenderObjectParentData =
+        child1.renderObject!.parentData! as StackParentData;
     expect(child1RenderObjectParentData.offset, equals(const Offset(5.0, 5.0)));
 
     await tester.pumpWidget(
@@ -225,19 +205,13 @@ void main() {
 
   testWidgets('Can construct an empty IndexedStack', (WidgetTester tester) async {
     await tester.pumpWidget(
-      const Directionality(
-        textDirection: TextDirection.ltr,
-        child: IndexedStack(),
-      ),
+      const Directionality(textDirection: TextDirection.ltr, child: IndexedStack()),
     );
   });
 
   testWidgets('Can construct an empty Centered IndexedStack', (WidgetTester tester) async {
     await tester.pumpWidget(
-      const Directionality(
-        textDirection: TextDirection.ltr,
-        child: Center(child: IndexedStack()),
-      ),
+      const Directionality(textDirection: TextDirection.ltr, child: Center(child: IndexedStack())),
     );
   });
 
@@ -250,17 +224,15 @@ void main() {
       final List<Widget> items = List<Widget>.generate(itemCount, (int i) {
         return CustomPaint(
           painter: TestCallbackPainter(
-            onPaint: () { itemsPainted.add(i); },
+            onPaint: () {
+              itemsPainted.add(i);
+            },
           ),
           child: Text('$i', textDirection: TextDirection.ltr),
         );
       });
       return Center(
-        child: IndexedStack(
-          alignment: Alignment.topLeft,
-          index: index,
-          children: items,
-        ),
+        child: IndexedStack(alignment: Alignment.topLeft, index: index, children: items),
       );
     }
 
@@ -281,11 +253,11 @@ void main() {
     expect(itemsPainted, equals(<int>[0]));
 
     await tester.pumpWidget(buildFrame(1));
-      expectFindsChild(1);
+    expectFindsChild(1);
     expect(itemsPainted, equals(<int>[1]));
 
     await tester.pumpWidget(buildFrame(2));
-      expectFindsChild(2);
+    expectFindsChild(2);
     expect(itemsPainted, equals(<int>[2]));
   });
 
@@ -297,15 +269,15 @@ void main() {
     Widget buildFrame(int index) {
       itemsTapped = <int>[];
       final List<Widget> items = List<Widget>.generate(itemCount, (int i) {
-        return GestureDetector(child: Text('$i', textDirection: TextDirection.ltr), onTap: () { itemsTapped.add(i); });
+        return GestureDetector(
+          child: Text('$i', textDirection: TextDirection.ltr),
+          onTap: () {
+            itemsTapped.add(i);
+          },
+        );
       });
       return Center(
-        child: IndexedStack(
-          alignment: Alignment.topLeft,
-          key: key,
-          index: index,
-          children: items,
-        ),
+        child: IndexedStack(alignment: Alignment.topLeft, key: key, index: index, children: items),
       );
     }
 
@@ -320,17 +292,16 @@ void main() {
     expect(itemsTapped, <int>[2]);
   });
 
-  testWidgets('IndexedStack sets non-selected indexes to visible=false', (WidgetTester tester) async {
+  testWidgets('IndexedStack sets non-selected indexes to visible=false', (
+    WidgetTester tester,
+  ) async {
     Widget buildStack({required int itemCount, required int? selectedIndex}) {
       final List<Widget> children = List<Widget>.generate(itemCount, (int i) {
         return _ShowVisibility(index: i);
       });
       return Directionality(
         textDirection: TextDirection.ltr,
-        child: IndexedStack(
-          index: selectedIndex,
-          children: children,
-        ),
+        child: IndexedStack(index: selectedIndex, children: children),
       );
     }
 
@@ -358,9 +329,7 @@ void main() {
   testWidgets('Can set width and height', (WidgetTester tester) async {
     const Key key = Key('container');
 
-    const BoxDecoration kBoxDecoration = BoxDecoration(
-      color: Color(0xFF00FF00),
-    );
+    const BoxDecoration kBoxDecoration = BoxDecoration(color: Color(0xFF00FF00));
 
     await tester.pumpWidget(
       const Stack(
@@ -433,17 +402,24 @@ void main() {
   });
 
   testWidgets('Clip.none is respected by describeApproximateClip', (WidgetTester tester) async {
-    await tester.pumpWidget(const Stack(
-      textDirection: TextDirection.ltr,
-      children: <Widget>[Positioned(left: 1000, right: 2000, child: SizedBox(width: 2000, height: 2000))],
-    ));
+    await tester.pumpWidget(
+      const Stack(
+        textDirection: TextDirection.ltr,
+        children: <Widget>[
+          Positioned(left: 1000, right: 2000, child: SizedBox(width: 2000, height: 2000)),
+        ],
+      ),
+    );
     final RenderStack renderObject = tester.allRenderObjects.whereType<RenderStack>().first;
     expect(renderObject.clipBehavior, equals(Clip.hardEdge));
 
     bool visited = false;
     renderObject.visitChildren((RenderObject child) {
       visited = true;
-      expect(renderObject.describeApproximatePaintClip(child), const Rect.fromLTRB(0.0, 0.0, 800.0, 600.0));
+      expect(
+        renderObject.describeApproximatePaintClip(child),
+        const Rect.fromLTRB(0.0, 0.0, 800.0, 600.0),
+      );
     });
     expect(visited, true);
     visited = false;
@@ -467,11 +443,10 @@ void main() {
             children: <Widget>[
               GestureDetector(
                 behavior: HitTestBehavior.opaque,
-                onTap: () { tapped = true; },
-                child: const SizedBox(
-                  width: 200.0,
-                  height: 200.0,
-                ),
+                onTap: () {
+                  tapped = true;
+                },
+                child: const SizedBox(width: 200.0, height: 200.0),
               ),
             ],
           ),
@@ -486,19 +461,14 @@ void main() {
   });
 
   testWidgets('IndexedStack reports hidden children as offstage', (WidgetTester tester) async {
-    final List<Widget> children = <Widget>[
-      for (int i = 0; i < 5; i++) Text('child $i'),
-    ];
+    final List<Widget> children = <Widget>[for (int i = 0; i < 5; i++) Text('child $i')];
 
-    Future<void> pumpIndexedStack(int? activeIndex) async{
+    Future<void> pumpIndexedStack(int? activeIndex) async {
       await tester.pumpWidget(
         Directionality(
           textDirection: TextDirection.ltr,
-          child: IndexedStack(
-            index: activeIndex,
-            children: children,
-          ),
-        )
+          child: IndexedStack(index: activeIndex, children: children),
+        ),
       );
     }
 
@@ -526,18 +496,8 @@ void main() {
         child: Center(
           child: Stack(
             children: <Widget>[
-              SizedBox(
-                width: 100.0,
-                height: 100.0,
-              ),
-              Positioned(
-                top: 0.0,
-                left: 0.0,
-                child: SizedBox(
-                  width: 200.0,
-                  height: 200.0,
-                ),
-              ),
+              SizedBox(width: 100.0, height: 100.0),
+              Positioned(top: 0.0, left: 0.0, child: SizedBox(width: 200.0, height: 200.0)),
             ],
           ),
         ),
@@ -556,18 +516,8 @@ void main() {
           child: Stack(
             clipBehavior: Clip.none,
             children: <Widget>[
-              SizedBox(
-                width: 100.0,
-                height: 100.0,
-              ),
-              Positioned(
-                top: 0.0,
-                left: 0.0,
-                child: SizedBox(
-                  width: 200.0,
-                  height: 200.0,
-                ),
-              ),
+              SizedBox(width: 100.0, height: 100.0),
+              Positioned(top: 0.0, left: 0.0, child: SizedBox(width: 200.0, height: 200.0)),
             ],
           ),
         ),
@@ -638,6 +588,7 @@ void main() {
         ),
       );
     }
+
     await tester.pumpWidget(buildStack(StackFit.loose));
     logs.add('=1=');
     await tester.pumpWidget(buildStack(StackFit.expand));
@@ -725,21 +676,9 @@ void main() {
   });
 
   testWidgets('Can change the text direction of a Stack', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const Stack(
-        alignment: Alignment.center,
-      ),
-    );
-    await tester.pumpWidget(
-      const Stack(
-        textDirection: TextDirection.rtl,
-      ),
-    );
-    await tester.pumpWidget(
-      const Stack(
-        alignment: Alignment.center,
-      ),
-    );
+    await tester.pumpWidget(const Stack(alignment: Alignment.center));
+    await tester.pumpWidget(const Stack(textDirection: TextDirection.rtl));
+    await tester.pumpWidget(const Stack(alignment: Alignment.center));
   });
 
   testWidgets('Alignment with partially-positioned children', (WidgetTester tester) async {
@@ -762,15 +701,42 @@ void main() {
         ),
       ),
     );
-    expect(tester.getRect(find.byType(SizedBox).at(0)), const Rect.fromLTWH(350.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(1)), const Rect.fromLTWH(0.0,   250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(2)), const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(3)), const Rect.fromLTWH(350.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(4)), const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(5)), const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(6)), const Rect.fromLTWH(0.0,   250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(7)), const Rect.fromLTWH(350.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(8)), const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0));
+    expect(
+      tester.getRect(find.byType(SizedBox).at(0)),
+      const Rect.fromLTWH(350.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(1)),
+      const Rect.fromLTWH(0.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(2)),
+      const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(3)),
+      const Rect.fromLTWH(350.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(4)),
+      const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(5)),
+      const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(6)),
+      const Rect.fromLTWH(0.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(7)),
+      const Rect.fromLTWH(350.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(8)),
+      const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0),
+    );
 
     await tester.pumpWidget(
       const Directionality(
@@ -791,15 +757,42 @@ void main() {
         ),
       ),
     );
-    expect(tester.getRect(find.byType(SizedBox).at(0)), const Rect.fromLTWH(350.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(1)), const Rect.fromLTWH(0.0,   250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(2)), const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(3)), const Rect.fromLTWH(350.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(4)), const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(5)), const Rect.fromLTWH(0.0,   250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(6)), const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(7)), const Rect.fromLTWH(350.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(8)), const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0));
+    expect(
+      tester.getRect(find.byType(SizedBox).at(0)),
+      const Rect.fromLTWH(350.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(1)),
+      const Rect.fromLTWH(0.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(2)),
+      const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(3)),
+      const Rect.fromLTWH(350.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(4)),
+      const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(5)),
+      const Rect.fromLTWH(0.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(6)),
+      const Rect.fromLTWH(700.0, 250.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(7)),
+      const Rect.fromLTWH(350.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(8)),
+      const Rect.fromLTWH(350.0, 500.0, 100.0, 100.0),
+    );
 
     await tester.pumpWidget(
       const Directionality(
@@ -820,15 +813,42 @@ void main() {
         ),
       ),
     );
-    expect(tester.getRect(find.byType(SizedBox).at(0)), const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(1)), const Rect.fromLTWH(0.0,   500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(2)), const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(3)), const Rect.fromLTWH(700.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(4)), const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(5)), const Rect.fromLTWH(0.0,   500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(6)), const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(7)), const Rect.fromLTWH(700.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(8)), const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0));
+    expect(
+      tester.getRect(find.byType(SizedBox).at(0)),
+      const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(1)),
+      const Rect.fromLTWH(0.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(2)),
+      const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(3)),
+      const Rect.fromLTWH(700.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(4)),
+      const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(5)),
+      const Rect.fromLTWH(0.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(6)),
+      const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(7)),
+      const Rect.fromLTWH(700.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(8)),
+      const Rect.fromLTWH(700.0, 500.0, 100.0, 100.0),
+    );
 
     await tester.pumpWidget(
       const Directionality(
@@ -849,59 +869,93 @@ void main() {
         ),
       ),
     );
-    expect(tester.getRect(find.byType(SizedBox).at(0)), const Rect.fromLTWH(0.0,   0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(1)), const Rect.fromLTWH(0.0,   0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(2)), const Rect.fromLTWH(700.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(3)), const Rect.fromLTWH(0.0,   0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(4)), const Rect.fromLTWH(0.0,   500.0, 100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(5)), const Rect.fromLTWH(0.0,   0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(6)), const Rect.fromLTWH(700.0, 0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(7)), const Rect.fromLTWH(0.0,   0.0,   100.0, 100.0));
-    expect(tester.getRect(find.byType(SizedBox).at(8)), const Rect.fromLTWH(0.0,   500.0, 100.0, 100.0));
-  });
-
-  testWidgets('Stack error messages', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const Stack(),
+    expect(
+      tester.getRect(find.byType(SizedBox).at(0)),
+      const Rect.fromLTWH(0.0, 0.0, 100.0, 100.0),
     );
-    final String exception = tester.takeException().toString();
-
     expect(
-      exception, startsWith(
-      'No Directionality widget found.\n'
-      "Stack widgets require a Directionality widget ancestor to resolve the 'alignment' argument.\n"
-      "The default value for 'alignment' is AlignmentDirectional.topStart, which requires a text direction.\n"
-      'The specific widget that could not find a Directionality ancestor was:\n'
-      '  Stack\n'
-      'The ownership chain for the affected widget is: "Stack ← ', // Omitted full ownership chain because it is not relevant for the test.
-    ));
+      tester.getRect(find.byType(SizedBox).at(1)),
+      const Rect.fromLTWH(0.0, 0.0, 100.0, 100.0),
+    );
     expect(
-      exception, endsWith(
-      '← [root]"\n' // End of ownership chain.
-      'Typically, the Directionality widget is introduced by the MaterialApp or WidgetsApp widget at the '
-      'top of your application widget tree. It determines the ambient reading direction and is used, for '
-      'example, to determine how to lay out text, how to interpret "start" and "end" values, and to resolve '
-      'EdgeInsetsDirectional, AlignmentDirectional, and other *Directional objects.\n'
-      'Instead of providing a Directionality widget, another solution would be passing a non-directional '
-      "'alignment', or an explicit 'textDirection', to the Stack.",
-    ));
+      tester.getRect(find.byType(SizedBox).at(2)),
+      const Rect.fromLTWH(700.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(3)),
+      const Rect.fromLTWH(0.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(4)),
+      const Rect.fromLTWH(0.0, 500.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(5)),
+      const Rect.fromLTWH(0.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(6)),
+      const Rect.fromLTWH(700.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(7)),
+      const Rect.fromLTWH(0.0, 0.0, 100.0, 100.0),
+    );
+    expect(
+      tester.getRect(find.byType(SizedBox).at(8)),
+      const Rect.fromLTWH(0.0, 500.0, 100.0, 100.0),
+    );
   });
 
-  testWidgets('Can update clipBehavior of IndexedStack',
-      (WidgetTester tester) async {
+  testWidgets(
+    'Stack error messages',
+    experimentalLeakTesting:
+        LeakTesting.settings.withIgnoredAll(), // leaking by design because of exception
+    (WidgetTester tester) async {
+      await tester.pumpWidget(const Stack());
+      final String exception = tester.takeException().toString();
+
+      expect(
+        exception,
+        startsWith(
+          'No Directionality widget found.\n'
+          "Stack widgets require a Directionality widget ancestor to resolve the 'alignment' argument.\n"
+          "The default value for 'alignment' is AlignmentDirectional.topStart, which requires a text direction.\n"
+          'The specific widget that could not find a Directionality ancestor was:\n'
+          '  Stack\n'
+          'The ownership chain for the affected widget is: "Stack ← ', // Omitted full ownership chain because it is not relevant for the test.
+        ),
+      );
+      expect(
+        exception,
+        endsWith(
+          '_ViewScope ← ⋯"\n' // End of ownership chain.
+          'Typically, the Directionality widget is introduced by the MaterialApp or WidgetsApp widget at the '
+          'top of your application widget tree. It determines the ambient reading direction and is used, for '
+          'example, to determine how to lay out text, how to interpret "start" and "end" values, and to resolve '
+          'EdgeInsetsDirectional, AlignmentDirectional, and other *Directional objects.\n'
+          'Instead of providing a Directionality widget, another solution would be passing a non-directional '
+          "'alignment', or an explicit 'textDirection', to the Stack.",
+        ),
+      );
+    },
+  );
+
+  testWidgets('Can update clipBehavior of IndexedStack', (WidgetTester tester) async {
     await tester.pumpWidget(const IndexedStack(textDirection: TextDirection.ltr));
-    final RenderIndexedStack renderObject =
-      tester.renderObject<RenderIndexedStack>(find.byType(IndexedStack));
+    final RenderIndexedStack renderObject = tester.renderObject<RenderIndexedStack>(
+      find.byType(IndexedStack),
+    );
     expect(renderObject.clipBehavior, equals(Clip.hardEdge));
 
     // Update clipBehavior to Clip.antiAlias
 
-    await tester.pumpWidget(const IndexedStack(
-      textDirection: TextDirection.ltr,
-      clipBehavior: Clip.antiAlias,
-    ));
-    final RenderIndexedStack renderIndexedObject =
-      tester.renderObject<RenderIndexedStack>(find.byType(IndexedStack));
+    await tester.pumpWidget(
+      const IndexedStack(textDirection: TextDirection.ltr, clipBehavior: Clip.antiAlias),
+    );
+    final RenderIndexedStack renderIndexedObject = tester.renderObject<RenderIndexedStack>(
+      find.byType(IndexedStack),
+    );
     expect(renderIndexedObject.clipBehavior, equals(Clip.antiAlias));
   });
 
@@ -933,6 +987,7 @@ void main() {
         ),
       );
     }
+
     await tester.pumpWidget(buildIndexedStack(StackFit.loose));
     logs.add('=1=');
     await tester.pumpWidget(buildIndexedStack(StackFit.expand));
