@@ -6,11 +6,7 @@ import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 class TestStatusTransitionWidget extends StatusTransitionWidget {
-  const TestStatusTransitionWidget({
-    super.key,
-    required this.builder,
-    required super.animation,
-  });
+  const TestStatusTransitionWidget({super.key, required this.builder, required super.animation});
 
   final WidgetBuilder builder;
 
@@ -25,15 +21,18 @@ void main() {
       duration: const Duration(seconds: 1),
       vsync: const TestVSync(),
     );
+    addTearDown(controller.dispose);
 
-    await tester.pumpWidget(TestStatusTransitionWidget(
-      animation: controller,
-      builder: (BuildContext context) {
-        expect(didBuild, isFalse);
-        didBuild = true;
-        return Container();
-      },
-    ));
+    await tester.pumpWidget(
+      TestStatusTransitionWidget(
+        animation: controller,
+        builder: (BuildContext context) {
+          expect(didBuild, isFalse);
+          didBuild = true;
+          return Container();
+        },
+      ),
+    );
 
     expect(didBuild, isTrue);
     didBuild = false;
@@ -62,15 +61,18 @@ void main() {
       duration: const Duration(seconds: 1),
       vsync: const TestVSync(),
     );
+    addTearDown(anotherController.dispose);
 
-    await tester.pumpWidget(TestStatusTransitionWidget(
-      animation: anotherController,
-      builder: (BuildContext context) {
-        expect(didBuild, isFalse);
-        didBuild = true;
-        return Container();
-      },
-    ));
+    await tester.pumpWidget(
+      TestStatusTransitionWidget(
+        animation: anotherController,
+        builder: (BuildContext context) {
+          expect(didBuild, isFalse);
+          didBuild = true;
+          return Container();
+        },
+      ),
+    );
 
     expect(didBuild, isTrue);
     didBuild = false;
