@@ -18,13 +18,11 @@ void main() {
           itemBuilder: (BuildContext context, int index) {
             return ListView(
               controller: controller,
-              children: List<Widget>.generate(
-                10,
-                (int i) => SizedBox(
-                  height: listItemHeight,
-                  child: Text('Page$index-Item$i'),
-                ),
-              ).toList(),
+              children:
+                  List<Widget>.generate(
+                    10,
+                    (int i) => SizedBox(height: listItemHeight, child: Text('Page$index-Item$i')),
+                  ).toList(),
             );
           },
         ),
@@ -64,29 +62,33 @@ void main() {
     int attach = 0;
     int detach = 0;
     final TrackingScrollController controller = TrackingScrollController(
-      onAttach: (_) { attach++; },
-      onDetach: (_) { detach++; },
+      onAttach: (_) {
+        attach++;
+      },
+      onDetach: (_) {
+        detach++;
+      },
     );
     addTearDown(controller.dispose);
     const double listItemHeight = 100.0;
 
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: PageView.builder(
-        itemBuilder: (BuildContext context, int index) {
-          return ListView(
-            controller: controller,
-            children: List<Widget>.generate(
-              10,
-              (int i) => SizedBox(
-                height: listItemHeight,
-                child: Text('Page$index-Item$i'),
-              ),
-            ).toList(),
-          );
-        },
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: PageView.builder(
+          itemBuilder: (BuildContext context, int index) {
+            return ListView(
+              controller: controller,
+              children:
+                  List<Widget>.generate(
+                    10,
+                    (int i) => SizedBox(height: listItemHeight, child: Text('Page$index-Item$i')),
+                  ).toList(),
+            );
+          },
+        ),
       ),
-    ));
+    );
     await tester.pumpAndSettle();
 
     expect(attach, 1);
