@@ -12,7 +12,9 @@ void main() {
   Object object;
 
   // Change made in https://github.com/flutter/flutter/pull/41859
-  CupertinoTextThemeData themeData = CupertinoTextThemeData(brightness: Brightness.dark);
+  CupertinoTextThemeData themeData = CupertinoTextThemeData(
+    brightness: Brightness.dark,
+  );
   themeData.copyWith(brightness: Brightness.light);
   themeData = CupertinoTextThemeData(error: '');
   themeData.copyWith(error: '');
@@ -155,9 +157,12 @@ void main() {
   textField.maxLengthEnforced;
 
   // Changes made in https://github.com/flutter/flutter/pull/59127
-  const BottomNavigationBarItem bottomNavigationBarItem = BottomNavigationBarItem(title: myTitle);
-  const BottomNavigationBarItem bottomNavigationBarItem = BottomNavigationBarItem();
-  const BottomNavigationBarItem bottomNavigationBarItem = BottomNavigationBarItem(error: '');
+  const BottomNavigationBarItem bottomNavigationBarItem =
+      BottomNavigationBarItem(title: myTitle);
+  const BottomNavigationBarItem bottomNavigationBarItem =
+      BottomNavigationBarItem();
+  const BottomNavigationBarItem bottomNavigationBarItem =
+      BottomNavigationBarItem(error: '');
   bottomNavigationBarItem.title;
 
   // Changes made in https://github.com/flutter/flutter/pull/79160
@@ -183,19 +188,23 @@ void main() {
   listWheelElement.insertChildRenderObject(renderObject, object);
   listWheelElement.moveChildRenderObject(renderObject, object);
   listWheelElement.removeChildRenderObject(renderObject);
-  final MultiChildRenderObjectElement multiChildRenderObjectElement = MultiChildRenderObjectElement();
+  final MultiChildRenderObjectElement multiChildRenderObjectElement =
+      MultiChildRenderObjectElement();
   multiChildRenderObjectElement.insertChildRenderObject(renderObject, object);
   multiChildRenderObjectElement.moveChildRenderObject(renderObject, object);
   multiChildRenderObjectElement.removeChildRenderObject(renderObject);
-  final SingleChildRenderObjectElement singleChildRenderObjectElement = SingleChildRenderObjectElement();
+  final SingleChildRenderObjectElement singleChildRenderObjectElement =
+      SingleChildRenderObjectElement();
   singleChildRenderObjectElement.insertChildRenderObject(renderObject, object);
   singleChildRenderObjectElement.moveChildRenderObject(renderObject, object);
   singleChildRenderObjectElement.removeChildRenderObject(renderObject);
-  final SliverMultiBoxAdaptorElement sliverMultiBoxAdaptorElement = SliverMultiBoxAdaptorElement();
+  final SliverMultiBoxAdaptorElement sliverMultiBoxAdaptorElement =
+      SliverMultiBoxAdaptorElement();
   sliverMultiBoxAdaptorElement.insertChildRenderObject(renderObject, object);
   sliverMultiBoxAdaptorElement.moveChildRenderObject(renderObject, object);
   sliverMultiBoxAdaptorElement.removeChildRenderObject(renderObject);
-  final RenderObjectToWidgetElement renderObjectToWidgetElement = RenderObjectToWidgetElement(widget);
+  final RenderObjectToWidgetElement renderObjectToWidgetElement =
+      RenderObjectToWidgetElement(widget);
   renderObjectToWidgetElement.insertChildRenderObject(renderObject, object);
   renderObjectToWidgetElement.moveChildRenderObject(renderObject, object);
   renderObjectToWidgetElement.removeChildRenderObject(renderObject);
@@ -217,7 +226,8 @@ void main() {
   listWheelViewport.clipToSize;
 
   // Changes made in https://github.com/flutter/flutter/pull/87839
-  OverscrollIndicatorNotification notification = OverscrollIndicatorNotification(leading: true);
+  OverscrollIndicatorNotification notification =
+      OverscrollIndicatorNotification(leading: true);
   notification = OverscrollIndicatorNotification(error: '');
   notification.disallowGlow();
 
@@ -233,7 +243,8 @@ void main() {
   // Changes made in https://github.com/flutter/flutter/pull/78588
   final ScrollBehavior scrollBehavior = ScrollBehavior();
   scrollBehavior.buildViewportChrome(context, child, axisDirection);
-  final CupertinoScrollBehavior cupertinoScrollBehavior = CupertinoScrollBehavior();
+  final CupertinoScrollBehavior cupertinoScrollBehavior =
+      CupertinoScrollBehavior();
   cupertinoScrollBehavior.buildViewportChrome(context, child, axisDirection);
 
   // Changes made in https://github.com/flutter/flutter/pull/114459
@@ -246,6 +257,36 @@ void main() {
   );
   final Clip clip = details.clipBehavior;
 
-  final PlatformMenuBar platformMenuBar = PlatformMenuBar(menus: <PlatformMenuItem>[], body: const SizedBox());
+  final PlatformMenuBar platformMenuBar = PlatformMenuBar(
+    menus: <PlatformMenuItem>[],
+    body: const SizedBox(),
+  );
   final Widget bodyValue = platformMenuBar.body;
+
+  // Changes made in https://github.com/flutter/flutter/pull/151367
+  final cupertinoSwitch = CupertinoSwitch(
+    value: value,
+    onChanged: onChanged,
+    activeColor: Colors.red,
+  );
+  Color? activeTrackColor = cupertinoSwitch.activeColor;
+
+  // Changes made in https://github.com/flutter/flutter/pull/151367
+  final cupertinoSwitch = CupertinoSwitch(
+    value: value,
+    onChanged: onChanged,
+    trackColor: Colors.red,
+  );
+  Color? inactiveTrackColor = cupertinoSwitch.trackColor;
+
+  // https://github.com/flutter/flutter/pull/152981
+  CupertinoCheckbox(inactiveColor: Colors.red);
+  CupertinoCheckbox(inactiveColor: Colors.red, activeColor: Colors.white);
+  CupertinoCheckbox(
+    inactiveColor: Colors.red,
+    fillColor: WidgetStatePropertyAll(CupertinoColors.white),
+  );
+
+  // https://github.com/flutter/flutter/pull/161295
+  CupertinoButton(minSize: 60.0);
 }
