@@ -19,5 +19,6 @@ void main() {
   SliverAppBar sliverAppBar = SliverAppBar();
   sliverAppBar = SliverAppBar(backwardsCompatibility: true);
   sliverAppBar = SliverAppBar(backwardsCompatibility: false);
-  sliverAppBar.backwardsCompatibility; // Removing field reference not supported.
+  sliverAppBar
+      .backwardsCompatibility; // Removing field reference not supported.
 }
