@@ -31,7 +31,7 @@ void main() {
       // Tests a different first day of week.
       const Locale('ru', 'RU'): <String, dynamic>{
         'textDirection': TextDirection.ltr,
-        'expectedDaysOfWeek': <String>['В', 'П', 'В', 'С', 'Ч', 'П', 'С',],
+        'expectedDaysOfWeek': <String>['В', 'П', 'В', 'С', 'Ч', 'П', 'С'],
         'expectedDaysOfMonth': List<String>.generate(30, (int i) => '${i + 1}'),
         'expectedMonthYearHeader': 'сентябрь 2017 г.',
       },
@@ -52,18 +52,26 @@ void main() {
 
     for (final Locale locale in testLocales.keys) {
       testWidgets('shows dates for $locale', (WidgetTester tester) async {
-        final List<String> expectedDaysOfWeek = testLocales[locale]!['expectedDaysOfWeek'] as List<String>;
-        final List<String> expectedDaysOfMonth = testLocales[locale]!['expectedDaysOfMonth'] as List<String>;
-        final String expectedMonthYearHeader = testLocales[locale]!['expectedMonthYearHeader'] as String;
+        final List<String> expectedDaysOfWeek =
+            testLocales[locale]!['expectedDaysOfWeek'] as List<String>;
+        final List<String> expectedDaysOfMonth =
+            testLocales[locale]!['expectedDaysOfMonth'] as List<String>;
+        final String expectedMonthYearHeader =
+            testLocales[locale]!['expectedMonthYearHeader'] as String;
         final TextDirection textDirection = testLocales[locale]!['textDirection'] as TextDirection;
         final DateTime baseDate = DateTime(2017, 9, 27);
 
-        await _pumpBoilerplate(tester, CalendarDatePicker(
-          initialDate: baseDate,
-          firstDate: baseDate.subtract(const Duration(days: 90)),
-          lastDate: baseDate.add(const Duration(days: 90)),
-          onDateChanged: (DateTime newValue) {},
-        ), locale: locale, textDirection: textDirection);
+        await _pumpBoilerplate(
+          tester,
+          CalendarDatePicker(
+            initialDate: baseDate,
+            firstDate: baseDate.subtract(const Duration(days: 90)),
+            lastDate: baseDate.add(const Duration(days: 90)),
+            onDateChanged: (DateTime newValue) {},
+          ),
+          locale: locale,
+          textDirection: textDirection,
+        );
 
         expect(find.text(expectedMonthYearHeader), findsOneWidget);
 
@@ -73,7 +81,10 @@ void main() {
 
         Offset? previousCellOffset;
         for (final String dayOfMonth in expectedDaysOfMonth) {
-          final Finder dayCell = find.descendant(of: find.byType(GridView), matching: find.text(dayOfMonth));
+          final Finder dayCell = find.descendant(
+            of: find.byType(GridView),
+            matching: find.text(dayOfMonth),
+          );
           expect(dayCell, findsOneWidget);
 
           // Check that cells are correctly positioned relative to each other,
@@ -81,9 +92,17 @@ void main() {
           final Offset offset = tester.getCenter(dayCell);
           if (previousCellOffset != null) {
             if (textDirection == TextDirection.ltr) {
-              expect(offset.dx > previousCellOffset.dx && offset.dy == previousCellOffset.dy || offset.dy > previousCellOffset.dy, true);
+              expect(
+                offset.dx > previousCellOffset.dx && offset.dy == previousCellOffset.dy ||
+                    offset.dy > previousCellOffset.dy,
+                true,
+              );
             } else {
-              expect(offset.dx < previousCellOffset.dx && offset.dy == previousCellOffset.dy || offset.dy > previousCellOffset.dy, true);
+              expect(
+                offset.dx < previousCellOffset.dx && offset.dy == previousCellOffset.dy ||
+                    offset.dy > previousCellOffset.dy,
+                true,
+              );
             }
           }
           previousCellOffset = offset;
@@ -97,10 +116,7 @@ void main() {
       return MaterialApp(
         theme: ThemeData(useMaterial3: false),
         locale: const Locale('en', 'US'),
-        supportedLocales: const <Locale>[
-          Locale('en', 'US'),
-          Locale('fr', 'CA'),
-        ],
+        supportedLocales: const <Locale>[Locale('en', 'US'), Locale('fr', 'CA')],
         localizationsDelegates: GlobalMaterialLocalizations.delegates,
         home: Material(
           child: Builder(
@@ -129,14 +145,8 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle();
 
-    expect(
-      Localizations.localeOf(getPicker()),
-      const Locale('fr', 'CA'),
-    );
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.ltr,
-    );
+    expect(Localizations.localeOf(getPicker()), const Locale('fr', 'CA'));
+    expect(Directionality.of(getPicker()), TextDirection.ltr);
 
     await tester.tap(find.text('ANNULER'));
   });
@@ -144,12 +154,8 @@ void main() {
   testWidgets('Material3 - locale parameter overrides ambient locale', (WidgetTester tester) async {
     Widget buildFrame() {
       return MaterialApp(
-        theme: ThemeData(useMaterial3: true),
         locale: const Locale('en', 'US'),
-        supportedLocales: const <Locale>[
-          Locale('en', 'US'),
-          Locale('fr', 'CA'),
-        ],
+        supportedLocales: const <Locale>[Locale('en', 'US'), Locale('fr', 'CA')],
         localizationsDelegates: GlobalMaterialLocalizations.delegates,
         home: Material(
           child: Builder(
@@ -178,19 +184,15 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle();
 
-    expect(
-      Localizations.localeOf(getPicker()),
-      const Locale('fr', 'CA'),
-    );
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.ltr,
-    );
+    expect(Localizations.localeOf(getPicker()), const Locale('fr', 'CA'));
+    expect(Directionality.of(getPicker()), TextDirection.ltr);
 
     await tester.tap(find.text('Annuler'));
   });
 
-  testWidgets('Material2 - textDirection parameter overrides ambient textDirection', (WidgetTester tester) async {
+  testWidgets('Material2 - textDirection parameter overrides ambient textDirection', (
+    WidgetTester tester,
+  ) async {
     Widget buildFrame() {
       return MaterialApp(
         theme: ThemeData(useMaterial3: false),
@@ -222,18 +224,16 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle();
 
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.rtl,
-    );
+    expect(Directionality.of(getPicker()), TextDirection.rtl);
 
     await tester.tap(find.text('CANCEL'));
   });
 
-  testWidgets('Material3 - textDirection parameter overrides ambient textDirection', (WidgetTester tester) async {
+  testWidgets('Material3 - textDirection parameter overrides ambient textDirection', (
+    WidgetTester tester,
+  ) async {
     Widget buildFrame() {
       return MaterialApp(
-        theme: ThemeData(useMaterial3: true),
         locale: const Locale('en', 'US'),
         home: Material(
           child: Builder(
@@ -262,23 +262,19 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle();
 
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.rtl,
-    );
+    expect(Directionality.of(getPicker()), TextDirection.rtl);
 
     await tester.tap(find.text('Cancel'));
   });
 
-  testWidgets('Material2 - textDirection parameter takes precedence over locale parameter', (WidgetTester tester) async {
+  testWidgets('Material2 - textDirection parameter takes precedence over locale parameter', (
+    WidgetTester tester,
+  ) async {
     Widget buildFrame() {
       return MaterialApp(
         theme: ThemeData(useMaterial3: false),
         locale: const Locale('en', 'US'),
-        supportedLocales: const <Locale>[
-          Locale('en', 'US'),
-          Locale('fr', 'CA'),
-        ],
+        supportedLocales: const <Locale>[Locale('en', 'US'), Locale('fr', 'CA')],
         localizationsDelegates: GlobalMaterialLocalizations.delegates,
         home: Material(
           child: Builder(
@@ -308,28 +304,20 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle();
 
-    expect(
-      Localizations.localeOf(getPicker()),
-      const Locale('fr', 'CA'),
-    );
+    expect(Localizations.localeOf(getPicker()), const Locale('fr', 'CA'));
 
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.rtl,
-    );
+    expect(Directionality.of(getPicker()), TextDirection.rtl);
 
     await tester.tap(find.text('ANNULER'));
   });
 
-  testWidgets('Material3 - textDirection parameter takes precedence over locale parameter', (WidgetTester tester) async {
+  testWidgets('Material3 - textDirection parameter takes precedence over locale parameter', (
+    WidgetTester tester,
+  ) async {
     Widget buildFrame() {
       return MaterialApp(
-        theme: ThemeData(useMaterial3: true),
         locale: const Locale('en', 'US'),
-        supportedLocales: const <Locale>[
-          Locale('en', 'US'),
-          Locale('fr', 'CA'),
-        ],
+        supportedLocales: const <Locale>[Locale('en', 'US'), Locale('fr', 'CA')],
         localizationsDelegates: GlobalMaterialLocalizations.delegates,
         home: Material(
           child: Builder(
@@ -359,15 +347,9 @@ void main() {
     await tester.tap(find.text('X'));
     await tester.pumpAndSettle(const Duration(seconds: 1));
 
-    expect(
-      Localizations.localeOf(getPicker()),
-      const Locale('fr', 'CA'),
-    );
+    expect(Localizations.localeOf(getPicker()), const Locale('fr', 'CA'));
 
-    expect(
-      Directionality.of(getPicker()),
-      TextDirection.rtl,
-    );
+    expect(Directionality.of(getPicker()), TextDirection.rtl);
 
     await tester.tap(find.text('Annuler'));
   });
@@ -405,7 +387,7 @@ void main() {
               );
             },
           ),
-        )
+        ),
       );
       await tester.tap(find.text('X'));
       await tester.pumpAndSettle();
@@ -432,7 +414,6 @@ void main() {
       expect(tester.takeException(), isNull);
     });
   });
-
 }
 
 Future<void> _pumpBoilerplate(
@@ -441,16 +422,16 @@ Future<void> _pumpBoilerplate(
   Locale locale = const Locale('en', 'US'),
   TextDirection textDirection = TextDirection.ltr,
 }) async {
-  await tester.pumpWidget(MaterialApp(
-    home: Directionality(
-      textDirection: TextDirection.ltr,
-      child: Localizations(
-        locale: locale,
-        delegates: GlobalMaterialLocalizations.delegates,
-        child: Material(
-          child: child,
+  await tester.pumpWidget(
+    MaterialApp(
+      home: Directionality(
+        textDirection: TextDirection.ltr,
+        child: Localizations(
+          locale: locale,
+          delegates: GlobalMaterialLocalizations.delegates,
+          child: Material(child: child),
         ),
       ),
     ),
-  ));
+  );
 }
