@@ -156,7 +156,10 @@ void testWidgets(
   int? retry,
   LeakTesting? experimentalLeakTesting,
 }) {
-  assert(variant.values.isNotEmpty, 'There must be at least one value to test in the testing variant.');
+  assert(
+    variant.values.isNotEmpty,
+    'There must be at least one value to test in the testing variant.',
+  );
   final TestWidgetsFlutterBinding binding = TestWidgetsFlutterBinding.ensureInitialized();
   final WidgetTester tester = WidgetTester._(binding);
   for (final dynamic value in variant.values) {
@@ -165,9 +168,10 @@ void testWidgets(
     // support running tests directly from the editor (where they may have
     // access to only the test name, provided by the analysis server).
     // See https://github.com/flutter/flutter/issues/86659.
-    final String combinedDescription = variationDescription.isNotEmpty
-        ? '$description (variant: $variationDescription)'
-        : description;
+    final String combinedDescription =
+        variationDescription.isNotEmpty
+            ? '$description (variant: $variationDescription)'
+            : description;
     test(
       combinedDescription,
       () {
@@ -275,25 +279,18 @@ class TargetPlatformVariant extends TestVariant<TargetPlatform> {
   /// Creates a [TargetPlatformVariant] that tests all values from
   /// the [TargetPlatform] enum. If [excluding] is provided, will test all platforms
   /// except those in [excluding].
-  TargetPlatformVariant.all({
-    Set<TargetPlatform> excluding = const <TargetPlatform>{},
-  }) : values = TargetPlatform.values.toSet()..removeAll(excluding);
+  TargetPlatformVariant.all({Set<TargetPlatform> excluding = const <TargetPlatform>{}})
+    : values = TargetPlatform.values.toSet()..removeAll(excluding);
 
   /// Creates a [TargetPlatformVariant] that includes platforms that are
   /// considered desktop platforms.
-  TargetPlatformVariant.desktop() : values = <TargetPlatform>{
-    TargetPlatform.linux,
-    TargetPlatform.macOS,
-    TargetPlatform.windows,
-  };
+  TargetPlatformVariant.desktop()
+    : values = <TargetPlatform>{TargetPlatform.linux, TargetPlatform.macOS, TargetPlatform.windows};
 
   /// Creates a [TargetPlatformVariant] that includes platforms that are
   /// considered mobile platforms.
-  TargetPlatformVariant.mobile() : values = <TargetPlatform>{
-    TargetPlatform.android,
-    TargetPlatform.iOS,
-    TargetPlatform.fuchsia,
-  };
+  TargetPlatformVariant.mobile()
+    : values = <TargetPlatform>{TargetPlatform.android, TargetPlatform.iOS, TargetPlatform.fuchsia};
 
   /// Creates a [TargetPlatformVariant] that tests only the given value of
   /// [TargetPlatform].
@@ -452,13 +449,10 @@ Future<void> benchmarkWidgets(
     semanticsHandle = tester.ensureSemantics();
   }
   tester._recordNumberOfSemanticsHandles();
-  return binding.runTest(
-    () async {
-      await callback(tester);
-      semanticsHandle?.dispose();
-    },
-    tester._endOfTestVerifications,
-  );
+  return binding.runTest(() async {
+    await callback(tester);
+    semanticsHandle?.dispose();
+  }, tester._endOfTestVerifications);
 }
 
 /// Assert that `actual` matches `matcher`.
@@ -489,11 +483,7 @@ void expect(
 ///
 /// Generally, it is better to use [expect], which does include checks to ensure
 /// that asynchronous APIs are not being called.
-void expectSync(
-  dynamic actual,
-  dynamic matcher, {
-  String? reason,
-}) {
+void expectSync(dynamic actual, dynamic matcher, {String? reason}) {
   matcher_expect.expect(actual, matcher, reason: reason);
 }
 
@@ -514,8 +504,9 @@ Future<void> expectLater(
   // We can't wrap the delegate in a guard, or we'll hit async barriers in
   // [TestWidgetsFlutterBinding] while we're waiting for the matcher to complete
   TestAsyncUtils.guardSync();
-  return matcher_expect.expectLater(actual, matcher, reason: reason, skip: skip)
-           .then<void>((dynamic value) => null);
+  return matcher_expect
+      .expectLater(actual, matcher, reason: reason, skip: skip)
+      .then<void>((dynamic value) => null);
 }
 
 /// Class that programmatically interacts with widgets and the test environment.
@@ -629,9 +620,7 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
         } else {
           await binding.pump();
           await binding.delayed(timeDiff);
-          handleTimeStampDiff.add(
-            binding.clock.now().difference(startTime) - record.timeDelay,
-          );
+          handleTimeStampDiff.add(binding.clock.now().difference(startTime) - record.timeDelay);
           for (final PointerEvent event in record.events) {
             binding.handlePointerEventForSource(event, source: TestBindingEventSource.test);
           }
@@ -660,10 +649,7 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   /// See also [LiveTestWidgetsFlutterBindingFramePolicy], which affects how
   /// this method works when the test is run with `flutter run`.
   @override
-  Future<void> pump([
-    Duration? duration,
-    EnginePhase phase = EnginePhase.sendSemanticsUpdate,
-  ]) {
+  Future<void> pump([Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) {
     return TestAsyncUtils.guard<void>(() => binding.pump(duration, phase));
   }
 
@@ -679,19 +665,27 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
     assert(() {
       final TestWidgetsFlutterBinding widgetsBinding = binding;
       return widgetsBinding is LiveTestWidgetsFlutterBinding &&
-             widgetsBinding.framePolicy == LiveTestWidgetsFlutterBindingFramePolicy.benchmark;
+          widgetsBinding.framePolicy == LiveTestWidgetsFlutterBindingFramePolicy.benchmark;
     }());
 
     dynamic caughtException;
-    void handleError(dynamic error, StackTrace stackTrace) => caughtException ??= error;
+    StackTrace? stackTrace;
+    void handleError(dynamic error, StackTrace trace) {
+      caughtException ??= error;
+      stackTrace ??= trace;
+    }
 
-    await Future<void>.microtask(() { binding.handleBeginFrame(duration); }).catchError(handleError);
+    await Future<void>.microtask(() {
+      binding.handleBeginFrame(duration);
+    }).catchError(handleError);
     await idle();
-    await Future<void>.microtask(() { binding.handleDrawFrame(); }).catchError(handleError);
+    await Future<void>.microtask(() {
+      binding.handleDrawFrame();
+    }).catchError(handleError);
     await idle();
 
     if (caughtException != null) {
-      throw caughtException as Object; // ignore: only_throw_errors, rethrowing caught exception.
+      Error.throwWithStackTrace(caughtException as Object, stackTrace!);
     }
   }
 
@@ -839,7 +833,7 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
     Future<T> Function() callback, {
     @Deprecated(
       'This is no longer supported and has no effect. '
-      'This feature was deprecated after v3.12.0-1.1.pre.'
+      'This feature was deprecated after v3.12.0-1.1.pre.',
     )
     Duration additionalTime = const Duration(milliseconds: 1000),
   }) => binding.runAsync<T?>(callback);
@@ -863,7 +857,9 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   @override
   HitTestResult hitTestOnBinding(Offset location, {int? viewId}) {
     viewId ??= view.viewId;
-    final RenderView renderView = binding.renderViews.firstWhere((RenderView r) => r.flutterView.viewId == viewId);
+    final RenderView renderView = binding.renderViews.firstWhere(
+      (RenderView r) => r.flutterView.viewId == viewId,
+    );
     location = binding.localToGlobal(location, renderView);
     return super.hitTestOnBinding(location, viewId: viewId);
   }
@@ -883,16 +879,18 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   @override
   void dispatchEvent(PointerEvent event, HitTestResult result) {
     if (event is PointerDownEvent) {
-      final RenderObject innerTarget = result.path
-        .map((HitTestEntry candidate) => candidate.target)
-        .whereType<RenderObject>()
-        .first;
-      final Element? innerTargetElement = binding.renderViews.contains(innerTarget)
-          ? null
-          : _lastWhereOrNull(
-              collectAllElementsFrom(binding.rootElement!, skipOffstage: true),
-              (Element element) => element.renderObject == innerTarget,
-            );
+      final RenderObject innerTarget =
+          result.path
+              .map((HitTestEntry candidate) => candidate.target)
+              .whereType<RenderObject>()
+              .first;
+      final Element? innerTargetElement =
+          binding.renderViews.contains(innerTarget)
+              ? null
+              : _lastWhereOrNull(
+                collectAllElementsFrom(binding.rootElement!, skipOffstage: true),
+                (Element element) => element.renderObject == innerTarget,
+              );
       if (innerTargetElement == null) {
         printToConsole('No widgets found at ${event.position}.');
         return;
@@ -963,7 +961,8 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
           }
 
           if (descendantText != null && numberOfWithTexts < 5) {
-            final Iterable<Element> matches = find.widgetWithText(widget.runtimeType, descendantText).evaluate();
+            final Iterable<Element> matches =
+                find.widgetWithText(widget.runtimeType, descendantText).evaluate();
             if (matches.length == 1) {
               printToConsole("  find.widgetWithText(${widget.runtimeType}, '$descendantText')");
               numberOfWithTexts += 1;
@@ -1042,7 +1041,7 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   /// An argument can be specified to provide a string that will be used in the
   /// error message. It should be an adverbial phrase describing the current
   /// situation, such as "at the end of the test".
-  void verifyTickersWereDisposed([ String when = 'when none should have been' ]) {
+  void verifyTickersWereDisposed([String when = 'when none should have been']) {
     if (_tickers != null) {
       for (final Ticker ticker in _tickers!) {
         if (ticker.isActive) {
@@ -1052,7 +1051,7 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
             ErrorHint(
               'Tickers used by AnimationControllers '
               'should be disposed by calling dispose() on the AnimationController itself. '
-              'Otherwise, the ticker will leak.'
+              'Otherwise, the ticker will leak.',
             ),
             ticker.describeForError('The offending ticker was'),
           ]);
@@ -1069,14 +1068,16 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   void _verifySemanticsHandlesWereDisposed() {
     assert(_lastRecordedSemanticsHandles != null);
     // TODO(goderbauer): Fix known leak in web engine when running integration tests and remove this "correction", https://github.com/flutter/flutter/issues/121640.
-    final int knownWebEngineLeakForLiveTestsCorrection = kIsWeb && binding is LiveTestWidgetsFlutterBinding ? 1 : 0;
+    final int knownWebEngineLeakForLiveTestsCorrection =
+        kIsWeb && binding is LiveTestWidgetsFlutterBinding ? 1 : 0;
 
-    if (_currentSemanticsHandles - knownWebEngineLeakForLiveTestsCorrection > _lastRecordedSemanticsHandles!) {
+    if (_currentSemanticsHandles - knownWebEngineLeakForLiveTestsCorrection >
+        _lastRecordedSemanticsHandles!) {
       throw FlutterError.fromParts(<DiagnosticsNode>[
         ErrorSummary('A SemanticsHandle was active at the end of the test.'),
         ErrorDescription(
           'All SemanticsHandle instances must be disposed by calling dispose() on '
-          'the SemanticsHandle.'
+          'the SemanticsHandle.',
         ),
       ]);
     }
@@ -1086,7 +1087,9 @@ class WidgetTester extends WidgetController implements HitTestDispatcher, Ticker
   int? _lastRecordedSemanticsHandles;
 
   // TODO(goderbauer): Only use binding.debugOutstandingSemanticsHandles when deprecated binding.pipelineOwner is removed.
-  int get _currentSemanticsHandles => binding.debugOutstandingSemanticsHandles + binding.pipelineOwner.debugOutstandingSemanticsHandles;
+  int get _currentSemanticsHandles =>
+      binding.debugOutstandingSemanticsHandles +
+      binding.pipelineOwner.debugOutstandingSemanticsHandles;
 
   void _recordNumberOfSemanticsHandles() {
     _lastRecordedSemanticsHandles = _currentSemanticsHandles;
