@@ -15,16 +15,23 @@ import 'package:matcher/expect.dart' as matcher show expect;
 
 class TestAPI {
   Future<Object?> testGuard1() {
-    return TestAsyncUtils.guard<Object?>(() async { return null; });
+    return TestAsyncUtils.guard<Object?>(() async {
+      return null;
+    });
   }
+
   Future<Object?> testGuard2() {
-    return TestAsyncUtils.guard<Object?>(() async { return null; });
+    return TestAsyncUtils.guard<Object?>(() async {
+      return null;
+    });
   }
 }
 
 class TestAPISubclass extends TestAPI {
   Future<Object?> testGuard3() {
-    return TestAsyncUtils.guard<Object?>(() async { return null; });
+    return TestAsyncUtils.guard<Object?>(() async {
+      return null;
+    });
   }
 }
 
@@ -50,11 +57,27 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Guarded function conflict.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.'));
-      matcher.expect(lines[3], matches(r'Then, the "testGuard2" method \(also from class TestAPI\) was called from .*test_async_utils_test.dart on line [0-9]+\.'));
-      matcher.expect(lines[4], 'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPI.testGuard2) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.');
+      matcher.expect(
+        lines[2],
+        matches(
+          r'The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'Then, the "testGuard2" method \(also from class TestAPI\) was called from .*test_async_utils_test.dart on line [0-9]+\.',
+        ),
+      );
+      matcher.expect(
+        lines[4],
+        'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPI.testGuard2) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.',
+      );
       matcher.expect(lines[5], '');
-      matcher.expect(lines[6], 'When the first method (TestAPI.testGuard1) was called, this was the stack:');
+      matcher.expect(
+        lines[6],
+        'When the first method (TestAPI.testGuard1) was called, this was the stack:',
+      );
       matcher.expect(lines.length, greaterThan(6));
     }
     expect(await f1, isNull);
@@ -72,11 +95,27 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Guarded function conflict.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[3], matches(r'^Then, the "testGuard2" method \(also from class TestAPI\) was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[4], 'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPI.testGuard2) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.');
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'^Then, the "testGuard2" method \(also from class TestAPI\) was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[4],
+        'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPI.testGuard2) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.',
+      );
       matcher.expect(lines[5], '');
-      matcher.expect(lines[6], 'When the first method (TestAPI.testGuard1) was called, this was the stack:');
+      matcher.expect(
+        lines[6],
+        'When the first method (TestAPI.testGuard1) was called, this was the stack:',
+      );
       matcher.expect(lines.length, greaterThan(7));
     }
     expect(await f1, isNull);
@@ -94,11 +133,27 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Guarded function conflict.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[3], matches(r'^Then, the "testGuard3" method from class TestAPISubclass was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[4], 'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPISubclass.testGuard3) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.');
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'^Then, the "testGuard3" method from class TestAPISubclass was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[4],
+        'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second method (TestAPISubclass.testGuard3) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.',
+      );
       matcher.expect(lines[5], '');
-      matcher.expect(lines[6], 'When the first method (TestAPI.testGuard1) was called, this was the stack:');
+      matcher.expect(
+        lines[6],
+        'When the first method (TestAPI.testGuard1) was called, this was the stack:',
+      );
       matcher.expect(lines.length, greaterThan(7));
     }
     expect(await f1, isNull);
@@ -116,12 +171,31 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Guarded function conflict.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[3], matches(r'^Then, the "expect" function was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[4], 'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second function (expect) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.');
-      matcher.expect(lines[5], 'If you are confident that all test APIs are being called using "await", and this expect() call is not being called at the top level but is itself being called from some sort of callback registered before the testGuard1 method was called, then consider using expectSync() instead.');
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "testGuard1" from class TestAPI was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'^Then, the "expect" function was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[4],
+        'The first method (TestAPI.testGuard1) had not yet finished executing at the time that the second function (expect) was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.',
+      );
+      matcher.expect(
+        lines[5],
+        'If you are confident that all test APIs are being called using "await", and this expect() call is not being called at the top level but is itself being called from some sort of callback registered before the testGuard1 method was called, then consider using expectSync() instead.',
+      );
       matcher.expect(lines[6], '');
-      matcher.expect(lines[7], 'When the first method (TestAPI.testGuard1) was called, this was the stack:');
+      matcher.expect(
+        lines[7],
+        'When the first method (TestAPI.testGuard1) was called, this was the stack:',
+      );
       matcher.expect(lines.length, greaterThan(7));
     }
     expect(await f1, isNull);
@@ -137,9 +211,20 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Guarded function conflict.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[3], matches(r'^Then, it was called from .*test_async_utils_test.dart on line [0-9]+\.$'));
-      matcher.expect(lines[4], 'The first method had not yet finished executing at the time that the second method was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.');
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(r'^Then, it was called from .*test_async_utils_test.dart on line [0-9]+\.$'),
+      );
+      matcher.expect(
+        lines[4],
+        'The first method had not yet finished executing at the time that the second method was called. Since both are guarded, and the second was not a nested call inside the first, the first must complete its execution before the second can be called. Typically, this is achieved by putting an "await" statement in front of the call to the first.',
+      );
       matcher.expect(lines[5], '');
       matcher.expect(lines[6], 'When the first method was called, this was the stack:');
       matcher.expect(lines.length, greaterThan(7));
@@ -162,7 +247,10 @@ void main() {
       matcher.expect(information[4], isA<DiagnosticsProperty<void>>());
       matcher.expect(information[5], isA<DiagnosticsStackTrace>());
       final DiagnosticsStackTrace stackTraceProperty = information[5] as DiagnosticsStackTrace;
-      matcher.expect(stackTraceProperty.name, '\nWhen the first method was called, this was the stack');
+      matcher.expect(
+        stackTraceProperty.name,
+        '\nWhen the first method was called, this was the stack',
+      );
       matcher.expect(stackTraceProperty.value, isA<StackTrace>());
     }
     await f1;
@@ -179,8 +267,18 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Asynchronous call to guarded function leaked.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+, but never completed before its parent scope closed\.$'));
-      matcher.expect(lines[3], matches(r'^The guarded method "pump" from class AutomatedTestWidgetsFlutterBinding was called from [^ ]+ on line [0-9]+, but never completed before its parent scope closed\.'));
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+, but never completed before its parent scope closed\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'^The guarded method "pump" from class AutomatedTestWidgetsFlutterBinding was called from [^ ]+ on line [0-9]+, but never completed before its parent scope closed\.',
+        ),
+      );
       matcher.expect(lines.length, 4);
       final DiagnosticPropertiesBuilder propertiesBuilder = DiagnosticPropertiesBuilder();
       e.debugFillProperties(propertiesBuilder);
@@ -204,8 +302,18 @@ void main() {
       final List<String> lines = e.message.split('\n');
       matcher.expect(lines[0], 'Asynchronous call to guarded function leaked.');
       matcher.expect(lines[1], 'You must use "await" with all Future-returning test APIs.');
-      matcher.expect(lines[2], matches(r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+, but never completed before its parent scope closed\.$'));
-      matcher.expect(lines[3], matches(r'^The guarded method "pump" from class AutomatedTestWidgetsFlutterBinding was called from [^ ]+ on line [0-9]+, but never completed before its parent scope closed\.'));
+      matcher.expect(
+        lines[2],
+        matches(
+          r'^The guarded method "pump" from class WidgetTester was called from .*test_async_utils_test.dart on line [0-9]+, but never completed before its parent scope closed\.$',
+        ),
+      );
+      matcher.expect(
+        lines[3],
+        matches(
+          r'^The guarded method "pump" from class AutomatedTestWidgetsFlutterBinding was called from [^ ]+ on line [0-9]+, but never completed before its parent scope closed\.',
+        ),
+      );
       matcher.expect(lines.length, 4);
       final DiagnosticPropertiesBuilder propertiesBuilder = DiagnosticPropertiesBuilder();
       e.debugFillProperties(propertiesBuilder);
