@@ -6,6 +6,7 @@ import 'dart:async';
 
 import 'package:meta/meta.dart';
 import 'package:process/process.dart';
+import 'package:vm_service/vm_service.dart';
 
 import '../application_package.dart';
 import '../base/common.dart' show throwToolExit;
@@ -18,8 +19,10 @@ import '../build_info.dart';
 import '../convert.dart';
 import '../device.dart';
 import '../device_port_forwarder.dart';
+import '../device_vm_service_discovery_for_attach.dart';
 import '../project.dart';
 import '../protocol_discovery.dart';
+import '../vmservice.dart';
 import 'android.dart';
 import 'android_builder.dart';
 import 'android_console.dart';
@@ -58,7 +61,7 @@ class AndroidDevice extends Device {
     this.productID,
     required this.modelID,
     this.deviceCodeName,
-    required Logger logger,
+    required super.logger,
     required ProcessManager processManager,
     required Platform platform,
     required AndroidSdk androidSdk,
@@ -71,11 +74,7 @@ class AndroidDevice extends Device {
        _fileSystem = fileSystem,
        _androidConsoleSocketFactory = androidConsoleSocketFactory,
        _processUtils = ProcessUtils(logger: logger, processManager: processManager),
-       super(
-         category: Category.mobile,
-         platformType: PlatformType.android,
-         ephemeral: true,
-       );
+       super(category: Category.mobile, platformType: PlatformType.android, ephemeral: true);
 
   final Logger _logger;
   final ProcessManager _processManager;
@@ -171,15 +170,15 @@ class AndroidDevice extends Device {
       final AndroidConsole console = AndroidConsole(socket);
 
       try {
-        await console
-            .connect()
-            .timeout(const Duration(seconds: 2),
-                onTimeout: () => throw TimeoutException('Connection timed out'));
+        await console.connect().timeout(
+          const Duration(seconds: 2),
+          onTimeout: () => throw TimeoutException('Connection timed out'),
+        );
 
-        return await console
-            .getAvdName()
-            .timeout(const Duration(seconds: 2),
-                onTimeout: () => throw TimeoutException('"avd name" timed out'));
+        return await console.getAvdName().timeout(
+          const Duration(seconds: 2),
+          onTimeout: () => throw TimeoutException('"avd name" timed out'),
+        );
       } finally {
         console.destroy();
       }
@@ -234,12 +233,14 @@ class AndroidDevice extends Device {
       case TargetPlatform.tester:
       case TargetPlatform.web_javascript:
       case TargetPlatform.windows_x64:
+      case TargetPlatform.windows_arm64:
         throw UnsupportedError('Invalid target platform for Android');
     }
   }
 
   @override
-  Future<String> get sdkNameAndVersion async => 'Android ${await _sdkVersion} (API ${await apiVersion})';
+  Future<String> get sdkNameAndVersion async =>
+      'Android ${await _sdkVersion} (API ${await apiVersion})';
 
   Future<String?> get _sdkVersion => _getProperty('ro.build.version.release');
 
@@ -285,8 +286,7 @@ class AndroidDevice extends Device {
       }
       return false;
     }
-    _logger.printError(
-        'Unrecognized adb version string $adbVersion. Skipping version check.');
+    _logger.printError('Unrecognized adb version string $adbVersion. Skipping version check.');
     return true;
   }
 
@@ -297,14 +297,16 @@ class AndroidDevice extends Device {
     }
 
     try {
-      final RunResult adbVersion = await _processUtils.run(
-        <String>[adbPath, 'version'],
-        throwOnError: true,
-      );
+      final RunResult adbVersion = await _processUtils.run(<String>[
+        adbPath,
+        'version',
+      ], throwOnError: true);
       if (_isValidAdbVersion(adbVersion.stdout)) {
         return true;
       }
-      _logger.printError('The ADB at "$adbPath" is too old; please install version 1.0.39 or later.');
+      _logger.printError(
+        'The ADB at "$adbPath" is too old; please install version 1.0.39 or later.',
+      );
     } on Exception catch (error, trace) {
       _logger.printError('Error running ADB: $error', stackTrace: trace);
     }
@@ -322,16 +324,13 @@ class AndroidDevice extends Device {
       // output lines like this, which we want to ignore:
       //   adb server is out of date. killing..
       //   * daemon started successfully *
-      await _processUtils.run(
-        <String>[adbPath, 'start-server'],
-        throwOnError: true,
-      );
+      await _processUtils.run(<String>[adbPath, 'start-server'], throwOnError: true);
 
       // This has been reported to return null on some devices. In this case,
       // assume the lowest supported API to still allow Flutter to run.
       // Sample output: '22'
-      final String sdkVersion = await _getProperty('ro.build.version.sdk')
-        ?? minApiLevel.toString();
+      final String sdkVersion =
+          await _getProperty('ro.build.version.sdk') ?? minApiLevel.toString();
 
       final int? sdkVersionParsed = int.tryParse(sdkVersion);
       if (sdkVersionParsed == null) {
@@ -342,7 +341,8 @@ class AndroidDevice extends Device {
       if (sdkVersionParsed < minApiLevel) {
         _logger.printError(
           'The Android version ($sdkVersion) on the target device is too old. Please '
-          'use a $minVersionName (version $minApiLevel / $minVersionText) device or later.');
+          'use a $minVersionName (version $minApiLevel / $minVersionText) device or later.',
+        );
         return false;
       }
 
@@ -360,7 +360,8 @@ class AndroidDevice extends Device {
 
   Future<String> _getDeviceApkSha1(AndroidApk apk) async {
     final RunResult result = await _processUtils.run(
-      adbCommandForDevice(<String>['shell', 'cat', _getDeviceSha1Path(apk)]));
+      adbCommandForDevice(<String>['shell', 'cat', _getDeviceSha1Path(apk)]),
+    );
     return result.stdout;
   }
 
@@ -376,10 +377,7 @@ class AndroidDevice extends Device {
   bool get supportsFlavors => true;
 
   @override
-  Future<bool> isAppInstalled(
-    ApplicationPackage app, {
-    String? userIdentifier,
-  }) async {
+  Future<bool> isAppInstalled(ApplicationPackage app, {String? userIdentifier}) async {
     // This call takes 400ms - 600ms.
     try {
       final RunResult listOut = await runAdbCheckedAsync(<String>[
@@ -387,8 +385,7 @@ class AndroidDevice extends Device {
         'pm',
         'list',
         'packages',
-        if (userIdentifier != null)
-          ...<String>['--user', userIdentifier],
+        if (userIdentifier != null) ...<String>['--user', userIdentifier],
         app.id,
       ]);
       return LineSplitter.split(listOut.stdout).contains('package:${app.id}');
@@ -405,24 +402,16 @@ class AndroidDevice extends Device {
   }
 
   @override
-  Future<bool> installApp(
-    covariant AndroidApk app, {
-    String? userIdentifier,
-  }) async {
+  Future<bool> installApp(covariant AndroidApk app, {String? userIdentifier}) async {
     if (!await _adbIsValid) {
       return false;
     }
-    final bool wasInstalled = await isAppInstalled(app, userIdentifier: userIdentifier);
-    if (wasInstalled && await isLatestBuildInstalled(app)) {
-      _logger.printTrace('Latest build already installed.');
-      return true;
-    }
     _logger.printTrace('Installing APK.');
     if (await _installApp(app, userIdentifier: userIdentifier)) {
       return true;
     }
     _logger.printTrace('Warning: Failed to install APK.');
-    if (!wasInstalled) {
+    if (!await isAppInstalled(app, userIdentifier: userIdentifier)) {
       return false;
     }
     _logger.printStatus('Uninstalling old version...');
@@ -437,12 +426,11 @@ class AndroidDevice extends Device {
     return true;
   }
 
-  Future<bool> _installApp(
-    AndroidApk app, {
-    String? userIdentifier,
-  }) async {
+  Future<bool> _installApp(AndroidApk app, {String? userIdentifier}) async {
     if (!app.applicationPackage.existsSync()) {
-      _logger.printError('"${_fileSystem.path.relative(app.applicationPackage.path)}" does not exist.');
+      _logger.printError(
+        '"${_fileSystem.path.relative(app.applicationPackage.path)}" does not exist.',
+      );
       return false;
     }
 
@@ -454,10 +442,10 @@ class AndroidDevice extends Device {
         'install',
         '-t',
         '-r',
-        if (userIdentifier != null)
-          ...<String>['--user', userIdentifier],
+        if (userIdentifier != null) ...<String>['--user', userIdentifier],
         app.applicationPackage.path,
-      ]));
+      ]),
+    );
     status.stop();
     // Some versions of adb exit with exit code 0 even on failure :(
     // Parsing the output to check for failures.
@@ -469,7 +457,9 @@ class AndroidDevice extends Device {
     }
     if (installResult.exitCode != 0) {
       if (installResult.stderr.contains('Bad user number')) {
-        _logger.printError('Error: User "$userIdentifier" not found. Run "adb shell pm list users" to see list of available identifiers.');
+        _logger.printError(
+          'Error: User "$userIdentifier" not found. Run "adb shell pm list users" to see list of available identifiers.',
+        );
       } else {
         _logger.printError('Error: ADB exited with exit code ${installResult.exitCode}');
         _logger.printError('$installResult');
@@ -478,7 +468,12 @@ class AndroidDevice extends Device {
     }
     try {
       await runAdbCheckedAsync(<String>[
-        'shell', 'echo', '-n', _getSourceSha1(app), '>', _getDeviceSha1Path(app),
+        'shell',
+        'echo',
+        '-n',
+        _getSourceSha1(app),
+        '>',
+        _getDeviceSha1Path(app),
       ]);
     } on ProcessException catch (error) {
       _logger.printError('adb shell failed to write the SHA hash: $error.');
@@ -488,10 +483,7 @@ class AndroidDevice extends Device {
   }
 
   @override
-  Future<bool> uninstallApp(
-    ApplicationPackage app, {
-    String? userIdentifier,
-  }) async {
+  Future<bool> uninstallApp(ApplicationPackage app, {String? userIdentifier}) async {
     if (!await _adbIsValid) {
       return false;
     }
@@ -501,8 +493,7 @@ class AndroidDevice extends Device {
       final RunResult uninstallResult = await _processUtils.run(
         adbCommandForDevice(<String>[
           'uninstall',
-          if (userIdentifier != null)
-            ...<String>['--user', userIdentifier],
+          if (userIdentifier != null) ...<String>['--user', userIdentifier],
           app.id,
         ]),
         throwOnError: true,
@@ -544,8 +535,7 @@ class AndroidDevice extends Device {
     }
 
     final TargetPlatform devicePlatform = await targetPlatform;
-    if (devicePlatform == TargetPlatform.android_x86 &&
-       !debuggingOptions.buildInfo.isDebug) {
+    if (devicePlatform == TargetPlatform.android_x86 && !debuggingOptions.buildInfo.isDebug) {
       _logger.printError('Profile and release builds are only supported on ARM/x64 targets.');
       return LaunchResult.failed();
     }
@@ -570,28 +560,33 @@ class AndroidDevice extends Device {
       case TargetPlatform.linux_x64:
       case TargetPlatform.tester:
       case TargetPlatform.web_javascript:
+      case TargetPlatform.windows_arm64:
       case TargetPlatform.windows_x64:
         _logger.printError('Android platforms are only supported.');
         return LaunchResult.failed();
     }
 
-    if (!prebuiltApplication || _androidSdk.licensesAvailable && _androidSdk.latestVersion == null) {
+    if (!prebuiltApplication ||
+        _androidSdk.licensesAvailable && _androidSdk.latestVersion == null) {
       _logger.printTrace('Building APK');
       final FlutterProject project = FlutterProject.current();
       await androidBuilder!.buildApk(
-          project: project,
-          target: mainPath ?? 'lib/main.dart',
-          androidBuildInfo: AndroidBuildInfo(
-            debuggingOptions.buildInfo,
-            targetArchs: <AndroidArch>[androidArch],
-            fastStart: debuggingOptions.fastStart,
-            multidexEnabled: (platformArgs['multidex'] as bool?) ?? false,
-          ),
+        project: project,
+        target: mainPath ?? 'lib/main.dart',
+        androidBuildInfo: AndroidBuildInfo(
+          debuggingOptions.buildInfo,
+          targetArchs: <AndroidArch>[androidArch],
+          fastStart: debuggingOptions.fastStart,
+        ),
       );
       // Package has been built, so we can get the updated application ID and
       // activity name from the .apk.
-      builtPackage = await ApplicationPackageFactory.instance!
-        .getPackageForPlatform(devicePlatform, buildInfo: debuggingOptions.buildInfo) as AndroidApk?;
+      builtPackage =
+          await ApplicationPackageFactory.instance!.getPackageForPlatform(
+                devicePlatform,
+                buildInfo: debuggingOptions.buildInfo,
+              )
+              as AndroidApk?;
     }
     // There was a failure parsing the android project information.
     if (builtPackage == null) {
@@ -611,12 +606,9 @@ class AndroidDevice extends Device {
     if (debuggingOptions.debuggingEnabled) {
       vmServiceDiscovery = ProtocolDiscovery.vmService(
         // Avoid using getLogReader, which returns a singleton instance, because the
-        // VM Service discovery will dipose at the end. creating a new logger here allows
+        // VM Service discovery will dispose at the end. creating a new logger here allows
         // logs to be surfaced normally during `flutter drive`.
-        await AdbLogReader.createLogReader(
-          this,
-          _processManager,
-        ),
+        await AdbLogReader.createLogReader(this, _processManager, _logger),
         portForwarder: portForwarder,
         hostPort: debuggingOptions.hostVmServicePort,
         devicePort: debuggingOptions.deviceVmServicePort,
@@ -625,7 +617,6 @@ class AndroidDevice extends Device {
       );
     }
 
-    final String dartVmFlags = computeDartVmFlags(debuggingOptions);
     final String? traceAllowlist = debuggingOptions.traceAllowlist;
     final String? traceSkiaAllowlist = debuggingOptions.traceSkiaAllowlist;
     final String? traceToFile = debuggingOptions.traceToFile;
@@ -634,57 +625,72 @@ class AndroidDevice extends Device {
       '-a', 'android.intent.action.MAIN',
       '-c', 'android.intent.category.LAUNCHER',
       '-f', '0x20000000', // FLAG_ACTIVITY_SINGLE_TOP
-      if (debuggingOptions.enableDartProfiling)
-        ...<String>['--ez', 'enable-dart-profiling', 'true'],
-      if (traceStartup)
-        ...<String>['--ez', 'trace-startup', 'true'],
-      if (route != null)
-        ...<String>['--es', 'route', route],
-      if (debuggingOptions.enableSoftwareRendering)
-        ...<String>['--ez', 'enable-software-rendering', 'true'],
-      if (debuggingOptions.skiaDeterministicRendering)
-        ...<String>['--ez', 'skia-deterministic-rendering', 'true'],
-      if (debuggingOptions.traceSkia)
-        ...<String>['--ez', 'trace-skia', 'true'],
-      if (traceAllowlist != null)
-        ...<String>['--es', 'trace-allowlist', traceAllowlist],
-      if (traceSkiaAllowlist != null)
-        ...<String>['--es', 'trace-skia-allowlist', traceSkiaAllowlist],
-      if (debuggingOptions.traceSystrace)
-        ...<String>['--ez', 'trace-systrace', 'true'],
-      if (traceToFile != null)
-        ...<String>['--es', 'trace-to-file', traceToFile],
-      if (debuggingOptions.endlessTraceBuffer)
-        ...<String>['--ez', 'endless-trace-buffer', 'true'],
-      if (debuggingOptions.dumpSkpOnShaderCompilation)
-        ...<String>['--ez', 'dump-skp-on-shader-compilation', 'true'],
-      if (debuggingOptions.cacheSkSL)
-      ...<String>['--ez', 'cache-sksl', 'true'],
-      if (debuggingOptions.purgePersistentCache)
-        ...<String>['--ez', 'purge-persistent-cache', 'true'],
-      if (debuggingOptions.enableImpeller == ImpellerStatus.enabled)
-        ...<String>['--ez', 'enable-impeller', 'true'],
-      if (debuggingOptions.enableImpeller == ImpellerStatus.disabled)
-        ...<String>['--ez', 'enable-impeller', 'false'],
-      if (debuggingOptions.enableVulkanValidation)
-        ...<String>['--ez', 'enable-vulkan-validation', 'true'],
+      if (debuggingOptions.enableDartProfiling) ...<String>[
+        '--ez',
+        'enable-dart-profiling',
+        'true',
+      ],
+      if (traceStartup) ...<String>['--ez', 'trace-startup', 'true'],
+      if (route != null) ...<String>['--es', 'route', route],
+      if (debuggingOptions.enableSoftwareRendering) ...<String>[
+        '--ez',
+        'enable-software-rendering',
+        'true',
+      ],
+      if (debuggingOptions.skiaDeterministicRendering) ...<String>[
+        '--ez',
+        'skia-deterministic-rendering',
+        'true',
+      ],
+      if (debuggingOptions.traceSkia) ...<String>['--ez', 'trace-skia', 'true'],
+      if (traceAllowlist != null) ...<String>['--es', 'trace-allowlist', traceAllowlist],
+      if (traceSkiaAllowlist != null) ...<String>[
+        '--es',
+        'trace-skia-allowlist',
+        traceSkiaAllowlist,
+      ],
+      if (debuggingOptions.traceSystrace) ...<String>['--ez', 'trace-systrace', 'true'],
+      if (traceToFile != null) ...<String>['--es', 'trace-to-file', traceToFile],
+      if (debuggingOptions.endlessTraceBuffer) ...<String>['--ez', 'endless-trace-buffer', 'true'],
+      if (debuggingOptions.purgePersistentCache) ...<String>[
+        '--ez',
+        'purge-persistent-cache',
+        'true',
+      ],
+      if (debuggingOptions.enableImpeller == ImpellerStatus.enabled) ...<String>[
+        '--ez',
+        'enable-impeller',
+        'true',
+      ],
+      if (debuggingOptions.enableImpeller == ImpellerStatus.disabled) ...<String>[
+        '--ez',
+        'enable-impeller',
+        'false',
+      ],
+      if (debuggingOptions.enableVulkanValidation) ...<String>[
+        '--ez',
+        'enable-vulkan-validation',
+        'true',
+      ],
       if (debuggingOptions.debuggingEnabled) ...<String>[
         if (debuggingOptions.buildInfo.isDebug) ...<String>[
           ...<String>['--ez', 'enable-checked-mode', 'true'],
           ...<String>['--ez', 'verify-entry-points', 'true'],
         ],
-        if (debuggingOptions.startPaused)
-          ...<String>['--ez', 'start-paused', 'true'],
-        if (debuggingOptions.disableServiceAuthCodes)
-          ...<String>['--ez', 'disable-service-auth-codes', 'true'],
-        if (dartVmFlags.isNotEmpty)
-          ...<String>['--es', 'dart-flags', dartVmFlags],
-        if (debuggingOptions.useTestFonts)
-          ...<String>['--ez', 'use-test-fonts', 'true'],
-        if (debuggingOptions.verboseSystemLogs)
-          ...<String>['--ez', 'verbose-logging', 'true'],
-        if (userIdentifier != null)
-          ...<String>['--user', userIdentifier],
+        if (debuggingOptions.startPaused) ...<String>['--ez', 'start-paused', 'true'],
+        if (debuggingOptions.disableServiceAuthCodes) ...<String>[
+          '--ez',
+          'disable-service-auth-codes',
+          'true',
+        ],
+        if (debuggingOptions.dartFlags.isNotEmpty) ...<String>[
+          '--es',
+          'dart-flags',
+          debuggingOptions.dartFlags,
+        ],
+        if (debuggingOptions.useTestFonts) ...<String>['--ez', 'use-test-fonts', 'true'],
+        if (debuggingOptions.verboseSystemLogs) ...<String>['--ez', 'verbose-logging', 'true'],
+        if (userIdentifier != null) ...<String>['--user', userIdentifier],
       ],
       builtPackage.launchActivity,
     ];
@@ -734,10 +740,7 @@ class AndroidDevice extends Device {
   bool get supportsFastStart => true;
 
   @override
-  Future<bool> stopApp(
-    ApplicationPackage? app, {
-    String? userIdentifier,
-  }) async {
+  Future<bool> stopApp(ApplicationPackage? app, {String? userIdentifier}) async {
     if (app == null) {
       return false;
     }
@@ -745,12 +748,14 @@ class AndroidDevice extends Device {
       'shell',
       'am',
       'force-stop',
-      if (userIdentifier != null)
-        ...<String>['--user', userIdentifier],
+      if (userIdentifier != null) ...<String>['--user', userIdentifier],
       app.id,
     ]);
-    return _processUtils.stream(command).then<bool>(
-        (int exitCode) => exitCode == 0 || _allowHeapCorruptionOnWindows(exitCode, _platform));
+    return _processUtils
+        .stream(command)
+        .then<bool>(
+          (int exitCode) => exitCode == 0 || _allowHeapCorruptionOnWindows(exitCode, _platform),
+        );
   }
 
   @override
@@ -760,13 +765,9 @@ class AndroidDevice extends Device {
       _logger.printError('Android package unknown, skipping dumpsys meminfo.');
       return const MemoryInfo.empty();
     }
-    final RunResult runResult = await _processUtils.run(adbCommandForDevice(<String>[
-      'shell',
-      'dumpsys',
-      'meminfo',
-      package.id,
-      '-d',
-    ]));
+    final RunResult runResult = await _processUtils.run(
+      adbCommandForDevice(<String>['shell', 'dumpsys', 'meminfo', package.id, '-d']),
+    );
 
     if (runResult.exitCode != 0) {
       return const MemoryInfo.empty();
@@ -776,7 +777,14 @@ class AndroidDevice extends Device {
 
   @override
   void clearLogs() {
-    _processUtils.runSync(adbCommandForDevice(<String>['logcat', '-c']));
+    final RunResult result = _processUtils.runSync(adbCommandForDevice(<String>['logcat', '-c']));
+    // Do not log to standard error because that causes test to fail.
+    if (result.exitCode != 0) {
+      _logger.printTrace(
+        '"adb logcat -c" failed: exitCode: ${result.exitCode}'
+        ' stdout: ${result.stdout} stderr: ${result.stderr}',
+      );
+    }
   }
 
   @override
@@ -789,16 +797,33 @@ class AndroidDevice extends Device {
       return _pastLogReader ??= await AdbLogReader.createLogReader(
         this,
         _processManager,
+        _logger,
         includePastLogs: true,
       );
     } else {
-      return _logReader ??= await AdbLogReader.createLogReader(
-        this,
-        _processManager,
-      );
+      return _logReader ??= await AdbLogReader.createLogReader(this, _processManager, _logger);
     }
   }
 
+  @override
+  VMServiceDiscoveryForAttach getVMServiceDiscoveryForAttach({
+    String? appId,
+    String? fuchsiaModule,
+    int? filterDevicePort,
+    int? expectedHostPort,
+    required bool ipv6,
+    required Logger logger,
+  }) => LogScanningVMServiceDiscoveryForAttach(
+    // If it's an Android device, attaching relies on past log searching
+    // to find the service protocol.
+    Future<DeviceLogReader>.value(getLogReader(includePastLogs: true)),
+    portForwarder: portForwarder,
+    ipv6: ipv6,
+    devicePort: filterDevicePort,
+    hostPort: expectedHostPort,
+    logger: logger,
+  );
+
   @override
   late final DevicePortForwarder? portForwarder = () {
     final String? adbPath = _androidSdk.adbPath;
@@ -813,7 +838,10 @@ class AndroidDevice extends Device {
     );
   }();
 
-  static final RegExp _timeRegExp = RegExp(r'^\d{2}-\d{2} \d{2}:\d{2}:\d{2}\.\d{3}', multiLine: true);
+  static final RegExp _timeRegExp = RegExp(
+    r'^\d{2}-\d{2} \d{2}:\d{2}:\d{2}\.\d{3}',
+    multiLine: true,
+  );
 
   /// Return the most recent timestamp in the Android log or [null] if there is
   /// no available timestamp. The format can be passed to logcat's -T option.
@@ -821,11 +849,11 @@ class AndroidDevice extends Device {
   Future<String?> lastLogcatTimestamp() async {
     RunResult output;
     try {
-      output = await runAdbCheckedAsync(<String>[
-        'shell', '-x', 'logcat', '-v', 'time', '-t', '1',
-      ]);
+      output = await runAdbCheckedAsync(<String>['shell', '-x', 'logcat', '-v', 'time', '-t', '1']);
     } on Exception catch (error) {
-      _logger.printError('Failed to extract the most recent timestamp from the Android log: $error.');
+      _logger.printError(
+        'Failed to extract the most recent timestamp from the Android log: $error.',
+      );
       return null;
     }
     final Match? timeMatch = _timeRegExp.firstMatch(output.stdout);
@@ -876,7 +904,7 @@ Map<String, String> parseAdbDeviceProperties(String str) {
 ///
 /// Example output:
 ///
-/// ```
+/// ```none
 /// Applications Memory Usage (in Kilobytes):
 /// Uptime: 441088659 Realtime: 521464097
 ///
@@ -937,36 +965,37 @@ AndroidMemoryInfo parseMeminfoDump(String input) {
 
   final List<String> lines = input.split('\n');
 
-  final String timelineData = lines.firstWhere((String line) =>
-    line.startsWith('${AndroidMemoryInfo._kUpTimeKey}: '));
+  final String timelineData = lines.firstWhere(
+    (String line) => line.startsWith('${AndroidMemoryInfo._kUpTimeKey}: '),
+  );
   final List<String> times = timelineData.trim().split('${AndroidMemoryInfo._kRealTimeKey}:');
   androidMemoryInfo.realTime = int.tryParse(times.last.trim()) ?? 0;
 
   lines
-    .skipWhile((String line) => !line.contains('App Summary'))
-    .takeWhile((String line) => !line.contains('TOTAL'))
-    .where((String line) => line.contains(':'))
-    .forEach((String line) {
-      final List<String> sections = line.trim().split(':');
-      final String key = sections.first.trim();
-      final int value = int.tryParse(sections.last.trim()) ?? 0;
-      switch (key) {
-        case AndroidMemoryInfo._kJavaHeapKey:
-          androidMemoryInfo.javaHeap = value;
-        case AndroidMemoryInfo._kNativeHeapKey:
-          androidMemoryInfo.nativeHeap = value;
-        case AndroidMemoryInfo._kCodeKey:
-          androidMemoryInfo.code = value;
-        case AndroidMemoryInfo._kStackKey:
-          androidMemoryInfo.stack = value;
-        case AndroidMemoryInfo._kGraphicsKey:
-          androidMemoryInfo.graphics = value;
-        case AndroidMemoryInfo._kPrivateOtherKey:
-          androidMemoryInfo.privateOther = value;
-        case AndroidMemoryInfo._kSystemKey:
-          androidMemoryInfo.system = value;
-      }
-  });
+      .skipWhile((String line) => !line.contains('App Summary'))
+      .takeWhile((String line) => !line.contains('TOTAL'))
+      .where((String line) => line.contains(':'))
+      .forEach((String line) {
+        final List<String> sections = line.trim().split(':');
+        final String key = sections.first.trim();
+        final int value = int.tryParse(sections.last.trim()) ?? 0;
+        switch (key) {
+          case AndroidMemoryInfo._kJavaHeapKey:
+            androidMemoryInfo.javaHeap = value;
+          case AndroidMemoryInfo._kNativeHeapKey:
+            androidMemoryInfo.nativeHeap = value;
+          case AndroidMemoryInfo._kCodeKey:
+            androidMemoryInfo.code = value;
+          case AndroidMemoryInfo._kStackKey:
+            androidMemoryInfo.stack = value;
+          case AndroidMemoryInfo._kGraphicsKey:
+            androidMemoryInfo.graphics = value;
+          case AndroidMemoryInfo._kPrivateOtherKey:
+            androidMemoryInfo.privateOther = value;
+          case AndroidMemoryInfo._kSystemKey:
+            androidMemoryInfo.system = value;
+        }
+      });
   return androidMemoryInfo;
 }
 
@@ -1015,15 +1044,16 @@ class AndroidMemoryInfo extends MemoryInfo {
 
 /// A log reader that logs from `adb logcat`.
 class AdbLogReader extends DeviceLogReader {
-  AdbLogReader._(this._adbProcess, this.name);
+  AdbLogReader._(this._adbProcess, this.name, this._logger);
 
   @visibleForTesting
-  factory AdbLogReader.test(Process adbProcess, String name) = AdbLogReader._;
+  factory AdbLogReader.test(Process adbProcess, String name, Logger logger) = AdbLogReader._;
 
   /// Create a new [AdbLogReader] from an [AndroidDevice] instance.
   static Future<AdbLogReader> createLogReader(
     AndroidDevice device,
-    ProcessManager processManager, {
+    ProcessManager processManager,
+    Logger logger, {
     bool includePastLogs = false,
   }) async {
     // logcat -T is not supported on Android releases before Lollipop.
@@ -1037,13 +1067,7 @@ class AdbLogReader extends DeviceLogReader {
     // Start the adb logcat process and filter the most recent logs since `lastTimestamp`.
     // Some devices (notably LG) will only output logcat via shell
     // https://github.com/flutter/flutter/issues/51853
-    final List<String> args = <String>[
-      'shell',
-      '-x',
-      'logcat',
-      '-v',
-      'time',
-    ];
+    final List<String> args = <String>['shell', '-x', 'logcat', '-v', 'time'];
 
     // If past logs are included then filter for 'flutter' logs only.
     if (includePastLogs) {
@@ -1058,11 +1082,15 @@ class AdbLogReader extends DeviceLogReader {
       ]);
     }
     final Process process = await processManager.start(device.adbCommandForDevice(args));
-    return AdbLogReader._(process, device.name);
+    return AdbLogReader._(process, device.displayName, logger);
   }
 
+  int? _appPid;
+
   final Process _adbProcess;
 
+  final Logger _logger;
+
   @override
   final String name;
 
@@ -1074,21 +1102,38 @@ class AdbLogReader extends DeviceLogReader {
   @override
   Stream<String> get logLines => _linesController.stream;
 
+  @override
+  Future<void> provideVmService(FlutterVmService connectedVmService) async {
+    final VM? vm = await connectedVmService.getVmGuarded();
+    if (vm == null) {
+      _logger.printError(
+        'An error occurred when setting up filtering for adb logs. '
+        'Unable to communicate with the VM service.',
+      );
+    } else {
+      _appPid = vm.pid;
+    }
+  }
+
   void _start() {
     // We expect logcat streams to occasionally contain invalid utf-8,
     // see: https://github.com/flutter/flutter/pull/8864.
     const Utf8Decoder decoder = Utf8Decoder(reportErrors: false);
-    _adbProcess.stdout.transform<String>(decoder)
-      .transform<String>(const LineSplitter())
-      .listen(_onLine);
-    _adbProcess.stderr.transform<String>(decoder)
-      .transform<String>(const LineSplitter())
-      .listen(_onLine);
-    unawaited(_adbProcess.exitCode.whenComplete(() {
-      if (_linesController.hasListener) {
-        _linesController.close();
-      }
-    }));
+    _adbProcess.stdout
+        .transform<String>(decoder)
+        .transform<String>(const LineSplitter())
+        .listen(_onLine);
+    _adbProcess.stderr
+        .transform<String>(decoder)
+        .transform<String>(const LineSplitter())
+        .listen(_onLine);
+    unawaited(
+      _adbProcess.exitCode.whenComplete(() {
+        if (_linesController.hasListener) {
+          _linesController.close();
+        }
+      }),
+    );
   }
 
   // 'W/ActivityManager(pid): '
@@ -1104,10 +1149,15 @@ class AdbLogReader extends DeviceLogReader {
     RegExp(r'^[F]\/[\S^:]+:\s+'),
   ];
 
-  // E/SurfaceSyncer(22636): Failed to find sync for id=9
-  // Some versions of Android spew this out. It is inactionable to the end user
-  // and causes no problems for the application.
-  static final RegExp _surfaceSyncerSpam = RegExp(r'^E/SurfaceSyncer\(\s*\d+\): Failed to find sync for id=\d+');
+  static final List<RegExp> _filteredMessagees = <RegExp>[
+    // E/SurfaceSyncer(22636): Failed to find sync for id=9
+    // Some versions of Android spew this out. It is inactionable to the end user
+    // and causes no problems for the application.
+    RegExp(r'^E/SurfaceSyncer\(\s*\d+\): Failed to find sync for id=\d+'),
+    // See https://github.com/flutter/flutter/issues/160598
+    RegExp(r'ViewPostIme pointer'),
+    RegExp(r'mali.instrumentation.graph.work'),
+  ];
 
   // 'F/libc(pid): Fatal signal 11'
   static final RegExp _fatalLog = RegExp(r'^F\/libc\s*\(\s*\d+\):\sFatal signal (\d+)');
@@ -1162,8 +1212,8 @@ class AdbLogReader extends DeviceLogReader {
             _fatalCrash = false;
           }
         }
-      } else if (appPid != null && int.parse(logMatch.group(1)!) == appPid) {
-        acceptLine = !_surfaceSyncerSpam.hasMatch(line);
+      } else if (_appPid != null && int.parse(logMatch.group(1)!) == _appPid) {
+        acceptLine = !_filteredMessagees.any((RegExp e) => e.hasMatch(line));
 
         if (_fatalLog.hasMatch(line)) {
           // Hit fatal signal, app is now crashing
@@ -1180,8 +1230,7 @@ class AdbLogReader extends DeviceLogReader {
         return;
       }
       _acceptedLastLine = false;
-    } else if (line == '--------- beginning of system' ||
-               line == '--------- beginning of main') {
+    } else if (line == '--------- beginning of system' || line == '--------- beginning of main') {
       // hide the ugly adb logcat log boundaries at the start
       _acceptedLastLine = false;
     } else {
@@ -1232,16 +1281,11 @@ class AndroidDevicePortForwarder extends DevicePortForwarder {
 
     String stdout;
     try {
-      stdout = _processUtils.runSync(
-        <String>[
-          _adbPath,
-          '-s',
-          _deviceId,
-          'forward',
-          '--list',
-        ],
-        throwOnError: true,
-      ).stdout.trim();
+      stdout =
+          _processUtils
+              .runSync(<String>[_adbPath, '-s', _deviceId, 'forward', '--list'], throwOnError: true)
+              .stdout
+              .trim();
     } on ProcessException catch (error) {
       _logger.printError('Failed to list forwarded ports: $error.');
       return ports;
@@ -1275,19 +1319,16 @@ class AndroidDevicePortForwarder extends DevicePortForwarder {
   }
 
   @override
-  Future<int> forward(int devicePort, { int? hostPort }) async {
+  Future<int> forward(int devicePort, {int? hostPort}) async {
     hostPort ??= 0;
-    final RunResult process = await _processUtils.run(
-      <String>[
-        _adbPath,
-        '-s',
-        _deviceId,
-        'forward',
-        'tcp:$hostPort',
-        'tcp:$devicePort',
-      ],
-      throwOnError: true,
-    );
+    final RunResult process = await _processUtils.run(<String>[
+      _adbPath,
+      '-s',
+      _deviceId,
+      'forward',
+      'tcp:$hostPort',
+      'tcp:$devicePort',
+    ], throwOnError: true);
 
     if (process.stderr.isNotEmpty) {
       process.throwException('adb returned error:\n${process.stderr}');
@@ -1333,16 +1374,14 @@ class AndroidDevicePortForwarder extends DevicePortForwarder {
   @override
   Future<void> unforward(ForwardedPort forwardedPort) async {
     final String tcpLine = 'tcp:${forwardedPort.hostPort}';
-    final RunResult runResult = await _processUtils.run(
-      <String>[
-        _adbPath,
-        '-s',
-        _deviceId,
-        'forward',
-        '--remove',
-        tcpLine,
-      ],
-    );
+    final RunResult runResult = await _processUtils.run(<String>[
+      _adbPath,
+      '-s',
+      _deviceId,
+      'forward',
+      '--remove',
+      tcpLine,
+    ]);
     if (runResult.exitCode == 0) {
       return;
     }
