@@ -19,7 +19,6 @@ import '../base/utils.dart';
 import '../build_info.dart';
 import '../cache.dart';
 import '../convert.dart';
-import '../reporting/reporting.dart';
 import 'depfile.dart';
 import 'exceptions.dart';
 import 'file_store.dart';
@@ -111,6 +110,7 @@ class BuildSystemConfig {
 /// and meets any additional contracts present in the target.
 abstract class Target {
   const Target();
+
   /// The user-readable name of the target.
   ///
   /// This information is surfaced in the assemble commands and used as an
@@ -163,9 +163,7 @@ abstract class Target {
       this,
       inputsFiles.sources,
       outputFiles.sources,
-      <Node>[
-        for (final Target target in dependencies) target._toNode(environment),
-      ],
+      <Node>[for (final Target target in dependencies) target._toNode(environment)],
       buildKey,
       environment,
       inputsFiles.containsNewDepfile,
@@ -178,11 +176,7 @@ abstract class Target {
     ErrorHandlingFileSystem.deleteIfExists(stamp);
   }
 
-  void _writeStamp(
-    List<File> inputs,
-    List<File> outputs,
-    Environment environment,
-  ) {
+  void _writeStamp(List<File> inputs, List<File> outputs, Environment environment) {
     String getPath(File file) => file.path;
     final Map<String, Object> result = <String, Object>{
       'inputs': inputs.map(getPath).toList(),
@@ -213,7 +207,9 @@ abstract class Target {
   /// Performs a fold across this target and its dependencies.
   T fold<T>(T initialValue, T Function(T previousValue, Target target) combine) {
     final T dependencyResult = dependencies.fold(
-        initialValue, (T prev, Target t) => t.fold(prev, combine));
+      initialValue,
+      (T prev, Target t) => t.fold(prev, combine),
+    );
     return combine(dependencyResult, this);
   }
 
@@ -226,15 +222,9 @@ abstract class Target {
     final String? key = buildKey;
     return <String, Object>{
       'name': name,
-      'dependencies': <String>[
-        for (final Target target in dependencies) target.name,
-      ],
-      'inputs': <String>[
-        for (final File file in resolveInputs(environment).sources) file.path,
-      ],
-      'outputs': <String>[
-        for (final File file in resolveOutputs(environment).sources) file.path,
-      ],
+      'dependencies': <String>[for (final Target target in dependencies) target.name],
+      'inputs': <String>[for (final File file in resolveInputs(environment).sources) file.path],
+      'outputs': <String>[for (final File file in resolveOutputs(environment).sources) file.path],
       if (key != null) 'buildKey': key,
       'stamp': _findStampFile(environment).absolute.path,
     };
@@ -275,7 +265,7 @@ class CompositeTarget extends Target {
   String get name => '_composite';
 
   @override
-  Future<void> build(Environment environment) async { }
+  Future<void> build(Environment environment) async {}
 
   @override
   List<Source> get inputs => <Source>[];
@@ -334,6 +324,7 @@ class Environment {
   /// [engineVersion] should be set to null for local engine builds.
   factory Environment({
     required Directory projectDir,
+    required String packageConfigPath,
     required Directory outputDir,
     required Directory cacheDir,
     required Directory flutterRootDir,
@@ -342,7 +333,6 @@ class Environment {
     required Artifacts artifacts,
     required ProcessManager processManager,
     required Platform platform,
-    required Usage usage,
     required Analytics analytics,
     String? engineVersion,
     required bool generateDartPluginRegistry,
@@ -374,6 +364,7 @@ class Environment {
     return Environment._(
       outputDir: outputDir,
       projectDir: projectDir,
+      packageConfigPath: packageConfigPath,
       buildDir: buildDirectory,
       rootBuildDir: rootBuildDir,
       cacheDir: cacheDir,
@@ -384,7 +375,6 @@ class Environment {
       artifacts: artifacts,
       processManager: processManager,
       platform: platform,
-      usage: usage,
       analytics: analytics,
       engineVersion: engineVersion,
       inputs: inputs,
@@ -396,8 +386,10 @@ class Environment {
   ///
   /// Any directories not provided will fallback to a [testDirectory]
   @visibleForTesting
-  factory Environment.test(Directory testDirectory, {
+  factory Environment.test(
+    Directory testDirectory, {
     Directory? projectDir,
+    String? packageConfigPath,
     Directory? outputDir,
     Directory? cacheDir,
     Directory? flutterRootDir,
@@ -406,7 +398,6 @@ class Environment {
     Map<String, String> inputs = const <String, String>{},
     String? engineVersion,
     Platform? platform,
-    Usage? usage,
     Analytics? analytics,
     bool generateDartPluginRegistry = false,
     required FileSystem fileSystem,
@@ -416,6 +407,7 @@ class Environment {
   }) {
     return Environment(
       projectDir: projectDir ?? testDirectory,
+      packageConfigPath: packageConfigPath ?? '.dart_tool/package_config.json',
       outputDir: outputDir ?? testDirectory,
       cacheDir: cacheDir ?? testDirectory,
       flutterRootDir: flutterRootDir ?? testDirectory,
@@ -427,7 +419,6 @@ class Environment {
       artifacts: artifacts,
       processManager: processManager,
       platform: platform ?? FakePlatform(),
-      usage: usage ?? TestUsage(),
       analytics: analytics ?? const NoOpAnalytics(),
       engineVersion: engineVersion,
       generateDartPluginRegistry: generateDartPluginRegistry,
@@ -437,6 +428,7 @@ class Environment {
   Environment._({
     required this.outputDir,
     required this.projectDir,
+    required this.packageConfigPath,
     required this.buildDir,
     required this.rootBuildDir,
     required this.cacheDir,
@@ -447,7 +439,6 @@ class Environment {
     required this.logger,
     required this.fileSystem,
     required this.artifacts,
-    required this.usage,
     required this.analytics,
     this.engineVersion,
     required this.inputs,
@@ -457,6 +448,11 @@ class Environment {
   /// The [Source] value which is substituted with the path to [projectDir].
   static const String kProjectDirectory = '{PROJECT_DIR}';
 
+  /// The [Source] value which is substituted with the path to the directory
+  /// that contains `.dart_tool/package_config.json1`.
+  /// That is the grand-parent of [BuildInfo.packageConfigPath].
+  static const String kWorkspaceDirectory = '{WORKSPACE_DIR}';
+
   /// The [Source] value which is substituted with the path to [buildDir].
   static const String kBuildDirectory = '{BUILD_DIR}';
 
@@ -475,10 +471,16 @@ class Environment {
   /// can be located.
   final Directory projectDir;
 
+  /// The path to the package configuration file to use for compilation.
+  ///
+  /// This is used by package:package_config to locate the actual package_config.json
+  /// file. If not provided in tests, defaults to `.dart_tool/package_config.json`.
+  final String packageConfigPath;
+
   /// The `BUILD_DIR` environment variable.
   ///
   /// The root of the output directory where build step intermediates and
-  /// outputs are written. Current usages of assemble configure ths to be
+  /// outputs are written. Current usages of assemble configure this to be
   /// a unique directory under `.dart_tool/flutter_build`, though it can
   /// be placed anywhere. The uniqueness is only enforced by callers, and
   /// is currently done by hashing the build configuration.
@@ -529,8 +531,6 @@ class Environment {
 
   final FileSystem fileSystem;
 
-  final Usage usage;
-
   final Analytics analytics;
 
   /// The version of the current engine, or `null` if built with a local engine.
@@ -541,10 +541,7 @@ class Environment {
   /// the new entrypoint.
   final bool generateDartPluginRegistry;
 
-  late final DepfileService depFileService = DepfileService(
-    logger: logger,
-    fileSystem: fileSystem,
-  );
+  late final DepfileService depFileService = DepfileService(logger: logger, fileSystem: fileSystem);
 }
 
 /// The result information from the build system.
@@ -613,10 +610,7 @@ class FlutterBuildSystem extends BuildSystem {
 
     // Load file store from previous builds.
     final File cacheFile = environment.buildDir.childFile(FileStore.kFileCache);
-    final FileStore fileCache = FileStore(
-      cacheFile: cacheFile,
-      logger: _logger,
-    )..initialize();
+    final FileStore fileCache = FileStore(cacheFile: cacheFile, logger: _logger)..initialize();
 
     // Perform sanity checks on build.
     checkCycles(target);
@@ -645,31 +639,37 @@ class FlutterBuildSystem extends BuildSystem {
     // We also remove files under .dart_tool, since these are intermediaries
     // and don't need to be tracked by external systems.
     {
+      bool isUnconditionalFile(String path) {
+        return switch (_fileSystem.path.basename(path)) {
+          '.flutter-plugins' || '.flutter-plugins-dependencies' => true,
+          _ when _fileSystem.path.extension(path) == '.xcconfig' => true,
+          _ when _fileSystem.path.split(path).contains('.dart_tool') => true,
+          _ => false,
+        };
+      }
+
       buildInstance.inputFiles.removeWhere((String path, File file) {
-        return path.contains('.flutter-plugins') ||
-                       path.contains('xcconfig') ||
-                     path.contains('.dart_tool');
+        return isUnconditionalFile(path);
       });
       buildInstance.outputFiles.removeWhere((String path, File file) {
-        return path.contains('.flutter-plugins') ||
-                       path.contains('xcconfig') ||
-                     path.contains('.dart_tool');
+        return isUnconditionalFile(path);
       });
     }
-    trackSharedBuildDirectory(
-      environment, _fileSystem, buildInstance.outputFiles,
-    );
-    environment.buildDir.childFile('outputs.json')
-      .writeAsStringSync(json.encode(buildInstance.outputFiles.keys.toList()));
+    trackSharedBuildDirectory(environment, _fileSystem, buildInstance.outputFiles);
+    environment.buildDir
+        .childFile('outputs.json')
+        .writeAsStringSync(json.encode(buildInstance.outputFiles.keys.toList()));
 
     return BuildResult(
       success: passed,
       exceptions: buildInstance.exceptionMeasurements,
       performance: buildInstance.stepTimings,
-      inputFiles: buildInstance.inputFiles.values.toList()
-          ..sort((File a, File b) => a.path.compareTo(b.path)),
-      outputFiles: buildInstance.outputFiles.values.toList()
-          ..sort((File a, File b) => a.path.compareTo(b.path)),
+      inputFiles:
+          buildInstance.inputFiles.values.toList()
+            ..sort((File a, File b) => a.path.compareTo(b.path)),
+      outputFiles:
+          buildInstance.outputFiles.values.toList()
+            ..sort((File a, File b) => a.path.compareTo(b.path)),
     );
   }
 
@@ -760,18 +760,17 @@ class FlutterBuildSystem extends BuildSystem {
     lastBuildIdFile
       ..createSync()
       ..writeAsStringSync(currentBuildId);
-    final File outputsFile = environment.buildDir
-      .parent
-      .childDirectory(lastBuildId)
-      .childFile('outputs.json');
+    final File outputsFile = environment.buildDir.parent
+        .childDirectory(lastBuildId)
+        .childFile('outputs.json');
 
     if (!outputsFile.existsSync()) {
       // There is no output list. This could happen if the user manually
       // edited .last_config or deleted .dart_tool.
       return;
     }
-    final List<String> lastOutputs = (json.decode(outputsFile.readAsStringSync()) as List<Object?>)
-      .cast<String>();
+    final List<String> lastOutputs =
+        (json.decode(outputsFile.readAsStringSync()) as List<Object?>).cast<String>();
     for (final String lastOutput in lastOutputs) {
       if (!currentOutputs.containsKey(lastOutput)) {
         final File lastOutputFile = fileSystem.file(lastOutput);
@@ -790,8 +789,7 @@ class _BuildInstance {
     required this.logger,
     required this.fileSystem,
     Platform? platform,
-  })
-    : resourcePool = Pool(buildSystemConfig.resourcePoolSize ?? platform?.numberOfProcessors ?? 1);
+  }) : resourcePool = Pool(buildSystemConfig.resourcePoolSize ?? platform?.numberOfProcessors ?? 1);
 
   final Logger logger;
   final FileSystem fileSystem;
@@ -850,8 +848,8 @@ class _BuildInstance {
     try {
       // If we're missing a depfile, wait until after evaluating the target to
       // compute changes.
-      final bool canSkip = !node.missingDepfile &&
-        node.computeChanges(environment, fileCache, fileSystem, logger);
+      final bool canSkip =
+          !node.missingDepfile && node.computeChanges(environment, fileCache, fileSystem, logger);
 
       if (canSkip) {
         skipped = true;
@@ -903,7 +901,11 @@ class _BuildInstance {
       succeeded = false;
       skipped = false;
       exceptionMeasurements[node.target.name] = ExceptionMeasurement(
-          node.target.name, exception, stackTrace, fatal: true);
+        node.target.name,
+        exception,
+        stackTrace,
+        fatal: true,
+      );
     } finally {
       resource.release();
       stopwatch.stop();
@@ -969,6 +971,7 @@ void checkCycles(Target initial) {
     }
     stack.remove(target);
   }
+
   checkInternal(initial, <Target>{}, <Target>{});
 }
 
@@ -1040,14 +1043,7 @@ class Node {
         );
       }
     }
-    return Node.withNoStamp(
-      target,
-      inputs,
-      outputs,
-      dependencies,
-      buildKey,
-      missingDepfile,
-    );
+    return Node.withNoStamp(target, inputs, outputs, dependencies, buildKey, missingDepfile);
   }
 
   Node.withNoStamp(
@@ -1115,7 +1111,8 @@ class Node {
   /// One or more reasons why a task was invalidated.
   ///
   /// May be empty if the task was skipped.
-  final Map<InvalidatedReasonKind, InvalidatedReason> invalidatedReasons = <InvalidatedReasonKind, InvalidatedReason>{};
+  final Map<InvalidatedReasonKind, InvalidatedReason> invalidatedReasons =
+      <InvalidatedReasonKind, InvalidatedReason>{};
 
   /// Whether this node needs an action performed.
   bool get dirty => _dirty;
@@ -1138,9 +1135,7 @@ class Node {
       _invalidate(InvalidatedReasonKind.buildKeyChanged);
       _dirty = true;
     }
-    final Set<String> currentOutputPaths = <String>{
-      for (final File file in outputs) file.path,
-    };
+    final Set<String> currentOutputPaths = <String>{for (final File file in outputs) file.path};
     // For each input, first determine if we've already computed the key
     // for it. Then collect it to be sent off for diffing as a group.
     final List<File> sourcesToDiff = <File>[];
@@ -1227,6 +1222,7 @@ class InvalidatedReason {
   InvalidatedReason(this.kind);
 
   final InvalidatedReasonKind kind;
+
   /// Absolute file paths of inputs or outputs, depending on [kind].
   final List<String> data = <String>[];
 
@@ -1234,10 +1230,14 @@ class InvalidatedReason {
   String toString() {
     return switch (kind) {
       InvalidatedReasonKind.inputMissing => 'The following inputs were missing: ${data.join(',')}',
-      InvalidatedReasonKind.inputChanged => 'The following inputs have updated contents: ${data.join(',')}',
-      InvalidatedReasonKind.outputChanged => 'The following outputs have updated contents: ${data.join(',')}',
-      InvalidatedReasonKind.outputMissing => 'The following outputs were missing: ${data.join(',')}',
-      InvalidatedReasonKind.outputSetChanged => 'The following outputs were removed from the output set: ${data.join(',')}',
+      InvalidatedReasonKind.inputChanged =>
+        'The following inputs have updated contents: ${data.join(',')}',
+      InvalidatedReasonKind.outputChanged =>
+        'The following outputs have updated contents: ${data.join(',')}',
+      InvalidatedReasonKind.outputMissing =>
+        'The following outputs were missing: ${data.join(',')}',
+      InvalidatedReasonKind.outputSetChanged =>
+        'The following outputs were removed from the output set: ${data.join(',')}',
       InvalidatedReasonKind.buildKeyChanged => 'The target build key changed.',
     };
   }
