@@ -50,17 +50,20 @@ class BuildWindowsCommand extends BuildSubCommand {
   Future<FlutterCommandResult> runCommand() async {
     final BuildInfo buildInfo = await getBuildInfo();
     if (!featureFlags.isWindowsEnabled) {
-      throwToolExit('"build windows" is not currently supported. To enable, run "flutter config --enable-windows-desktop".');
+      throwToolExit(
+        '"build windows" is not currently supported. To enable, run "flutter config --enable-windows-desktop".',
+      );
     }
     if (!globals.platform.isWindows) {
       throwToolExit('"build windows" only supported on Windows hosts.');
     }
 
-    final String defaultTargetPlatform = (_operatingSystemUtils.hostPlatform == HostPlatform.windows_arm64) ?
-            'windows-arm64' : 'windows-x64';
+    final String defaultTargetPlatform =
+        (_operatingSystemUtils.hostPlatform == HostPlatform.windows_arm64)
+            ? 'windows-arm64'
+            : 'windows-x64';
     final TargetPlatform targetPlatform = getTargetPlatformForName(defaultTargetPlatform);
 
-    displayNullSafetyMode(buildInfo);
     await buildWindows(
       project.windows,
       buildInfo,
@@ -71,7 +74,6 @@ class BuildWindowsCommand extends BuildSubCommand {
         fileSystem: globals.fs,
         logger: globals.logger,
         appFilenamePattern: 'app.so',
-        flutterUsage: globals.flutterUsage,
         analytics: analytics,
       ),
     );
