@@ -3,29 +3,49 @@
 // found in the LICENSE file.
 
 import '../base/common.dart';
+import '../base/process.dart';
 import '../cache.dart';
 import '../globals.dart' as globals;
 import '../runner/flutter_command.dart';
+import '../runner/flutter_command_runner.dart';
 import '../version.dart';
 
+import 'upgrade.dart' show precacheArtifacts;
+
 class ChannelCommand extends FlutterCommand {
-  ChannelCommand({ bool verboseHelp = false }) {
+  ChannelCommand({bool verboseHelp = false}) {
     argParser.addFlag(
       'all',
       abbr: 'a',
       help: 'Include all the available branches (including local branches) when listing channels.',
       hide: !verboseHelp,
     );
+    argParser.addFlag(
+      'cache-artifacts',
+      help:
+          'After switching channels, download all required binary artifacts. '
+          'This is the equivalent of running "flutter precache" with the "--all-platforms" flag.',
+      defaultsTo: true,
+    );
   }
 
   @override
-  final String name = 'channel';
+  String get name => 'channel';
 
   @override
-  final String description = 'List or switch Flutter channels.';
+  String get description =>
+      'List or switch Flutter channels.\n'
+      '\n'
+      'Common commands:\n'
+      '\n'
+      ' flutter channel\n'
+      '   List Flutter channels.\n'
+      '\n'
+      ' flutter channel main\n'
+      "   Switch to Flutter's main channel.";
 
   @override
-  final String category = FlutterCommandCategory.sdk;
+  String get category => FlutterCommandCategory.sdk;
 
   @override
   String get invocation => '${runner?.executableName} $name [<channel-name>]';
@@ -40,26 +60,30 @@ class ChannelCommand extends FlutterCommand {
       case 0:
         await _listChannels(
           showAll: boolArg('all'),
-          verbose: globalResults?['verbose'] == true,
+          verbose: globalResults?[FlutterGlobalOptions.kVerboseFlag] == true,
         );
         return FlutterCommandResult.success();
       case 1:
         await _switchChannel(rest[0]);
         return FlutterCommandResult.success();
       default:
-        throw ToolExit('Too many arguments.\n$usage');
+        throwToolExit('Too many arguments.\n$usage');
     }
   }
 
-  Future<void> _listChannels({ required bool showAll, required bool verbose }) async {
+  Future<void> _listChannels({required bool showAll, required bool verbose}) async {
     // Beware: currentBranch could contain PII. See getBranchName().
-    final String currentChannel = globals.flutterVersion.channel;
+    final String currentChannel = globals.flutterVersion.channel; // limited to known branch names
+    assert(
+      kOfficialChannels.contains(currentChannel) ||
+          kObsoleteBranches.containsKey(currentChannel) ||
+          currentChannel == kUserBranch,
+      'potential PII leak in channel name: "$currentChannel"',
+    );
     final String currentBranch = globals.flutterVersion.getBranchName();
     final Set<String> seenUnofficialChannels = <String>{};
     final List<String> rawOutput = <String>[];
 
-    showAll = showAll || currentChannel != currentBranch;
-
     globals.printStatus('Flutter channels:');
     final int result = await globals.processUtils.stream(
       <String>['git', 'branch', '-r'],
@@ -74,8 +98,7 @@ class ChannelCommand extends FlutterCommand {
       throwToolExit('List channels failed: $result$details', exitCode: result);
     }
 
-    final List<String> officialChannels = kOfficialChannels.toList();
-    final List<bool> availableChannels = List<bool>.filled(officialChannels.length, false);
+    final Set<String> availableChannels = <String>{};
 
     for (final String line in rawOutput) {
       final List<String> split = line.split('/');
@@ -84,27 +107,25 @@ class ChannelCommand extends FlutterCommand {
         continue;
       }
       final String branch = split[1];
-      if (split.length > 1) {
-        final int index = officialChannels.indexOf(branch);
-
-        if (index != -1) { // Mark all available channels official channels from output
-          availableChannels[index] = true;
-        } else if (showAll && !seenUnofficialChannels.contains(branch)) {
-        // add other branches to seenUnofficialChannels if --all flag is given (to print later)
-          seenUnofficialChannels.add(branch);
-        }
+      if (kOfficialChannels.contains(branch)) {
+        availableChannels.add(branch);
+      } else if (showAll) {
+        seenUnofficialChannels.add(branch);
       }
     }
 
+    bool currentChannelIsOfficial = false;
+
     // print all available official channels in sorted manner
-    for (int i = 0; i < officialChannels.length; i++) {
+    for (final String channel in kOfficialChannels) {
       // only print non-missing channels
-      if (availableChannels[i]) {
+      if (availableChannels.contains(channel)) {
         String currentIndicator = ' ';
-        if (officialChannels[i] == currentChannel) {
+        if (channel == currentChannel) {
           currentIndicator = '*';
+          currentChannelIsOfficial = true;
         }
-        globals.printStatus('$currentIndicator ${officialChannels[i]}');
+        globals.printStatus('$currentIndicator $channel (${kChannelDescriptions[channel]})');
       }
     }
 
@@ -117,9 +138,15 @@ class ChannelCommand extends FlutterCommand {
           globals.printStatus('  $branch');
         }
       }
+    } else if (!currentChannelIsOfficial) {
+      globals.printStatus('* $currentBranch');
     }
 
-    if (currentChannel == 'unknown') {
+    if (!currentChannelIsOfficial) {
+      assert(
+        currentChannel == kUserBranch,
+        'Current channel is "$currentChannel", which is not an official branch. (Current branch is "$currentBranch".)',
+      );
       globals.printStatus('');
       globals.printStatus('Currently not on an official channel.');
     }
@@ -129,13 +156,22 @@ class ChannelCommand extends FlutterCommand {
     globals.printStatus("Switching to flutter channel '$branchName'...");
     if (kObsoleteBranches.containsKey(branchName)) {
       final String alternative = kObsoleteBranches[branchName]!;
-      globals.printStatus("This channel is obsolete. Consider switching to the '$alternative' channel instead.");
+      globals.printStatus(
+        "This channel is obsolete. Consider switching to the '$alternative' channel instead.",
+      );
     } else if (!kOfficialChannels.contains(branchName)) {
-      globals.printStatus('This is not an official channel. For a list of available channels, try "flutter channel".');
+      globals.printStatus(
+        'This is not an official channel. For a list of available channels, try "flutter channel".',
+      );
     }
     await _checkout(branchName);
+    if (boolArg('cache-artifacts')) {
+      await precacheArtifacts(Cache.flutterRoot);
+    }
     globals.printStatus("Successfully switched to flutter channel '$branchName'.");
-    globals.printStatus("To ensure that you're on the latest build from this channel, run 'flutter upgrade'");
+    globals.printStatus(
+      "To ensure that you're on the latest build from this channel, run 'flutter upgrade'",
+    );
   }
 
   static Future<void> upgradeChannel(FlutterVersion currentVersion) async {
@@ -149,36 +185,44 @@ class ChannelCommand extends FlutterCommand {
 
   static Future<void> _checkout(String branchName) async {
     // Get latest refs from upstream.
-    int result = await globals.processUtils.stream(
-      <String>['git', 'fetch'],
-      workingDirectory: Cache.flutterRoot,
-      prefix: 'git: ',
-    );
+    RunResult runResult = await globals.processUtils.run(<String>[
+      'git',
+      'fetch',
+    ], workingDirectory: Cache.flutterRoot);
 
-    if (result == 0) {
-      result = await globals.processUtils.stream(
-        <String>['git', 'show-ref', '--verify', '--quiet', 'refs/heads/$branchName'],
-        workingDirectory: Cache.flutterRoot,
-        prefix: 'git: ',
-      );
-      if (result == 0) {
+    if (runResult.processResult.exitCode == 0) {
+      runResult = await globals.processUtils.run(<String>[
+        'git',
+        'show-ref',
+        '--verify',
+        '--quiet',
+        'refs/heads/$branchName',
+      ], workingDirectory: Cache.flutterRoot);
+      if (runResult.processResult.exitCode == 0) {
         // branch already exists, try just switching to it
-        result = await globals.processUtils.stream(
-          <String>['git', 'checkout', branchName, '--'],
-          workingDirectory: Cache.flutterRoot,
-          prefix: 'git: ',
-        );
+        runResult = await globals.processUtils.run(<String>[
+          'git',
+          'checkout',
+          branchName,
+          '--',
+        ], workingDirectory: Cache.flutterRoot);
       } else {
         // branch does not exist, we have to create it
-        result = await globals.processUtils.stream(
-          <String>['git', 'checkout', '--track', '-b', branchName, 'origin/$branchName'],
-          workingDirectory: Cache.flutterRoot,
-          prefix: 'git: ',
-        );
+        runResult = await globals.processUtils.run(<String>[
+          'git',
+          'checkout',
+          '--track',
+          '-b',
+          branchName,
+          'origin/$branchName',
+        ], workingDirectory: Cache.flutterRoot);
       }
     }
-    if (result != 0) {
-      throwToolExit('Switching channels failed with error code $result.', exitCode: result);
+    if (runResult.processResult.exitCode != 0) {
+      throwToolExit(
+        'Switching channels failed\n$runResult.',
+        exitCode: runResult.processResult.exitCode,
+      );
     } else {
       // Remove the version check stamp, since it could contain out-of-date
       // information that pertains to the previous channel.
