@@ -38,11 +38,11 @@ bool _regexesEqual(RegExp? a, RegExp? b) {
     return false;
   }
 
-  return a.pattern == b.pattern
-    && a.isMultiLine == b.isMultiLine
-    && a.isCaseSensitive == b.isCaseSensitive
-    && a.isUnicode == b.isUnicode
-    && a.isDotAll == b.isDotAll;
+  return a.pattern == b.pattern &&
+      a.isMultiLine == b.isMultiLine &&
+      a.isCaseSensitive == b.isCaseSensitive &&
+      a.isUnicode == b.isUnicode &&
+      a.isDotAll == b.isDotAll;
 }
 
 /// Something went wrong while trying to load the custom devices config from the
@@ -54,7 +54,7 @@ class CustomDeviceRevivalException implements Exception {
 
   const CustomDeviceRevivalException.fromDescriptions(
     String fieldDescription,
-    String expectedValueDescription
+    String expectedValueDescription,
   ) : message = 'Expected $fieldDescription to be $expectedValueDescription.';
 
   final String message;
@@ -66,8 +66,7 @@ class CustomDeviceRevivalException implements Exception {
 
   @override
   bool operator ==(Object other) {
-    return (other is CustomDeviceRevivalException) &&
-        (other.message == message);
+    return (other is CustomDeviceRevivalException) && (other.message == message);
   }
 
   @override
@@ -94,12 +93,12 @@ class CustomDeviceConfig {
     required this.runDebugCommand,
     this.forwardPortCommand,
     this.forwardPortSuccessRegex,
-    this.screenshotCommand
+    this.screenshotCommand,
   }) : assert(forwardPortCommand == null || forwardPortSuccessRegex != null),
        assert(
-         platform == null
-         || platform == TargetPlatform.linux_x64
-         || platform == TargetPlatform.linux_arm64
+         platform == null ||
+             platform == TargetPlatform.linux_x64 ||
+             platform == TargetPlatform.linux_arm64,
        );
 
   /// Create a CustomDeviceConfig from some JSON value.
@@ -111,67 +110,74 @@ class CustomDeviceConfig {
     final Map<String, dynamic> typedMap = _castJsonObject(
       json,
       'device configuration',
-      'a JSON object'
+      'a JSON object',
     );
 
     final List<String>? forwardPortCommand = _castStringListOrNull(
       typedMap[_kForwardPortCommand],
       _kForwardPortCommand,
       'null or array of strings with at least one element',
-      minLength: 1
+      minLength: 1,
     );
 
     final RegExp? forwardPortSuccessRegex = _convertToRegexOrNull(
       typedMap[_kForwardPortSuccessRegex],
       _kForwardPortSuccessRegex,
-      'null or string-ified regex'
+      'null or string-ified regex',
     );
 
     final String? archString = _castStringOrNull(
       typedMap[_kPlatform],
       _kPlatform,
-      'null or one of linux-arm64, linux-x64'
+      'null or one of linux-arm64, linux-x64',
     );
 
     late TargetPlatform? platform;
     try {
-      platform = archString == null
-        ? null
-        : getTargetPlatformForName(archString);
-    } on FallThroughError {
+      platform = archString == null ? null : getTargetPlatformForName(archString);
+    } on UnsupportedError {
       throw const CustomDeviceRevivalException.fromDescriptions(
         _kPlatform,
-        'null or one of linux-arm64, linux-x64'
+        'null or one of linux-arm64, linux-x64',
       );
     }
 
-    if (platform != null
-        && platform != TargetPlatform.linux_arm64
-        && platform != TargetPlatform.linux_x64
-    ) {
+    if (platform != null &&
+        platform != TargetPlatform.linux_arm64 &&
+        platform != TargetPlatform.linux_x64) {
       throw const CustomDeviceRevivalException.fromDescriptions(
         _kPlatform,
-        'null or one of linux-arm64, linux-x64'
+        'null or one of linux-arm64, linux-x64',
       );
     }
 
     if (forwardPortCommand != null && forwardPortSuccessRegex == null) {
-      throw const CustomDeviceRevivalException('When forwardPort is given, forwardPortSuccessRegex must be specified too.');
+      throw const CustomDeviceRevivalException(
+        'When forwardPort is given, forwardPortSuccessRegex must be specified too.',
+      );
     }
 
     return CustomDeviceConfig(
       id: _castString(typedMap[_kId], _kId, 'a string'),
       label: _castString(typedMap[_kLabel], _kLabel, 'a string'),
-      sdkNameAndVersion: _castString(typedMap[_kSdkNameAndVersion], _kSdkNameAndVersion, 'a string'),
+      sdkNameAndVersion: _castString(
+        typedMap[_kSdkNameAndVersion],
+        _kSdkNameAndVersion,
+        'a string',
+      ),
       platform: platform,
       enabled: _castBool(typedMap[_kEnabled], _kEnabled, 'a boolean'),
       pingCommand: _castStringList(
         typedMap[_kPingCommand],
         _kPingCommand,
         'array of strings with at least one element',
-        minLength: 1
+        minLength: 1,
+      ),
+      pingSuccessRegex: _convertToRegexOrNull(
+        typedMap[_kPingSuccessRegex],
+        _kPingSuccessRegex,
+        'null or string-ified regex',
       ),
-      pingSuccessRegex: _convertToRegexOrNull(typedMap[_kPingSuccessRegex], _kPingSuccessRegex, 'null or string-ified regex'),
       postBuildCommand: _castStringListOrNull(
         typedMap[_kPostBuildCommand],
         _kPostBuildCommand,
@@ -182,19 +188,19 @@ class CustomDeviceConfig {
         typedMap[_kInstallCommand],
         _kInstallCommand,
         'array of strings with at least one element',
-        minLength: 1
+        minLength: 1,
       ),
       uninstallCommand: _castStringList(
         typedMap[_kUninstallCommand],
         _kUninstallCommand,
         'array of strings with at least one element',
-        minLength: 1
+        minLength: 1,
       ),
       runDebugCommand: _castStringList(
         typedMap[_kRunDebugCommand],
         _kRunDebugCommand,
         'array of strings with at least one element',
-        minLength: 1
+        minLength: 1,
       ),
       forwardPortCommand: forwardPortCommand,
       forwardPortSuccessRegex: forwardPortSuccessRegex,
@@ -202,8 +208,8 @@ class CustomDeviceConfig {
         typedMap[_kScreenshotCommand],
         _kScreenshotCommand,
         'array of strings with at least one element',
-        minLength: 1
-      )
+        minLength: 1,
+      ),
     );
   }
 
@@ -231,45 +237,47 @@ class CustomDeviceConfig {
     sdkNameAndVersion: 'Raspberry Pi 4 Model B+',
     platform: TargetPlatform.linux_arm64,
     enabled: false,
-    pingCommand: const <String>[
-      'ping',
-      '-w', '500',
-      '-n', '1',
-      'raspberrypi',
-    ],
+    pingCommand: const <String>['ping', '-w', '500', '-n', '1', 'raspberrypi'],
     pingSuccessRegex: RegExp(r'[<=]\d+ms'),
     postBuildCommand: null,
     installCommand: const <String>[
       'scp',
       '-r',
-      '-o', 'BatchMode=yes',
+      '-o',
+      'BatchMode=yes',
       r'${localPath}',
       r'pi@raspberrypi:/tmp/${appName}',
     ],
     uninstallCommand: const <String>[
       'ssh',
-      '-o', 'BatchMode=yes',
+      '-o',
+      'BatchMode=yes',
       'pi@raspberrypi',
       r'rm -rf "/tmp/${appName}"',
     ],
     runDebugCommand: const <String>[
       'ssh',
-      '-o', 'BatchMode=yes',
+      '-o',
+      'BatchMode=yes',
       'pi@raspberrypi',
       r'flutter-pi "/tmp/${appName}"',
     ],
     forwardPortCommand: const <String>[
       'ssh',
-      '-o', 'BatchMode=yes',
-      '-o', 'ExitOnForwardFailure=yes',
-      '-L', r'127.0.0.1:${hostPort}:127.0.0.1:${devicePort}',
+      '-o',
+      'BatchMode=yes',
+      '-o',
+      'ExitOnForwardFailure=yes',
+      '-L',
+      r'127.0.0.1:${hostPort}:127.0.0.1:${devicePort}',
       'pi@raspberrypi',
       "echo 'Port forwarding success'; read",
     ],
     forwardPortSuccessRegex: RegExp('Port forwarding success'),
     screenshotCommand: const <String>[
       'ssh',
-      '-o', 'BatchMode=yes',
+      '-o',
+      'BatchMode=yes',
       'pi@raspberrypi',
       r"fbgrab /tmp/screenshot.png && cat /tmp/screenshot.png | base64 | tr -d ' \n\t'",
     ],
@@ -279,13 +287,8 @@ class CustomDeviceConfig {
   /// Uses ping and pingSuccessRegex values that only work on linux or macOs.
   /// For the Windows example config, see [exampleWindows].
   static final CustomDeviceConfig exampleUnix = exampleWindows.copyWith(
-    pingCommand: const <String>[
-      'ping',
-      '-w', '1',
-      '-c', '1',
-      'raspberrypi'
-    ],
-    explicitPingSuccessRegex: true
+    pingCommand: const <String>['ping', '-w', '1', '-c', '1', 'raspberrypi'],
+    explicitPingSuccessRegex: true,
   );
 
   /// Returns an example custom device config that works on the given host platform.
@@ -300,7 +303,7 @@ class CustomDeviceConfig {
     if (platform.isLinux || platform.isMacOS) {
       return exampleUnix;
     }
-    throw FallThroughError();
+    throw UnsupportedError('Unsupported operating system');
   }
 
   final String id;
@@ -331,11 +334,18 @@ class CustomDeviceConfig {
   /// If anything at all is thrown when executing the closure, a
   /// [CustomDeviceRevivalException] is thrown with the given [fieldDescription] and
   /// [expectedValueDescription].
-  static T _maybeRethrowAsRevivalException<T>(T Function() closure, String fieldDescription, String expectedValueDescription) {
+  static T _maybeRethrowAsRevivalException<T>(
+    T Function() closure,
+    String fieldDescription,
+    String expectedValueDescription,
+  ) {
     try {
       return closure();
     } on Object {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
   }
 
@@ -343,9 +353,16 @@ class CustomDeviceConfig {
   ///
   /// If the value is null or not a valid string-keyed map, a [CustomDeviceRevivalException]
   /// with the given [fieldDescription] and [expectedValueDescription] is thrown.
-  static Map<String, dynamic> _castJsonObject(dynamic value, String fieldDescription, String expectedValueDescription) {
+  static Map<String, dynamic> _castJsonObject(
+    dynamic value,
+    String fieldDescription,
+    String expectedValueDescription,
+  ) {
     if (value == null) {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
 
     return _maybeRethrowAsRevivalException(
@@ -361,7 +378,10 @@ class CustomDeviceConfig {
   /// [fieldDescription] and [expectedValueDescription] is thrown.
   static bool _castBool(dynamic value, String fieldDescription, String expectedValueDescription) {
     if (value == null) {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
 
     return _maybeRethrowAsRevivalException(
@@ -375,9 +395,16 @@ class CustomDeviceConfig {
   ///
   /// If the value is null or not a String, a [CustomDeviceRevivalException] with the given
   /// [fieldDescription] and [expectedValueDescription] is thrown.
-  static String _castString(dynamic value, String fieldDescription, String expectedValueDescription) {
+  static String _castString(
+    dynamic value,
+    String fieldDescription,
+    String expectedValueDescription,
+  ) {
     if (value == null) {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
 
     return _maybeRethrowAsRevivalException(
@@ -391,7 +418,11 @@ class CustomDeviceConfig {
   ///
   /// If the value not null and not a String, a [CustomDeviceRevivalException] with the given
   /// [fieldDescription] and [expectedValueDescription] is thrown.
-  static String? _castStringOrNull(dynamic value, String fieldDescription, String expectedValueDescription) {
+  static String? _castStringOrNull(
+    dynamic value,
+    String fieldDescription,
+    String expectedValueDescription,
+  ) {
     if (value == null) {
       return null;
     }
@@ -411,7 +442,10 @@ class CustomDeviceConfig {
     int minLength = 0,
   }) {
     if (value == null) {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
 
     final List<String> list = _maybeRethrowAsRevivalException(
@@ -421,7 +455,10 @@ class CustomDeviceConfig {
     );
 
     if (list.length < minLength) {
-      throw CustomDeviceRevivalException.fromDescriptions(fieldDescription, expectedValueDescription);
+      throw CustomDeviceRevivalException.fromDescriptions(
+        fieldDescription,
+        expectedValueDescription,
+      );
     }
 
     return list;
@@ -452,7 +489,11 @@ class CustomDeviceConfig {
   /// If the value is not null and not a valid string-ified regex,
   /// a [CustomDeviceRevivalException] with the given [fieldDescription] and
   /// [expectedValueDescription] is thrown.
-  static RegExp? _convertToRegexOrNull(dynamic value, String fieldDescription, String expectedValueDescription) {
+  static RegExp? _convertToRegexOrNull(
+    dynamic value,
+    String fieldDescription,
+    String expectedValueDescription,
+  ) {
     if (value == null) {
       return null;
     }
@@ -503,7 +544,7 @@ class CustomDeviceConfig {
     bool explicitForwardPortSuccessRegex = false,
     RegExp? forwardPortSuccessRegex,
     bool explicitScreenshotCommand = false,
-    List<String>? screenshotCommand
+    List<String>? screenshotCommand,
   }) {
     return CustomDeviceConfig(
       id: id ?? this.id,
@@ -512,70 +553,81 @@ class CustomDeviceConfig {
       platform: explicitPlatform ? platform : (platform ?? this.platform),
       enabled: enabled ?? this.enabled,
       pingCommand: pingCommand ?? this.pingCommand,
-      pingSuccessRegex: explicitPingSuccessRegex ? pingSuccessRegex : (pingSuccessRegex ?? this.pingSuccessRegex),
-      postBuildCommand: explicitPostBuildCommand ? postBuildCommand : (postBuildCommand ?? this.postBuildCommand),
+      pingSuccessRegex:
+          explicitPingSuccessRegex ? pingSuccessRegex : (pingSuccessRegex ?? this.pingSuccessRegex),
+      postBuildCommand:
+          explicitPostBuildCommand ? postBuildCommand : (postBuildCommand ?? this.postBuildCommand),
       installCommand: installCommand ?? this.installCommand,
       uninstallCommand: uninstallCommand ?? this.uninstallCommand,
       runDebugCommand: runDebugCommand ?? this.runDebugCommand,
-      forwardPortCommand: explicitForwardPortCommand ? forwardPortCommand : (forwardPortCommand ?? this.forwardPortCommand),
-      forwardPortSuccessRegex: explicitForwardPortSuccessRegex ? forwardPortSuccessRegex : (forwardPortSuccessRegex ?? this.forwardPortSuccessRegex),
-      screenshotCommand: explicitScreenshotCommand ? screenshotCommand : (screenshotCommand ?? this.screenshotCommand),
+      forwardPortCommand:
+          explicitForwardPortCommand
+              ? forwardPortCommand
+              : (forwardPortCommand ?? this.forwardPortCommand),
+      forwardPortSuccessRegex:
+          explicitForwardPortSuccessRegex
+              ? forwardPortSuccessRegex
+              : (forwardPortSuccessRegex ?? this.forwardPortSuccessRegex),
+      screenshotCommand:
+          explicitScreenshotCommand
+              ? screenshotCommand
+              : (screenshotCommand ?? this.screenshotCommand),
     );
   }
 
   @override
   bool operator ==(Object other) {
-    return other is CustomDeviceConfig
-      && other.id == id
-      && other.label == label
-      && other.sdkNameAndVersion == sdkNameAndVersion
-      && other.platform == platform
-      && other.enabled == enabled
-      && _listsEqual(other.pingCommand, pingCommand)
-      && _regexesEqual(other.pingSuccessRegex, pingSuccessRegex)
-      && _listsEqual(other.postBuildCommand, postBuildCommand)
-      && _listsEqual(other.installCommand, installCommand)
-      && _listsEqual(other.uninstallCommand, uninstallCommand)
-      && _listsEqual(other.runDebugCommand, runDebugCommand)
-      && _listsEqual(other.forwardPortCommand, forwardPortCommand)
-      && _regexesEqual(other.forwardPortSuccessRegex, forwardPortSuccessRegex)
-      && _listsEqual(other.screenshotCommand, screenshotCommand);
+    return other is CustomDeviceConfig &&
+        other.id == id &&
+        other.label == label &&
+        other.sdkNameAndVersion == sdkNameAndVersion &&
+        other.platform == platform &&
+        other.enabled == enabled &&
+        _listsEqual(other.pingCommand, pingCommand) &&
+        _regexesEqual(other.pingSuccessRegex, pingSuccessRegex) &&
+        _listsEqual(other.postBuildCommand, postBuildCommand) &&
+        _listsEqual(other.installCommand, installCommand) &&
+        _listsEqual(other.uninstallCommand, uninstallCommand) &&
+        _listsEqual(other.runDebugCommand, runDebugCommand) &&
+        _listsEqual(other.forwardPortCommand, forwardPortCommand) &&
+        _regexesEqual(other.forwardPortSuccessRegex, forwardPortSuccessRegex) &&
+        _listsEqual(other.screenshotCommand, screenshotCommand);
   }
 
   @override
   int get hashCode {
-    return id.hashCode
-      ^ label.hashCode
-      ^ sdkNameAndVersion.hashCode
-      ^ platform.hashCode
-      ^ enabled.hashCode
-      ^ pingCommand.hashCode
-      ^ (pingSuccessRegex?.pattern).hashCode
-      ^ postBuildCommand.hashCode
-      ^ installCommand.hashCode
-      ^ uninstallCommand.hashCode
-      ^ runDebugCommand.hashCode
-      ^ forwardPortCommand.hashCode
-      ^ (forwardPortSuccessRegex?.pattern).hashCode
-      ^ screenshotCommand.hashCode;
+    return id.hashCode ^
+        label.hashCode ^
+        sdkNameAndVersion.hashCode ^
+        platform.hashCode ^
+        enabled.hashCode ^
+        pingCommand.hashCode ^
+        (pingSuccessRegex?.pattern).hashCode ^
+        postBuildCommand.hashCode ^
+        installCommand.hashCode ^
+        uninstallCommand.hashCode ^
+        runDebugCommand.hashCode ^
+        forwardPortCommand.hashCode ^
+        (forwardPortSuccessRegex?.pattern).hashCode ^
+        screenshotCommand.hashCode;
   }
 
   @override
   String toString() {
     return 'CustomDeviceConfig('
-      'id: $id, '
-      'label: $label, '
-      'sdkNameAndVersion: $sdkNameAndVersion, '
-      'platform: $platform, '
-      'enabled: $enabled, '
-      'pingCommand: $pingCommand, '
-      'pingSuccessRegex: $pingSuccessRegex, '
-      'postBuildCommand: $postBuildCommand, '
-      'installCommand: $installCommand, '
-      'uninstallCommand: $uninstallCommand, '
-      'runDebugCommand: $runDebugCommand, '
-      'forwardPortCommand: $forwardPortCommand, '
-      'forwardPortSuccessRegex: $forwardPortSuccessRegex, '
-      'screenshotCommand: $screenshotCommand)';
+        'id: $id, '
+        'label: $label, '
+        'sdkNameAndVersion: $sdkNameAndVersion, '
+        'platform: $platform, '
+        'enabled: $enabled, '
+        'pingCommand: $pingCommand, '
+        'pingSuccessRegex: $pingSuccessRegex, '
+        'postBuildCommand: $postBuildCommand, '
+        'installCommand: $installCommand, '
+        'uninstallCommand: $uninstallCommand, '
+        'runDebugCommand: $runDebugCommand, '
+        'forwardPortCommand: $forwardPortCommand, '
+        'forwardPortSuccessRegex: $forwardPortSuccessRegex, '
+        'screenshotCommand: $screenshotCommand)';
   }
 }
