@@ -37,11 +37,7 @@ enum Category {
   String toString() => value;
 
   static Category? fromString(String category) {
-    return const <String, Category>{
-      'web': web,
-      'desktop': desktop,
-      'mobile': mobile,
-    }[category];
+    return const <String, Category>{'web': web, 'desktop': desktop, 'mobile': mobile}[category];
   }
 }
 
@@ -54,8 +50,7 @@ enum PlatformType {
   macos,
   windows,
   fuchsia,
-  custom,
-  windowsPreview;
+  custom;
 
   @override
   String toString() => name;
@@ -65,9 +60,7 @@ enum PlatformType {
 
 /// A discovery mechanism for flutter-supported development devices.
 abstract class DeviceManager {
-  DeviceManager({
-    required Logger logger,
-  }) : _logger = logger;
+  DeviceManager({required Logger logger}) : _logger = logger;
 
   final Logger _logger;
 
@@ -90,9 +83,7 @@ abstract class DeviceManager {
   }
 
   /// A minimum duration to use when discovering wireless iOS devices.
-  static const Duration minimumWirelessDeviceDiscoveryTimeout = Duration(
-    seconds: 5,
-  );
+  static const Duration minimumWirelessDeviceDiscoveryTimeout = Duration(seconds: 5);
 
   /// True when the user has specified a single specific device.
   bool get hasSpecifiedDeviceId => specifiedDeviceId != null;
@@ -108,16 +99,12 @@ abstract class DeviceManager {
   ///
   /// If an exact match is found, return it immediately. Otherwise wait for all
   /// discoverers to complete and return any partial matches.
-  Future<List<Device>> getDevicesById(
-    String deviceId, {
-    DeviceDiscoveryFilter? filter,
-  }) async {
+  Future<List<Device>> getDevicesById(String deviceId, {DeviceDiscoveryFilter? filter}) async {
     filter ??= DeviceDiscoveryFilter();
 
     final String lowerDeviceId = deviceId.toLowerCase();
     bool exactlyMatchesDeviceId(Device device) =>
-        device.id.toLowerCase() == lowerDeviceId ||
-        device.name.toLowerCase() == lowerDeviceId;
+        device.id.toLowerCase() == lowerDeviceId || device.name.toLowerCase() == lowerDeviceId;
     bool startsWithDeviceId(Device device) =>
         device.id.toLowerCase().startsWith(lowerDeviceId) ||
         device.name.toLowerCase().startsWith(lowerDeviceId);
@@ -125,9 +112,8 @@ abstract class DeviceManager {
     // Some discoverers have hard-coded device IDs and return quickly, and others
     // shell out to other processes and can take longer.
     // If an ID was specified, first check if it was a "well-known" device id.
-    final Set<String> wellKnownIds = _platformDiscoverers
-      .expand((DeviceDiscovery discovery) => discovery.wellKnownIds)
-      .toSet();
+    final Set<String> wellKnownIds =
+        _platformDiscoverers.expand((DeviceDiscovery discovery) => discovery.wellKnownIds).toSet();
     final bool hasWellKnownId = hasSpecifiedDeviceId && wellKnownIds.contains(specifiedDeviceId);
 
     // Process discoverers as they can return results, so if an exact match is
@@ -138,22 +124,25 @@ abstract class DeviceManager {
       for (final DeviceDiscovery discoverer in _platformDiscoverers)
         if (!hasWellKnownId || discoverer.wellKnownIds.contains(specifiedDeviceId))
           discoverer
-          .devices(filter: filter)
-          .then((List<Device> devices) {
-            for (final Device device in devices) {
-              if (exactlyMatchesDeviceId(device)) {
-                exactMatchCompleter.complete(device);
-                return null;
-              }
-              if (startsWithDeviceId(device)) {
-                prefixMatches.add(device);
-              }
-            }
-            return null;
-          }, onError: (dynamic error, StackTrace stackTrace) {
-            // Return matches from other discoverers even if one fails.
-            _logger.printTrace('Ignored error discovering $deviceId: $error');
-          }),
+              .devices(filter: filter)
+              .then(
+                (List<Device> devices) {
+                  for (final Device device in devices) {
+                    if (exactlyMatchesDeviceId(device)) {
+                      exactMatchCompleter.complete(device);
+                      return null;
+                    }
+                    if (startsWithDeviceId(device)) {
+                      prefixMatches.add(device);
+                    }
+                  }
+                  return null;
+                },
+                onError: (dynamic error, StackTrace stackTrace) {
+                  // Return matches from other discoverers even if one fails.
+                  _logger.printTrace('Ignored error discovering $deviceId: $error');
+                },
+              ),
     ];
 
     // Wait for an exact match, or for all discoverers to return results.
@@ -173,9 +162,7 @@ abstract class DeviceManager {
   ///
   /// If [filter] is not provided, a default filter that requires devices to be
   /// connected will be used.
-  Future<List<Device>> getDevices({
-    DeviceDiscoveryFilter? filter,
-  }) {
+  Future<List<Device>> getDevices({DeviceDiscoveryFilter? filter}) {
     filter ??= DeviceDiscoveryFilter();
     final String? id = specifiedDeviceId;
     if (id == null) {
@@ -192,9 +179,7 @@ abstract class DeviceManager {
   ///
   /// If [filter] is not provided, a default filter that requires devices to be
   /// connected will be used.
-  Future<List<Device>> getAllDevices({
-    DeviceDiscoveryFilter? filter,
-  }) async {
+  Future<List<Device>> getAllDevices({DeviceDiscoveryFilter? filter}) async {
     filter ??= DeviceDiscoveryFilter();
     final List<List<Device>> devices = await Future.wait<List<Device>>(<Future<List<Device>>>[
       for (final DeviceDiscovery discoverer in _platformDiscoverers)
@@ -210,10 +195,7 @@ abstract class DeviceManager {
   /// connected will be used.
   ///
   /// Search for devices to populate the cache for no longer than [timeout].
-  Future<List<Device>> refreshAllDevices({
-    Duration? timeout,
-    DeviceDiscoveryFilter? filter,
-  }) async {
+  Future<List<Device>> refreshAllDevices({Duration? timeout, DeviceDiscoveryFilter? filter}) async {
     filter ??= DeviceDiscoveryFilter();
     final List<List<Device>> devices = await Future.wait<List<Device>>(<Future<List<Device>>>[
       for (final DeviceDiscovery discoverer in _platformDiscoverers)
@@ -235,7 +217,7 @@ abstract class DeviceManager {
     await Future.wait<List<Device>>(<Future<List<Device>>>[
       for (final DeviceDiscovery discoverer in _platformDiscoverers)
         if (discoverer.requiresExtendedWirelessDeviceDiscovery)
-          discoverer.discoverDevices(timeout: timeout)
+          discoverer.discoverDevices(timeout: timeout),
     ]);
   }
 
@@ -296,7 +278,7 @@ abstract class DeviceManager {
   ///
   /// Note: ephemeral is nullable for device types where this is not well
   /// defined.
-  Device? getSingleEphemeralDevice(List<Device> devices){
+  Device? getSingleEphemeralDevice(List<Device> devices) {
     if (!hasSpecifiedDeviceId) {
       try {
         return devices.singleWhere((Device device) => device.ephemeral);
@@ -312,9 +294,9 @@ abstract class DeviceManager {
 class DeviceDiscoverySupportFilter {
   /// Filter devices to only include those supported by Flutter.
   DeviceDiscoverySupportFilter.excludeDevicesUnsupportedByFlutter()
-      : _excludeDevicesNotSupportedByProject = false,
-        _excludeDevicesNotSupportedByAll = false,
-        _flutterProject = null;
+    : _excludeDevicesNotSupportedByProject = false,
+      _excludeDevicesNotSupportedByAll = false,
+      _flutterProject = null;
 
   /// Filter devices to only include those supported by Flutter and the
   /// provided [flutterProject].
@@ -323,9 +305,9 @@ class DeviceDiscoverySupportFilter {
   /// the project.
   DeviceDiscoverySupportFilter.excludeDevicesUnsupportedByFlutterOrProject({
     required FlutterProject? flutterProject,
-  })  : _flutterProject = flutterProject,
-        _excludeDevicesNotSupportedByProject = true,
-        _excludeDevicesNotSupportedByAll = false;
+  }) : _flutterProject = flutterProject,
+       _excludeDevicesNotSupportedByProject = true,
+       _excludeDevicesNotSupportedByAll = false;
 
   /// Filter devices to only include those supported by Flutter, the provided
   /// [flutterProject], and `--device all`.
@@ -334,9 +316,9 @@ class DeviceDiscoverySupportFilter {
   /// the project.
   DeviceDiscoverySupportFilter.excludeDevicesUnsupportedByFlutterOrProjectOrAll({
     required FlutterProject? flutterProject,
-  })  : _flutterProject = flutterProject,
-        _excludeDevicesNotSupportedByProject = true,
-        _excludeDevicesNotSupportedByAll = true;
+  }) : _flutterProject = flutterProject,
+       _excludeDevicesNotSupportedByProject = true,
+       _excludeDevicesNotSupportedByAll = true;
 
   final FlutterProject? _flutterProject;
   final bool _excludeDevicesNotSupportedByProject;
@@ -344,8 +326,10 @@ class DeviceDiscoverySupportFilter {
 
   Future<bool> matchesRequirements(Device device) async {
     final bool meetsSupportByFlutterRequirement = device.isSupported();
-    final bool meetsSupportForProjectRequirement = !_excludeDevicesNotSupportedByProject || isDeviceSupportedForProject(device);
-    final bool meetsSupportForAllRequirement = !_excludeDevicesNotSupportedByAll || await isDeviceSupportedForAll(device);
+    final bool meetsSupportForProjectRequirement =
+        !_excludeDevicesNotSupportedByProject || isDeviceSupportedForProject(device);
+    final bool meetsSupportForAllRequirement =
+        !_excludeDevicesNotSupportedByAll || await isDeviceSupportedForAll(device);
 
     return meetsSupportByFlutterRequirement &&
         meetsSupportForProjectRequirement &&
@@ -407,8 +391,12 @@ class DeviceDiscoveryFilter {
     final DeviceDiscoverySupportFilter? localSupportFilter = supportFilter;
 
     final bool meetsConnectionRequirement = !excludeDisconnected || device.isConnected;
-    final bool meetsSupportRequirements = localSupportFilter == null || (await localSupportFilter.matchesRequirements(device));
-    final bool meetsConnectionInterfaceRequirement = matchesDeviceConnectionInterface(device, deviceConnectionInterface);
+    final bool meetsSupportRequirements =
+        localSupportFilter == null || (await localSupportFilter.matchesRequirements(device));
+    final bool meetsConnectionInterfaceRequirement = matchesDeviceConnectionInterface(
+      device,
+      deviceConnectionInterface,
+    );
 
     return meetsConnectionRequirement &&
         meetsSupportRequirements &&
@@ -450,10 +438,7 @@ abstract class DeviceDiscovery {
   Future<List<Device>> devices({DeviceDiscoveryFilter? filter});
 
   /// Return all connected devices. Discards existing cache of devices.
-  Future<List<Device>> discoverDevices({
-    Duration? timeout,
-    DeviceDiscoveryFilter? filter,
-  });
+  Future<List<Device>> discoverDevices({Duration? timeout, DeviceDiscoveryFilter? filter});
 
   /// Gets a list of diagnostic messages pertaining to issues with any connected
   /// devices (will be an empty list if there are no issues).
@@ -527,10 +512,7 @@ abstract class PollingDeviceDiscovery extends DeviceDiscovery {
   ///
   /// If [filter] is null, it may return devices that are not connected.
   @override
-  Future<List<Device>> discoverDevices({
-    Duration? timeout,
-    DeviceDiscoveryFilter? filter,
-  }) {
+  Future<List<Device>> discoverDevices({Duration? timeout, DeviceDiscoveryFilter? filter}) {
     return _populateDevices(timeout: timeout, filter: filter, resetCache: true);
   }
 
@@ -575,10 +557,7 @@ abstract class PollingDeviceDiscovery extends DeviceDiscovery {
 }
 
 /// How a device is connected.
-enum DeviceConnectionInterface {
-  attached,
-  wireless,
-}
+enum DeviceConnectionInterface { attached, wireless }
 
 /// Returns the `DeviceConnectionInterface` enum based on its string name.
 DeviceConnectionInterface getDeviceConnectionInterfaceForName(String name) {
@@ -602,11 +581,13 @@ String getNameForDeviceConnectionInterface(DeviceConnectionInterface connectionI
 /// This may correspond to a connected iOS or Android device, or represent
 /// the host operating system in the case of Flutter Desktop.
 abstract class Device {
-  Device(this.id, {
+  Device(
+    this.id, {
+    required Logger logger,
     required this.category,
     required this.platformType,
     required this.ephemeral,
-  });
+  }) : dds = DartDevelopmentService(logger: logger);
 
   final String id;
 
@@ -621,14 +602,20 @@ abstract class Device {
 
   bool get isConnected => true;
 
-  DeviceConnectionInterface get connectionInterface =>
-      DeviceConnectionInterface.attached;
+  DeviceConnectionInterface get connectionInterface => DeviceConnectionInterface.attached;
 
-  bool get isWirelesslyConnected =>
-      connectionInterface == DeviceConnectionInterface.wireless;
+  bool get isWirelesslyConnected => connectionInterface == DeviceConnectionInterface.wireless;
 
   String get name;
 
+  String get displayName {
+    String result = name;
+    if (isWirelesslyConnected) {
+      result += ' (wireless)';
+    }
+    return result;
+  }
+
   bool get supportsStartPaused => true;
 
   /// Whether it is an emulated device running on localhost.
@@ -663,10 +650,7 @@ abstract class Device {
   /// Check if a version of the given app is already installed.
   ///
   /// Specify [userIdentifier] to check if installed for a particular user (Android only).
-  Future<bool> isAppInstalled(
-    ApplicationPackage app, {
-    String? userIdentifier,
-  });
+  Future<bool> isAppInstalled(ApplicationPackage app, {String? userIdentifier});
 
   /// Check if the latest build of the [app] is already installed.
   Future<bool> isLatestBuildInstalled(ApplicationPackage app);
@@ -674,19 +658,13 @@ abstract class Device {
   /// Install an app package on the current device.
   ///
   /// Specify [userIdentifier] to install for a particular user (Android only).
-  Future<bool> installApp(
-    ApplicationPackage app, {
-    String? userIdentifier,
-  });
+  Future<bool> installApp(ApplicationPackage app, {String? userIdentifier});
 
   /// Uninstall an app package from the current device.
   ///
   /// Specify [userIdentifier] to uninstall for a particular user,
   /// defaults to all users (Android only).
-  Future<bool> uninstallApp(
-    ApplicationPackage app, {
-    String? userIdentifier,
-  });
+  Future<bool> uninstallApp(ApplicationPackage app, {String? userIdentifier});
 
   /// Check if the device is supported by Flutter.
   bool isSupported();
@@ -709,10 +687,7 @@ abstract class Device {
   ///
   /// For example, the desktop device classes can use a writer which
   /// copies the files across the local file system.
-  DevFSWriter? createDevFSWriter(
-    ApplicationPackage? app,
-    String? userIdentifier,
-  ) {
+  DevFSWriter? createDevFSWriter(ApplicationPackage? app, String? userIdentifier) {
     return null;
   }
 
@@ -724,16 +699,13 @@ abstract class Device {
   /// If `includePastLogs` is true and the device type supports it, the log
   /// reader will also include log messages from before the invocation time.
   /// Defaults to false.
-  FutureOr<DeviceLogReader> getLogReader({
-    ApplicationPackage? app,
-    bool includePastLogs = false,
-  });
+  FutureOr<DeviceLogReader> getLogReader({ApplicationPackage? app, bool includePastLogs = false});
 
   /// Get the port forwarder for this device.
   DevicePortForwarder? get portForwarder;
 
   /// Get the DDS instance for this device.
-  final DartDevelopmentService dds = DartDevelopmentService();
+  final DartDevelopmentService dds;
 
   /// Clear the device's logs.
   void clearLogs();
@@ -757,15 +729,14 @@ abstract class Device {
     int? expectedHostPort,
     required bool ipv6,
     required Logger logger,
-  }) =>
-      LogScanningVMServiceDiscoveryForAttach(
-        Future<DeviceLogReader>.value(getLogReader()),
-        portForwarder: portForwarder,
-        devicePort: filterDevicePort,
-        hostPort: expectedHostPort,
-        ipv6: ipv6,
-        logger: logger,
-      );
+  }) => LogScanningVMServiceDiscoveryForAttach(
+    Future<DeviceLogReader>.value(getLogReader()),
+    portForwarder: portForwarder,
+    devicePort: filterDevicePort,
+    hostPort: expectedHostPort,
+    ipv6: ipv6,
+    logger: logger,
+  );
 
   /// Start an app package on the current device.
   ///
@@ -778,7 +749,6 @@ abstract class Device {
     required DebuggingOptions debuggingOptions,
     Map<String, Object?> platformArgs,
     bool prebuiltApplication = false,
-    bool ipv6 = false,
     String? userIdentifier,
   });
 
@@ -805,10 +775,7 @@ abstract class Device {
   /// Stop an app package on the current device.
   ///
   /// Specify [userIdentifier] to stop app installed to a profile (Android only).
-  Future<bool> stopApp(
-    ApplicationPackage? app, {
-    String? userIdentifier,
-  });
+  Future<bool> stopApp(ApplicationPackage? app, {String? userIdentifier});
 
   /// Query the current application memory usage..
   ///
@@ -832,8 +799,7 @@ abstract class Device {
     if (identical(this, other)) {
       return true;
     }
-    return other is Device
-        && other.id == id;
+    return other is Device && other.id == id;
   }
 
   @override
@@ -854,7 +820,7 @@ abstract class Device {
         supportIndicator += ' ($type)';
       }
       table.add(<String>[
-        '${device.name} (${device.category})',
+        '${device.displayName} (${device.category})',
         device.id,
         await device.targetPlatformDisplayName,
         '${await device.sdkNameAndVersion}$supportIndicator',
@@ -871,21 +837,25 @@ abstract class Device {
     // Join columns into lines of text
     return <String>[
       for (final List<String> row in table)
-        indices.map<String>((int i) => row[i].padRight(widths[i])).followedBy(<String>[row.last]).join(' • '),
+        indices
+            .map<String>((int i) => row[i].padRight(widths[i]))
+            .followedBy(<String>[row.last])
+            .join(' • '),
     ];
   }
 
-  static Future<void> printDevices(List<Device> devices, Logger logger, { String prefix = '' }) async {
+  static Future<void> printDevices(
+    List<Device> devices,
+    Logger logger, {
+    String prefix = '',
+  }) async {
     for (final String line in await descriptions(devices)) {
       logger.printStatus('$prefix$line');
     }
   }
 
   static List<String> devicesPlatformTypes(List<Device> devices) {
-    return devices
-        .map(
-          (Device d) => d.platformType.toString(),
-        ).toSet().toList()..sort();
+    return devices.map((Device d) => d.platformType.toString()).toSet().toList()..sort();
   }
 
   /// Convert the Device object to a JSON representation suitable for serialization.
@@ -943,9 +913,9 @@ enum ImpellerStatus {
   const ImpellerStatus._(this.asBool);
 
   factory ImpellerStatus.fromBool(bool? b) => switch (b) {
-    true  => enabled,
+    true => enabled,
     false => disabled,
-    null  => platformDefault,
+    null => platformDefault,
   };
 
   final bool? asBool;
@@ -968,8 +938,6 @@ class DebuggingOptions {
     this.traceSystrace = false,
     this.traceToFile,
     this.endlessTraceBuffer = false,
-    this.dumpSkpOnShaderCompilation = false,
-    this.cacheSkSL = false,
     this.purgePersistentCache = false,
     this.useTestFonts = false,
     this.verboseSystemLogs = false,
@@ -994,10 +962,8 @@ class DebuggingOptions {
     this.webLaunchUrl,
     WebRendererMode? webRenderer,
     this.webUseWasm = false,
-    this.webUseLocalCanvaskit = false,
     this.vmserviceOutFile,
     this.fastStart = false,
-    this.nullAssertions = false,
     this.nativeNullAssertions = false,
     this.enableImpeller = ImpellerStatus.platformDefault,
     this.enableVulkanValidation = false,
@@ -1007,65 +973,70 @@ class DebuggingOptions {
     this.enableEmbedderApi = false,
     this.usingCISystem = false,
     this.debugLogsDirectoryPath,
-   })  : debuggingEnabled = true,
-        webRenderer = webRenderer ?? WebRendererMode.getDefault(useWasm: webUseWasm);
+    this.enableDevTools = true,
+    this.ipv6 = false,
+    this.google3WorkspaceRoot,
+    this.printDtd = false,
+  }) : debuggingEnabled = true,
+       webRenderer = webRenderer ?? WebRendererMode.getDefault(useWasm: webUseWasm);
 
-  DebuggingOptions.disabled(this.buildInfo, {
-      this.dartEntrypointArgs = const <String>[],
-      this.port,
-      this.hostname,
-      this.tlsCertPath,
-      this.tlsCertKeyPath,
-      this.webEnableExposeUrl,
-      this.webUseSseForDebugProxy = true,
-      this.webUseSseForDebugBackend = true,
-      this.webUseSseForInjectedClient = true,
-      this.webRunHeadless = false,
-      this.webBrowserDebugPort,
-      this.webBrowserFlags = const <String>[],
-      this.webLaunchUrl,
-      this.webHeaders = const <String, String>{},
-      WebRendererMode? webRenderer,
-      this.webUseWasm = false,
-      this.webUseLocalCanvaskit = false,
-      this.cacheSkSL = false,
-      this.traceAllowlist,
-      this.enableImpeller = ImpellerStatus.platformDefault,
-      this.enableVulkanValidation = false,
-      this.uninstallFirst = false,
-      this.enableDartProfiling = true,
-      this.enableEmbedderApi = false,
-      this.usingCISystem = false,
-      this.debugLogsDirectoryPath,
-    }) : debuggingEnabled = false,
-      useTestFonts = false,
-      startPaused = false,
-      dartFlags = '',
-      disableServiceAuthCodes = false,
-      enableDds = true,
-      cacheStartupProfile = false,
-      enableSoftwareRendering = false,
-      skiaDeterministicRendering = false,
-      traceSkia = false,
-      traceSkiaAllowlist = null,
-      traceSystrace = false,
-      traceToFile = null,
-      endlessTraceBuffer = false,
-      dumpSkpOnShaderCompilation = false,
-      purgePersistentCache = false,
-      verboseSystemLogs = false,
-      hostVmServicePort = null,
-      disablePortPublication = false,
-      deviceVmServicePort = null,
-      ddsPort = null,
-      devToolsServerAddress = null,
-      vmserviceOutFile = null,
-      fastStart = false,
-      webEnableExpressionEvaluation = false,
-      nullAssertions = false,
-      nativeNullAssertions = false,
-      serveObservatory = false,
-      webRenderer = webRenderer ?? WebRendererMode.getDefault(useWasm: webUseWasm);
+  DebuggingOptions.disabled(
+    this.buildInfo, {
+    this.dartEntrypointArgs = const <String>[],
+    this.port,
+    this.hostname,
+    this.tlsCertPath,
+    this.tlsCertKeyPath,
+    this.webEnableExposeUrl,
+    this.webUseSseForDebugProxy = true,
+    this.webUseSseForDebugBackend = true,
+    this.webUseSseForInjectedClient = true,
+    this.webRunHeadless = false,
+    this.webBrowserDebugPort,
+    this.webBrowserFlags = const <String>[],
+    this.webLaunchUrl,
+    this.webHeaders = const <String, String>{},
+    WebRendererMode? webRenderer,
+    this.webUseWasm = false,
+    this.traceAllowlist,
+    this.enableImpeller = ImpellerStatus.platformDefault,
+    this.enableVulkanValidation = false,
+    this.uninstallFirst = false,
+    this.enableDartProfiling = true,
+    this.enableEmbedderApi = false,
+    this.usingCISystem = false,
+    this.debugLogsDirectoryPath,
+  }) : debuggingEnabled = false,
+       useTestFonts = false,
+       startPaused = false,
+       dartFlags = '',
+       disableServiceAuthCodes = false,
+       enableDds = false,
+       cacheStartupProfile = false,
+       enableSoftwareRendering = false,
+       skiaDeterministicRendering = false,
+       traceSkia = false,
+       traceSkiaAllowlist = null,
+       traceSystrace = false,
+       traceToFile = null,
+       endlessTraceBuffer = false,
+       purgePersistentCache = false,
+       verboseSystemLogs = false,
+       hostVmServicePort = null,
+       disablePortPublication = false,
+       deviceVmServicePort = null,
+       ddsPort = null,
+       devToolsServerAddress = null,
+       vmserviceOutFile = null,
+       fastStart = false,
+       webEnableExpressionEvaluation = false,
+       nativeNullAssertions = false,
+       serveObservatory = false,
+       enableDevTools = false,
+       ipv6 = false,
+       google3WorkspaceRoot = null,
+       printDtd = false,
+       webRenderer = webRenderer ?? WebRendererMode.getDefault(useWasm: webUseWasm);
 
   DebuggingOptions._({
     required this.buildInfo,
@@ -1084,8 +1055,6 @@ class DebuggingOptions {
     required this.traceSystrace,
     required this.traceToFile,
     required this.endlessTraceBuffer,
-    required this.dumpSkpOnShaderCompilation,
-    required this.cacheSkSL,
     required this.purgePersistentCache,
     required this.useTestFonts,
     required this.verboseSystemLogs,
@@ -1110,10 +1079,8 @@ class DebuggingOptions {
     required this.webLaunchUrl,
     required this.webRenderer,
     required this.webUseWasm,
-    required this.webUseLocalCanvaskit,
     required this.vmserviceOutFile,
     required this.fastStart,
-    required this.nullAssertions,
     required this.nativeNullAssertions,
     required this.enableImpeller,
     required this.enableVulkanValidation,
@@ -1123,6 +1090,10 @@ class DebuggingOptions {
     required this.enableEmbedderApi,
     required this.usingCISystem,
     required this.debugLogsDirectoryPath,
+    required this.enableDevTools,
+    required this.ipv6,
+    required this.google3WorkspaceRoot,
+    required this.printDtd,
   });
 
   final bool debuggingEnabled;
@@ -1142,8 +1113,6 @@ class DebuggingOptions {
   final bool traceSystrace;
   final String? traceToFile;
   final bool endlessTraceBuffer;
-  final bool dumpSkpOnShaderCompilation;
-  final bool cacheSkSL;
   final bool purgePersistentCache;
   final bool useTestFonts;
   final bool verboseSystemLogs;
@@ -1167,6 +1136,10 @@ class DebuggingOptions {
   final bool enableEmbedderApi;
   final bool usingCISystem;
   final String? debugLogsDirectoryPath;
+  final bool enableDevTools;
+  final bool ipv6;
+  final String? google3WorkspaceRoot;
+  final bool printDtd;
 
   /// Whether the tool should try to uninstall a previously installed version of the app.
   ///
@@ -1201,15 +1174,10 @@ class DebuggingOptions {
   /// Whether to compile to webassembly
   final bool webUseWasm;
 
-  /// If true, serve CanvasKit assets locally rather than using the CDN.
-  final bool webUseLocalCanvaskit;
-
   /// A file where the VM Service URL should be written after the application is started.
   final String? vmserviceOutFile;
   final bool fastStart;
 
-  final bool nullAssertions;
-
   /// Additional null runtime checks inserted for web applications.
   ///
   /// See also:
@@ -1220,21 +1188,19 @@ class DebuggingOptions {
     EnvironmentType environmentType,
     String? route,
     Map<String, Object?> platformArgs, {
-    bool ipv6 = false,
     DeviceConnectionInterface interfaceType = DeviceConnectionInterface.attached,
     bool isCoreDevice = false,
   }) {
-    final String dartVmFlags = computeDartVmFlags(this);
     return <String>[
       if (enableDartProfiling) '--enable-dart-profiling',
       if (disableServiceAuthCodes) '--disable-service-auth-codes',
       if (disablePortPublication) '--disable-vm-service-publication',
       if (startPaused) '--start-paused',
       // Wrap dart flags in quotes for physical devices
-      if (environmentType == EnvironmentType.physical && dartVmFlags.isNotEmpty)
-        '--dart-flags="$dartVmFlags"',
-      if (environmentType == EnvironmentType.simulator && dartVmFlags.isNotEmpty)
-        '--dart-flags=$dartVmFlags',
+      if (environmentType == EnvironmentType.physical && dartFlags.isNotEmpty)
+        '--dart-flags="$dartFlags"',
+      if (environmentType == EnvironmentType.simulator && dartFlags.isNotEmpty)
+        '--dart-flags=$dartFlags',
       if (useTestFonts) '--use-test-fonts',
       // Core Devices (iOS 17 devices) are debugged through Xcode so don't
       // include these flags, which are used to check if the app was launched
@@ -1251,9 +1217,7 @@ class DebuggingOptions {
       if (traceAllowlist != null) '--trace-allowlist="$traceAllowlist"',
       if (traceSkiaAllowlist != null) '--trace-skia-allowlist="$traceSkiaAllowlist"',
       if (endlessTraceBuffer) '--endless-trace-buffer',
-      if (dumpSkpOnShaderCompilation) '--dump-skp-on-shader-compilation',
       if (verboseSystemLogs) '--verbose-logging',
-      if (cacheSkSL) '--cache-sksl',
       if (purgePersistentCache) '--purge-persistent-cache',
       if (route != null) '--route=$route',
       if (platformArgs['trace-startup'] as bool? ?? false) '--trace-startup',
@@ -1288,8 +1252,6 @@ class DebuggingOptions {
     'traceSystrace': traceSystrace,
     'traceToFile': traceToFile,
     'endlessTraceBuffer': endlessTraceBuffer,
-    'dumpSkpOnShaderCompilation': dumpSkpOnShaderCompilation,
-    'cacheSkSL': cacheSkSL,
     'purgePersistentCache': purgePersistentCache,
     'useTestFonts': useTestFonts,
     'verboseSystemLogs': verboseSystemLogs,
@@ -1314,10 +1276,8 @@ class DebuggingOptions {
     'webHeaders': webHeaders,
     'webRenderer': webRenderer.name,
     'webUseWasm': webUseWasm,
-    'webUseLocalCanvaskit': webUseLocalCanvaskit,
     'vmserviceOutFile': vmserviceOutFile,
     'fastStart': fastStart,
-    'nullAssertions': nullAssertions,
     'nativeNullAssertions': nativeNullAssertions,
     'enableImpeller': enableImpeller.asBool,
     'enableVulkanValidation': enableVulkanValidation,
@@ -1326,76 +1286,89 @@ class DebuggingOptions {
     'enableEmbedderApi': enableEmbedderApi,
     'usingCISystem': usingCISystem,
     'debugLogsDirectoryPath': debugLogsDirectoryPath,
+    'enableDevTools': enableDevTools,
+    'ipv6': ipv6,
+    'google3WorkspaceRoot': google3WorkspaceRoot,
+    'printDtd': printDtd,
+    // TODO(jsimmons): This field is required for backward compatibility with
+    // the flutter_tools binary that is currently checked into Google3.
+    // Remove this when that binary has been updated.
+    'webUseLocalCanvaskit': false,
+    // See above: these fields are required for backwards compatibility
+    // with the google3 checked in binary.
+    'dumpSkpOnShaderCompilation': false,
+    'cacheSkSL': false,
   };
 
   static DebuggingOptions fromJson(Map<String, Object?> json, BuildInfo buildInfo) =>
-    DebuggingOptions._(
-      buildInfo: buildInfo,
-      debuggingEnabled: json['debuggingEnabled']! as bool,
-      startPaused: json['startPaused']! as bool,
-      dartFlags: json['dartFlags']! as String,
-      dartEntrypointArgs: (json['dartEntrypointArgs']! as List<dynamic>).cast<String>(),
-      disableServiceAuthCodes: json['disableServiceAuthCodes']! as bool,
-      enableDds: json['enableDds']! as bool,
-      cacheStartupProfile: json['cacheStartupProfile']! as bool,
-      enableSoftwareRendering: json['enableSoftwareRendering']! as bool,
-      skiaDeterministicRendering: json['skiaDeterministicRendering']! as bool,
-      traceSkia: json['traceSkia']! as bool,
-      traceAllowlist: json['traceAllowlist'] as String?,
-      traceSkiaAllowlist: json['traceSkiaAllowlist'] as String?,
-      traceSystrace: json['traceSystrace']! as bool,
-      traceToFile: json['traceToFile'] as String?,
-      endlessTraceBuffer: json['endlessTraceBuffer']! as bool,
-      dumpSkpOnShaderCompilation: json['dumpSkpOnShaderCompilation']! as bool,
-      cacheSkSL: json['cacheSkSL']! as bool,
-      purgePersistentCache: json['purgePersistentCache']! as bool,
-      useTestFonts: json['useTestFonts']! as bool,
-      verboseSystemLogs: json['verboseSystemLogs']! as bool,
-      hostVmServicePort: json['hostVmServicePort'] as int? ,
-      deviceVmServicePort: json['deviceVmServicePort'] as int?,
-      disablePortPublication: json['disablePortPublication']! as bool,
-      ddsPort: json['ddsPort'] as int?,
-      devToolsServerAddress: json['devToolsServerAddress'] != null ? Uri.parse(json['devToolsServerAddress']! as String) : null,
-      port: json['port'] as String?,
-      hostname: json['hostname'] as String?,
-      tlsCertPath: json['tlsCertPath'] as String?,
-      tlsCertKeyPath: json['tlsCertKeyPath'] as String?,
-      webEnableExposeUrl: json['webEnableExposeUrl'] as bool?,
-      webUseSseForDebugProxy: json['webUseSseForDebugProxy']! as bool,
-      webUseSseForDebugBackend: json['webUseSseForDebugBackend']! as bool,
-      webUseSseForInjectedClient: json['webUseSseForInjectedClient']! as bool,
-      webRunHeadless: json['webRunHeadless']! as bool,
-      webBrowserDebugPort: json['webBrowserDebugPort'] as int?,
-      webBrowserFlags: (json['webBrowserFlags']! as List<dynamic>).cast<String>(),
-      webEnableExpressionEvaluation: json['webEnableExpressionEvaluation']! as bool,
-      webHeaders: (json['webHeaders']! as Map<dynamic, dynamic>).cast<String, String>(),
-      webLaunchUrl: json['webLaunchUrl'] as String?,
-      webRenderer: WebRendererMode.values.byName(json['webRenderer']! as String),
-      webUseWasm: json['webUseWasm']! as bool,
-      webUseLocalCanvaskit: json['webUseLocalCanvaskit']! as bool,
-      vmserviceOutFile: json['vmserviceOutFile'] as String?,
-      fastStart: json['fastStart']! as bool,
-      nullAssertions: json['nullAssertions']! as bool,
-      nativeNullAssertions: json['nativeNullAssertions']! as bool,
-      enableImpeller: ImpellerStatus.fromBool(json['enableImpeller'] as bool?),
-      enableVulkanValidation: (json['enableVulkanValidation'] as bool?) ?? false,
-      uninstallFirst: (json['uninstallFirst'] as bool?) ?? false,
-      serveObservatory: (json['serveObservatory'] as bool?) ?? false,
-      enableDartProfiling: (json['enableDartProfiling'] as bool?) ?? true,
-      enableEmbedderApi: (json['enableEmbedderApi'] as bool?) ?? false,
-      usingCISystem: (json['usingCISystem'] as bool?) ?? false,
-      debugLogsDirectoryPath: json['debugLogsDirectoryPath'] as String?,
-    );
+      DebuggingOptions._(
+        buildInfo: buildInfo,
+        debuggingEnabled: json['debuggingEnabled']! as bool,
+        startPaused: json['startPaused']! as bool,
+        dartFlags: json['dartFlags']! as String,
+        dartEntrypointArgs: (json['dartEntrypointArgs']! as List<dynamic>).cast<String>(),
+        disableServiceAuthCodes: json['disableServiceAuthCodes']! as bool,
+        enableDds: json['enableDds']! as bool,
+        cacheStartupProfile: json['cacheStartupProfile']! as bool,
+        enableSoftwareRendering: json['enableSoftwareRendering']! as bool,
+        skiaDeterministicRendering: json['skiaDeterministicRendering']! as bool,
+        traceSkia: json['traceSkia']! as bool,
+        traceAllowlist: json['traceAllowlist'] as String?,
+        traceSkiaAllowlist: json['traceSkiaAllowlist'] as String?,
+        traceSystrace: json['traceSystrace']! as bool,
+        traceToFile: json['traceToFile'] as String?,
+        endlessTraceBuffer: json['endlessTraceBuffer']! as bool,
+        purgePersistentCache: json['purgePersistentCache']! as bool,
+        useTestFonts: json['useTestFonts']! as bool,
+        verboseSystemLogs: json['verboseSystemLogs']! as bool,
+        hostVmServicePort: json['hostVmServicePort'] as int?,
+        deviceVmServicePort: json['deviceVmServicePort'] as int?,
+        disablePortPublication: json['disablePortPublication']! as bool,
+        ddsPort: json['ddsPort'] as int?,
+        devToolsServerAddress:
+            json['devToolsServerAddress'] != null
+                ? Uri.parse(json['devToolsServerAddress']! as String)
+                : null,
+        port: json['port'] as String?,
+        hostname: json['hostname'] as String?,
+        tlsCertPath: json['tlsCertPath'] as String?,
+        tlsCertKeyPath: json['tlsCertKeyPath'] as String?,
+        webEnableExposeUrl: json['webEnableExposeUrl'] as bool?,
+        webUseSseForDebugProxy: json['webUseSseForDebugProxy']! as bool,
+        webUseSseForDebugBackend: json['webUseSseForDebugBackend']! as bool,
+        webUseSseForInjectedClient: json['webUseSseForInjectedClient']! as bool,
+        webRunHeadless: json['webRunHeadless']! as bool,
+        webBrowserDebugPort: json['webBrowserDebugPort'] as int?,
+        webBrowserFlags: (json['webBrowserFlags']! as List<dynamic>).cast<String>(),
+        webEnableExpressionEvaluation: json['webEnableExpressionEvaluation']! as bool,
+        webHeaders: (json['webHeaders']! as Map<dynamic, dynamic>).cast<String, String>(),
+        webLaunchUrl: json['webLaunchUrl'] as String?,
+        webRenderer: WebRendererMode.values.byName(json['webRenderer']! as String),
+        webUseWasm: json['webUseWasm']! as bool,
+        vmserviceOutFile: json['vmserviceOutFile'] as String?,
+        fastStart: json['fastStart']! as bool,
+        nativeNullAssertions: json['nativeNullAssertions']! as bool,
+        enableImpeller: ImpellerStatus.fromBool(json['enableImpeller'] as bool?),
+        enableVulkanValidation: (json['enableVulkanValidation'] as bool?) ?? false,
+        uninstallFirst: (json['uninstallFirst'] as bool?) ?? false,
+        serveObservatory: (json['serveObservatory'] as bool?) ?? false,
+        enableDartProfiling: (json['enableDartProfiling'] as bool?) ?? true,
+        enableEmbedderApi: (json['enableEmbedderApi'] as bool?) ?? false,
+        usingCISystem: (json['usingCISystem'] as bool?) ?? false,
+        debugLogsDirectoryPath: json['debugLogsDirectoryPath'] as String?,
+        enableDevTools: (json['enableDevTools'] as bool?) ?? true,
+        ipv6: (json['ipv6'] as bool?) ?? false,
+        google3WorkspaceRoot: json['google3WorkspaceRoot'] as String?,
+        printDtd: (json['printDtd'] as bool?) ?? false,
+      );
 }
 
 class LaunchResult {
-  LaunchResult.succeeded({ Uri? vmServiceUri, Uri? observatoryUri }) :
-    started = true,
-    vmServiceUri = vmServiceUri ?? observatoryUri;
+  LaunchResult.succeeded({Uri? vmServiceUri, Uri? observatoryUri})
+    : started = true,
+      vmServiceUri = vmServiceUri ?? observatoryUri;
 
-  LaunchResult.failed()
-    : started = false,
-      vmServiceUri = null;
+  LaunchResult.failed() : started = false, vmServiceUri = null;
 
   bool get hasVmService => vmServiceUri != null;
 
@@ -1421,14 +1394,11 @@ abstract class DeviceLogReader {
 
   /// Some logs can be obtained from a VM service stream.
   /// Set this after the VM services are connected.
-  FlutterVmService? connectedVMService;
+  Future<void> provideVmService(FlutterVmService connectedVmService);
 
   @override
   String toString() => name;
 
-  /// Process ID of the app on the device.
-  int? appPid;
-
   // Clean up resources allocated by log reader e.g. subprocesses
   void dispose();
 }
@@ -1447,26 +1417,12 @@ class NoOpDeviceLogReader implements DeviceLogReader {
   @override
   final String name;
 
-  @override
-  int? appPid;
-
-  @override
-  FlutterVmService? connectedVMService;
-
   @override
   Stream<String> get logLines => const Stream<String>.empty();
 
   @override
-  void dispose() { }
-}
+  void dispose() {}
 
-/// Append --null_assertions to any existing Dart VM flags if
-/// [debuggingOptions.nullAssertions] is true.
-String computeDartVmFlags(DebuggingOptions debuggingOptions) {
-  return <String>[
-    if (debuggingOptions.dartFlags.isNotEmpty)
-      debuggingOptions.dartFlags,
-    if (debuggingOptions.nullAssertions)
-      '--null_assertions',
-  ].join(',');
+  @override
+  Future<void> provideVmService(FlutterVmService connectedVmService) async {}
 }
