@@ -51,18 +51,19 @@ class FlutterCache extends Cache {
       registerArtifact(IosUsbArtifacts(artifactName, this, platform: platform));
     }
     registerArtifact(FontSubsetArtifacts(this, platform: platform));
-    registerArtifact(PubDependencies(
-      logger: logger,
-      // flutter root and pub must be lazily initialized to avoid accessing
-      // before the version is determined.
-      flutterRoot: () => Cache.flutterRoot!,
-      pub: () => pub,
-      projectFactory: projectFactory,
-    ));
+    registerArtifact(
+      PubDependencies(
+        logger: logger,
+        // flutter root and pub must be lazily initialized to avoid accessing
+        // before the version is determined.
+        flutterRoot: () => Cache.flutterRoot!,
+        pub: () => pub,
+        projectFactory: projectFactory,
+      ),
+    );
   }
 }
 
-
 /// Ensures that the source files for all of the dependencies for the
 /// flutter_tool are present.
 ///
@@ -87,11 +88,15 @@ class PubDependencies extends ArtifactSet {
   final FlutterProjectFactory _projectFactory;
 
   @override
-  Future<bool> isUpToDate(
-    FileSystem fileSystem,
-  ) async {
+  Future<bool> isUpToDate(FileSystem fileSystem) async {
     final File toolPackageConfig = fileSystem.file(
-      fileSystem.path.join(_flutterRoot(), 'packages', 'flutter_tools', '.dart_tool', 'package_config.json'),
+      fileSystem.path.join(
+        _flutterRoot(),
+        'packages',
+        'flutter_tools',
+        '.dart_tool',
+        'package_config.json',
+      ),
     );
     if (!toolPackageConfig.existsSync()) {
       return false;
@@ -120,27 +125,23 @@ class PubDependencies extends ArtifactSet {
     ArtifactUpdater artifactUpdater,
     Logger logger,
     FileSystem fileSystem,
-    OperatingSystemUtils operatingSystemUtils,
-    {bool offline = false}
-  ) async {
+    OperatingSystemUtils operatingSystemUtils, {
+    bool offline = false,
+  }) async {
     await _pub().get(
       context: PubContext.pubGet,
       project: _projectFactory.fromDirectory(
-        fileSystem.directory(fileSystem.path.join(_flutterRoot(), 'packages', 'flutter_tools'))
+        fileSystem.directory(fileSystem.path.join(_flutterRoot(), 'packages', 'flutter_tools')),
       ),
       offline: offline,
-      outputMode: PubOutputMode.none,
+      outputMode: PubOutputMode.failuresOnly,
     );
   }
 }
 
 /// A cached artifact containing fonts used for Material Design.
 class MaterialFonts extends CachedArtifact {
-  MaterialFonts(Cache cache) : super(
-    'material_fonts',
-    cache,
-    DevelopmentArtifact.universal,
-  );
+  MaterialFonts(Cache cache) : super('material_fonts', cache, DevelopmentArtifact.universal);
 
   @override
   Future<void> updateInner(
@@ -149,7 +150,11 @@ class MaterialFonts extends CachedArtifact {
     OperatingSystemUtils operatingSystemUtils,
   ) async {
     final Uri archiveUri = _toStorageUri(version!);
-    return artifactUpdater.downloadZipArchive('Downloading Material fonts...', archiveUri, location);
+    return artifactUpdater.downloadZipArchive(
+      'Downloading Material fonts...',
+      archiveUri,
+      location,
+    );
   }
 
   Uri _toStorageUri(String path) => Uri.parse('${cache.storageBaseUrl}/$path');
@@ -160,18 +165,13 @@ class MaterialFonts extends CachedArtifact {
 ///
 /// This SDK references code within the regular Dart sdk to reduce download size.
 class FlutterWebSdk extends CachedArtifact {
-  FlutterWebSdk(Cache cache)
-   : super(
-      'flutter_web_sdk',
-      cache,
-      DevelopmentArtifact.web,
-    );
+  FlutterWebSdk(Cache cache) : super('flutter_web_sdk', cache, DevelopmentArtifact.web);
 
   @override
   Directory get location => cache.getWebSdkDirectory();
 
   @override
-  String? get version => cache.getVersionFor('engine');
+  String? get version => cache.engineRevision;
 
   @override
   Future<void> updateInner(
@@ -179,7 +179,9 @@ class FlutterWebSdk extends CachedArtifact {
     FileSystem fileSystem,
     OperatingSystemUtils operatingSystemUtils,
   ) async {
-    final Uri url = Uri.parse('${cache.storageBaseUrl}/flutter_infra_release/flutter/$version/flutter-web-sdk.zip');
+    final Uri url = Uri.parse(
+      '${cache.storageBaseUrl}/flutter_infra_release/flutter/$version/flutter-web-sdk.zip',
+    );
     ErrorHandlingFileSystem.deleteIfExists(location, recursive: true);
     await artifactUpdater.downloadZipArchive('Downloading Web SDK...', url, location);
   }
@@ -198,35 +200,27 @@ class LegacyCanvasKitRemover extends ArtifactSet {
   String get name => 'legacy_canvaskit_remover';
 
   Directory _getLegacyCanvasKitDirectory(FileSystem fileSystem) =>
-    fileSystem.directory(fileSystem.path.join(
-      cache.getRoot().path,
-      'canvaskit',
-    ));
+      fileSystem.directory(fileSystem.path.join(cache.getRoot().path, 'canvaskit'));
 
   @override
   Future<bool> isUpToDate(FileSystem fileSystem) async =>
-    !(await _getLegacyCanvasKitDirectory(fileSystem).exists());
+      !(await _getLegacyCanvasKitDirectory(fileSystem).exists());
 
   @override
   Future<void> update(
     ArtifactUpdater artifactUpdater,
     Logger logger,
     FileSystem fileSystem,
-    OperatingSystemUtils operatingSystemUtils,
-    {bool offline = false}
-  ) => _getLegacyCanvasKitDirectory(fileSystem).delete(recursive: true);
+    OperatingSystemUtils operatingSystemUtils, {
+    bool offline = false,
+  }) => _getLegacyCanvasKitDirectory(fileSystem).delete(recursive: true);
 }
 
 /// A cached artifact containing the dart:ui source code.
 class FlutterSdk extends EngineCachedArtifact {
-  FlutterSdk(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-      super(
-        'flutter_sdk',
-        cache,
-        DevelopmentArtifact.universal,
-      );
+  FlutterSdk(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('flutter_sdk', cache, DevelopmentArtifact.universal);
 
   final Platform _platform;
 
@@ -244,8 +238,7 @@ class FlutterSdk extends EngineCachedArtifact {
         <String>['windows-$arch', 'windows-$arch/artifacts.zip'],
         <String>['linux-$arch', 'linux-$arch/artifacts.zip'],
         <String>['darwin-x64', 'darwin-$arch/artifacts.zip'],
-      ]
-      else if (_platform.isWindows)
+      ] else if (_platform.isWindows)
         <String>['windows-$arch', 'windows-$arch/artifacts.zip']
       else if (_platform.isMacOS)
         <String>['darwin-x64', 'darwin-$arch/artifacts.zip']
@@ -259,14 +252,9 @@ class FlutterSdk extends EngineCachedArtifact {
 }
 
 class MacOSEngineArtifacts extends EngineCachedArtifact {
-  MacOSEngineArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-        super(
-        'macos-sdk',
-        cache,
-        DevelopmentArtifact.macOS,
-      );
+  MacOSEngineArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('macos-sdk', cache, DevelopmentArtifact.macOS);
 
   final Platform _platform;
 
@@ -287,14 +275,9 @@ class MacOSEngineArtifacts extends EngineCachedArtifact {
 
 /// Artifacts required for desktop Windows builds.
 class WindowsEngineArtifacts extends EngineCachedArtifact {
-  WindowsEngineArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-       super(
-        'windows-sdk',
-         cache,
-         DevelopmentArtifact.windows,
-       );
+  WindowsEngineArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('windows-sdk', cache, DevelopmentArtifact.windows);
 
   final Platform _platform;
 
@@ -316,14 +299,9 @@ class WindowsEngineArtifacts extends EngineCachedArtifact {
 
 /// Artifacts required for desktop Linux builds.
 class LinuxEngineArtifacts extends EngineCachedArtifact {
-  LinuxEngineArtifacts(Cache cache, {
-    required Platform platform
-  }) : _platform = platform,
-       super(
-        'linux-sdk',
-        cache,
-        DevelopmentArtifact.linux,
-      );
+  LinuxEngineArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('linux-sdk', cache, DevelopmentArtifact.linux);
 
   final Platform _platform;
 
@@ -349,14 +327,9 @@ class LinuxEngineArtifacts extends EngineCachedArtifact {
 
 /// The artifact used to generate snapshots for Android builds.
 class AndroidGenSnapshotArtifacts extends EngineCachedArtifact {
-  AndroidGenSnapshotArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-        super(
-        'android-sdk',
-        cache,
-        DevelopmentArtifact.androidGenSnapshot,
-      );
+  AndroidGenSnapshotArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('android-sdk', cache, DevelopmentArtifact.androidGenSnapshot);
 
   final Platform _platform;
 
@@ -381,7 +354,9 @@ class AndroidGenSnapshotArtifacts extends EngineCachedArtifact {
   }
 
   @override
-  List<String> getLicenseDirs() { return <String>[]; }
+  List<String> getLicenseDirs() {
+    return <String>[];
+  }
 }
 
 /// A cached artifact containing the Maven dependencies used to build Android projects.
@@ -390,12 +365,10 @@ class AndroidGenSnapshotArtifacts extends EngineCachedArtifact {
 ///
 /// Set [Java] to `null` to indicate that no Java/JDK installation could be found.
 class AndroidMavenArtifacts extends ArtifactSet {
-  AndroidMavenArtifacts(this.cache, {
-    required Java? java,
-    required Platform platform,
-  }) : _java = java,
-       _platform = platform,
-       super(DevelopmentArtifact.androidMaven);
+  AndroidMavenArtifacts(this.cache, {required Java? java, required Platform platform})
+    : _java = java,
+      _platform = platform,
+      super(DevelopmentArtifact.androidMaven);
 
   final Java? _java;
   final Platform _platform;
@@ -406,9 +379,9 @@ class AndroidMavenArtifacts extends ArtifactSet {
     ArtifactUpdater artifactUpdater,
     Logger logger,
     FileSystem fileSystem,
-    OperatingSystemUtils operatingSystemUtils,
-    {bool offline = false}
-  ) async {
+    OperatingSystemUtils operatingSystemUtils, {
+    bool offline = false,
+  }) async {
     // TODO(andrewkolos): Should this really be no-op if the Android SDK
     // is unavailable? https://github.com/flutter/flutter/issues/127848
     if (globals.androidSdk == null) {
@@ -418,21 +391,24 @@ class AndroidMavenArtifacts extends ArtifactSet {
     globals.gradleUtils?.injectGradleWrapperIfNeeded(tempDir);
 
     final Status status = logger.startProgress('Downloading Android Maven dependencies...');
-    final File gradle = tempDir.childFile(
-      _platform.isWindows ? 'gradlew.bat' : 'gradlew',
-    );
+    final File gradle = tempDir.childFile(_platform.isWindows ? 'gradlew.bat' : 'gradlew');
     try {
       final String gradleExecutable = gradle.absolute.path;
       final String flutterSdk = globals.fsUtils.escapePath(Cache.flutterRoot!);
-      final RunResult processResult = await globals.processUtils.run(
-        <String>[
-          gradleExecutable,
-          '-b', globals.fs.path.join(flutterSdk, 'packages', 'flutter_tools', 'gradle', 'resolve_dependencies.gradle'),
-          '--project-cache-dir', tempDir.path,
-          'resolveDependencies',
-        ],
-        environment: _java?.environment,
-      );
+      final RunResult processResult = await globals.processUtils.run(<String>[
+        gradleExecutable,
+        '-b',
+        globals.fs.path.join(
+          flutterSdk,
+          'packages',
+          'flutter_tools',
+          'gradle',
+          'resolve_dependencies.gradle.kts',
+        ),
+        '--project-cache-dir',
+        tempDir.path,
+        'resolveDependencies',
+      ], environment: _java?.environment);
       if (processResult.exitCode != 0) {
         logger.printError('Failed to download the Android dependencies');
       }
@@ -458,11 +434,8 @@ class AndroidMavenArtifacts extends ArtifactSet {
 /// Artifacts used for internal builds. The flutter tool builds Android projects
 /// using the artifacts cached by [AndroidMavenArtifacts].
 class AndroidInternalBuildArtifacts extends EngineCachedArtifact {
-  AndroidInternalBuildArtifacts(Cache cache) : super(
-    'android-internal-build-artifacts',
-    cache,
-    DevelopmentArtifact.androidInternalBuild,
-  );
+  AndroidInternalBuildArtifacts(Cache cache)
+    : super('android-internal-build-artifacts', cache, DevelopmentArtifact.androidInternalBuild);
 
   @override
   List<String> getPackageDirs() => const <String>[];
@@ -473,27 +446,21 @@ class AndroidInternalBuildArtifacts extends EngineCachedArtifact {
   }
 
   @override
-  List<String> getLicenseDirs() { return <String>[]; }
+  List<String> getLicenseDirs() {
+    return <String>[];
+  }
 }
 
 class IOSEngineArtifacts extends EngineCachedArtifact {
-  IOSEngineArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-        super(
-        'ios-sdk',
-        cache,
-        DevelopmentArtifact.iOS,
-      );
+  IOSEngineArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('ios-sdk', cache, DevelopmentArtifact.iOS);
 
   final Platform _platform;
 
   @override
   List<List<String>> getBinaryDirs() {
-    return <List<String>>[
-      if (_platform.isMacOS || ignorePlatformFiltering)
-        ..._iosBinaryDirs,
-    ];
+    return <List<String>>[if (_platform.isMacOS || ignorePlatformFiltering) ..._iosBinaryDirs];
   }
 
   @override
@@ -515,11 +482,7 @@ class IOSEngineArtifacts extends EngineCachedArtifact {
 /// While this is only required for Android, we need to always download it due
 /// the ensurePlatformSpecificTooling logic.
 class GradleWrapper extends CachedArtifact {
-  GradleWrapper(Cache cache) : super(
-    'gradle_wrapper',
-    cache,
-    DevelopmentArtifact.universal,
-  );
+  GradleWrapper(Cache cache) : super('gradle_wrapper', cache, DevelopmentArtifact.universal);
 
   List<String> get _gradleScripts => <String>['gradlew', 'gradlew.bat'];
 
@@ -532,21 +495,27 @@ class GradleWrapper extends CachedArtifact {
     OperatingSystemUtils operatingSystemUtils,
   ) async {
     final Uri archiveUri = _toStorageUri(version!);
-    await artifactUpdater.downloadZippedTarball('Downloading Gradle Wrapper...', archiveUri, location);
+    await artifactUpdater.downloadZippedTarball(
+      'Downloading Gradle Wrapper...',
+      archiveUri,
+      location,
+    );
     // Delete property file, allowing templates to provide it.
     // Remove NOTICE file. Should not be part of the template.
-    final File propertiesFile = fileSystem.file(fileSystem.path.join(location.path, 'gradle', 'wrapper', 'gradle-wrapper.properties'));
+    final File propertiesFile = fileSystem.file(
+      fileSystem.path.join(location.path, 'gradle', 'wrapper', 'gradle-wrapper.properties'),
+    );
     final File noticeFile = fileSystem.file(fileSystem.path.join(location.path, 'NOTICE'));
     ErrorHandlingFileSystem.deleteIfExists(propertiesFile);
     ErrorHandlingFileSystem.deleteIfExists(noticeFile);
   }
 
   @override
-  bool isUpToDateInner(
-    FileSystem fileSystem,
-  ) {
+  bool isUpToDateInner(FileSystem fileSystem) {
     final String gradleWrapper = fileSystem.path.join('gradle', 'wrapper', 'gradle-wrapper.jar');
-    final Directory wrapperDir = cache.getCacheDir(fileSystem.path.join('artifacts', 'gradle_wrapper'));
+    final Directory wrapperDir = cache.getCacheDir(
+      fileSystem.path.join('artifacts', 'gradle_wrapper'),
+    );
     if (!fileSystem.directory(wrapperDir).existsSync()) {
       return false;
     }
@@ -556,7 +525,9 @@ class GradleWrapper extends CachedArtifact {
         return false;
       }
     }
-    final File gradleWrapperJar = fileSystem.file(fileSystem.path.join(wrapperDir.path, gradleWrapper));
+    final File gradleWrapperJar = fileSystem.file(
+      fileSystem.path.join(wrapperDir.path, gradleWrapper),
+    );
     if (!gradleWrapperJar.existsSync()) {
       return false;
     }
@@ -566,13 +537,9 @@ class GradleWrapper extends CachedArtifact {
 
 /// Common functionality for pulling Fuchsia SDKs.
 abstract class _FuchsiaSDKArtifacts extends CachedArtifact {
-  _FuchsiaSDKArtifacts(Cache cache, String platform) :
-    _path = 'fuchsia/sdk/core/$platform-amd64',
-    super(
-      'fuchsia-$platform',
-      cache,
-      DevelopmentArtifact.fuchsia,
-    );
+  _FuchsiaSDKArtifacts(Cache cache, String platform)
+    : _path = 'fuchsia/sdk/core/$platform-amd64',
+      super('fuchsia-$platform', cache, DevelopmentArtifact.fuchsia);
 
   final String _path;
 
@@ -581,21 +548,19 @@ abstract class _FuchsiaSDKArtifacts extends CachedArtifact {
 
   Future<void> _doUpdate(ArtifactUpdater artifactUpdater) {
     final String url = '${cache.cipdBaseUrl}/$_path/+/$version';
-    return artifactUpdater.downloadZipArchive('Downloading package fuchsia SDK...',
-                               Uri.parse(url), location);
+    return artifactUpdater.downloadZipArchive(
+      'Downloading package fuchsia SDK...',
+      Uri.parse(url),
+      location,
+    );
   }
 }
 
 /// The pre-built flutter runner for Fuchsia development.
 class FlutterRunnerSDKArtifacts extends CachedArtifact {
-  FlutterRunnerSDKArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-        super(
-        'flutter_runner',
-        cache,
-        DevelopmentArtifact.flutterRunner,
-      );
+  FlutterRunnerSDKArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super('flutter_runner', cache, DevelopmentArtifact.flutterRunner);
 
   final Platform _platform;
 
@@ -603,7 +568,7 @@ class FlutterRunnerSDKArtifacts extends CachedArtifact {
   Directory get location => cache.getArtifactDirectory('flutter_runner');
 
   @override
-  String? get version => cache.getVersionFor('engine');
+  String? get version => cache.engineRevision;
 
   @override
   Future<void> updateInner(
@@ -615,7 +580,11 @@ class FlutterRunnerSDKArtifacts extends CachedArtifact {
       return;
     }
     final String url = '${cache.cipdBaseUrl}/flutter/fuchsia/+/git_revision:$version';
-    await artifactUpdater.downloadZipArchive('Downloading package flutter runner...', Uri.parse(url), location);
+    await artifactUpdater.downloadZipArchive(
+      'Downloading package flutter runner...',
+      Uri.parse(url),
+      location,
+    );
   }
 }
 
@@ -643,7 +612,8 @@ class CipdArchiveResolver extends VersionedPackageResolver {
 
 /// The debug symbols for flutter runner for Fuchsia development.
 class FlutterRunnerDebugSymbols extends CachedArtifact {
-  FlutterRunnerDebugSymbols(Cache cache, {
+  FlutterRunnerDebugSymbols(
+    Cache cache, {
     required Platform platform,
     VersionedPackageResolver? packageResolver,
   }) : _platform = platform,
@@ -657,7 +627,7 @@ class FlutterRunnerDebugSymbols extends CachedArtifact {
   Directory get location => cache.getArtifactDirectory(name);
 
   @override
-  String? get version => cache.getVersionFor('engine');
+  String? get version => cache.engineRevision;
 
   Future<void> _downloadDebugSymbols(String targetArch, ArtifactUpdater artifactUpdater) async {
     final String packageName = 'fuchsia-debug-symbols-$targetArch';
@@ -685,10 +655,9 @@ class FlutterRunnerDebugSymbols extends CachedArtifact {
 
 /// The Fuchsia core SDK for Linux.
 class LinuxFuchsiaSDKArtifacts extends _FuchsiaSDKArtifacts {
-  LinuxFuchsiaSDKArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-       super(cache, 'linux');
+  LinuxFuchsiaSDKArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super(cache, 'linux');
 
   final Platform _platform;
 
@@ -707,10 +676,9 @@ class LinuxFuchsiaSDKArtifacts extends _FuchsiaSDKArtifacts {
 
 /// The Fuchsia core SDK for MacOS.
 class MacOSFuchsiaSDKArtifacts extends _FuchsiaSDKArtifacts {
-  MacOSFuchsiaSDKArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-       super(cache, 'mac');
+  MacOSFuchsiaSDKArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super(cache, 'mac');
 
   final Platform _platform;
 
@@ -729,10 +697,9 @@ class MacOSFuchsiaSDKArtifacts extends _FuchsiaSDKArtifacts {
 
 /// Cached artifacts for font subsetting.
 class FontSubsetArtifacts extends EngineCachedArtifact {
-  FontSubsetArtifacts(Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-       super(artifactName, cache, DevelopmentArtifact.universal);
+  FontSubsetArtifacts(Cache cache, {required Platform platform})
+    : _platform = platform,
+      super(artifactName, cache, DevelopmentArtifact.universal);
 
   final Platform _platform;
 
@@ -742,7 +709,7 @@ class FontSubsetArtifacts extends EngineCachedArtifact {
   List<List<String>> getBinaryDirs() {
     // Linux and Windows both support arm64 and x64.
     final String arch = cache.getHostPlatformArchName();
-    final Map<String, List<String>> artifacts = <String, List<String>> {
+    final Map<String, List<String>> artifacts = <String, List<String>>{
       'macos': <String>['darwin-x64', 'darwin-$arch/$artifactName.zip'],
       'linux': <String>['linux-$arch', 'linux-$arch/$artifactName.zip'],
       'windows': <String>['windows-$arch', 'windows-$arch/$artifactName.zip'],
@@ -767,14 +734,9 @@ class FontSubsetArtifacts extends EngineCachedArtifact {
 
 /// Cached iOS/USB binary artifacts.
 class IosUsbArtifacts extends CachedArtifact {
-  IosUsbArtifacts(String name, Cache cache, {
-    required Platform platform,
-  }) : _platform = platform,
-       super(
-        name,
-        cache,
-        DevelopmentArtifact.universal,
-      );
+  IosUsbArtifacts(String name, Cache cache, {required Platform platform})
+    : _platform = platform,
+      super(name, cache, DevelopmentArtifact.universal);
 
   final Platform _platform;
 
@@ -791,25 +753,18 @@ class IosUsbArtifacts extends CachedArtifact {
   // used for additional download checks below, so we can re-download if they are
   // missing.
   static const Map<String, List<String>> _kExecutables = <String, List<String>>{
-    'libimobiledevice': <String>[
-      'idevicescreenshot',
-      'idevicesyslog',
-    ],
-    'usbmuxd': <String>[
-      'iproxy',
-    ],
+    'libimobiledevice': <String>['idevicescreenshot', 'idevicesyslog'],
+    'usbmuxd': <String>['iproxy'],
   };
 
   @override
-  Map<String, String> get environment {
-    return <String, String>{
-      'DYLD_LIBRARY_PATH': cache.getArtifactDirectory(name).path,
-    };
-  }
+  Map<String, String> get environment => <String, String>{
+    'DYLD_LIBRARY_PATH': cache.getArtifactDirectory(name).path,
+  };
 
   @override
   bool isUpToDateInner(FileSystem fileSystem) {
-    final List<String>? executables =_kExecutables[name];
+    final List<String>? executables = _kExecutables[name];
     if (executables == null) {
       return true;
     }
@@ -912,10 +867,9 @@ const List<List<String>> _androidBinaryDirs = <List<String>>[
   <String>['android-arm64-release', 'android-arm64-release/artifacts.zip'],
   <String>['android-x64-profile', 'android-x64-profile/artifacts.zip'],
   <String>['android-x64-release', 'android-x64-release/artifacts.zip'],
-  <String>['android-x86-jit-release', 'android-x86-jit-release/artifacts.zip'],
 ];
 
-const List<List<String>> _dartSdks = <List<String>> [
+const List<List<String>> _dartSdks = <List<String>>[
   <String>['darwin-x64', 'dart-sdk-darwin-x64.zip'],
   <String>['linux-x64', 'dart-sdk-linux-x64.zip'],
   <String>['windows-x64', 'dart-sdk-windows-x64.zip'],
