@@ -2,6 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'localizations/gen_l10n.dart';
+library;
+
 import 'package:meta/meta.dart';
 import 'package:pub_semver/pub_semver.dart';
 import 'package:yaml/yaml.dart';
@@ -13,11 +16,13 @@ import 'base/utils.dart';
 import 'globals.dart' as globals;
 import 'plugins.dart';
 
-/// Whether or not Impeller Scene 3D model import is enabled.
-const bool kIs3dSceneSupported = true;
-
 const Set<String> _kValidPluginPlatforms = <String>{
-  'android', 'ios', 'web', 'windows', 'linux', 'macos',
+  'android',
+  'ios',
+  'web',
+  'windows',
+  'linux',
+  'macos',
 };
 
 /// A wrapper around the `flutter` section in the `pubspec.yaml` file.
@@ -25,10 +30,11 @@ class FlutterManifest {
   FlutterManifest._({required Logger logger}) : _logger = logger;
 
   /// Returns an empty manifest.
-  factory FlutterManifest.empty({ required Logger logger }) = FlutterManifest._;
+  factory FlutterManifest.empty({required Logger logger}) = FlutterManifest._;
 
   /// Returns null on invalid manifest. Returns empty manifest on missing file.
-  static FlutterManifest? createFromPath(String path, {
+  static FlutterManifest? createFromPath(
+    String path, {
     required FileSystem fileSystem,
     required Logger logger,
   }) {
@@ -41,7 +47,7 @@ class FlutterManifest {
 
   /// Returns null on missing or invalid manifest.
   @visibleForTesting
-  static FlutterManifest? createFromString(String manifest, { required Logger logger }) {
+  static FlutterManifest? createFromString(String manifest, {required Logger logger}) {
     return _createFromYaml(loadYaml(manifest), logger);
   }
 
@@ -56,7 +62,8 @@ class FlutterManifest {
       pubspec._descriptor = yamlMap.cast<String, Object?>();
     }
 
-    final Map<Object?, Object?>? flutterMap = pubspec._descriptor['flutter'] as Map<Object?, Object?>?;
+    final Map<Object?, Object?>? flutterMap =
+        pubspec._descriptor['flutter'] as Map<Object?, Object?>?;
     if (flutterMap != null) {
       pubspec._flutterDescriptor = flutterMap.cast<String, Object?>();
     }
@@ -64,6 +71,52 @@ class FlutterManifest {
     return pubspec;
   }
 
+  /// Creates a copy of the current manifest with some subset of properties
+  /// modified.
+  FlutterManifest copyWith({
+    required Logger logger,
+    List<AssetsEntry>? assets,
+    List<Font>? fonts,
+    List<Uri>? shaders,
+    List<DeferredComponent>? deferredComponents,
+  }) {
+    final FlutterManifest copy = FlutterManifest._(logger: _logger);
+    copy._descriptor = <String, Object?>{..._descriptor};
+    copy._flutterDescriptor = <String, Object?>{..._flutterDescriptor};
+
+    if (assets != null && assets.isNotEmpty) {
+      copy._flutterDescriptor['assets'] = YamlList.wrap(<Object?>[
+        for (final AssetsEntry asset in assets) asset.descriptor,
+      ]);
+    }
+
+    if (fonts != null && fonts.isNotEmpty) {
+      copy._flutterDescriptor['fonts'] = YamlList.wrap(<Map<String, Object?>>[
+        for (final Font font in fonts) font.descriptor,
+      ]);
+    }
+
+    if (shaders != null && shaders.isNotEmpty) {
+      copy._flutterDescriptor['shaders'] = YamlList.wrap(
+        shaders.map((Uri uri) => uri.toString()).toList(),
+      );
+    }
+
+    if (deferredComponents != null && deferredComponents.isNotEmpty) {
+      copy._flutterDescriptor['deferred-components'] = YamlList.wrap(
+        deferredComponents.map((DeferredComponent dc) => dc.descriptor).toList(),
+      );
+    }
+
+    copy._descriptor['flutter'] = YamlMap.wrap(copy._flutterDescriptor);
+
+    if (!_validate(YamlMap.wrap(copy._descriptor), logger)) {
+      throw StateError('Generated invalid pubspec.yaml.');
+    }
+
+    return copy;
+  }
+
   final Logger _logger;
 
   /// A map representation of the entire `pubspec.yaml` file.
@@ -87,6 +140,10 @@ class FlutterManifest {
     return dependencies != null ? <String>{...dependencies.keys.cast<String>()} : <String>{};
   }
 
+  /// List of all the entries in the workspace field of the `pubspec.yaml` file.
+  List<String> get workspace =>
+      (_descriptor['workspace'] as YamlList?)?.cast<String>() ?? <String>[];
+
   // Flag to avoid printing multiple invalid version messages.
   bool _hasShowInvalidVersionMsg = false;
 
@@ -103,7 +160,10 @@ class FlutterManifest {
       version = Version.parse(verStr);
     } on Exception {
       if (!_hasShowInvalidVersionMsg) {
-        _logger.printStatus(globals.userMessages.invalidVersionSettingHintMessage(verStr), emphasis: true);
+        _logger.printStatus(
+          globals.userMessages.invalidVersionSettingHintMessage(verStr),
+          emphasis: true,
+        );
         _hasShowInvalidVersionMsg = true;
       }
     }
@@ -166,11 +226,10 @@ class FlutterManifest {
   ///     - assets/foo_license.txt
   /// ```
   List<String> get additionalLicenses {
-    final Object? licenses = _flutterDescriptor['licenses'];
-    if (licenses is YamlList) {
-      return licenses.map((Object? element) => element.toString()).toList();
-    }
-    return <String>[];
+    return <String>[
+      if (_flutterDescriptor case {'licenses': final YamlList list})
+        for (final Object? item in list) '$item',
+    ];
   }
 
   /// True if this manifest declares a Flutter module project.
@@ -197,27 +256,19 @@ class FlutterManifest {
   /// such declaration.
   String? get androidPackage {
     if (isModule) {
-      final Object? module = _flutterDescriptor['module'];
-      if (module is YamlMap) {
-        return module['androidPackage'] as String?;
+      if (_flutterDescriptor case {'module': final YamlMap map}) {
+        return map['androidPackage'] as String?;
       }
     }
-    final Map<String, Object?>? platforms = supportedPlatforms;
-    if (platforms == null) {
+
+    late final YamlMap? plugin = _flutterDescriptor['plugin'] as YamlMap?;
+
+    return switch (supportedPlatforms) {
+      {'android': final YamlMap map} => map['package'] as String?,
       // Pre-multi-platform plugin format
-      if (isPlugin) {
-        final YamlMap? plugin = _flutterDescriptor['plugin'] as YamlMap?;
-        return plugin?['androidPackage'] as String?;
-      }
-      return null;
-    }
-    if (platforms.containsKey('android')) {
-      final Object? android = platforms['android'];
-      if (android is YamlMap) {
-        return android['package'] as String?;
-      }
-    }
-    return null;
+      null when isPlugin => plugin?['androidPackage'] as String?,
+      _ => null,
+    };
   }
 
   /// Returns the deferred components configuration if declared. Returns
@@ -240,10 +291,12 @@ class FlutterManifest {
       components.add(
         DeferredComponent(
           name: component['name'] as String,
-          libraries: component['libraries'] == null ?
-              <String>[] : (component['libraries'] as List<dynamic>).cast<String>(),
+          libraries:
+              component['libraries'] == null
+                  ? <String>[]
+                  : (component['libraries'] as List<dynamic>).cast<String>(),
           assets: _computeAssets(component['assets']),
-        )
+        ),
       );
     }
     return components;
@@ -253,9 +306,8 @@ class FlutterManifest {
   /// module descriptor. Returns null if there is no such declaration.
   String? get iosBundleIdentifier {
     if (isModule) {
-      final Object? module = _flutterDescriptor['module'];
-      if (module is YamlMap) {
-        return module['iosBundleIdentifier'] as String?;
+      if (_flutterDescriptor case {'module': final YamlMap map}) {
+        return map['iosBundleIdentifier'] as String?;
       }
     }
     return null;
@@ -297,7 +349,10 @@ class FlutterManifest {
     final List<Object?>? fontList = _flutterDescriptor['fonts'] as List<Object?>?;
     return fontList == null
         ? const <Map<String, Object?>>[]
-        : fontList.map<Map<String, Object?>?>(castStringKeyedMap).whereType<Map<String, Object?>>().toList();
+        : fontList
+            .map<Map<String, Object?>?>(castStringKeyedMap)
+            .whereType<Map<String, Object?>>()
+            .toList();
   }
 
   late final List<AssetsEntry> assets = _computeAssets(_flutterDescriptor['assets']);
@@ -330,11 +385,13 @@ class FlutterManifest {
           continue;
         }
 
-        fontAssets.add(FontAsset(
-          Uri.parse(asset),
-          weight: fontFile['weight'] as int?,
-          style: fontFile['style'] as String?,
-        ));
+        fontAssets.add(
+          FontAsset(
+            Uri.parse(asset),
+            weight: fontFile['weight'] as int?,
+            style: fontFile['style'] as String?,
+          ),
+        );
       }
       if (fontAssets.isNotEmpty) {
         fonts.add(Font(familyName, fontAssets));
@@ -344,7 +401,6 @@ class FlutterManifest {
   }
 
   late final List<Uri> shaders = _extractAssetUris('shaders', 'Shader');
-  late final List<Uri> models = kIs3dSceneSupported ? _extractAssetUris('models', 'Model') : <Uri>[];
 
   List<Uri> _extractAssetUris(String key, String singularName) {
     if (!_flutterDescriptor.containsKey(key)) {
@@ -370,31 +426,28 @@ class FlutterManifest {
     return results;
   }
 
-  /// Whether a synthetic flutter_gen package should be generated.
+  /// Whether localization Dart files should be generated.
   ///
-  /// This can be provided to the [Pub] interface to inject a new entry
-  /// into the package_config.json file which points to `.dart_tool/flutter_gen`.
+  /// **NOTE**: This method was previously called `generateSyntheticPackage`,
+  /// which was incorrect; the presence of `generate: true` in `pubspec.yaml`
+  /// does _not_ imply a synthetic package (and never did); additional
+  /// introspection is required to determine whether a synthetic package is
+  /// required.
   ///
-  /// This allows generated source code to be imported using a package
-  /// alias.
-  late final bool generateSyntheticPackage = _computeGenerateSyntheticPackage();
-  bool _computeGenerateSyntheticPackage() {
-    if (!_flutterDescriptor.containsKey('generate')) {
-      return false;
-    }
-    final Object? value = _flutterDescriptor['generate'];
-    if (value is! bool) {
-      return false;
-    }
-    return value;
-  }
+  /// See also:
+  ///
+  ///   * [Deprecate and remove synthethic `package:flutter_gen`](https://github.com/flutter/flutter/issues/102983)
+  late final bool generateLocalizations = _flutterDescriptor['generate'] == true;
 
   String? get defaultFlavor => _flutterDescriptor['default-flavor'] as String?;
+
+  YamlMap toYaml() {
+    return YamlMap.wrap(_descriptor);
+  }
 }
 
 class Font {
-  Font(this.familyName, this.fontAssets)
-    : assert(fontAssets.isNotEmpty);
+  Font(this.familyName, this.fontAssets) : assert(fontAssets.isNotEmpty);
 
   final String familyName;
   final List<FontAsset> fontAssets;
@@ -435,7 +488,6 @@ class FontAsset {
   String toString() => '$runtimeType(asset: ${assetUri.path}, weight; $weight, style: $style)';
 }
 
-
 bool _validate(Object? manifest, Logger logger) {
   final List<String> errors = <String>[];
   if (manifest is! YamlMap) {
@@ -456,12 +508,14 @@ bool _validate(Object? manifest, Logger logger) {
             continue;
           }
           if (kvp.value is! YamlMap) {
-            errors.add('Expected "${kvp.key}" section to be an object or null, but got ${kvp.value}.');
+            errors.add(
+              'Expected "${kvp.key}" section to be an object or null, but got ${kvp.value}.',
+            );
           } else {
             _validateFlutter(kvp.value as YamlMap?, errors);
           }
         default:
-        // additionalProperties are allowed.
+          // additionalProperties are allowed.
           break;
       }
     }
@@ -490,23 +544,17 @@ void _validateFlutter(YamlMap? yaml, List<String> errors) {
     switch (yamlKey) {
       case 'uses-material-design':
         if (yamlValue is! bool) {
-          errors.add('Expected "$yamlKey" to be a bool, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be a bool, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
         }
       case 'assets':
         errors.addAll(_validateAssets(yamlValue));
       case 'shaders':
         if (yamlValue is! YamlList) {
-          errors.add('Expected "$yamlKey" to be a list, but got $yamlValue (${yamlValue.runtimeType}).');
-        } else if (yamlValue.isEmpty) {
-          break;
-        } else if (yamlValue[0] is! String) {
           errors.add(
-            'Expected "$yamlKey" to be a list of strings, but the first element is $yamlValue (${yamlValue.runtimeType}).',
+            'Expected "$yamlKey" to be a list, but got $yamlValue (${yamlValue.runtimeType}).',
           );
-        }
-      case 'models':
-        if (yamlValue is! YamlList) {
-          errors.add('Expected "$yamlKey" to be a list, but got $yamlValue (${yamlValue.runtimeType}).');
         } else if (yamlValue.isEmpty) {
           break;
         } else if (yamlValue[0] is! String) {
@@ -516,7 +564,9 @@ void _validateFlutter(YamlMap? yaml, List<String> errors) {
         }
       case 'fonts':
         if (yamlValue is! YamlList) {
-          errors.add('Expected "$yamlKey" to be a list, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be a list, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
         } else if (yamlValue.isEmpty) {
           break;
         } else if (yamlValue.first is! YamlMap) {
@@ -531,7 +581,9 @@ void _validateFlutter(YamlMap? yaml, List<String> errors) {
         errors.addAll(filesErrors);
       case 'module':
         if (yamlValue is! YamlMap) {
-          errors.add('Expected "$yamlKey" to be an object, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be an object, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
           break;
         }
 
@@ -541,12 +593,15 @@ void _validateFlutter(YamlMap? yaml, List<String> errors) {
         if (yamlValue['androidPackage'] != null && yamlValue['androidPackage'] is! String) {
           errors.add('The "androidPackage" value must be a string if set.');
         }
-        if (yamlValue['iosBundleIdentifier'] != null && yamlValue['iosBundleIdentifier'] is! String) {
+        if (yamlValue['iosBundleIdentifier'] != null &&
+            yamlValue['iosBundleIdentifier'] is! String) {
           errors.add('The "iosBundleIdentifier" section must be a string if set.');
         }
       case 'plugin':
         if (yamlValue is! YamlMap) {
-          errors.add('Expected "$yamlKey" to be an object, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be an object, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
           break;
         }
         final List<String> pluginErrors = Plugin.validatePluginYaml(yamlValue);
@@ -557,31 +612,40 @@ void _validateFlutter(YamlMap? yaml, List<String> errors) {
         _validateDeferredComponents(kvp, errors);
       case 'disable-swift-package-manager':
         if (yamlValue is! bool) {
-          errors.add('Expected "$yamlKey" to be a bool, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be a bool, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
         }
       case 'default-flavor':
         if (yamlValue is! String) {
-          errors.add('Expected "$yamlKey" to be a string, but got $yamlValue (${yamlValue.runtimeType}).');
+          errors.add(
+            'Expected "$yamlKey" to be a string, but got $yamlValue (${yamlValue.runtimeType}).',
+          );
         }
       default:
         errors.add('Unexpected child "$yamlKey" found under "flutter".');
-        break;
     }
   }
 }
 
-(List<T>? result, List<String> errors) _parseList<T>(Object? yamlList, String context, String typeAlias) {
+(List<T>? result, List<String> errors) _parseList<T>(
+  Object? yamlList,
+  String context,
+  String typeAlias,
+) {
   final List<String> errors = <String>[];
 
   if (yamlList is! YamlList) {
-    final String message = 'Expected $context to be a list of $typeAlias, but got $yamlList (${yamlList.runtimeType}).';
+    final String message =
+        'Expected $context to be a list of $typeAlias, but got $yamlList (${yamlList.runtimeType}).';
     return (null, <String>[message]);
   }
 
   for (int i = 0; i < yamlList.length; i++) {
     if (yamlList[i] is! T) {
-      // ignore: avoid_dynamic_calls
-      errors.add('Expected $context to be a list of $typeAlias, but element at index $i was a ${yamlList[i].runtimeType}.');
+      errors.add(
+        'Expected $context to be a list of $typeAlias, but element at index $i was a ${yamlList[i].runtimeType}.',
+      );
     }
   }
 
@@ -596,12 +660,15 @@ void _validateDeferredComponents(MapEntry<Object?, Object?> kvp, List<String> er
     for (int i = 0; i < yamlList.length; i++) {
       final Object? valueMap = yamlList[i];
       if (valueMap is! YamlMap) {
-        // ignore: avoid_dynamic_calls
-        errors.add('Expected the $i element in "${kvp.key}" to be a map, but got ${yamlList[i]} (${yamlList[i].runtimeType}).');
+        errors.add(
+          'Expected the $i element in "${kvp.key}" to be a map, but got ${yamlList[i]} (${yamlList[i].runtimeType}).',
+        );
         continue;
       }
       if (!valueMap.containsKey('name') || valueMap['name'] is! String) {
-        errors.add('Expected the $i element in "${kvp.key}" to have required key "name" of type String');
+        errors.add(
+          'Expected the $i element in "${kvp.key}" to have required key "name" of type String',
+        );
       }
       if (valueMap.containsKey('libraries')) {
         final (_, List<String> librariesErrors) = _parseList<String>(
@@ -652,22 +719,24 @@ List<String> _validateAssets(Object? yaml) {
 List<AssetsEntry> _computeAssets(Object? assetsSection) {
   final (List<AssetsEntry> result, List<String> errors) = _computeAssetsSafe(assetsSection);
   if (errors.isNotEmpty) {
-    throw Exception('Uncaught error(s) in assets section: '
-      '${errors.join('\n')}');
+    throw Exception(
+      'Uncaught error(s) in assets section: '
+      '${errors.join('\n')}',
+    );
   }
   return result;
 }
 
 void _validateFonts(YamlList fonts, List<String> errors) {
-  const Set<int> fontWeights = <int>{
-    100, 200, 300, 400, 500, 600, 700, 800, 900,
-  };
+  const Set<int> fontWeights = <int>{100, 200, 300, 400, 500, 600, 700, 800, 900};
   for (final Object? fontMap in fonts) {
     if (fontMap is! YamlMap) {
       errors.add('Unexpected child "$fontMap" found under "fonts". Expected a map.');
       continue;
     }
-    for (final Object? key in fontMap.keys.where((Object? key) => key != 'family' && key != 'fonts')) {
+    for (final Object? key in fontMap.keys.where(
+      (Object? key) => key != 'family' && key != 'fonts',
+    )) {
       errors.add('Unexpected child "$key" found under "fonts".');
     }
     if (fontMap['family'] != null && fontMap['family'] is! String) {
@@ -692,19 +761,24 @@ void _validateFonts(YamlList fonts, List<String> errors) {
         switch (fontKey) {
           case 'asset':
             if (kvp.value is! String) {
-              errors.add('Expected font asset ${kvp.value} ((${kvp.value.runtimeType})) to be a string.');
+              errors.add(
+                'Expected font asset ${kvp.value} ((${kvp.value.runtimeType})) to be a string.',
+              );
             }
           case 'weight':
             if (!fontWeights.contains(kvp.value)) {
-              errors.add('Invalid value ${kvp.value} ((${kvp.value.runtimeType})) for font -> weight.');
+              errors.add(
+                'Invalid value ${kvp.value} ((${kvp.value.runtimeType})) for font -> weight.',
+              );
             }
           case 'style':
             if (kvp.value != 'normal' && kvp.value != 'italic') {
-              errors.add('Invalid value ${kvp.value} ((${kvp.value.runtimeType})) for font -> style.');
+              errors.add(
+                'Invalid value ${kvp.value} ((${kvp.value.runtimeType})) for font -> style.',
+              );
             }
           default:
             errors.add('Unexpected key $fontKey ((${kvp.value.runtimeType})) under font.');
-            break;
         }
       }
     }
@@ -724,6 +798,18 @@ class AssetsEntry {
   final Set<String> flavors;
   final List<AssetTransformerEntry> transformers;
 
+  Object? get descriptor {
+    if (transformers.isEmpty && flavors.isEmpty) {
+      return uri.toString();
+    }
+    return <String, Object?>{
+      _pathKey: uri.toString(),
+      if (flavors.isNotEmpty) _flavorKey: flavors.toList(),
+      if (transformers.isNotEmpty)
+        _transformersKey: transformers.map((AssetTransformerEntry e) => e.descriptor).toList(),
+    };
+  }
+
   static const String _pathKey = 'path';
   static const String _flavorKey = 'flavors';
   static const String _transformersKey = 'transformers';
@@ -737,7 +823,6 @@ class AssetsEntry {
   }
 
   static (AssetsEntry? assetsEntry, String? error) parseFromYamlSafe(Object? yaml) {
-
     (Uri?, String?) tryParseUri(String uri) {
       try {
         return (Uri(pathSegments: uri.split('/')), null);
@@ -763,26 +848,30 @@ class AssetsEntry {
       final Object? path = yaml[_pathKey];
 
       if (path == null || path is! String) {
-        return (null, 'Asset manifest entry is malformed. '
-          'Expected asset entry to be either a string or a map '
-          'containing a "$_pathKey" entry. Got ${path.runtimeType} instead.');
+        return (
+          null,
+          'Asset manifest entry is malformed. '
+              'Expected asset entry to be either a string or a map '
+              'containing a "$_pathKey" entry. Got ${path.runtimeType} instead.',
+        );
       }
 
-      final (List<String>? flavors, List<String> flavorsErrors) = _parseFlavorsSection(yaml[_flavorKey]);
-      final (List<AssetTransformerEntry>? transformers, List<String> transformersErrors) = _parseTransformersSection(yaml[_transformersKey]);
+      final (List<String>? flavors, List<String> flavorsErrors) = _parseFlavorsSection(
+        yaml[_flavorKey],
+      );
+      final (
+        List<AssetTransformerEntry>? transformers,
+        List<String> transformersErrors,
+      ) = _parseTransformersSection(yaml[_transformersKey]);
 
       final List<String> errors = <String>[
         ...flavorsErrors.map((String e) => 'In $_flavorKey section of asset "$path": $e'),
-        ...transformersErrors.map((String e) => 'In $_transformersKey section of asset "$path": $e'),
+        ...transformersErrors.map(
+          (String e) => 'In $_transformersKey section of asset "$path": $e',
+        ),
       ];
       if (errors.isNotEmpty) {
-        return (
-          null,
-          <String>[
-            'Unable to parse assets section.',
-            ...errors
-          ].join('\n'),
-        );
+        return (null, <String>['Unable to parse assets section.', ...errors].join('\n'));
       }
 
       return (
@@ -795,8 +884,11 @@ class AssetsEntry {
       );
     }
 
-    return (null, 'Assets entry had unexpected shape. '
-      'Expected a string or an object. Got ${yaml.runtimeType} instead.');
+    return (
+      null,
+      'Assets entry had unexpected shape. '
+          'Expected a string or an object. Got ${yaml.runtimeType} instead.',
+    );
   }
 
   static (List<String>? flavors, List<String> errors) _parseFlavorsSection(Object? yaml) {
@@ -807,7 +899,9 @@ class AssetsEntry {
     return _parseList<String>(yaml, _flavorKey, 'String');
   }
 
-  static (List<AssetTransformerEntry>?, List<String> errors) _parseTransformersSection(Object? yaml) {
+  static (List<AssetTransformerEntry>?, List<String> errors) _parseTransformersSection(
+    Object? yaml,
+  ) {
     if (yaml == null) {
       return (null, <String>[]);
     }
@@ -824,7 +918,10 @@ class AssetsEntry {
     final List<AssetTransformerEntry> transformers = <AssetTransformerEntry>[];
     final List<String> errors = <String>[];
     for (final YamlMap yaml in yamlObjects!) {
-      final (AssetTransformerEntry? transformerEntry, List<String> transformerErrors) = AssetTransformerEntry.tryParse(yaml);
+      final (
+        AssetTransformerEntry? transformerEntry,
+        List<String> transformerErrors,
+      ) = AssetTransformerEntry.tryParse(yaml);
       if (transformerEntry != null) {
         transformers.add(transformerEntry);
       } else {
@@ -858,18 +955,22 @@ class AssetsEntry {
   String toString() => 'AssetsEntry(uri: $uri, flavors: $flavors, transformers: $transformers)';
 }
 
-
 /// Represents an entry in the "transformers" section of an asset.
 @immutable
 final class AssetTransformerEntry {
-  const AssetTransformerEntry({
-    required this.package,
-    required List<String>? args,
-  }): args = args ?? const <String>[];
+  const AssetTransformerEntry({required this.package, required List<String>? args})
+    : args = args ?? const <String>[];
 
   final String package;
   final List<String>? args;
 
+  Map<String, Object?> get descriptor {
+    return <String, Object?>{_kPackage: package, if (args != null) _kArgs: args};
+  }
+
+  static const String _kPackage = 'package';
+  static const String _kArgs = 'args';
+
   static (AssetTransformerEntry? entry, List<String> errors) tryParse(Object? yaml) {
     if (yaml == null) {
       return (null, <String>['Transformer entry is null.']);
@@ -880,21 +981,23 @@ final class AssetTransformerEntry {
 
     final Object? package = yaml['package'];
     if (package is! String || package.isEmpty) {
-      return (null, <String>['Expected "package" to be a String. Found ${package.runtimeType} instead.']);
+      return (
+        null,
+        <String>['Expected "package" to be a String. Found ${package.runtimeType} instead.'],
+      );
     }
 
     final (List<String>? args, List<String> argsErrors) = _parseArgsSection(yaml['args']);
     if (argsErrors.isNotEmpty) {
-      return (null, argsErrors.map((String e) => 'In args section of transformer using package "$package": $e').toList());
+      return (
+        null,
+        argsErrors
+            .map((String e) => 'In args section of transformer using package "$package": $e')
+            .toList(),
+      );
     }
 
-    return (
-      AssetTransformerEntry(
-        package: package,
-        args: args,
-      ),
-      <String>[],
-    );
+    return (AssetTransformerEntry(package: package, args: args), <String>[]);
   }
 
   static (List<String>? args, List<String> errors) _parseArgsSection(Object? yaml) {
@@ -913,32 +1016,29 @@ final class AssetTransformerEntry {
       return false;
     }
 
-    final bool argsAreEqual = (() {
-      if (args == null && other.args == null) {
-        return true;
-      }
-      if (args?.length != other.args?.length) {
-        return false;
-      }
+    final bool argsAreEqual =
+        (() {
+          if (args == null && other.args == null) {
+            return true;
+          }
+          if (args?.length != other.args?.length) {
+            return false;
+          }
 
-      for (int index = 0; index < args!.length; index += 1) {
-        if (args![index] != other.args![index]) {
-          return false;
-        }
-      }
-      return true;
-    })();
+          for (int index = 0; index < args!.length; index += 1) {
+            if (args![index] != other.args![index]) {
+              return false;
+            }
+          }
+          return true;
+        })();
 
     return package == other.package && argsAreEqual;
   }
 
   @override
-  int get hashCode => Object.hashAll(
-    <Object?>[
-      package.hashCode,
-      args?.map((String e) => e.hashCode),
-    ],
-  );
+  int get hashCode =>
+      Object.hashAll(<Object?>[package.hashCode, args?.map((String e) => e.hashCode)]);
 
   @override
   String toString() {
