@@ -6,7 +6,10 @@ import 'dart:async';
 
 import 'package:meta/meta.dart';
 import 'package:process/process.dart';
+import 'package:xml/xml.dart';
+import 'package:xml/xpath.dart';
 
+import '../base/common.dart';
 import '../base/error_handling_io.dart';
 import '../base/file_system.dart';
 import '../base/io.dart';
@@ -25,10 +28,10 @@ class XcodeDebug {
     required ProcessManager processManager,
     required Xcode xcode,
     required FileSystem fileSystem,
-  })  : _logger = logger,
-        _processUtils = ProcessUtils(logger: logger, processManager: processManager),
-        _xcode = xcode,
-        _fileSystem = fileSystem;
+  }) : _logger = logger,
+       _processUtils = ProcessUtils(logger: logger, processManager: processManager),
+       _xcode = xcode,
+       _fileSystem = fileSystem;
 
   final ProcessUtils _processUtils;
   final Logger _logger;
@@ -58,7 +61,6 @@ class XcodeDebug {
     required String deviceId,
     required List<String> launchArguments,
   }) async {
-
     // If project is not already opened in Xcode, open it.
     if (!await _isProjectOpenInXcode(project: project)) {
       final bool openResult = await _openProjectInXcode(xcodeWorkspace: project.xcodeWorkspace);
@@ -71,37 +73,34 @@ class XcodeDebug {
     StreamSubscription<String>? stdoutSubscription;
     StreamSubscription<String>? stderrSubscription;
     try {
-      startDebugActionProcess = await _processUtils.start(
-        <String>[
-          ..._xcode.xcrunCommand(),
-          'osascript',
-          '-l',
-          'JavaScript',
-          _xcode.xcodeAutomationScriptPath,
-          'debug',
-          '--xcode-path',
-          _xcode.xcodeAppPath,
-          '--project-path',
-          project.xcodeProject.path,
-          '--workspace-path',
-          project.xcodeWorkspace.path,
-          '--project-name',
-          project.hostAppProjectName,
-          if (project.expectedConfigurationBuildDir != null)
-            ...<String>[
-              '--expected-configuration-build-dir',
-              project.expectedConfigurationBuildDir!,
-            ],
-          '--device-id',
-          deviceId,
-          '--scheme',
-          project.scheme,
-          '--skip-building',
-          '--launch-args',
-          json.encode(launchArguments),
-          if (project.verboseLogging) '--verbose',
+      startDebugActionProcess = await _processUtils.start(<String>[
+        ..._xcode.xcrunCommand(),
+        'osascript',
+        '-l',
+        'JavaScript',
+        _xcode.xcodeAutomationScriptPath,
+        'debug',
+        '--xcode-path',
+        _xcode.xcodeAppPath,
+        '--project-path',
+        project.xcodeProject.path,
+        '--workspace-path',
+        project.xcodeWorkspace.path,
+        '--project-name',
+        project.hostAppProjectName,
+        if (project.expectedConfigurationBuildDir != null) ...<String>[
+          '--expected-configuration-build-dir',
+          project.expectedConfigurationBuildDir!,
         ],
-      );
+        '--device-id',
+        deviceId,
+        '--scheme',
+        project.scheme,
+        '--skip-building',
+        '--launch-args',
+        json.encode(launchArguments),
+        if (project.verboseLogging) '--verbose',
+      ]);
 
       final StringBuffer stdoutBuffer = StringBuffer();
       stdoutSubscription = startDebugActionProcess!.stdout
@@ -110,7 +109,7 @@ class XcodeDebug {
           .listen((String line) {
             _logger.printTrace(line);
             stdoutBuffer.write(line);
-      });
+          });
 
       final StringBuffer stderrBuffer = StringBuffer();
       bool permissionWarningPrinted = false;
@@ -122,16 +121,18 @@ class XcodeDebug {
             _logger.printTrace('stderr: $line');
             stderrBuffer.write(line);
 
-          // This error may occur if Xcode automation has not been allowed.
-          // Example: Failed to get workspace: Error: An error occurred.
-          if (!permissionWarningPrinted && line.contains('Failed to get workspace') && line.contains('An error occurred')) {
-            _logger.printError(
-              'There was an error finding the project in Xcode. Ensure permission '
-              'has been given to control Xcode in Settings > Privacy & Security > Automation.',
-            );
-            permissionWarningPrinted = true;
-          }
-      });
+            // This error may occur if Xcode automation has not been allowed.
+            // Example: Failed to get workspace: Error: An error occurred.
+            if (!permissionWarningPrinted &&
+                line.contains('Failed to get workspace') &&
+                line.contains('An error occurred')) {
+              _logger.printError(
+                'There was an error finding the project in Xcode. Ensure permission '
+                'has been given to control Xcode in Settings > Privacy & Security > Automation.',
+              );
+              permissionWarningPrinted = true;
+            }
+          });
 
       final int exitCode = await startDebugActionProcess!.exitCode.whenComplete(() async {
         await stdoutSubscription?.cancel();
@@ -144,9 +145,7 @@ class XcodeDebug {
         return false;
       }
 
-      final XcodeAutomationScriptResponse? response = parseScriptResponse(
-        stdoutBuffer.toString(),
-      );
+      final XcodeAutomationScriptResponse? response = parseScriptResponse(stdoutBuffer.toString());
       if (response == null) {
         return false;
       }
@@ -163,7 +162,7 @@ class XcodeDebug {
           'Unexpected debug results: \n'
           '  Status: ${response.debugResult?.status}\n'
           '  Completed: ${response.debugResult?.completed}\n'
-          '  Error Message: ${response.debugResult?.errorMessage}\n'
+          '  Error Message: ${response.debugResult?.errorMessage}\n',
         );
         return false;
       }
@@ -182,11 +181,7 @@ class XcodeDebug {
   /// will kill all Xcode app processes. Otherwise, it will stop the debug
   /// session in Xcode. If the project is temporary, it will close the Xcode
   /// window of the project and then delete the project.
-  Future<bool> exit({
-    bool force = false,
-    @visibleForTesting
-    bool skipDelay = false,
-  }) async {
+  Future<bool> exit({bool force = false, @visibleForTesting bool skipDelay = false}) async {
     final bool success = (startDebugActionProcess == null) || startDebugActionProcess!.kill();
 
     if (force) {
@@ -196,10 +191,7 @@ class XcodeDebug {
         if (project.isTemporaryProject) {
           // Only delete if it exists. This is to prevent crashes when racing
           // with shutdown hooks to delete temporary files.
-          ErrorHandlingFileSystem.deleteIfExists(
-            project.xcodeProject.parent,
-            recursive: true,
-          );
+          ErrorHandlingFileSystem.deleteIfExists(project.xcodeProject.parent, recursive: true);
         }
         currentDebuggingProject = null;
       }
@@ -207,10 +199,7 @@ class XcodeDebug {
 
     if (currentDebuggingProject != null) {
       final XcodeDebugProject project = currentDebuggingProject!;
-      await stopDebuggingApp(
-        project: project,
-        closeXcode: project.isTemporaryProject,
-      );
+      await stopDebuggingApp(project: project, closeXcode: project.isTemporaryProject);
 
       if (project.isTemporaryProject) {
         // Wait a couple seconds before deleting the project. If project is
@@ -223,7 +212,9 @@ class XcodeDebug {
         try {
           project.xcodeProject.parent.deleteSync(recursive: true);
         } on FileSystemException {
-          _logger.printError('Failed to delete temporary Xcode project: ${project.xcodeProject.parent.path}');
+          _logger.printError(
+            'Failed to delete temporary Xcode project: ${project.xcodeProject.parent.path}',
+          );
         }
       }
       currentDebuggingProject = null;
@@ -234,13 +225,7 @@ class XcodeDebug {
 
   /// Kill all opened Xcode applications.
   Future<bool> _forceExitXcode() async {
-    final RunResult result = await _processUtils.run(
-      <String>[
-        'killall',
-        '-9',
-        'Xcode',
-      ],
-    );
+    final RunResult result = await _processUtils.run(<String>['killall', '-9', 'Xcode']);
 
     if (result.exitCode != 0) {
       _logger.printError('Error killing Xcode: ${result.exitCode}\n${result.stderr}');
@@ -249,27 +234,22 @@ class XcodeDebug {
     return true;
   }
 
-  Future<bool> _isProjectOpenInXcode({
-    required XcodeDebugProject project,
-  }) async {
-
-    final RunResult result = await _processUtils.run(
-      <String>[
-        ..._xcode.xcrunCommand(),
-        'osascript',
-        '-l',
-        'JavaScript',
-        _xcode.xcodeAutomationScriptPath,
-        'check-workspace-opened',
-        '--xcode-path',
-        _xcode.xcodeAppPath,
-        '--project-path',
-        project.xcodeProject.path,
-        '--workspace-path',
-        project.xcodeWorkspace.path,
-        if (project.verboseLogging) '--verbose',
-      ],
-    );
+  Future<bool> _isProjectOpenInXcode({required XcodeDebugProject project}) async {
+    final RunResult result = await _processUtils.run(<String>[
+      ..._xcode.xcrunCommand(),
+      'osascript',
+      '-l',
+      'JavaScript',
+      _xcode.xcodeAutomationScriptPath,
+      'check-workspace-opened',
+      '--xcode-path',
+      _xcode.xcodeAppPath,
+      '--project-path',
+      project.xcodeProject.path,
+      '--workspace-path',
+      project.xcodeWorkspace.path,
+      if (project.verboseLogging) '--verbose',
+    ]);
 
     if (result.exitCode != 0) {
       _logger.printError('Error executing osascript: ${result.exitCode}\n${result.stderr}');
@@ -289,39 +269,47 @@ class XcodeDebug {
 
   @visibleForTesting
   XcodeAutomationScriptResponse? parseScriptResponse(String results) {
+    // Some users reported text before the json. Trim any text before the opening
+    // curly brace.
+    // Example: `start process_extensions{"status":true,"errorMessage":null,"debugResult":{"completed":false,"status":"running","errorMessage":null}}`
+    final String trimmedResults;
+    final int jsonBeginIndex = results.indexOf('{');
+    if (jsonBeginIndex > -1) {
+      trimmedResults = results.substring(jsonBeginIndex);
+    } else {
+      trimmedResults = results;
+    }
+
     try {
-      final Object decodeResult = json.decode(results) as Object;
+      final Object decodeResult = json.decode(trimmedResults) as Object;
       if (decodeResult is Map<String, Object?>) {
-        final XcodeAutomationScriptResponse response = XcodeAutomationScriptResponse.fromJson(decodeResult);
+        final XcodeAutomationScriptResponse response = XcodeAutomationScriptResponse.fromJson(
+          decodeResult,
+        );
         // Status should always be found
         if (response.status != null) {
           return response;
         }
       }
-      _logger.printError('osascript returned unexpected JSON response: $results');
+      _logger.printError('osascript returned unexpected JSON response: $trimmedResults');
       return null;
     } on FormatException {
-      _logger.printError('osascript returned non-JSON response: $results');
+      _logger.printError('osascript returned non-JSON response: $trimmedResults');
       return null;
     }
   }
 
-  Future<bool> _openProjectInXcode({
-    required Directory xcodeWorkspace,
-  }) async {
+  Future<bool> _openProjectInXcode({required Directory xcodeWorkspace}) async {
     try {
-      await _processUtils.run(
-        <String>[
-          'open',
-          '-a',
-          _xcode.xcodeAppPath,
-          '-g', // Do not bring the application to the foreground.
-          '-j', // Launches the app hidden.
-          '-F', // Open "fresh", without restoring windows.
-          xcodeWorkspace.path
-        ],
-        throwOnError: true,
-      );
+      await _processUtils.run(<String>[
+        'open',
+        '-a',
+        _xcode.xcodeAppPath,
+        '-g', // Do not bring the application to the foreground.
+        '-j', // Launches the app hidden.
+        '-F', // Open "fresh", without restoring windows.
+        xcodeWorkspace.path,
+      ], throwOnError: true);
       return true;
     } on ProcessException catch (error, stackTrace) {
       _logger.printError('$error', stackTrace: stackTrace);
@@ -339,25 +327,23 @@ class XcodeDebug {
     bool closeXcode = false,
     bool promptToSaveOnClose = false,
   }) async {
-    final RunResult result = await _processUtils.run(
-      <String>[
-        ..._xcode.xcrunCommand(),
-        'osascript',
-        '-l',
-        'JavaScript',
-        _xcode.xcodeAutomationScriptPath,
-        'stop',
-        '--xcode-path',
-        _xcode.xcodeAppPath,
-        '--project-path',
-        project.xcodeProject.path,
-        '--workspace-path',
-        project.xcodeWorkspace.path,
-        if (closeXcode) '--close-window',
-        if (promptToSaveOnClose) '--prompt-to-save',
-        if (project.verboseLogging) '--verbose',
-      ],
-    );
+    final RunResult result = await _processUtils.run(<String>[
+      ..._xcode.xcrunCommand(),
+      'osascript',
+      '-l',
+      'JavaScript',
+      _xcode.xcodeAutomationScriptPath,
+      'stop',
+      '--xcode-path',
+      _xcode.xcodeAppPath,
+      '--project-path',
+      project.xcodeProject.path,
+      '--workspace-path',
+      project.xcodeWorkspace.path,
+      if (closeXcode) '--close-window',
+      if (promptToSaveOnClose) '--prompt-to-save',
+      if (project.verboseLogging) '--verbose',
+    ]);
 
     if (result.exitCode != 0) {
       _logger.printError('Error executing osascript: ${result.exitCode}\n${result.stderr}');
@@ -380,11 +366,12 @@ class XcodeDebug {
   Future<XcodeDebugProject> createXcodeProjectWithCustomBundle(
     String deviceBundlePath, {
     required TemplateRenderer templateRenderer,
-    @visibleForTesting
-    Directory? projectDestination,
+    @visibleForTesting Directory? projectDestination,
     bool verboseLogging = false,
   }) async {
-    final Directory tempXcodeProject = projectDestination ?? _fileSystem.systemTempDirectory.createTempSync('flutter_empty_xcode.');
+    final Directory tempXcodeProject =
+        projectDestination ??
+        _fileSystem.systemTempDirectory.createTempSync('flutter_empty_xcode.');
 
     final Template template = await Template.fromName(
       _fileSystem.path.join('xcode', 'ios', 'custom_application_bundle'),
@@ -394,13 +381,9 @@ class XcodeDebug {
       templateRenderer: templateRenderer,
     );
 
-    template.render(
-      tempXcodeProject,
-      <String, Object>{
-        'applicationBundlePath': deviceBundlePath
-      },
-      printStatusWhenWriting: false,
-    );
+    template.render(tempXcodeProject, <String, Object>{
+      'applicationBundlePath': deviceBundlePath,
+    }, printStatusWhenWriting: false);
 
     return XcodeDebugProject(
       scheme: 'Runner',
@@ -411,22 +394,63 @@ class XcodeDebug {
       verboseLogging: verboseLogging,
     );
   }
+
+  /// Ensure the Xcode project is set up to launch an LLDB debugger. If these
+  /// settings are not set, the launch will fail with a "Cannot create a
+  /// FlutterEngine instance in debug mode without Flutter tooling or Xcode."
+  /// error message. These settings should be correct by default, but some users
+  /// reported them not being so after upgrading to Xcode 15.
+  void ensureXcodeDebuggerLaunchAction(File schemeFile) {
+    if (!schemeFile.existsSync()) {
+      _logger.printError('Failed to find ${schemeFile.path}');
+      return;
+    }
+
+    final String schemeXml = schemeFile.readAsStringSync();
+    try {
+      final XmlDocument document = XmlDocument.parse(schemeXml);
+      final Iterable<XmlNode> nodes = document.xpath('/Scheme/LaunchAction');
+      if (nodes.isEmpty) {
+        _logger.printError('Failed to find LaunchAction for the Scheme in ${schemeFile.path}.');
+        return;
+      }
+      final XmlNode launchAction = nodes.first;
+      final XmlAttribute? debuggerIdentifier =
+          launchAction.attributes
+              .where(
+                (XmlAttribute attribute) => attribute.localName == 'selectedDebuggerIdentifier',
+              )
+              .firstOrNull;
+      final XmlAttribute? launcherIdentifier =
+          launchAction.attributes
+              .where(
+                (XmlAttribute attribute) => attribute.localName == 'selectedLauncherIdentifier',
+              )
+              .firstOrNull;
+      if (debuggerIdentifier == null ||
+          launcherIdentifier == null ||
+          !debuggerIdentifier.value.contains('LLDB') ||
+          !launcherIdentifier.value.contains('LLDB')) {
+        throwToolExit('''
+Your Xcode project is not setup to start a debugger. To fix this, launch Xcode
+and select "Product > Scheme > Edit Scheme", select "Run" in the sidebar,
+and ensure "Debug executable" is checked in the "Info" tab.
+''');
+      }
+    } on XmlException catch (exception) {
+      _logger.printError('Failed to parse ${schemeFile.path}: $exception');
+    }
+  }
 }
 
 @visibleForTesting
 class XcodeAutomationScriptResponse {
-  XcodeAutomationScriptResponse._({
-    this.status,
-    this.errorMessage,
-    this.debugResult,
-  });
+  XcodeAutomationScriptResponse._({this.status, this.errorMessage, this.debugResult});
 
   factory XcodeAutomationScriptResponse.fromJson(Map<String, Object?> data) {
     XcodeAutomationScriptDebugResult? debugResult;
-    if (data['debugResult'] != null && data['debugResult'] is Map<String, Object?>) {
-      debugResult = XcodeAutomationScriptDebugResult.fromJson(
-        data['debugResult']! as Map<String, Object?>,
-      );
+    if (data case {'debugResult': final Map<String, Object?> resultData}) {
+      debugResult = XcodeAutomationScriptDebugResult.fromJson(resultData);
     }
     return XcodeAutomationScriptResponse._(
       status: data['status'] is bool? ? data['status'] as bool? : null,
@@ -456,7 +480,7 @@ class XcodeAutomationScriptDebugResult {
     );
   }
 
-  /// Whether this scheme action has completed (sucessfully or otherwise). Will
+  /// Whether this scheme action has completed (successfully or otherwise). Will
   /// be false if still running.
   final bool? completed;
 
