@@ -133,6 +133,9 @@ class HotRunner extends ResidentRunner {
 
   String? flavor;
 
+  @override
+  bool get supportsDetach => stopAppDuringCleanup;
+
   Future<void> _calculateTargetPlatform() async {
     if (_targetPlatform != null) {
       return;
@@ -253,12 +256,10 @@ class HotRunner extends ResidentRunner {
         reloadSources: _reloadSourcesService,
         restart: _restartService,
         compileExpression: _compileExpressionService,
-        getSkSLMethod: writeSkSL,
         allowExistingDdsInstance: allowExistingDdsInstance,
       );
       // Catches all exceptions, non-Exception objects are rethrown.
     } catch (error) {
-      // ignore: avoid_catches_without_on_clauses
       if (error is! Exception && error is! String) {
         rethrow;
       }
@@ -536,7 +537,7 @@ class HotRunner extends ResidentRunner {
           bundleFirstUpload: isFirstUpload,
           bundleDirty: !isFirstUpload && rebuildBundle,
           fullRestart: fullRestart,
-          pathToReload: getReloadPath(fullRestart: fullRestart, swap: _swap),
+          pathToReload: getReloadPath(resetCompiler: fullRestart, swap: _swap),
           invalidatedFiles: invalidationResult.uris!,
           packageConfig: invalidationResult.packageConfig!,
           dillOutputPath: dillOutputPath,
@@ -556,7 +557,6 @@ class HotRunner extends ResidentRunner {
       }
       devFS.assetPathsToEvict.clear();
       devFS.shaderPathsToEvict.clear();
-      devFS.scenePathsToEvict.clear();
     }
   }
 
@@ -645,7 +645,7 @@ class HotRunner extends ResidentRunner {
         );
         operations.add(
           reloadIsolate.then((vm_service.Isolate? isolate) async {
-            if ((isolate != null) && isPauseEvent(isolate.pauseEvent!.kind!)) {
+            if (isolate != null) {
               // The embedder requires that the isolate is unpaused, because the
               // runInView method requires interaction with dart engine APIs that
               // are not thread-safe, and thus must be run on the same thread that
@@ -655,7 +655,7 @@ class HotRunner extends ResidentRunner {
               // or in a frequently called method) or an exception. Instead, all
               // breakpoints are first disabled and exception pause mode set to
               // None, and then the isolate resumed.
-              // These settings to not need restoring as Hot Restart results in
+              // These settings do not need restoring as Hot Restart results in
               // new isolates, which will be configured by the editor as they are
               // started.
               final List<Future<void>> breakpointAndExceptionRemoval = <Future<void>>[
@@ -667,12 +667,22 @@ class HotRunner extends ResidentRunner {
                   device.vmService!.service.removeBreakpoint(isolate.id!, breakpoint.id!),
               ];
               await Future.wait(breakpointAndExceptionRemoval);
-              await device.vmService!.service.resume(view.uiIsolate!.id!);
+              if (isPauseEvent(isolate.pauseEvent!.kind!)) {
+                await device.vmService!.service.resume(view.uiIsolate!.id!);
+              }
             }
           }),
         );
       }
 
+      // Wait for the UI isolates to have their breakpoints removed and exception pause mode
+      // cleared while also ensuring the isolate's are no longer paused. If we don't clear
+      // the exception pause mode before we start killing child isolates, it's possible that
+      // any UI isolate waiting on a result from a child isolate could throw an unhandled
+      // exception and re-pause the isolate, causing hot restart to hang.
+      await Future.wait(operations);
+      operations.clear();
+
       // The engine handles killing and recreating isolates that it has spawned
       // ("uiIsolates"). The isolates that were spawned from these uiIsolates
       // will not be restarted, and so they must be manually killed.
@@ -716,7 +726,6 @@ class HotRunner extends ResidentRunner {
 
     // Send timing analytics.
     final Duration elapsedDuration = restartTimer.elapsed;
-    globals.flutterUsage.sendTiming('hot', 'restart', elapsedDuration);
     _analytics.send(
       Event.timing(
         workflow: 'hot',
@@ -1046,7 +1055,6 @@ class HotRunner extends ResidentRunner {
         sdkName,
         emulator,
         reason,
-        globals.flutterUsage,
         globals.analytics,
       );
       if (result.code != 0) {
@@ -1145,7 +1153,6 @@ class HotRunner extends ResidentRunner {
     if ((reassembleResult.reassembleViews.length == 1) &&
         !reassembleResult.failedReassemble &&
         shouldReportReloadTime) {
-      globals.flutterUsage.sendTiming('hot', 'reload', reloadDuration);
       _analytics.send(
         Event.timing(
           workflow: 'hot',
@@ -1161,42 +1168,11 @@ class HotRunner extends ResidentRunner {
     );
   }
 
-  @override
-  void printHelp({required bool details}) {
-    globals.printStatus('Flutter run key commands.');
-    commandHelp.r.print();
-    if (supportsRestart) {
-      commandHelp.R.print();
-    }
-    if (details) {
-      printHelpDetails();
-      commandHelp.hWithDetails.print();
-    } else {
-      commandHelp.hWithoutDetails.print();
-    }
-    if (stopAppDuringCleanup) {
-      commandHelp.d.print();
-    }
-    commandHelp.c.print();
-    commandHelp.q.print();
-    if (debuggingOptions.buildInfo.nullSafetyMode != NullSafetyMode.sound) {
-      globals.printStatus('');
-      globals.printStatus('Running without sound null safety ⚠️', emphasis: true);
-      globals.printStatus(
-        'Dart 3 will only support sound null safety, see https://dart.dev/null-safety',
-      );
-    }
-    globals.printStatus('');
-    printDebuggerList();
-  }
-
   @visibleForTesting
   Future<void> evictDirtyAssets() async {
     final List<Future<void>> futures = <Future<void>>[];
     for (final FlutterDevice? device in flutterDevices) {
-      if (device!.devFS!.assetPathsToEvict.isEmpty &&
-          device.devFS!.shaderPathsToEvict.isEmpty &&
-          device.devFS!.scenePathsToEvict.isEmpty) {
+      if (device!.devFS!.assetPathsToEvict.isEmpty && device.devFS!.shaderPathsToEvict.isEmpty) {
         continue;
       }
       final List<FlutterView> views = await device.vmService!.getFlutterViews();
@@ -1246,14 +1222,8 @@ class HotRunner extends ResidentRunner {
           device.vmService!.flutterEvictShader(assetPath, isolateId: views.first.uiIsolate!.id!),
         );
       }
-      for (final String assetPath in device.devFS!.scenePathsToEvict) {
-        futures.add(
-          device.vmService!.flutterEvictScene(assetPath, isolateId: views.first.uiIsolate!.id!),
-        );
-      }
       device.devFS!.assetPathsToEvict.clear();
       device.devFS!.shaderPathsToEvict.clear();
-      device.devFS!.scenePathsToEvict.clear();
     }
     await Future.wait<void>(futures);
   }
@@ -1298,7 +1268,6 @@ typedef ReloadSourcesHelper =
       String? sdkName,
       bool? emulator,
       String? reason,
-      Usage usage,
       Analytics analytics,
     );
 
@@ -1312,7 +1281,6 @@ Future<OperationResult> defaultReloadSourcesHelper(
   String? sdkName,
   bool? emulator,
   String? reason,
-  Usage usage,
   Analytics analytics,
 ) async {
   final Stopwatch vmReloadTimer = Stopwatch()..start();
@@ -1348,22 +1316,12 @@ Future<OperationResult> defaultReloadSourcesHelper(
       (await Future.wait(allReportsFutures)).whereType<DeviceReloadReport>();
   final vm_service.ReloadReport? reloadReport = reports.isEmpty ? null : reports.first.reports[0];
   if (reloadReport == null || !HotRunner.validateReloadReport(reloadReport)) {
-    // Reload failed.
-    HotEvent(
-      'reload-reject',
-      targetPlatform: targetPlatform!,
-      sdkName: sdkName!,
-      emulator: emulator!,
-      fullRestart: false,
-      reason: reason,
-      usage: usage,
-    ).send();
     analytics.send(
       Event.hotRunnerInfo(
         label: 'reload-reject',
-        targetPlatform: targetPlatform,
-        sdkName: sdkName,
-        emulator: emulator,
+        targetPlatform: targetPlatform!,
+        sdkName: sdkName!,
+        emulator: emulator!,
         fullRestart: false,
         reason: reason,
       ),
@@ -1468,7 +1426,7 @@ Future<ReassembleResult> _defaultReassembleHelper(
         // If the tool identified a change in a single widget, do a fast instead
         // of a full reassemble.
         final Future<void> reassembleWork = device.vmService!.flutterReassemble(
-          isolateId: view.uiIsolate!.id!,
+          isolateId: view.uiIsolate!.id,
         );
         reassembleFutures.add(
           reassembleWork.then(
