@@ -5,17 +5,22 @@
 import 'dart:async';
 
 import 'package:test_core/src/executable.dart' as test; // ignore: implementation_imports
-import 'package:test_core/src/platform.dart' as hack show registerPlatformPlugin; // ignore: implementation_imports
+import 'package:test_core/src/platform.dart' // ignore: implementation_imports
+    as hack
+    show registerPlatformPlugin;
 import 'package:test_core/src/platform.dart'; // ignore: implementation_imports
 
-export 'package:test_api/backend.dart' show Runtime; // ignore: deprecated_member_use
+export 'package:test_api/backend.dart' show Runtime;
 export 'package:test_core/src/platform.dart' show PlatformPlugin;
 
 abstract class TestWrapper {
   const factory TestWrapper() = _DefaultTestWrapper;
 
   Future<void> main(List<String> args);
-  void registerPlatformPlugin(Iterable<Runtime> runtimes, FutureOr<PlatformPlugin> Function() platforms);
+  void registerPlatformPlugin(
+    Iterable<Runtime> runtimes,
+    FutureOr<PlatformPlugin> Function() platforms,
+  );
 }
 
 class _DefaultTestWrapper implements TestWrapper {
@@ -27,7 +32,10 @@ class _DefaultTestWrapper implements TestWrapper {
   }
 
   @override
-  void registerPlatformPlugin(Iterable<Runtime> runtimes, FutureOr<PlatformPlugin> Function() platforms) {
+  void registerPlatformPlugin(
+    Iterable<Runtime> runtimes,
+    FutureOr<PlatformPlugin> Function() platforms,
+  ) {
     hack.registerPlatformPlugin(runtimes, platforms);
   }
 }
