@@ -6,11 +6,9 @@ import 'dart:typed_data';
 
 import 'package:args/command_runner.dart';
 import 'package:file/memory.dart';
-import 'package:flutter_tools/src/artifacts.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
 import 'package:flutter_tools/src/base/logger.dart';
 import 'package:flutter_tools/src/base/platform.dart';
-import 'package:flutter_tools/src/base/process.dart';
 import 'package:flutter_tools/src/base/version.dart';
 import 'package:flutter_tools/src/build_system/build_system.dart';
 import 'package:flutter_tools/src/cache.dart';
@@ -28,6 +26,7 @@ import '../../src/context.dart';
 import '../../src/fake_process_manager.dart';
 import '../../src/fake_pub_deps.dart';
 import '../../src/fakes.dart';
+import '../../src/package_config.dart';
 import '../../src/test_build_system.dart';
 import '../../src/test_flutter_command_runner.dart';
 
@@ -74,10 +73,8 @@ class FakePlistUtils extends Fake implements PlistParser {
 void main() {
   late MemoryFileSystem fileSystem;
   late FakeProcessManager fakeProcessManager;
-  late ProcessUtils processUtils;
   late FakePlistUtils plistUtils;
   late BufferLogger logger;
-  late Artifacts artifacts;
   late FakeAnalytics fakeAnalytics;
 
   setUpAll(() {
@@ -86,10 +83,8 @@ void main() {
 
   setUp(() {
     fileSystem = MemoryFileSystem.test();
-    artifacts = Artifacts.test(fileSystem: fileSystem);
     fakeProcessManager = FakeProcessManager.empty();
     logger = BufferLogger.test();
-    processUtils = ProcessUtils(logger: logger, processManager: fakeProcessManager);
     plistUtils = FakePlistUtils();
     fakeAnalytics = getInitializedFakeAnalyticsInstance(
       fs: fileSystem,
@@ -99,8 +94,8 @@ void main() {
 
   // Sets up the minimal mock project files necessary to look like a Flutter project.
   void createCoreMockProjectFiles() {
-    fileSystem.file('pubspec.yaml').createSync();
-    fileSystem.directory('.dart_tool').childFile('package_config.json').createSync(recursive: true);
+    fileSystem.file('pubspec.yaml').writeAsStringSync('name: my_app');
+    writePackageConfigFile(directory: fileSystem.currentDirectory, mainLibName: 'my_app');
     fileSystem.file(fileSystem.path.join('lib', 'main.dart')).createSync(recursive: true);
   }
 
@@ -172,6 +167,8 @@ void main() {
         '-configuration',
         'Release',
         if (verbose) 'VERBOSE_SCRIPT_LOGGING=YES' else '-quiet',
+        '-allowProvisioningUpdates',
+        '-allowProvisioningDeviceRegistration',
         '-workspace',
         'Runner.xcworkspace',
         '-scheme',
@@ -232,12 +229,10 @@ void main() {
     'ipa build fails when there is no ios project',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createCoreMockProjectFiles();
@@ -259,12 +254,10 @@ void main() {
     'ipa build fails in debug with code analysis',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createCoreMockProjectFiles();
@@ -288,19 +281,14 @@ void main() {
     'ipa build fails on non-macOS platform',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fileSystem.file('pubspec.yaml').createSync();
-      fileSystem
-          .directory('.dart_tool')
-          .childFile('package_config.json')
-          .createSync(recursive: true);
+      writePackageConfigFile(directory: fileSystem.currentDirectory, mainLibName: 'my_app');
       fileSystem.file(fileSystem.path.join('lib', 'main.dart')).createSync(recursive: true);
 
       final bool supported =
@@ -323,12 +311,10 @@ void main() {
     'ipa build fails when export plist does not exist',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createMinimalMockProjectFiles();
@@ -354,12 +340,10 @@ void main() {
     () async {
       final Directory bogus = fileSystem.directory('bogus')..createSync();
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createMinimalMockProjectFiles();
@@ -383,12 +367,10 @@ void main() {
     'ipa build fails when --export-options-plist and --export-method are used together',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createMinimalMockProjectFiles();
@@ -418,12 +400,10 @@ void main() {
     'ipa build reports method from --export-method when used',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -454,12 +434,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -510,12 +488,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -566,12 +542,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -621,12 +595,10 @@ void main() {
     'ipa build accepts "enterprise" export method when on Xcode versions <= 15.3',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -656,12 +628,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -711,12 +681,10 @@ void main() {
     'ipa build accepts legacy methods when on Xcode versions <= 15.3',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -758,12 +726,10 @@ void main() {
         exportArchiveCommand(exportOptionsPlist: exportOptions.path),
       ]);
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(
@@ -788,12 +754,10 @@ void main() {
     'ipa build reports when IPA fails',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -849,12 +813,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -886,12 +848,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -945,12 +905,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1006,12 +964,10 @@ void main() {
     () async {
       final File cachedExportOptionsPlist = fileSystem.file('/CachedExportOptions.plist');
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1066,12 +1022,10 @@ void main() {
     'ipa build invokes xcode build with verbosity',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1098,12 +1052,10 @@ void main() {
     'ipa build invokes xcode build without disablePortPublication',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1131,12 +1083,10 @@ void main() {
     'ipa build --no-codesign skips codesigning and IPA creation',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1193,12 +1143,10 @@ void main() {
     'code size analysis fails when app not found',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createMinimalMockProjectFiles();
@@ -1224,12 +1172,10 @@ void main() {
     'Performs code size analysis and sends analytics',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       createMinimalMockProjectFiles();
@@ -1291,12 +1237,10 @@ void main() {
       );
       final File exportOptions = fileSystem.file('ExportOptions.plist')..createSync();
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1335,12 +1279,10 @@ void main() {
     'Trace error if xcresult is empty.',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1377,12 +1319,10 @@ void main() {
     'Display xcresult issues on console if parsed.',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1423,12 +1363,10 @@ void main() {
     'Do not display xcresult issues that needs to be discarded.',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1477,12 +1415,10 @@ void main() {
     'Trace if xcresult bundle does not exist.',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1516,12 +1452,10 @@ void main() {
     'Extra error message for provision profile issue in xcresult bundle.',
     () async {
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       fakeProcessManager.addCommands(<FakeCommand>[
@@ -1591,12 +1525,10 @@ void main() {
       };
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -1657,12 +1589,10 @@ void main() {
       };
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -1721,12 +1651,10 @@ void main() {
       };
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -1780,12 +1708,10 @@ void main() {
       };
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -1830,12 +1756,10 @@ void main() {
       };
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -1927,12 +1851,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2021,12 +1943,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2099,12 +2019,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2175,12 +2093,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2251,12 +2167,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2328,12 +2242,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2448,12 +2360,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2541,12 +2451,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
@@ -2633,12 +2541,10 @@ void main() {
       createMinimalMockProjectFiles();
 
       final BuildCommand command = BuildCommand(
-        artifacts: artifacts,
         androidSdk: FakeAndroidSdk(),
         buildSystem: TestBuildSystem.all(BuildResult(success: true)),
         logger: logger,
         fileSystem: fileSystem,
-        processUtils: processUtils,
         osUtils: FakeOperatingSystemUtils(),
       );
       await createTestCommandRunner(command).run(<String>['build', 'ipa', '--no-pub']);
