@@ -20,11 +20,7 @@ void main() {
 
   setUp(() {
     memoryFileSystem = MemoryFileSystem.test();
-    fakePlatform = FakePlatform(
-      environment: <String, String>{
-        'HOME': '/',
-      },
-    );
+    fakePlatform = FakePlatform(environment: <String, String>{'HOME': '/'});
     config = Config(
       'example',
       fileSystem: memoryFileSystem,
@@ -65,8 +61,7 @@ void main() {
 
   testWithoutContext('Config does not error on a file with a deprecated field', () {
     final BufferLogger bufferLogger = BufferLogger.test();
-    final File file = memoryFileSystem.file('.flutter_example')
-      ..writeAsStringSync('''
+    final File file = memoryFileSystem.file('.flutter_example')..writeAsStringSync('''
 {
   "is-bot": false,
   "license-hash": "3e8c85e63b26ce223cda96a9a8fbb410",
@@ -88,8 +83,7 @@ void main() {
 
   testWithoutContext('Config parse error', () {
     final BufferLogger bufferLogger = BufferLogger.test();
-    final File file = memoryFileSystem.file('.flutter_example')
-      ..writeAsStringSync('{"hello":"bar');
+    final File file = memoryFileSystem.file('.flutter_example')..writeAsStringSync('{"hello":"bar');
     config = Config(
       'example',
       fileSystem: memoryFileSystem,
@@ -136,8 +130,8 @@ void main() {
     final FileExceptionHandler handler = FileExceptionHandler();
     final MemoryFileSystem fs = MemoryFileSystem.test(opHandle: handler.opHandle);
     final File file = fs.file('testfile')
-        // We write invalid JSON so that we test catching a `FormatException`
-        ..writeAsStringSync('{"This is not valid JSON"');
+      // We write invalid JSON so that we test catching a `FormatException`
+      ..writeAsStringSync('{"This is not valid JSON"');
     handler.addError(
       file,
       FileSystemOp.delete,
@@ -162,17 +156,20 @@ void main() {
     expect(memoryFileSystem.file('.config/flutter/example').existsSync(), false);
   });
 
-  testWithoutContext('Config is created in config dir if it does not already exist in home dir', () {
-    config = Config(
-      'example',
-      fileSystem: memoryFileSystem,
-      logger: BufferLogger.test(),
-      platform: fakePlatform,
-    );
+  testWithoutContext(
+    'Config is created in config dir if it does not already exist in home dir',
+    () {
+      config = Config(
+        'example',
+        fileSystem: memoryFileSystem,
+        logger: BufferLogger.test(),
+        platform: fakePlatform,
+      );
 
-    config.setValue('foo', 'bar');
-    expect(memoryFileSystem.file('.config/flutter/example').existsSync(), true);
-  });
+      config.setValue('foo', 'bar');
+      expect(memoryFileSystem.file('.config/flutter/example').existsSync(), true);
+    },
+  );
 }
 
 class FakeFile extends Fake implements File {
