@@ -7,6 +7,7 @@ import 'dart:async';
 import 'package:file/file.dart';
 import 'package:file/memory.dart';
 import 'package:file_testing/file_testing.dart';
+import 'package:flutter_tools/src/artifacts.dart';
 import 'package:flutter_tools/src/base/logger.dart';
 import 'package:flutter_tools/src/build_info.dart';
 import 'package:flutter_tools/src/build_system/build_system.dart';
@@ -26,17 +27,17 @@ import 'package:test/fake.dart';
 import '../../src/common.dart';
 import '../../src/context.dart';
 import '../../src/fakes.dart';
-
+import '../../src/package_config.dart';
 
 void _writeCustomDevicesConfigFile(Directory dir, List<CustomDeviceConfig> configs) {
   dir.createSync();
 
   final File file = dir.childFile('.flutter_custom_devices.json');
-  file.writeAsStringSync(jsonEncode(
-    <String, dynamic>{
+  file.writeAsStringSync(
+    jsonEncode(<String, dynamic>{
       'custom-devices': configs.map<dynamic>((CustomDeviceConfig c) => c.toJson()).toList(),
-    }
-  ));
+    }),
+  );
 }
 
 FlutterProject _setUpFlutterProject(Directory directory) {
@@ -48,50 +49,35 @@ FlutterProject _setUpFlutterProject(Directory directory) {
 }
 
 void main() {
-  testWithoutContext('replacing string interpolation occurrences in custom device commands', () async {
-    expect(
-      interpolateCommand(
-        <String>['scp', r'${localPath}', r'/tmp/${appName}', 'pi@raspberrypi'],
-        <String, String>{
-          'localPath': 'build/flutter_assets',
-          'appName': 'hello_world',
-        },
-      ),
-      <String>[
-        'scp', 'build/flutter_assets', '/tmp/hello_world', 'pi@raspberrypi',
-      ]
-    );
+  testWithoutContext(
+    'replacing string interpolation occurrences in custom device commands',
+    () async {
+      expect(
+        interpolateCommand(
+          <String>['scp', r'${localPath}', r'/tmp/${appName}', 'pi@raspberrypi'],
+          <String, String>{'localPath': 'build/flutter_assets', 'appName': 'hello_world'},
+        ),
+        <String>['scp', 'build/flutter_assets', '/tmp/hello_world', 'pi@raspberrypi'],
+      );
 
-    expect(
-      interpolateCommand(
-        <String>[r'${test1}', r' ${test2}', r'${test3}'],
-        <String, String>{
-          'test1': '_test1',
-          'test2': '_test2',
-        },
-      ),
-      <String>[
-        '_test1', ' _test2', r'',
-      ]
-    );
+      expect(
+        interpolateCommand(
+          <String>[r'${test1}', r' ${test2}', r'${test3}'],
+          <String, String>{'test1': '_test1', 'test2': '_test2'},
+        ),
+        <String>['_test1', ' _test2', r''],
+      );
 
-    expect(
-      interpolateCommand(
-        <String>[r'${test1}', r' ${test2}', r'${test3}'],
-        <String, String>{
-          'test1': '_test1',
-          'test2': '_test2',
-        },
-        additionalReplacementValues: <String, String>{
-          'test2': '_nottest2',
-          'test3': '_test3',
-        }
-      ),
-      <String>[
-        '_test1', ' _test2', r'_test3',
-      ]
-    );
-  });
+      expect(
+        interpolateCommand(
+          <String>[r'${test1}', r' ${test2}', r'${test3}'],
+          <String, String>{'test1': '_test1', 'test2': '_test2'},
+          additionalReplacementValues: <String, String>{'test2': '_nottest2', 'test3': '_test3'},
+        ),
+        <String>['_test1', ' _test2', r'_test3'],
+      );
+    },
+  );
 
   final CustomDeviceConfig testConfig = CustomDeviceConfig(
     id: 'testid',
@@ -117,12 +103,13 @@ void main() {
     explicitForwardPortSuccessRegex: true,
   );
 
-  testUsingContext('CustomDevice defaults',
+  testUsingContext(
+    'CustomDevice defaults',
     () async {
       final CustomDevice device = CustomDevice(
         config: testConfig,
         processManager: FakeProcessManager.any(),
-        logger: BufferLogger.test()
+        logger: BufferLogger.test(),
       );
 
       final PrebuiltLinuxApp linuxApp = PrebuiltLinuxApp(executable: 'foo');
@@ -148,44 +135,56 @@ void main() {
     overrides: <Type, dynamic Function()>{
       FileSystem: () => MemoryFileSystem.test(),
       ProcessManager: () => FakeProcessManager.any(),
-    }
+    },
   );
 
-  testWithoutContext('CustomDevice: no devices listed if only disabled devices configured', () async {
-    final MemoryFileSystem fs = MemoryFileSystem.test();
-    final Directory dir = fs.directory('custom_devices_config_dir');
+  testWithoutContext(
+    'CustomDevice: no devices listed if only disabled devices configured',
+    () async {
+      final MemoryFileSystem fs = MemoryFileSystem.test();
+      final Directory dir = fs.directory('custom_devices_config_dir');
 
-    _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[disabledTestConfig]);
+      _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[disabledTestConfig]);
 
-    expect(await CustomDevices(
-      featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.any(),
-      config: CustomDevicesConfig.test(
-        fileSystem: fs,
-        directory: dir,
-        logger: BufferLogger.test()
-      )
-    ).devices(), <Device>[]);
-  });
+      expect(
+        await CustomDevices(
+          featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
+          logger: BufferLogger.test(),
+          processManager: FakeProcessManager.any(),
+          config: CustomDevicesConfig.test(
+            fileSystem: fs,
+            directory: dir,
+            logger: BufferLogger.test(),
+          ),
+        ).devices(),
+        <Device>[],
+      );
+    },
+  );
 
-  testWithoutContext('CustomDevice: no devices listed if custom devices feature flag disabled', () async {
-    final MemoryFileSystem fs = MemoryFileSystem.test();
-    final Directory dir = fs.directory('custom_devices_config_dir');
+  testWithoutContext(
+    'CustomDevice: no devices listed if custom devices feature flag disabled',
+    () async {
+      final MemoryFileSystem fs = MemoryFileSystem.test();
+      final Directory dir = fs.directory('custom_devices_config_dir');
 
-    _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
+      _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
 
-    expect(await CustomDevices(
-      featureFlags: TestFeatureFlags(),
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.any(),
-      config: CustomDevicesConfig.test(
-        fileSystem: fs,
-        directory: dir,
-        logger: BufferLogger.test()
-      )
-    ).devices(), <Device>[]);
-  });
+      expect(
+        await CustomDevices(
+          featureFlags: TestFeatureFlags(),
+          logger: BufferLogger.test(),
+          processManager: FakeProcessManager.any(),
+          config: CustomDevicesConfig.test(
+            fileSystem: fs,
+            directory: dir,
+            logger: BufferLogger.test(),
+          ),
+        ).devices(),
+        <Device>[],
+      );
+    },
+  );
 
   testWithoutContext('CustomDevices.devices', () async {
     final MemoryFileSystem fs = MemoryFileSystem.test();
@@ -195,117 +194,124 @@ void main() {
 
     expect(
       await CustomDevices(
+        featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
+        logger: BufferLogger.test(),
+        processManager: FakeProcessManager.list(<FakeCommand>[
+          FakeCommand(command: testConfig.pingCommand, stdout: testConfigPingSuccessOutput),
+        ]),
+        config: CustomDevicesConfig.test(
+          fileSystem: fs,
+          directory: dir,
+          logger: BufferLogger.test(),
+        ),
+      ).devices(),
+      hasLength(1),
+    );
+  });
+
+  testWithoutContext(
+    'CustomDevices.discoverDevices successfully discovers devices and executes ping command',
+    () async {
+      final MemoryFileSystem fs = MemoryFileSystem.test();
+      final Directory dir = fs.directory('custom_devices_config_dir');
+
+      _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
+
+      bool pingCommandWasExecuted = false;
+
+      final CustomDevices discovery = CustomDevices(
         featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
         logger: BufferLogger.test(),
         processManager: FakeProcessManager.list(<FakeCommand>[
           FakeCommand(
             command: testConfig.pingCommand,
-            stdout: testConfigPingSuccessOutput
+            onRun: (_) => pingCommandWasExecuted = true,
+            stdout: testConfigPingSuccessOutput,
           ),
         ]),
         config: CustomDevicesConfig.test(
           fileSystem: fs,
           directory: dir,
-          logger: BufferLogger.test()
-        )
-      ).devices(),
-      hasLength(1)
-    );
-  });
-
-  testWithoutContext('CustomDevices.discoverDevices successfully discovers devices and executes ping command', () async {
-    final MemoryFileSystem fs = MemoryFileSystem.test();
-    final Directory dir = fs.directory('custom_devices_config_dir');
-
-    _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
-
-    bool pingCommandWasExecuted = false;
-
-    final CustomDevices discovery = CustomDevices(
-      featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.list(<FakeCommand>[
-        FakeCommand(
-          command: testConfig.pingCommand,
-          onRun: (_) => pingCommandWasExecuted = true,
-          stdout: testConfigPingSuccessOutput
+          logger: BufferLogger.test(),
         ),
-      ]),
-      config: CustomDevicesConfig.test(
-        fileSystem: fs,
-        directory: dir,
+      );
+
+      final List<Device> discoveredDevices = await discovery.discoverDevices();
+
+      expect(discoveredDevices, hasLength(1));
+      expect(pingCommandWasExecuted, true);
+    },
+  );
+
+  testWithoutContext(
+    "CustomDevices.discoverDevices doesn't report device when ping command fails",
+    () async {
+      final MemoryFileSystem fs = MemoryFileSystem.test();
+      final Directory dir = fs.directory('custom_devices_config_dir');
+
+      _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
+
+      final CustomDevices discovery = CustomDevices(
+        featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
         logger: BufferLogger.test(),
-      ),
-    );
-
-    final List<Device> discoveredDevices = await discovery.discoverDevices();
-
-    expect(discoveredDevices, hasLength(1));
-    expect(pingCommandWasExecuted, true);
-  });
-
-  testWithoutContext("CustomDevices.discoverDevices doesn't report device when ping command fails", () async {
-    final MemoryFileSystem fs = MemoryFileSystem.test();
-    final Directory dir = fs.directory('custom_devices_config_dir');
-
-    _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
-
-    final CustomDevices discovery = CustomDevices(
-      featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.list(<FakeCommand>[
-        FakeCommand(
-          command: testConfig.pingCommand,
-          stdout: testConfigPingSuccessOutput,
-          exitCode: 1
+        processManager: FakeProcessManager.list(<FakeCommand>[
+          FakeCommand(
+            command: testConfig.pingCommand,
+            stdout: testConfigPingSuccessOutput,
+            exitCode: 1,
+          ),
+        ]),
+        config: CustomDevicesConfig.test(
+          fileSystem: fs,
+          directory: dir,
+          logger: BufferLogger.test(),
         ),
-      ]),
-      config: CustomDevicesConfig.test(
-        fileSystem: fs,
-        directory: dir,
+      );
+
+      expect(await discovery.discoverDevices(), hasLength(0));
+    },
+  );
+
+  testWithoutContext(
+    "CustomDevices.discoverDevices doesn't report device when ping command output doesn't match ping success regex",
+    () async {
+      final MemoryFileSystem fs = MemoryFileSystem.test();
+      final Directory dir = fs.directory('custom_devices_config_dir');
+
+      _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
+
+      final CustomDevices discovery = CustomDevices(
+        featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
         logger: BufferLogger.test(),
-      ),
-    );
-
-    expect(await discovery.discoverDevices(), hasLength(0));
-  });
-
-  testWithoutContext("CustomDevices.discoverDevices doesn't report device when ping command output doesn't match ping success regex", () async {
-    final MemoryFileSystem fs = MemoryFileSystem.test();
-    final Directory dir = fs.directory('custom_devices_config_dir');
-
-    _writeCustomDevicesConfigFile(dir, <CustomDeviceConfig>[testConfig]);
-
-    final CustomDevices discovery = CustomDevices(
-      featureFlags: TestFeatureFlags(areCustomDevicesEnabled: true),
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.list(<FakeCommand>[
-        FakeCommand(
-          command: testConfig.pingCommand,
+        processManager: FakeProcessManager.list(<FakeCommand>[
+          FakeCommand(command: testConfig.pingCommand),
+        ]),
+        config: CustomDevicesConfig.test(
+          fileSystem: fs,
+          directory: dir,
+          logger: BufferLogger.test(),
         ),
-      ]),
-      config: CustomDevicesConfig.test(
-        fileSystem: fs,
-        directory: dir,
-        logger: BufferLogger.test(),
-      ),
-    );
+      );
 
-    expect(await discovery.discoverDevices(), hasLength(0));
-  });
+      expect(await discovery.discoverDevices(), hasLength(0));
+    },
+  );
 
   testWithoutContext('CustomDevice.isSupportedForProject is true with editable host app', () async {
     final MemoryFileSystem fileSystem = MemoryFileSystem.test();
     fileSystem.file('pubspec.yaml').createSync();
-    fileSystem.file('.packages').createSync();
+    writePackageConfigFile(directory: fileSystem.currentDirectory, mainLibName: 'my_app');
 
     final FlutterProject flutterProject = _setUpFlutterProject(fileSystem.currentDirectory);
 
-    expect(CustomDevice(
-      config: testConfig,
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.any(),
-    ).isSupportedForProject(flutterProject), true);
+    expect(
+      CustomDevice(
+        config: testConfig,
+        logger: BufferLogger.test(),
+        processManager: FakeProcessManager.any(),
+      ).isSupportedForProject(flutterProject),
+      true,
+    );
   });
 
   testUsingContext(
@@ -314,12 +320,15 @@ void main() {
       bool bothCommandsWereExecuted = false;
 
       final CustomDevice device = CustomDevice(
-          config: testConfig,
-          logger: BufferLogger.test(),
-          processManager: FakeProcessManager.list(<FakeCommand>[
-            FakeCommand(command: testConfig.uninstallCommand),
-            FakeCommand(command: testConfig.installCommand, onRun: (_) => bothCommandsWereExecuted = true),
-          ])
+        config: testConfig,
+        logger: BufferLogger.test(),
+        processManager: FakeProcessManager.list(<FakeCommand>[
+          FakeCommand(command: testConfig.uninstallCommand),
+          FakeCommand(
+            command: testConfig.installCommand,
+            onRun: (_) => bothCommandsWereExecuted = true,
+          ),
+        ]),
       );
 
       expect(await device.installApp(PrebuiltLinuxApp(executable: 'exe')), true);
@@ -328,112 +337,123 @@ void main() {
     overrides: <Type, dynamic Function()>{
       FileSystem: () => MemoryFileSystem.test(),
       ProcessManager: () => FakeProcessManager.any(),
-    }
+    },
   );
 
-  testWithoutContext('CustomDevicePortForwarder will run and terminate forwardPort command', () async {
-    final Completer<void> forwardPortCommandCompleter = Completer<void>();
+  testWithoutContext(
+    'CustomDevicePortForwarder will run and terminate forwardPort command',
+    () async {
+      final Completer<void> forwardPortCommandCompleter = Completer<void>();
 
-    final CustomDevicePortForwarder forwarder = CustomDevicePortForwarder(
-      deviceName: 'testdevicename',
-      forwardPortCommand: testConfig.forwardPortCommand!,
-      forwardPortSuccessRegex: testConfig.forwardPortSuccessRegex!,
-      logger: BufferLogger.test(),
-      processManager: FakeProcessManager.list(<FakeCommand>[
+      final CustomDevicePortForwarder forwarder = CustomDevicePortForwarder(
+        deviceName: 'testdevicename',
+        forwardPortCommand: testConfig.forwardPortCommand!,
+        forwardPortSuccessRegex: testConfig.forwardPortSuccessRegex!,
+        logger: BufferLogger.test(),
+        processManager: FakeProcessManager.list(<FakeCommand>[
+          FakeCommand(
+            command: testConfig.forwardPortCommand!,
+            stdout: testConfigForwardPortSuccessOutput,
+            completer: forwardPortCommandCompleter,
+          ),
+        ]),
+      );
+
+      // this should start the command
+      expect(await forwarder.forward(12345), 12345);
+      expect(forwardPortCommandCompleter.isCompleted, false);
+
+      // this should terminate it
+      await forwarder.dispose();
+
+      // the termination should have completed our completer
+      expect(forwardPortCommandCompleter.isCompleted, true);
+    },
+  );
+
+  testWithoutContext(
+    'CustomDevice forwards VM Service port correctly when port forwarding is configured',
+    () async {
+      final Completer<void> runDebugCompleter = Completer<void>();
+      final Completer<void> forwardPortCompleter = Completer<void>();
+
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+        FakeCommand(
+          command: testConfig.runDebugCommand,
+          completer: runDebugCompleter,
+          stdout: 'The Dart VM service is listening on http://127.0.0.1:12345/abcd/\n',
+        ),
         FakeCommand(
           command: testConfig.forwardPortCommand!,
+          completer: forwardPortCompleter,
           stdout: testConfigForwardPortSuccessOutput,
-          completer: forwardPortCommandCompleter,
         ),
-      ])
-    );
+      ]);
 
-    // this should start the command
-    expect(await forwarder.forward(12345), 12345);
-    expect(forwardPortCommandCompleter.isCompleted, false);
-
-    // this should terminate it
-    await forwarder.dispose();
-
-    // the termination should have completed our completer
-    expect(forwardPortCommandCompleter.isCompleted, true);
-  });
-
-  testWithoutContext('CustomDevice forwards VM Service port correctly when port forwarding is configured', () async {
-    final Completer<void> runDebugCompleter = Completer<void>();
-    final Completer<void> forwardPortCompleter = Completer<void>();
-
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
-      FakeCommand(
-        command: testConfig.runDebugCommand,
-        completer: runDebugCompleter,
-        stdout: 'The Dart VM service is listening on http://127.0.0.1:12345/abcd/\n',
-      ),
-      FakeCommand(
-        command: testConfig.forwardPortCommand!,
-        completer: forwardPortCompleter,
-        stdout: testConfigForwardPortSuccessOutput,
-      ),
-    ]);
-
-    final CustomDeviceAppSession appSession = CustomDeviceAppSession(
-      name: 'testname',
-      device: CustomDevice(
-        config: testConfig,
+      final CustomDeviceAppSession appSession = CustomDeviceAppSession(
+        name: 'testname',
+        device: CustomDevice(
+          config: testConfig,
+          logger: BufferLogger.test(),
+          processManager: processManager,
+        ),
+        appPackage: PrebuiltLinuxApp(executable: 'testexecutable'),
         logger: BufferLogger.test(),
-        processManager: processManager
-      ),
-      appPackage: PrebuiltLinuxApp(executable: 'testexecutable'),
-      logger: BufferLogger.test(),
-      processManager: processManager,
-    );
+        processManager: processManager,
+      );
 
-    final LaunchResult launchResult = await appSession.start(debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug));
+      final LaunchResult launchResult = await appSession.start(
+        debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
+      );
 
-    expect(launchResult.started, true);
-    expect(launchResult.vmServiceUri, Uri.parse('http://127.0.0.1:12345/abcd/'));
-    expect(runDebugCompleter.isCompleted, false);
-    expect(forwardPortCompleter.isCompleted, false);
+      expect(launchResult.started, true);
+      expect(launchResult.vmServiceUri, Uri.parse('http://127.0.0.1:12345/abcd/'));
+      expect(runDebugCompleter.isCompleted, false);
+      expect(forwardPortCompleter.isCompleted, false);
 
-    expect(await appSession.stop(), true);
-    expect(runDebugCompleter.isCompleted, true);
-    expect(forwardPortCompleter.isCompleted, true);
-  });
+      expect(await appSession.stop(), true);
+      expect(runDebugCompleter.isCompleted, true);
+      expect(forwardPortCompleter.isCompleted, true);
+    },
+  );
 
-  testWithoutContext('CustomDeviceAppSession forwards VM Service port correctly when port forwarding is not configured', () async {
-    final Completer<void> runDebugCompleter = Completer<void>();
+  testWithoutContext(
+    'CustomDeviceAppSession forwards VM Service port correctly when port forwarding is not configured',
+    () async {
+      final Completer<void> runDebugCompleter = Completer<void>();
 
-    final FakeProcessManager processManager = FakeProcessManager.list(
-      <FakeCommand>[
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
         FakeCommand(
           command: testConfigNonForwarding.runDebugCommand,
           completer: runDebugCompleter,
-          stdout: 'The Dart VM service is listening on http://192.168.178.123:12345/abcd/\n'
+          stdout: 'The Dart VM service is listening on http://192.168.178.123:12345/abcd/\n',
         ),
-      ]
-    );
+      ]);
 
-    final CustomDeviceAppSession appSession = CustomDeviceAppSession(
-      name: 'testname',
-      device: CustomDevice(
-        config: testConfigNonForwarding,
+      final CustomDeviceAppSession appSession = CustomDeviceAppSession(
+        name: 'testname',
+        device: CustomDevice(
+          config: testConfigNonForwarding,
+          logger: BufferLogger.test(),
+          processManager: processManager,
+        ),
+        appPackage: PrebuiltLinuxApp(executable: 'testexecutable'),
         logger: BufferLogger.test(),
-        processManager: processManager
-      ),
-      appPackage: PrebuiltLinuxApp(executable: 'testexecutable'),
-      logger: BufferLogger.test(),
-      processManager: processManager
-    );
+        processManager: processManager,
+      );
 
-    final LaunchResult launchResult = await appSession.start(debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug));
+      final LaunchResult launchResult = await appSession.start(
+        debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
+      );
 
-    expect(launchResult.started, true);
-    expect(launchResult.vmServiceUri, Uri.parse('http://192.168.178.123:12345/abcd/'));
-    expect(runDebugCompleter.isCompleted, false);
+      expect(launchResult.started, true);
+      expect(launchResult.vmServiceUri, Uri.parse('http://192.168.178.123:12345/abcd/'));
+      expect(runDebugCompleter.isCompleted, false);
 
-    expect(await appSession.stop(), true);
-    expect(runDebugCompleter.isCompleted, true);
-  });
+      expect(await appSession.stop(), true);
+      expect(runDebugCompleter.isCompleted, true);
+    },
+  );
 
   testUsingContext(
     'custom device end-to-end test',
@@ -441,27 +461,22 @@ void main() {
       final Completer<void> runDebugCompleter = Completer<void>();
       final Completer<void> forwardPortCompleter = Completer<void>();
 
-      final FakeProcessManager processManager = FakeProcessManager.list(
-        <FakeCommand>[
-          FakeCommand(
-            command: testConfig.pingCommand,
-            stdout: testConfigPingSuccessOutput
-          ),
-          FakeCommand(command: testConfig.postBuildCommand!),
-          FakeCommand(command: testConfig.uninstallCommand),
-          FakeCommand(command: testConfig.installCommand),
-          FakeCommand(
-            command: testConfig.runDebugCommand,
-            completer: runDebugCompleter,
-            stdout: 'The Dart VM service is listening on http://127.0.0.1:12345/abcd/\n',
-          ),
-          FakeCommand(
-            command: testConfig.forwardPortCommand!,
-            completer: forwardPortCompleter,
-            stdout: testConfigForwardPortSuccessOutput,
-          ),
-        ]
-      );
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+        FakeCommand(command: testConfig.pingCommand, stdout: testConfigPingSuccessOutput),
+        FakeCommand(command: testConfig.postBuildCommand!),
+        FakeCommand(command: testConfig.uninstallCommand),
+        FakeCommand(command: testConfig.installCommand),
+        FakeCommand(
+          command: testConfig.runDebugCommand,
+          completer: runDebugCompleter,
+          stdout: 'The Dart VM service is listening on http://127.0.0.1:12345/abcd/\n',
+        ),
+        FakeCommand(
+          command: testConfig.forwardPortCommand!,
+          completer: forwardPortCompleter,
+          stdout: testConfigForwardPortSuccessOutput,
+        ),
+      ]);
 
       // Reuse our filesystem from context instead of mixing two filesystem instances
       // together
@@ -482,8 +497,8 @@ void main() {
         config: CustomDevicesConfig.test(
           fileSystem: fs,
           directory: configFileDir,
-          logger: BufferLogger.test()
-        )
+          logger: BufferLogger.test(),
+        ),
       );
 
       final List<Device> devices = await customDevices.discoverDevices();
@@ -498,7 +513,7 @@ void main() {
       final LaunchResult result = await device.startApp(
         app,
         debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
-        bundleBuilder: FakeBundleBuilder()
+        bundleBuilder: FakeBundleBuilder(),
       );
       expect(result.started, true);
       expect(result.hasVmService, true);
@@ -513,7 +528,101 @@ void main() {
     overrides: <Type, Generator>{
       FileSystem: () => MemoryFileSystem.test(),
       ProcessManager: () => FakeProcessManager.any(),
-    }
+    },
+  );
+
+  testUsingContext(
+    'custom device command string interpolation end-to-end test',
+    () async {
+      final Completer<void> runDebugCompleter = Completer<void>();
+
+      final CustomDeviceConfig config = testConfig.copyWith(
+        platform: TargetPlatform.linux_arm64,
+        postBuildCommand: const <String>[
+          'testpostbuild',
+          r'--buildMode=${buildMode}',
+          r'--icuDataPath=${icuDataPath}',
+          r'--engineRevision=${engineRevision}',
+        ],
+        runDebugCommand: const <String>[
+          'testrundebug',
+          r'--buildMode=${buildMode}',
+          r'--icuDataPath=${icuDataPath}',
+          r'--engineRevision=${engineRevision}',
+        ],
+      );
+
+      final List<Pattern> commandArgumentsPattern = <Pattern>[
+        RegExp(r'--buildMode=.*'),
+        RegExp(r'--icuDataPath=.*'),
+        RegExp(r'--engineRevision=.*'),
+      ];
+
+      final String expectedIcuDataPath = globals.artifacts!.getArtifactPath(
+        Artifact.icuData,
+        platform: config.platform,
+      );
+      final String expectedEngineRevision = globals.flutterVersion.engineRevision;
+
+      final List<String> expectedCommandArguments = <String>[
+        '--buildMode=debug',
+        '--icuDataPath=$expectedIcuDataPath',
+        '--engineRevision=$expectedEngineRevision',
+      ];
+
+      final List<String> expectedRunDebugCommand = <String>[
+        'testrundebug',
+        ...expectedCommandArguments,
+      ];
+      final List<String> expectedPostBuildCommand = <String>[
+        'testpostbuild',
+        ...expectedCommandArguments,
+      ];
+
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+        FakeCommand(
+          command: <Pattern>['testpostbuild', ...commandArgumentsPattern],
+          onRun: (List<String> command) => expect(command, expectedPostBuildCommand),
+        ),
+        FakeCommand(command: config.uninstallCommand),
+        FakeCommand(command: config.installCommand),
+        FakeCommand(
+          command: <Pattern>['testrundebug', ...commandArgumentsPattern],
+          completer: runDebugCompleter,
+          onRun: (List<String> command) => expect(command, expectedRunDebugCommand),
+          stdout: 'The Dart VM service is listening on http://127.0.0.1:12345/abcd/\n',
+        ),
+        FakeCommand(
+          command: config.forwardPortCommand!,
+          stdout: testConfigForwardPortSuccessOutput,
+        ),
+      ]);
+
+      // CustomDevice.startApp doesn't care whether we pass a prebuilt app or
+      // buildable app as long as we pass prebuiltApplication as false
+      final PrebuiltLinuxApp app = PrebuiltLinuxApp(executable: 'testexecutable');
+
+      // finally start actually testing things
+      final CustomDevice device = CustomDevice(
+        config: config,
+        logger: BufferLogger.test(),
+        processManager: processManager,
+      );
+
+      await device.startApp(
+        app,
+        debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
+        bundleBuilder: FakeBundleBuilder(),
+      );
+      expect(runDebugCompleter.isCompleted, false);
+
+      expect(await device.stopApp(app), true);
+      expect(runDebugCompleter.isCompleted, true);
+    },
+    overrides: <Type, Generator>{
+      FileSystem: () => MemoryFileSystem.test(),
+      ProcessManager: () => FakeProcessManager.any(),
+    },
   );
 
   testWithoutContext('CustomDevice screenshotting', () async {
@@ -532,7 +641,7 @@ void main() {
     final CustomDevice device = CustomDevice(
       config: testConfig,
       logger: BufferLogger.test(),
-      processManager: processManager
+      processManager: processManager,
     );
 
     expect(device.supportsScreenshot, true);
@@ -556,11 +665,9 @@ void main() {
     final File screenshotFile = fs.file('screenshot.png');
 
     final CustomDevice device = CustomDevice(
-        config: testConfig.copyWith(
-          explicitScreenshotCommand: true
-        ),
-        logger: BufferLogger.test(),
-        processManager: processManager
+      config: testConfig.copyWith(explicitScreenshotCommand: true),
+      logger: BufferLogger.test(),
+      processManager: processManager,
     );
 
     expect(device.supportsScreenshot, false);
@@ -574,50 +681,58 @@ void main() {
 
   testWithoutContext('CustomDevice returns correct target platform', () async {
     final CustomDevice device = CustomDevice(
-      config: testConfig.copyWith(
-        platform: TargetPlatform.linux_x64
-      ),
+      config: testConfig.copyWith(platform: TargetPlatform.linux_x64),
       logger: BufferLogger.test(),
-      processManager: FakeProcessManager.empty()
+      processManager: FakeProcessManager.empty(),
     );
 
     expect(await device.targetPlatform, TargetPlatform.linux_x64);
   });
 
-  testWithoutContext('CustomDeviceLogReader cancels subscriptions before closing logLines stream', () async {
-    final CustomDeviceLogReader logReader = CustomDeviceLogReader('testname');
+  testWithoutContext(
+    'CustomDeviceLogReader cancels subscriptions before closing logLines stream',
+    () async {
+      final CustomDeviceLogReader logReader = CustomDeviceLogReader('testname');
 
-    final Iterable<List<int>> lines = Iterable<List<int>>.generate(5, (int _) => utf8.encode('test'));
+      final Iterable<List<int>> lines = Iterable<List<int>>.generate(
+        5,
+        (int _) => utf8.encode('test'),
+      );
 
-    logReader.listenToProcessOutput(
-      FakeProcess(
-        exitCode: Future<int>.value(0),
-        stdout: Stream<List<int>>.fromIterable(lines),
-        stderr: Stream<List<int>>.fromIterable(lines),
-      ),
-    );
+      logReader.listenToProcessOutput(
+        FakeProcess(
+          exitCode: Future<int>.value(0),
+          stdout: Stream<List<int>>.fromIterable(lines),
+          stderr: Stream<List<int>>.fromIterable(lines),
+        ),
+      );
 
-    final List<MyFakeStreamSubscription<String>> subscriptions = <MyFakeStreamSubscription<String>>[];
-    bool logLinesStreamDone = false;
-    logReader.logLines.listen((_) {}, onDone: () {
-      expect(subscriptions, everyElement((MyFakeStreamSubscription<String> s) => s.canceled));
-      logLinesStreamDone = true;
-    });
+      final List<MyFakeStreamSubscription<String>> subscriptions =
+          <MyFakeStreamSubscription<String>>[];
+      bool logLinesStreamDone = false;
+      logReader.logLines.listen(
+        (_) {},
+        onDone: () {
+          expect(subscriptions, everyElement((MyFakeStreamSubscription<String> s) => s.canceled));
+          logLinesStreamDone = true;
+        },
+      );
 
-    logReader.subscriptions.replaceRange(
-      0,
-      logReader.subscriptions.length,
-      logReader.subscriptions.map(
-        (StreamSubscription<String> e) => MyFakeStreamSubscription<String>(e)
-      ),
-    );
+      logReader.subscriptions.replaceRange(
+        0,
+        logReader.subscriptions.length,
+        logReader.subscriptions.map(
+          (StreamSubscription<String> e) => MyFakeStreamSubscription<String>(e),
+        ),
+      );
 
-    subscriptions.addAll(logReader.subscriptions.cast());
+      subscriptions.addAll(logReader.subscriptions.cast());
 
-    await logReader.dispose();
+      await logReader.dispose();
 
-    expect(logLinesStreamDone, true);
-  });
+      expect(logLinesStreamDone, true);
+    },
+  );
 }
 
 class MyFakeStreamSubscription<T> extends Fake implements StreamSubscription<T> {
@@ -646,6 +761,6 @@ class FakeBundleBuilder extends Fake implements BundleBuilder {
     String? assetDirPath,
     Uri? nativeAssets,
     bool buildNativeAssets = true,
-    @visibleForTesting BuildSystem? buildSystem
+    @visibleForTesting BuildSystem? buildSystem,
   }) async {}
 }
