@@ -21,7 +21,7 @@ import '../../src/common.dart';
 import '../../src/context.dart';
 
 void main() {
-group('PrebuiltMacOSApp', () {
+  group('PrebuiltMacOSApp', () {
     late FakeOperatingSystemUtils os;
     late FileSystem fileSystem;
     late BufferLogger logger;
@@ -41,7 +41,8 @@ group('PrebuiltMacOSApp', () {
     });
 
     testUsingContext('Error on non-existing file', () {
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('not_existing.app')) as PrebuiltMacOSApp?;
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('not_existing.app')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
       expect(logger.errorText, contains('File "not_existing.app" does not exist.'));
@@ -49,7 +50,8 @@ group('PrebuiltMacOSApp', () {
 
     testUsingContext('Error on non-app-bundle folder', () {
       fileSystem.directory('regular_folder').createSync();
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('regular_folder')) as PrebuiltMacOSApp?;
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('regular_folder')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
       expect(logger.errorText, contains('Folder "regular_folder" is not an app bundle.'));
@@ -57,42 +59,57 @@ group('PrebuiltMacOSApp', () {
 
     testUsingContext('Error on no info.plist', () {
       fileSystem.directory('bundle.app').createSync();
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
-      expect(logger.errorText, contains('Invalid prebuilt macOS app. Does not contain Info.plist.'));
+      expect(
+        logger.errorText,
+        contains('Invalid prebuilt macOS app. Does not contain Info.plist.'),
+      );
     }, overrides: overrides);
 
     testUsingContext('Error on info.plist missing bundle identifier', () {
       final String contentsDirectory = fileSystem.path.join('bundle.app', 'Contents');
       fileSystem.directory(contentsDirectory).createSync(recursive: true);
-      fileSystem.file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
-        .writeAsStringSync(badPlistData);
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
+      fileSystem
+          .file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
+          .writeAsStringSync(badPlistData);
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
-      expect(logger.errorText, contains('Invalid prebuilt macOS app. Info.plist does not contain bundle identifier'));
+      expect(
+        logger.errorText,
+        contains('Invalid prebuilt macOS app. Info.plist does not contain bundle identifier'),
+      );
     }, overrides: overrides);
 
     testUsingContext('Error on info.plist missing executable', () {
       final String contentsDirectory = fileSystem.path.join('bundle.app', 'Contents');
       fileSystem.directory(contentsDirectory).createSync(recursive: true);
-      fileSystem.file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
-        .writeAsStringSync(badPlistDataNoExecutable);
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
+      fileSystem
+          .file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
+          .writeAsStringSync(badPlistDataNoExecutable);
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
-      expect(logger.errorText, contains('Invalid prebuilt macOS app. Info.plist does not contain bundle executable'));
+      expect(
+        logger.errorText,
+        contains('Invalid prebuilt macOS app. Info.plist does not contain bundle executable'),
+      );
     }, overrides: overrides);
 
     testUsingContext('Success with app bundle', () {
       final String appDirectory = fileSystem.path.join('bundle.app', 'Contents', 'MacOS');
       fileSystem.directory(appDirectory).createSync(recursive: true);
-      fileSystem.file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
-        .writeAsStringSync(plistData);
-      fileSystem.file(fileSystem.path.join(appDirectory, executableName))
-        .createSync();
-      final PrebuiltMacOSApp macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app'))! as PrebuiltMacOSApp;
+      fileSystem
+          .file(fileSystem.path.join('bundle.app', 'Contents', 'Info.plist'))
+          .writeAsStringSync(plistData);
+      fileSystem.file(fileSystem.path.join(appDirectory, executableName)).createSync();
+      final PrebuiltMacOSApp macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('bundle.app'))! as PrebuiltMacOSApp;
 
       expect(logger.errorText, isEmpty);
       expect(macosApp.uncompressedBundle.path, 'bundle.app');
@@ -102,7 +119,8 @@ group('PrebuiltMacOSApp', () {
 
     testUsingContext('Bad zipped app, no payload dir', () {
       fileSystem.file('app.zip').createSync();
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip')) as PrebuiltMacOSApp?;
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
       expect(logger.errorText, contains('Archive "app.zip" does not contain a single app bundle.'));
@@ -119,7 +137,8 @@ group('PrebuiltMacOSApp', () {
         fileSystem.directory(bundlePath1).createSync(recursive: true);
         fileSystem.directory(bundlePath2).createSync(recursive: true);
       };
-      final PrebuiltMacOSApp? macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip')) as PrebuiltMacOSApp?;
+      final PrebuiltMacOSApp? macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip')) as PrebuiltMacOSApp?;
 
       expect(macosApp, isNull);
       expect(logger.errorText, contains('Archive "app.zip" does not contain a single app bundle.'));
@@ -131,17 +150,20 @@ group('PrebuiltMacOSApp', () {
         if (zipFile.path != 'app.zip') {
           return;
         }
-        final Directory bundleAppContentsDir = fileSystem.directory(fileSystem.path.join(targetDirectory.path, 'bundle.app', 'Contents'));
+        final Directory bundleAppContentsDir = fileSystem.directory(
+          fileSystem.path.join(targetDirectory.path, 'bundle.app', 'Contents'),
+        );
         bundleAppContentsDir.createSync(recursive: true);
-        fileSystem.file(fileSystem.path.join(bundleAppContentsDir.path, 'Info.plist'))
-          .writeAsStringSync(plistData);
-        fileSystem.directory(fileSystem.path.join(bundleAppContentsDir.path, 'MacOS'))
-          .createSync();
-        fileSystem.file(fileSystem.path
-          .join(bundleAppContentsDir.path, 'MacOS', executableName))
-          .createSync();
+        fileSystem
+            .file(fileSystem.path.join(bundleAppContentsDir.path, 'Info.plist'))
+            .writeAsStringSync(plistData);
+        fileSystem.directory(fileSystem.path.join(bundleAppContentsDir.path, 'MacOS')).createSync();
+        fileSystem
+            .file(fileSystem.path.join(bundleAppContentsDir.path, 'MacOS', executableName))
+            .createSync();
       };
-      final PrebuiltMacOSApp macosApp = MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip'))! as PrebuiltMacOSApp;
+      final PrebuiltMacOSApp macosApp =
+          MacOSApp.fromPrebuiltApp(fileSystem.file('app.zip'))! as PrebuiltMacOSApp;
 
       expect(logger.errorText, isEmpty);
       expect(macosApp.uncompressedBundle.path, endsWith('bundle.app'));
@@ -150,7 +172,9 @@ group('PrebuiltMacOSApp', () {
     }, overrides: overrides);
 
     testUsingContext('Success with project', () {
-      final MacOSApp macosApp = MacOSApp.fromMacOSProject(FlutterProject.fromDirectory(globals.fs.currentDirectory).macos);
+      final MacOSApp macosApp = MacOSApp.fromMacOSProject(
+        FlutterProject.fromDirectory(globals.fs.currentDirectory).macos,
+      );
 
       expect(logger.errorText, isEmpty);
       expect(macosApp.id, 'com.example.placeholder');
@@ -161,14 +185,23 @@ group('PrebuiltMacOSApp', () {
       final MacOSProject project = FlutterProject.fromDirectory(globals.fs.currentDirectory).macos;
       final BuildableMacOSApp macosApp = MacOSApp.fromMacOSProject(project) as BuildableMacOSApp;
 
-      const BuildInfo vanillaApp = BuildInfo(BuildMode.debug, null, treeShakeIcons: false, packageConfigPath: '.dart_tool/package_config.json');
+      const BuildInfo vanillaApp = BuildInfo(
+        BuildMode.debug,
+        null,
+        treeShakeIcons: false,
+        packageConfigPath: '.dart_tool/package_config.json',
+      );
       String? applicationBundle = macosApp.bundleDirectory(vanillaApp);
       expect(applicationBundle, 'Debug');
 
-      const BuildInfo flavoredApp = BuildInfo(BuildMode.release, 'flavor', treeShakeIcons: false, packageConfigPath: '.dart_tool/package_config.json');
+      const BuildInfo flavoredApp = BuildInfo(
+        BuildMode.release,
+        'flavor',
+        treeShakeIcons: false,
+        packageConfigPath: '.dart_tool/package_config.json',
+      );
       applicationBundle = macosApp.bundleDirectory(flavoredApp);
       expect(applicationBundle, 'Release-flavor');
-
     }, overrides: overrides);
   });
 }
