@@ -12,26 +12,33 @@ import 'package:flutter_tools/src/runner/local_engine.dart';
 
 import '../../src/common.dart';
 
-const String kEngineRoot = '/flutter/engine';
+const String kEngineRoot = '/flutter/flutter/engine';
 const String kArbitraryEngineRoot = '/arbitrary/engine';
-const String kDotPackages = '.packages';
+const String kPackageConfig = '.dart_tool/package_config.json';
 
 void main() {
   testWithoutContext('works if --local-engine is specified and --local-engine-src-path '
-    'is determined by sky_engine', () async {
+      'is determined by sky_engine', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
     fileSystem
-      .directory('$kArbitraryEngineRoot/src/out/ios_debug/gen/dart-pkg/sky_engine/lib/')
-      .createSync(recursive: true);
-    fileSystem
-      .directory('$kArbitraryEngineRoot/src/out/host_debug')
-      .createSync(recursive: true);
-    fileSystem
-      .file(kDotPackages)
-      .writeAsStringSync('sky_engine:file://$kArbitraryEngineRoot/src/out/ios_debug/gen/dart-pkg/sky_engine/lib/');
-    fileSystem
-      .file('bin/cache/pkg/sky_engine/lib')
-      .createSync(recursive: true);
+        .directory('$kArbitraryEngineRoot/src/out/ios_debug/gen/dart-pkg/sky_engine/lib/')
+        .createSync(recursive: true);
+    fileSystem.directory('$kArbitraryEngineRoot/src/out/host_debug').createSync(recursive: true);
+    fileSystem.file(kPackageConfig)
+      ..createSync(recursive: true)
+      ..writeAsStringSync('''
+{
+  "configVersion": 2,
+  "packages": [
+    {
+      "name": "sky_engine",
+      "rootUri": "file://$kArbitraryEngineRoot/src/out/ios_debug/gen/dart-pkg/sky_engine",
+      "packageUri": "lib/"
+    }
+  ]
+}
+''');
+    fileSystem.file('bin/cache/pkg/sky_engine/lib').createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
     final LocalEngineLocator localEngineLocator = LocalEngineLocator(
@@ -43,7 +50,10 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: 'ios_debug'),
+      await localEngineLocator.findEnginePath(
+        localEngine: 'ios_debug',
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug',
         targetEngine: '/arbitrary/engine/src/out/ios_debug',
@@ -53,12 +63,26 @@ void main() {
 
     // Verify that this also works if the sky_engine path is a symlink to the engine root.
     fileSystem.link('/symlink').createSync(kArbitraryEngineRoot);
-    fileSystem
-      .file(kDotPackages)
-      .writeAsStringSync('sky_engine:file:///symlink/src/out/ios_debug/gen/dart-pkg/sky_engine/lib/');
+    fileSystem.file(kPackageConfig)
+      ..createSync(recursive: true)
+      ..writeAsStringSync('''
+{
+  "configVersion": 2,
+  "packages": [
+    {
+      "name": "sky_engine",
+      "rootUri": "file:///symlink/src/out/ios_debug/gen/dart-pkg/sky_engine/",
+      "packageUri": "lib/"
+    }
+  ]
+}
+''');
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: 'ios_debug'),
+      await localEngineLocator.findEnginePath(
+        localEngine: 'ios_debug',
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/symlink/src/out/host_debug',
         targetEngine: '/symlink/src/out/ios_debug',
@@ -68,7 +92,7 @@ void main() {
   });
 
   testWithoutContext('works if --local-engine is specified and --local-engine-src-path '
-    'is specified', () async {
+      'is specified', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
     // Intentionally do not create a package_config to verify that it is not required.
     fileSystem.directory('$kArbitraryEngineRoot/src/out/ios_debug').createSync(recursive: true);
@@ -84,7 +108,11 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(engineSourcePath: '$kArbitraryEngineRoot/src', localEngine: 'ios_debug'),
+      await localEngineLocator.findEnginePath(
+        engineSourcePath: '$kArbitraryEngineRoot/src',
+        localEngine: 'ios_debug',
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug',
         targetEngine: '/arbitrary/engine/src/out/ios_debug',
@@ -93,12 +121,72 @@ void main() {
     expect(logger.traceText, contains('Local engine source at /arbitrary/engine/src'));
   });
 
+  testWithoutContext(
+    'works if --local-engine is specified and --local-engine-host is specified',
+    () async {
+      final FileSystem fileSystem = MemoryFileSystem.test();
+      final Directory localEngine = fileSystem.directory(
+        '$kArbitraryEngineRoot/src/out/android_debug_unopt_arm64/',
+      )..createSync(recursive: true);
+      fileSystem
+          .directory('$kArbitraryEngineRoot/src/out/host_debug_unopt_arm64/')
+          .createSync(recursive: true);
+
+      final BufferLogger logger = BufferLogger.test();
+      final LocalEngineLocator localEngineLocator = LocalEngineLocator(
+        fileSystem: fileSystem,
+        flutterRoot: 'flutter/flutter',
+        logger: logger,
+        userMessages: UserMessages(),
+        platform: FakePlatform(environment: <String, String>{}),
+      );
+
+      expect(
+        await localEngineLocator.findEnginePath(
+          localEngine: localEngine.path,
+          localHostEngine: 'host_debug_unopt_arm64',
+        ),
+        matchesEngineBuildPaths(
+          hostEngine: '/arbitrary/engine/src/out/host_debug_unopt_arm64',
+          targetEngine: '/arbitrary/engine/src/out/android_debug_unopt_arm64',
+        ),
+      );
+      expect(logger.traceText, contains('Local engine source at /arbitrary/engine/src'));
+    },
+  );
+
+  testWithoutContext('fails if --local-engine-host is omitted', () async {
+    final FileSystem fileSystem = MemoryFileSystem.test();
+    final Directory localEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/android_debug_unopt_arm64/',
+    )..createSync(recursive: true);
+    fileSystem
+        .directory('$kArbitraryEngineRoot/src/out/host_debug_unopt/')
+        .createSync(recursive: true);
+
+    final BufferLogger logger = BufferLogger.test();
+    final LocalEngineLocator localEngineLocator = LocalEngineLocator(
+      fileSystem: fileSystem,
+      flutterRoot: 'flutter/flutter',
+      logger: logger,
+      userMessages: UserMessages(),
+      platform: FakePlatform(environment: <String, String>{}),
+    );
+
+    await expectLater(
+      localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      throwsToolExit(
+        message:
+            'You are using a locally built engine (--local-engine) but have not specified --local-engine-host',
+      ),
+    );
+  });
+
   testWithoutContext('works if --local-engine is specified and --local-engine-src-path '
       'is determined by --local-engine', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/ios_debug/')
-        ..createSync(recursive: true);
+    final Directory localEngine = fileSystem.directory('$kArbitraryEngineRoot/src/out/ios_debug/')
+      ..createSync(recursive: true);
     fileSystem.directory('$kArbitraryEngineRoot/src/out/host_debug/').createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
@@ -111,20 +199,25 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      await localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug',
         targetEngine: '/arbitrary/engine/src/out/ios_debug',
       ),
     );
-    expect(logger.traceText, contains('Parsed engine source from local engine as /arbitrary/engine/src'));
+    expect(
+      logger.traceText,
+      contains('Parsed engine source from local engine as /arbitrary/engine/src'),
+    );
     expect(logger.traceText, contains('Local engine source at /arbitrary/engine/src'));
   });
 
   testWithoutContext('works if local engine is host engine', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/host_debug/')
+    final Directory localEngine = fileSystem.directory('$kArbitraryEngineRoot/src/out/host_debug/')
       ..createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
@@ -137,7 +230,10 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      await localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: localEngine.path,
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug',
         targetEngine: '/arbitrary/engine/src/out/host_debug',
@@ -148,9 +244,9 @@ void main() {
 
   testWithoutContext('works if local engine is host engine with suffixes', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/host_debug_unopt_arm64/')
-      ..createSync(recursive: true);
+    final Directory localEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/host_debug_unopt_arm64/',
+    )..createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
     final LocalEngineLocator localEngineLocator = LocalEngineLocator(
@@ -162,7 +258,10 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      await localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: localEngine.path,
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug_unopt_arm64',
         targetEngine: '/arbitrary/engine/src/out/host_debug_unopt_arm64',
@@ -172,12 +271,10 @@ void main() {
 
   testWithoutContext('works if local engine is simulator', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/ios_debug_sim/')
-      ..createSync(recursive: true);
-    fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/host_debug/')
-        .createSync(recursive: true);
+    final Directory localEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/ios_debug_sim/',
+    )..createSync(recursive: true);
+    fileSystem.directory('$kArbitraryEngineRoot/src/out/host_debug/').createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
     final LocalEngineLocator localEngineLocator = LocalEngineLocator(
@@ -189,7 +286,10 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      await localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug',
         targetEngine: '/arbitrary/engine/src/out/ios_debug_sim',
@@ -197,12 +297,11 @@ void main() {
     );
   });
 
-  testWithoutContext('works if local engine is simulator unoptimized',
-      () async {
+  testWithoutContext('works if local engine is simulator unoptimized', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/ios_debug_sim_unopt/')
-      ..createSync(recursive: true);
+    final Directory localEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/ios_debug_sim_unopt/',
+    )..createSync(recursive: true);
     fileSystem
         .directory('$kArbitraryEngineRoot/src/out/host_debug_unopt/')
         .createSync(recursive: true);
@@ -217,7 +316,10 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      await localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: 'host_debug_unopt',
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/host_debug_unopt',
         targetEngine: '/arbitrary/engine/src/out/ios_debug_sim_unopt',
@@ -227,8 +329,7 @@ void main() {
 
   testWithoutContext('fails if host_debug does not exist', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/ios_debug/')
+    final Directory localEngine = fileSystem.directory('$kArbitraryEngineRoot/src/out/ios_debug/')
       ..createSync(recursive: true);
 
     final LocalEngineLocator localEngineLocator = LocalEngineLocator(
@@ -240,24 +341,21 @@ void main() {
     );
 
     await expectToolExitLater(
-      localEngineLocator.findEnginePath(localEngine: localEngine.path),
+      localEngineLocator.findEnginePath(
+        localEngine: localEngine.path,
+        localHostEngine: 'host_debug',
+      ),
       contains('No Flutter engine build found at /arbitrary/engine/src/out/host_debug'),
     );
   });
 
   testWithoutContext('works if --local-engine is specified and --local-engine-src-path '
-    'is determined by flutter root', () async {
+      'is determined by flutter root', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    fileSystem.file(kDotPackages).writeAsStringSync('\n');
-    fileSystem
-      .directory('$kEngineRoot/src/out/ios_debug')
-      .createSync(recursive: true);
-    fileSystem
-      .directory('$kEngineRoot/src/out/host_debug')
-      .createSync(recursive: true);
-    fileSystem
-      .file('bin/cache/pkg/sky_engine/lib')
-      .createSync(recursive: true);
+    fileSystem.file(kPackageConfig).createSync(recursive: true);
+    fileSystem.directory('$kEngineRoot/src/out/ios_debug').createSync(recursive: true);
+    fileSystem.directory('$kEngineRoot/src/out/host_debug').createSync(recursive: true);
+    fileSystem.file('bin/cache/pkg/sky_engine/lib').createSync(recursive: true);
 
     final BufferLogger logger = BufferLogger.test();
     final LocalEngineLocator localEngineLocator = LocalEngineLocator(
@@ -269,13 +367,16 @@ void main() {
     );
 
     expect(
-      await localEngineLocator.findEnginePath(localEngine: 'ios_debug'),
+      await localEngineLocator.findEnginePath(
+        localEngine: 'ios_debug',
+        localHostEngine: 'host_debug',
+      ),
       matchesEngineBuildPaths(
-        hostEngine: 'flutter/engine/src/out/host_debug',
-        targetEngine: 'flutter/engine/src/out/ios_debug',
+        hostEngine: 'flutter/flutter/engine/src/out/host_debug',
+        targetEngine: 'flutter/flutter/engine/src/out/ios_debug',
       ),
     );
-    expect(logger.traceText, contains('Local engine source at flutter/engine/src'));
+    expect(logger.traceText, contains('Local engine source at flutter/flutter/engine/src'));
   });
 
   testWithoutContext('fails if --local-engine is specified and --local-engine-src-path '
@@ -291,19 +392,22 @@ void main() {
     );
 
     await expectToolExitLater(
-      localEngineLocator.findEnginePath(localEngine: '/path/to/nothing'),
+      localEngineLocator.findEnginePath(
+        localEngine: '/path/to/nothing',
+        localHostEngine: '/path/to/nothing',
+      ),
       contains('Unable to detect local Flutter engine src directory'),
     );
   });
 
   testWithoutContext('works for local web engine', () async {
     final FileSystem fileSystem = MemoryFileSystem.test();
-    final Directory localWasmEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/wasm_whatever/')
-      ..createSync(recursive: true);
-    final Directory localWebEngine = fileSystem
-        .directory('$kArbitraryEngineRoot/src/out/web_whatever/')
-      ..createSync(recursive: true);
+    final Directory localWasmEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/wasm_whatever/',
+    )..createSync(recursive: true);
+    final Directory localWebEngine = fileSystem.directory(
+      '$kArbitraryEngineRoot/src/out/web_whatever/',
+    )..createSync(recursive: true);
 
     final BufferLogger wasmLogger = BufferLogger.test();
     final LocalEngineLocator localWasmEngineLocator = LocalEngineLocator(
@@ -315,7 +419,10 @@ void main() {
     );
 
     expect(
-      await localWasmEngineLocator.findEnginePath(localEngine: localWasmEngine.path),
+      await localWasmEngineLocator.findEnginePath(
+        localEngine: localWasmEngine.path,
+        localHostEngine: localWasmEngine.path,
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/wasm_whatever',
         targetEngine: '/arbitrary/engine/src/out/wasm_whatever',
@@ -333,7 +440,10 @@ void main() {
     );
 
     expect(
-      await localWebEngineLocator.findEnginePath(localEngine: localWebEngine.path),
+      await localWebEngineLocator.findEnginePath(
+        localEngine: localWebEngine.path,
+        localHostEngine: localWebEngine.path,
+      ),
       matchesEngineBuildPaths(
         hostEngine: '/arbitrary/engine/src/out/web_whatever',
         targetEngine: '/arbitrary/engine/src/out/web_whatever',
@@ -355,27 +465,27 @@ void main() {
     expect(paths, isNull);
   });
 
-  test('throws if nothing is specified but the FLUTTER_ENGINE environment variable is set', () async {
-    final LocalEngineLocator localWebEngineLocator = LocalEngineLocator(
-      fileSystem: MemoryFileSystem.test(),
-      flutterRoot: 'flutter/flutter',
-      logger: BufferLogger.test(),
-      userMessages: UserMessages(),
-      platform: FakePlatform(environment: <String, String>{'FLUTTER_ENGINE': 'blah'}),
-    );
+  test(
+    'throws if nothing is specified but the FLUTTER_ENGINE environment variable is set',
+    () async {
+      final LocalEngineLocator localWebEngineLocator = LocalEngineLocator(
+        fileSystem: MemoryFileSystem.test(),
+        flutterRoot: 'flutter/flutter',
+        logger: BufferLogger.test(),
+        userMessages: UserMessages(),
+        platform: FakePlatform(environment: <String, String>{'FLUTTER_ENGINE': 'blah'}),
+      );
 
-    await expectToolExitLater(
-      localWebEngineLocator.findEnginePath(),
-      contains('Unable to detect a Flutter engine build directory in blah'),
-    );
-  });
+      await expectToolExitLater(
+        localWebEngineLocator.findEnginePath(),
+        contains('Unable to detect a Flutter engine build directory in blah'),
+      );
+    },
+  );
 }
 
-Matcher matchesEngineBuildPaths({
-  String? hostEngine,
-  String? targetEngine,
-}) {
+Matcher matchesEngineBuildPaths({String? hostEngine, String? targetEngine}) {
   return const TypeMatcher<EngineBuildPaths>()
-    .having((EngineBuildPaths paths) => paths.hostEngine, 'hostEngine', hostEngine)
-    .having((EngineBuildPaths paths) => paths.targetEngine, 'targetEngine', targetEngine);
+      .having((EngineBuildPaths paths) => paths.hostEngine, 'hostEngine', hostEngine)
+      .having((EngineBuildPaths paths) => paths.targetEngine, 'targetEngine', targetEngine);
 }
