@@ -15,8 +15,7 @@ void main() {
 
   setUp(() async {
     tempDirPluginMethodChannels = createResolvedTempDirectorySync('flutter_plugin_test.');
-    tempDirPluginFfi =
-        createResolvedTempDirectorySync('flutter_ffi_plugin_test.');
+    tempDirPluginFfi = createResolvedTempDirectorySync('flutter_ffi_plugin_test.');
   });
 
   tearDown(() async {
@@ -24,16 +23,7 @@ void main() {
     tryToDelete(tempDirPluginFfi);
   });
 
-  Future<void> testPlugin({
-    required String template,
-    required Directory tempDir,
-  }) async {
-    final String flutterBin = fileSystem.path.join(
-      getFlutterRoot(),
-      'bin',
-      'flutter',
-    );
-
+  Future<void> testPlugin({required String template, required Directory tempDir}) async {
     final String testName = '${template}_test';
 
     ProcessResult result = processManager.runSync(<String>[
@@ -45,25 +35,13 @@ void main() {
       testName,
     ], workingDirectory: tempDir.path);
     if (result.exitCode != 0) {
-      throw Exception('flutter create failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}');
+      throw Exception(
+        'flutter create failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}',
+      );
     }
 
-    final Directory exampleAppDir =
-        tempDir.childDirectory(testName).childDirectory('example');
+    final Directory exampleAppDir = tempDir.childDirectory(testName).childDirectory('example');
 
-    final File buildGradleFile = exampleAppDir.childDirectory('android').childFile('build.gradle');
-    expect(buildGradleFile, exists);
-
-    final String buildGradle = buildGradleFile.readAsStringSync();
-    final RegExp androidPluginRegExp =
-        RegExp(r'com\.android\.tools\.build:gradle:(\d+\.\d+\.\d+)');
-
-    // Use AGP 7.2.0
-    final String newBuildGradle = buildGradle.replaceAll(
-        androidPluginRegExp, 'com.android.tools.build:gradle:7.2.0');
-    buildGradleFile.writeAsStringSync(newBuildGradle);
-
-    // Run flutter build apk using AGP 7.2.0
     result = processManager.runSync(<String>[
       flutterBin,
       ...getLocalEngineArguments(),
@@ -72,17 +50,21 @@ void main() {
       '--target-platform=android-arm',
     ], workingDirectory: exampleAppDir.path);
     if (result.exitCode != 0) {
-      throw Exception('flutter build failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}');
+      throw Exception(
+        'flutter build failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}',
+      );
     }
 
-    final File exampleApk = fileSystem.file(fileSystem.path.join(
-      exampleAppDir.path,
-      'build',
-      'app',
-      'outputs',
-      'flutter-apk',
-      'app-release.apk',
-    ));
+    final File exampleApk = fileSystem.file(
+      fileSystem.path.join(
+        exampleAppDir.path,
+        'build',
+        'app',
+        'outputs',
+        'flutter-apk',
+        'app-release.apk',
+      ),
+    );
     expect(exampleApk, exists);
 
     if (template == 'plugin_ffi') {
@@ -97,22 +79,24 @@ void main() {
       'clean',
     ], workingDirectory: exampleAppDir.path);
     if (result.exitCode != 0) {
-      throw Exception('flutter clean failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}');
+      throw Exception(
+        'flutter clean failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}',
+      );
     }
 
     // Remove Gradle wrapper
     fileSystem
-        .directory(fileSystem.path
-            .join(exampleAppDir.path, 'android', 'gradle', 'wrapper'))
+        .directory(fileSystem.path.join(exampleAppDir.path, 'android', 'gradle', 'wrapper'))
         .deleteSync(recursive: true);
 
     // Enable R8 in gradle.properties
-    final File gradleProperties =
-        exampleAppDir.childDirectory('android').childFile('gradle.properties');
+    final File gradleProperties = exampleAppDir
+        .childDirectory('android')
+        .childFile('gradle.properties');
     expect(gradleProperties, exists);
 
     gradleProperties.writeAsStringSync('''
-org.gradle.jvmargs=-Xmx4G
+org.gradle.jvmargs=-Xmx8G -XX:MaxMetaspaceSize=4G -XX:ReservedCodeCacheSize=512m -XX:+HeapDumpOnOutOfMemoryError
 android.useAndroidX=true
 android.enableJetifier=true
 android.enableR8=true''');
@@ -126,24 +110,18 @@ android.enableR8=true''');
       '--target-platform=android-arm',
     ], workingDirectory: exampleAppDir.path);
     if (result.exitCode != 0) {
-      throw Exception('flutter build failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}');
+      throw Exception(
+        'flutter build failed: ${result.exitCode}\n${result.stderr}\n${result.stdout}',
+      );
     }
     expect(exampleApk, exists);
   }
 
-  test('plugin example can be built using current Flutter Gradle plugin',
-      () async {
-    await testPlugin(
-      template: 'plugin',
-      tempDir: tempDirPluginMethodChannels,
-    );
+  test('plugin example can be built using current Flutter Gradle plugin', () async {
+    await testPlugin(template: 'plugin', tempDir: tempDirPluginMethodChannels);
   });
 
-  test('FFI plugin example can be built using current Flutter Gradle plugin',
-      () async {
-    await testPlugin(
-      template: 'plugin_ffi',
-      tempDir: tempDirPluginFfi,
-    );
+  test('FFI plugin example can be built using current Flutter Gradle plugin', () async {
+    await testPlugin(template: 'plugin_ffi', tempDir: tempDirPluginFfi);
   });
 }
