@@ -2,6 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+@Tags(<String>['flutter-test-driver'])
+library;
+
 import 'package:file/file.dart';
 import 'package:file_testing/file_testing.dart';
 
@@ -32,6 +35,9 @@ void main() {
     final File lcovFile = tempDir.childDirectory('coverage').childFile('lcov.info');
 
     expect(lcovFile, exists);
-    expect(lcovFile.readAsStringSync(), contains('main.dart')); // either 'SF:lib/main.dart or SF:lib\\main.dart
+    expect(
+      lcovFile.readAsStringSync(),
+      contains('main.dart'),
+    ); // either 'SF:lib/main.dart or SF:lib\\main.dart
   });
 }
