@@ -31,25 +31,16 @@ final bool useInProcessDap = Platform.environment['DAP_TEST_INTERNAL'] == 'true'
 /// Service traffic (wrapped in a custom 'dart.log' event).
 final bool verboseLogging = Platform.environment['DAP_TEST_VERBOSE'] == 'true';
 
-const String endOfErrorOutputMarker = '════════════════════════════════════════════════════════════════════════════════════════════════════';
+const String endOfErrorOutputMarker =
+    '════════════════════════════════════════════════════════════════════════════════';
 
 /// Expects the lines in [actual] to match the relevant matcher in [expected],
 /// ignoring differences in line endings and trailing whitespace.
-void expectLines(
-  String actual,
-  List<Object> expected, {
-  bool allowExtras = false,
-}) {
+void expectLines(String actual, List<Object> expected, {bool allowExtras = false}) {
   if (allowExtras) {
-    expect(
-      actual.replaceAll('\r\n', '\n').trim().split('\n'),
-      containsAllInOrder(expected),
-    );
+    expect(actual.replaceAll('\r\n', '\n').trim().split('\n'), containsAllInOrder(expected));
   } else {
-    expect(
-      actual.replaceAll('\r\n', '\n').trim().split('\n'),
-      equals(expected),
-    );
+    expect(actual.replaceAll('\r\n', '\n').trim().split('\n'), equals(expected));
   }
 }
 
@@ -68,10 +59,12 @@ class SimpleFlutterRunner {
   Stream<String> get output => _output.stream;
 
   void _handleExitCode(int code) {
-      if (!_vmServiceUriCompleter.isCompleted) {
-        _vmServiceUriCompleter.completeError('Flutter process ended without producing a VM Service URI');
-      }
+    if (!_vmServiceUriCompleter.isCompleted) {
+      _vmServiceUriCompleter.completeError(
+        'Flutter process ended without producing a VM Service URI',
+      );
     }
+  }
 
   void _handleStderr(String err) {
     if (!_vmServiceUriCompleter.isCompleted) {
@@ -88,7 +81,8 @@ class SimpleFlutterRunner {
         final Object? message = json.single;
         // Parse the add.debugPort event which contains our VM Service URI.
         if (message is Map<String, Object?> && message['event'] == 'app.debugPort') {
-          final String vmServiceUri = (message['params']! as Map<String, Object?>)['wsUri']! as String;
+          final String vmServiceUri =
+              (message['params']! as Map<String, Object?>)['wsUri']! as String;
           if (!_vmServiceUriCompleter.isCompleted) {
             _vmServiceUriCompleter.complete(Uri.parse(vmServiceUri));
           }
@@ -103,17 +97,16 @@ class SimpleFlutterRunner {
 
   final Process process;
   final Completer<Uri> _vmServiceUriCompleter = Completer<Uri>();
-   Future<Uri> get vmServiceUri => _vmServiceUriCompleter.future;
+  Future<Uri> get vmServiceUri => _vmServiceUriCompleter.future;
 
   static Future<SimpleFlutterRunner> start(Directory projectDirectory) async {
-    final String flutterToolPath = globals.fs.path.join(Cache.flutterRoot!, 'bin', globals.platform.isWindows ? 'flutter.bat' : 'flutter');
+    final String flutterToolPath = globals.fs.path.join(
+      Cache.flutterRoot!,
+      'bin',
+      globals.platform.isWindows ? 'flutter.bat' : 'flutter',
+    );
 
-    final List<String> args = <String>[
-      'run',
-      '--machine',
-      '-d',
-      'flutter-tester',
-    ];
+    final List<String> args = <String>['run', '--machine', '-d', 'flutter-tester'];
 
     final Process process = await Process.start(
       flutterToolPath,
@@ -148,18 +141,9 @@ class DapTestSession {
   }
 
   /// Starts a DAP server that can be shared across tests.
-  static Future<DapTestServer> _startServer({
-    Logger? logger,
-    List<String>? additionalArgs,
-  }) async {
+  static Future<DapTestServer> _startServer({Logger? logger, List<String>? additionalArgs}) async {
     return useInProcessDap
-        ? await InProcessDapTestServer.create(
-            logger: logger,
-            additionalArgs: additionalArgs,
-          )
-        : await OutOfProcessDapTestServer.create(
-            logger: logger,
-            additionalArgs: additionalArgs,
-          );
+        ? await InProcessDapTestServer.create(logger: logger, additionalArgs: additionalArgs)
+        : await OutOfProcessDapTestServer.create(logger: logger, additionalArgs: additionalArgs);
   }
 }
