@@ -14,7 +14,7 @@ class IntegrationTestsProject extends Project implements TestsProject {
   final String pubspec = '''
   name: test
   environment:
-    sdk: '>=3.2.0-0 <4.0.0'
+    sdk: ^3.7.0-0
 
   dependencies:
     flutter:
