@@ -5,12 +5,11 @@
 import 'project.dart';
 
 class ProjectWithEarlyError extends Project {
-
   @override
   final String pubspec = '''
   name: test
   environment:
-    sdk: '>=3.2.0-0 <4.0.0'
+    sdk: ^3.7.0-0
 
   dependencies:
     flutter:
@@ -37,5 +36,4 @@ class ProjectWithEarlyError extends Project {
     }
   }
   ''';
-
 }
