@@ -12,12 +12,11 @@ import '../src/common.dart';
 import 'test_utils.dart';
 
 const String xcodeBackendPath = 'bin/xcode_backend.sh';
-const String xcodeBackendErrorHeader = '========================================================================';
+const String xcodeBackendErrorHeader =
+    '========================================================================';
 
 // Acceptable $CONFIGURATION/$FLUTTER_BUILD_MODE values should be debug, profile, or release
-const Map<String, String> unknownConfiguration = <String, String>{
-  'CONFIGURATION': 'Custom',
-};
+const Map<String, String> unknownConfiguration = <String, String>{'CONFIGURATION': 'Custom'};
 
 // $FLUTTER_BUILD_MODE will override $CONFIGURATION
 const Map<String, String> unknownFlutterBuildMode = <String, String>{
@@ -27,11 +26,9 @@ const Map<String, String> unknownFlutterBuildMode = <String, String>{
 
 void main() {
   Future<void> expectXcodeBackendFails(Map<String, String> environment) async {
-    final ProcessResult result = await Process.run(
-      xcodeBackendPath,
-      <String>['build'],
-      environment: environment,
-    );
+    final ProcessResult result = await Process.run(xcodeBackendPath, <String>[
+      'build',
+    ], environment: environment);
     expect(result.stderr, startsWith(xcodeBackendErrorHeader));
     expect(result.exitCode, isNot(0));
   }
@@ -45,7 +42,10 @@ void main() {
         'FLUTTER_ROOT': '../..',
       },
     );
-    expect(result.stderr, startsWith('error: Your Xcode project is incompatible with this version of Flutter.'));
+    expect(
+      result.stderr,
+      startsWith('error: Your Xcode project is incompatible with this version of Flutter.'),
+    );
     expect(result.exitCode, isNot(0));
   }, skip: !io.Platform.isMacOS); // [intended] requires macos toolchain.
 
@@ -58,10 +58,7 @@ void main() {
     final ProcessResult result = await Process.run(
       xcodeBackendPath,
       <String>['build'],
-      environment: <String, String>{
-        'CONFIGURATION': 'Debug',
-        'ACTION': 'install',
-      },
+      environment: <String, String>{'CONFIGURATION': 'Debug', 'ACTION': 'install'},
     );
     expect(result.stdout, contains('warning: Flutter archive not built in Release mode.'));
     expect(result.exitCode, isNot(0));
@@ -72,7 +69,9 @@ void main() {
     late File infoPlist;
 
     setUp(() {
-      buildDirectory = globals.fs.systemTempDirectory.createTempSync('flutter_tools_xcode_backend_test.');
+      buildDirectory = globals.fs.systemTempDirectory.createTempSync(
+        'flutter_tools_xcode_backend_test.',
+      );
       infoPlist = buildDirectory.childFile('Info.plist');
     });
 
@@ -141,8 +140,10 @@ void main() {
       });
     }
 
-    test('adds to existing Bonjour services, does not override network usage description', () async {
-      infoPlist.writeAsStringSync('''
+    test(
+      'adds to existing Bonjour services, does not override network usage description',
+      () async {
+        infoPlist.writeAsStringSync('''
 <?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
@@ -156,17 +157,17 @@ void main() {
 </dict>
 </plist>''');
 
-      final ProcessResult result = await Process.run(
-        xcodeBackendPath,
-        <String>['test_vm_service_bonjour_service'],
-        environment: <String, String>{
-          'CONFIGURATION': 'Debug',
-          'BUILT_PRODUCTS_DIR': buildDirectory.path,
-          'INFOPLIST_PATH': 'Info.plist',
-        },
-      );
+        final ProcessResult result = await Process.run(
+          xcodeBackendPath,
+          <String>['test_vm_service_bonjour_service'],
+          environment: <String, String>{
+            'CONFIGURATION': 'Debug',
+            'BUILT_PRODUCTS_DIR': buildDirectory.path,
+            'INFOPLIST_PATH': 'Info.plist',
+          },
+        );
 
-      expect(infoPlist.readAsStringSync(), '''
+        expect(infoPlist.readAsStringSync(), '''
 <?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
@@ -181,8 +182,9 @@ void main() {
 </dict>
 </plist>
 ''');
-      expect(result, const ProcessResultMatcher());
-    });
+        expect(result, const ProcessResultMatcher());
+      },
+    );
 
     test('does not add bonjour settings when port publication is disabled', () async {
       infoPlist.writeAsStringSync('''
