@@ -69,7 +69,13 @@ class FakeCommand {
 
   /// A callback that is run after [duration] expires but before the [exitCode]
   /// (and output) are passed back.
-  final VoidCallback? onRun;
+  ///
+  /// The callback will be provided the full command that matched this instance.
+  /// This can be useful in the rare scenario where the full command cannot be known
+  /// ahead of time (i.e. when one or more instances of [RegExp] are used to
+  /// match the command). For example, the command may contain one or more
+  /// randomly-generated elements, such as a temporary directory path.
+  final void Function(List<String> command)? onRun;
 
   /// The process' exit code.
   ///
@@ -112,7 +118,8 @@ class FakeCommand {
     Encoding? encoding,
     io.ProcessStartMode? mode,
   ) {
-    final List<dynamic> matchers = this.command.map((Pattern x) => x is String ? x : matches(x)).toList();
+    final List<dynamic> matchers =
+        this.command.map((Pattern x) => x is String ? x : matches(x)).toList();
     expect(command, matchers);
     if (processStartMode != null) {
       expect(mode, processStartMode);
@@ -154,20 +161,27 @@ class FakeProcess implements io.Process {
          }
          return exitCode;
        }),
-      _stderr = stderr,
-      stdin = stdin ?? IOSink(StreamController<List<int>>().sink),
-      _stdout = stdout,
-      _completer = completer
-  {
+       _stderr = stderr,
+       stdin =
+           stdin ??
+           IOSink(
+             StreamController<List<int>>()
+               ..stream.listen((_) {})
+               ..sink,
+           ),
+       _stdout = stdout,
+       _completer = completer {
     if (_stderr.isEmpty) {
       this.stderr = const Stream<List<int>>.empty();
     } else if (outputFollowsExit) {
       // Wait for the process to exit before emitting stderr.
-      this.stderr = Stream<List<int>>.fromFuture(this.exitCode.then((_) {
-        // Return a Future so stderr isn't immediately available to those who
-        // await exitCode, but is available asynchronously later.
-        return Future<List<int>>(() => _stderr);
-      }));
+      this.stderr = Stream<List<int>>.fromFuture(
+        this.exitCode.then((_) {
+          // Return a Future so stderr isn't immediately available to those who
+          // await exitCode, but is available asynchronously later.
+          return Future<List<int>>(() => _stderr);
+        }),
+      );
     } else {
       this.stderr = Stream<List<int>>.value(_stderr);
     }
@@ -176,11 +190,13 @@ class FakeProcess implements io.Process {
       this.stdout = const Stream<List<int>>.empty();
     } else if (outputFollowsExit) {
       // Wait for the process to exit before emitting stdout.
-      this.stdout = Stream<List<int>>.fromFuture(this.exitCode.then((_) {
-        // Return a Future so stdout isn't immediately available to those who
-        // await exitCode, but is available asynchronously later.
-        return Future<List<int>>(() => _stdout);
-      }));
+      this.stdout = Stream<List<int>>.fromFuture(
+        this.exitCode.then((_) {
+          // Return a Future so stdout isn't immediately available to those who
+          // await exitCode, but is available asynchronously later.
+          return Future<List<int>>(() => _stdout);
+        }),
+      );
     } else {
       this.stdout = Stream<List<int>>.value(_stdout);
     }
@@ -213,10 +229,17 @@ class FakeProcess implements io.Process {
   /// The raw byte content of stdout.
   final List<int> _stdout;
 
+  /// The list of [kill] signals this process received so far.
+  @visibleForTesting
+  List<io.ProcessSignal> get signals => _signals;
+  final List<io.ProcessSignal> _signals = <io.ProcessSignal>[];
+
   @override
   bool kill([io.ProcessSignal signal = io.ProcessSignal.sigterm]) {
+    _signals.add(signal);
+
     // Killing a fake process has no effect.
-    return false;
+    return true;
   }
 }
 
@@ -299,7 +322,7 @@ abstract class FakeProcessManager implements ProcessManager {
       throw fakeCommand.exception!; // ignore: only_throw_errors
     }
     if (fakeCommand.onRun != null) {
-      fakeCommand.onRun!();
+      fakeCommand.onRun!(command);
     }
     return FakeProcess(
       duration: fakeCommand.duration,
@@ -389,7 +412,8 @@ abstract class FakeProcessManager implements ProcessManager {
 
   /// Returns false if executable in [excludedExecutables].
   @override
-  bool canRun(dynamic executable, {String? workingDirectory}) => !excludedExecutables.contains(executable);
+  bool canRun(dynamic executable, {String? workingDirectory}) =>
+      !excludedExecutables.contains(executable);
 
   Set<String> excludedExecutables = <String>{};
 
@@ -400,8 +424,9 @@ abstract class FakeProcessManager implements ProcessManager {
     if (fakeProcess == null) {
       return false;
     }
+    fakeProcess.kill(signal);
     if (fakeProcess._completer != null) {
-      fakeProcess._completer!.complete();
+      fakeProcess._completer.complete();
     }
     return true;
   }
@@ -428,7 +453,7 @@ class _FakeAnyProcessManager extends FakeProcessManager {
   }
 
   @override
-  void addCommand(FakeCommand command) { }
+  void addCommand(FakeCommand command) {}
 
   @override
   bool get hasRemainingExpectations => true;
@@ -450,9 +475,12 @@ class _SequenceProcessManager extends FakeProcessManager {
     Encoding? encoding,
     io.ProcessStartMode? mode,
   ) {
-    expect(_commands, isNotEmpty,
-      reason: 'ProcessManager was told to execute $command (in $workingDirectory) '
-              'but the FakeProcessManager.list expected no more processes.'
+    expect(
+      _commands,
+      isNotEmpty,
+      reason:
+          'ProcessManager was told to execute $command (in $workingDirectory) '
+          'but the FakeProcessManager.list expected no more processes.',
     );
     _commands.first._matches(command, workingDirectory, environment, encoding, mode);
     return _commands.removeAt(0);
@@ -487,13 +515,14 @@ class _HasNoRemainingExpectations extends Matcher {
 
   @override
   Description describeMismatch(
-      dynamic item,
-      Description description,
-      Map<dynamic, dynamic> matchState,
-      bool verbose,
-      ) {
+    dynamic item,
+    Description description,
+    Map<dynamic, dynamic> matchState,
+    bool verbose,
+  ) {
     final FakeProcessManager fakeProcessManager = item as FakeProcessManager;
     return description.add(
-        'has remaining expectations:\n${fakeProcessManager._remainingExpectations.map((FakeCommand command) => command.command).join('\n')}');
+      'has remaining expectations:\n${fakeProcessManager._remainingExpectations.map((FakeCommand command) => command.command).join('\n')}',
+    );
   }
 }
