@@ -14,14 +14,10 @@ void main() {
     late List<Uri> uriConnections;
 
     setUp(() {
-      final List<Map<String, dynamic>> flutterViewCannedResponses =
-          <Map<String, dynamic>>[
+      final List<Map<String, dynamic>> flutterViewCannedResponses = <Map<String, dynamic>>[
         <String, dynamic>{
           'views': <Map<String, dynamic>>[
-            <String, dynamic>{
-              'type': 'FlutterView',
-              'id': 'flutterView0',
-            },
+            <String, dynamic>{'type': 'FlutterView', 'id': 'flutterView0'},
           ],
         },
         <String, dynamic>{
@@ -59,10 +55,7 @@ void main() {
       forwardedPorts = <FakePortForwarder>[];
       fakeVmServices = <FakeVmService>[];
       uriConnections = <Uri>[];
-      Future<vms.VmService> fakeVmConnectionFunction(
-        Uri uri, {
-        Duration? timeout,
-      }) {
+      Future<vms.VmService> fakeVmConnectionFunction(Uri uri, {Duration? timeout}) {
         return Future<vms.VmService>(() async {
           final FakeVmService service = FakeVmService();
           fakeVmServices.add(service);
@@ -138,7 +131,7 @@ void main() {
         '     },',
         '     "version": 1',
         '   }',
-        ' ]'
+        ' ]',
       ];
       fakeRunner.address = 'fe80::8eae:4cff:fef4:9247';
       fakeRunner.interface = 'eno1';
@@ -151,8 +144,7 @@ void main() {
 
       // VMs should be accessed via localhost ports given by
       // [fakePortForwardingFunction].
-      expect(uriConnections[0],
-          Uri(scheme: 'ws', host: '[::1]', port: 0, path: '/ws'));
+      expect(uriConnections[0], Uri(scheme: 'ws', host: '[::1]', port: 0, path: '/ws'));
 
       final List<FlutterView> views = await connection.getFlutterViews();
       expect(views, isNot(null));
@@ -224,7 +216,7 @@ void main() {
         '     },',
         '     "version": 1',
         '   }',
-        ' ]'
+        ' ]',
       ];
       fakeRunner.address = 'fe80::8eae:4cff:fef4:9247';
       fakeRunner.interface = 'eno1';
@@ -236,8 +228,10 @@ void main() {
 
       // VMs should be accessed via the alternate address given by
       // [fakePortForwardingFunction].
-      expect(uriConnections[0],
-          Uri(scheme: 'ws', host: '[fe80::1:2%25eno2]', port: 0, path: '/ws'));
+      expect(
+        uriConnections[0],
+        Uri(scheme: 'ws', host: '[fe80::1:2%25eno2]', port: 0, path: '/ws'),
+      );
 
       final List<FlutterView> views = await connection.getFlutterViews();
       expect(views, isNot(null));
@@ -308,7 +302,7 @@ void main() {
         '     },',
         '     "version": 1',
         '   }',
-        ' ]'
+        ' ]',
       ];
       fakeRunner.address = '196.168.1.4';
 
@@ -319,8 +313,7 @@ void main() {
       expect(forwardedPorts[0].remotePort, 12345);
 
       // VMs should be accessed via the ipv4 loopback.
-      expect(uriConnections[0],
-          Uri(scheme: 'ws', host: '127.0.0.1', port: 0, path: '/ws'));
+      expect(uriConnections[0], Uri(scheme: 'ws', host: '127.0.0.1', port: 0, path: '/ws'));
 
       final List<FlutterView> views = await connection.getFlutterViews();
       expect(views, isNot(null));
@@ -341,8 +334,7 @@ void main() {
       }
 
       // Should fail as no env variable has been passed.
-      expect(failingFunction,
-          throwsA(isA<FuchsiaRemoteConnectionError>()));
+      expect(failingFunction, throwsA(isA<FuchsiaRemoteConnectionError>()));
     });
   });
 }
@@ -394,7 +386,11 @@ class FakeVmService extends Fake implements vms.VmService {
   }
 
   @override
-  Future<vms.Response> callMethod(String method, {String? isolateId, Map<String, dynamic>? args}) async {
+  Future<vms.Response> callMethod(
+    String method, {
+    String? isolateId,
+    Map<String, dynamic>? args,
+  }) async {
     if (method == '_flutter.listViews') {
       return flutterListViews!;
     }
