@@ -12,7 +12,6 @@ import 'package:_fe_analyzer_shared/src/parser/parser.dart';
 import 'package:_fe_analyzer_shared/src/parser/stack_listener.dart';
 import 'package:_fe_analyzer_shared/src/scanner/token.dart';
 import 'package:analyzer/src/dart/analysis/experiments.dart';
-import 'package:collection/collection.dart';
 import 'package:pub_semver/pub_semver.dart';
 
 /// "Mini AST" representation of a declaration which can accept annotations.
@@ -161,7 +160,7 @@ class MiniAstBuilder extends StackListener {
   final compilationUnit = CompilationUnit();
 
   @override
-  Uri get importUri => throw UnimplementedError();
+  bool get isDartLibrary => throw UnimplementedError();
 
   @override
   Uri get uri => throw UnimplementedError();
@@ -195,7 +194,7 @@ class MiniAstBuilder extends StackListener {
   }
 
   @override
-  void endBinaryExpression(Token token) {
+  void endBinaryExpression(Token token, Token endToken) {
     debugEvent("BinaryExpression");
 
     if (identical('.', token.stringValue)) {
@@ -377,6 +376,7 @@ class MiniAstBuilder extends StackListener {
 
   @override
   void endTopLevelFields(
+      Token? augmentToken,
       Token? externalToken,
       Token? staticToken,
       Token? covariantToken,
@@ -416,7 +416,7 @@ class MiniAstBuilder extends StackListener {
   }
 
   @override
-  void handleEnumElement(Token beginToken) {
+  void handleEnumElement(Token beginToken, Token? augmentToken) {
     debugEvent("EnumElement");
     pop(); // Arguments.
     pop(); // Type arguments.
@@ -432,12 +432,13 @@ class MiniAstBuilder extends StackListener {
     var name = pop() as String;
     var metadata = popTypedList<Annotation>();
     var comment = pop() as Comment?;
-    compilationUnit.declarations.add(EnumDeclaration(
-        comment, metadata, name, constants.whereNotNull().toList()));
+    compilationUnit.declarations.add(
+        EnumDeclaration(comment, metadata, name, constants.nonNulls.toList()));
   }
 
   @override
-  void handleEnumHeader(Token enumKeyword, Token leftBrace) {
+  void handleEnumHeader(
+      Token? augmentToken, Token enumKeyword, Token leftBrace) {
     debugEvent("EnumHeader");
   }
 
@@ -541,7 +542,7 @@ class MiniAstBuilder extends StackListener {
   }
 
   @override
-  // TODO: Handle directly.
+  // TODO(jensj): Handle directly.
   void handleNamedRecordField(Token colon) => handleNamedArgument(colon);
 
   @override
@@ -670,7 +671,7 @@ class MiniAstParser extends Parser {
 
   @override
   Token parseArgumentsOpt(Token token) {
-    final listener = this.listener as MiniAstBuilder;
+    var listener = this.listener as MiniAstBuilder;
     if (listener.inMetadata) {
       return super.parseArgumentsOpt(token);
     } else {
