@@ -38,34 +38,34 @@ void main() {
       test('CBuilder $linkMode library $target $optimizationLevel', () async {
         final tempUri = await tempDirForTest();
         final tempUri2 = await tempDirForTest();
-        final addCUri =
-            packageUri.resolve('test/cbuilder/testfiles/add/src/add.c');
+        final addCUri = packageUri.resolve(
+          'test/cbuilder/testfiles/add/src/add.c',
+        );
         const name = 'add';
 
-        final buildConfigBuilder = BuildConfigBuilder()
-          ..setupHookConfig(
-            buildAssetTypes: [CodeAsset.type],
-            packageName: name,
-            packageRoot: tempUri,
-          )
-          ..setupBuildConfig(
-            linkingEnabled: false,
-            dryRun: false,
-          )
-          ..setupCodeConfig(
-            targetOS: OS.linux,
-            targetArchitecture: target,
-            linkModePreference: linkMode == DynamicLoadingBundled()
-                ? LinkModePreference.dynamic
-                : LinkModePreference.static,
-            cCompilerConfig: cCompiler,
-          );
-        buildConfigBuilder.setupBuildRunConfig(
-          outputDirectory: tempUri,
-          outputDirectoryShared: tempUri2,
-        );
+        final buildInputBuilder =
+            BuildInputBuilder()
+              ..setupShared(
+                packageName: name,
+                packageRoot: tempUri,
+                outputFile: tempUri.resolve('output.json'),
+                outputDirectory: tempUri,
+                outputDirectoryShared: tempUri2,
+              )
+              ..config.setupBuild(linkingEnabled: false)
+              ..addExtension(
+                CodeAssetExtension(
+                  targetOS: OS.linux,
+                  targetArchitecture: target,
+                  linkModePreference:
+                      linkMode == DynamicLoadingBundled()
+                          ? LinkModePreference.dynamic
+                          : LinkModePreference.static,
+                  cCompiler: cCompiler,
+                ),
+              );
 
-        final buildConfig = BuildConfig(buildConfigBuilder.json);
+        final buildInput = BuildInput(buildInputBuilder.json);
         final buildOutput = BuildOutputBuilder();
 
         final cbuilder = CBuilder.library(
@@ -76,13 +76,14 @@ void main() {
           buildMode: BuildMode.release,
         );
         await cbuilder.run(
-          config: buildConfig,
+          input: buildInput,
           output: buildOutput,
           logger: logger,
         );
 
-        final libUri =
-            tempUri.resolve(OS.linux.libraryFileName(name, linkMode));
+        final libUri = buildInput.outputDirectory.resolve(
+          OS.linux.libraryFileName(name, linkMode),
+        );
         final machine = await readelfMachine(libUri.path);
         expect(machine, contains(readElfMachine[target]));
       });
