@@ -2,8 +2,6 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-import 'package:collection/collection.dart';
-import 'package:dap/dap.dart';
 import 'package:test/test.dart';
 
 import 'test_client.dart';
@@ -114,10 +112,10 @@ main() {
       // Collect paths from any OutputEvents that had them.
       final stackFramePaths = outputEvents.output
           .map((event) => event.source?.path)
-          .whereNotNull()
+          .nonNulls
           .toList();
       // Ensure we had a frame with the absolute path of the test script.
-      expect(stackFramePaths, contains(testFile.path));
+      expect(stackFramePaths, contains(uppercaseDriveLetter(testFile.path)));
     });
 
     test('can hit and resume from a breakpoint', () async {
@@ -184,43 +182,6 @@ main() {
       await client.terminate();
     });
 
-    test('resolves and updates breakpoints', () async {
-      final client = dap.client;
-      final testFile =
-          dap.createTestFile(simpleTestBreakpointResolutionProgram);
-      final setBreakpointLine = lineWith(testFile, breakpointMarker);
-      final expectedResolvedBreakpointLine = setBreakpointLine + 1;
-
-      // Collect any breakpoint changes during the run.
-      final breakpointChangesFuture = client.breakpointChangeEvents.toList();
-
-      Future<SetBreakpointsResponseBody> setBreakpointFuture;
-      await Future.wait([
-        client
-            .expectStop('breakpoint',
-                file: testFile, line: expectedResolvedBreakpointLine)
-            .then((_) => client.terminate()),
-        client.initialize(),
-        setBreakpointFuture = client.setBreakpoint(testFile, setBreakpointLine),
-        client.launch(testFile.path),
-      ], eagerError: true);
-
-      // The initial setBreakpointResponse should always return unverified
-      // because we verify using the BreakpointAdded/BreakpointResolved events.
-      final setBreakpointResponse = await setBreakpointFuture;
-      expect(setBreakpointResponse.breakpoints, hasLength(1));
-      final setBreakpoint = setBreakpointResponse.breakpoints.single;
-      expect(setBreakpoint.verified, isFalse);
-
-      // The last breakpoint change we had should be verified and also update
-      // the line to [expectedResolvedBreakpointLine] since the breakpoint was
-      // on a blank line.
-      final breakpointChanges = await breakpointChangesFuture;
-      final updatedBreakpoint = breakpointChanges.last.breakpoint;
-      expect(updatedBreakpoint.verified, isTrue);
-      expect(updatedBreakpoint.line, expectedResolvedBreakpointLine);
-    });
-
     test('resolves modified breakpoints', () async {
       final client = dap.client;
       final testFile = dap.createTestFile(simpleTestMultiBreakpointProgram);
@@ -298,7 +259,8 @@ main() {
       final outputEvents = await client.collectTestOutput(
         launch: () => client.attach(
           vmServiceUri: 'ws://bogus.local/',
-          autoResume: false,
+          autoResumeOnEntry: false,
+          autoResumeOnExit: false,
         ),
       );
 
