@@ -16,6 +16,7 @@ import 'package:test/test.dart';
 import 'package:vm_service/vm_service.dart' as vm;
 
 import 'test_server.dart';
+import 'test_support.dart';
 
 /// A helper class to simplify acting as a client for interacting with the
 /// [DapTestServer] in tests.
@@ -51,19 +52,17 @@ class DapTestClient {
 
   late final Future<Uri?> vmServiceUri;
 
-  /// Used to control drive letter casing on Windows for testing.
-  bool? forceDriveLetterCasingUpper;
-
-  /// Used to control drive letter casing on Windows for testing.
-  bool? forceDriveLetterCasingLower;
-
-  /// Used to control drive letter casing for breakpoint requests on Windows for
+  /// Used to control drive letter casing for the 'program' value on Windows for
   /// testing.
-  bool? forceBreakpointDriveLetterCasingUpper;
+  DriveLetterCasing? forceProgramDriveLetterCasing;
 
-  /// Used to control drive letter casing for breakpoint requests on Windows for
+  /// Used to control drive letter casing for the 'cwd' value on Windows for
   /// testing.
-  bool? forceBreakpointDriveLetterCasingLower;
+  DriveLetterCasing? forceCwdDriveLetterCasing;
+
+  /// Used to control drive letter casing for breakpoint paths on Windows for
+  /// testing.
+  DriveLetterCasing? forceBreakpointDriveLetterCasing;
 
   /// All stderr OutputEvents that have occurred so far.
   final StringBuffer _stderr = StringBuffer();
@@ -86,6 +85,7 @@ class DapTestClient {
     _subscription = _channel.listen(
       _handleMessage,
       onDone: () {
+        _isStopping = true;
         if (_pendingRequests.isNotEmpty) {
           _logger?.call(
               'Application terminated without a response to ${_pendingRequests.length} requests');
@@ -174,8 +174,11 @@ class DapTestClient {
       DartAttachRequestArguments(
         vmServiceUri: vmServiceUri,
         vmServiceInfoFile: vmServiceInfoFile,
-        cwd: cwd != null ? _normalizePath(cwd) : null,
-        additionalProjectPaths: additionalProjectPaths,
+        cwd: cwd != null
+            ? setDriveLetterCasing(cwd, forceCwdDriveLetterCasing)
+            : null,
+        additionalProjectPaths:
+            additionalProjectPaths?.map(uppercaseDriveLetter).toList(),
         debugSdkLibraries: debugSdkLibraries,
         debugExternalPackageLibraries: debugExternalPackageLibraries,
         showGettersInDebugViews: showGettersInDebugViews,
@@ -320,6 +323,7 @@ class DapTestClient {
   Future<Response> launch(
     String program, {
     List<String>? args,
+    List<String>? vmAdditionalArgs,
     List<String>? toolArgs,
     String? cwd,
     bool? noDebug,
@@ -338,12 +342,15 @@ class DapTestClient {
     return sendRequest(
       DartLaunchRequestArguments(
         noDebug: noDebug,
-        program: _normalizePath(program),
-        cwd: cwd != null ? _normalizePath(cwd) : null,
+        program: setDriveLetterCasing(program, forceProgramDriveLetterCasing),
+        cwd: cwd != null
+            ? setDriveLetterCasing(cwd, forceCwdDriveLetterCasing)
+            : null,
         args: args,
+        vmAdditionalArgs: vmAdditionalArgs,
         toolArgs: toolArgs,
         additionalProjectPaths:
-            additionalProjectPaths?.map(_normalizePath).toList(),
+            additionalProjectPaths?.map(uppercaseDriveLetter).toList(),
         console: console,
         debugSdkLibraries: debugSdkLibraries,
         debugExternalPackageLibraries: debugExternalPackageLibraries,
@@ -480,10 +487,14 @@ class DapTestClient {
       sendRequest(StepOutArguments(threadId: threadId));
 
   Future<void> stop() async {
+    _isStopping = true;
     _channel.close();
     await _subscription.cancel();
   }
 
+  /// Whether this client is stopping (for any shutdown reason).
+  bool _isStopping = false;
+
   /// Whether or not any `terminate()` request has been sent.
   bool get hasSentTerminateRequest => _hasSentTerminateRequest;
   bool _hasSentTerminateRequest = false;
@@ -494,6 +505,7 @@ class DapTestClient {
   /// completes, or when a `terminated` event is received since it is not
   /// guaranteed that this request will return a response during a shutdown.
   Future<void> terminate() async {
+    _isStopping = true;
     _hasSentTerminateRequest = true;
     return Future.any([
       event('terminated').then(
@@ -559,6 +571,7 @@ class DapTestClient {
       // tests are waiting on something that will never come, they fail at
       // a useful location.
       if (message.event == 'terminated') {
+        _isStopping = true;
         unawaited(_eventController.close());
 
         if (_stderr.isNotEmpty) {
@@ -581,13 +594,30 @@ class DapTestClient {
   }
 
   /// Prints a warning if [future] takes longer than [_requestWarningDuration]
-  /// to complete.
+  /// to complete aid debugging test failures on bots from logs.
   ///
   /// Returns [future].
   Future<T> _logIfSlow<T>(String name, Future<T> future) {
-    final timer = Timer(_requestWarningDuration, () {
-      print(
-          '$name has taken longer than ${_requestWarningDuration.inSeconds}s');
+    // Use a loop to periodically check so that we can exit earlier if
+    // the test is being torn down.
+    var endTime = DateTime.now().add(_requestWarningDuration);
+    late Timer timer;
+    timer = Timer.periodic(Duration(milliseconds: 100), (_) {
+      // Shutting down, so just abort.
+      if (_isStopping) {
+        timer.cancel();
+        return;
+      }
+
+      // We've hit the warning threshold, report and then abort.
+      if (DateTime.now().isAfter(endTime)) {
+        print(
+            '$name has taken longer than ${_requestWarningDuration.inSeconds}s');
+        timer.cancel();
+        return;
+      }
+
+      // Otherwise, do nothing and check on the next tick.
     });
     return future.whenComplete(timer.cancel);
   }
@@ -693,6 +723,7 @@ extension DapTestClientExtension on DapTestClient {
     String? condition,
     String? cwd,
     List<String>? args,
+    List<String>? vmAdditionalArgs,
     List<String>? toolArgs,
     bool? evaluateToStringInDebugViews,
     Future<Response> Function()? launch,
@@ -713,6 +744,7 @@ extension DapTestClientExtension on DapTestClient {
             entryFile.path,
             cwd: cwd,
             args: args,
+            vmAdditionalArgs: vmAdditionalArgs,
             toolArgs: toolArgs,
             evaluateToStringInDebugViews: evaluateToStringInDebugViews,
           ),
@@ -773,50 +805,11 @@ extension DapTestClientExtension on DapTestClient {
     );
   }
 
-  /// Normalizes a non-breakpoint path being sent to the debug adapter based on
-  /// the values of [forceDriveLetterCasingUpper] and
-  /// [forceDriveLetterCasingLower].
-  String _normalizePath(String path) {
-    return _forceDriveLetterCasing(
-      path,
-      upper: forceDriveLetterCasingUpper,
-      lower: forceDriveLetterCasingLower,
-    );
-  }
-
-  /// Normalizes a a path to have an uppercase drive letter. All paths verified
-  /// that come out of the adapter are normalized this way so test expectations
-  /// should be normalized the same way before comparing.
-  String uppercaseDriveLetter(String path) {
-    return _forceDriveLetterCasing(
-      path,
-      upper: true,
-    );
-  }
-
   /// Normalizes a breakpoint path being sent to the debug adapter based on
   /// the values of [forceBreakpointDriveLetterCasingUpper] and
   /// [forceBreakpointDriveLetterCasingLower].
   String _normalizeBreakpointPath(String path) {
-    return _forceDriveLetterCasing(
-      path,
-      upper: forceBreakpointDriveLetterCasingUpper,
-      lower: forceBreakpointDriveLetterCasingLower,
-    );
-  }
-
-  String _forceDriveLetterCasing(String path, {bool? upper, bool? lower}) {
-    assert(upper != true || lower != true);
-    if (!Platform.isWindows || path.isEmpty) {
-      return path;
-    }
-    if (upper ?? false) {
-      return path.substring(0, 1).toUpperCase() + path.substring(1);
-    } else if (lower ?? false) {
-      return path.substring(0, 1).toLowerCase() + path.substring(1);
-    } else {
-      return path;
-    }
+    return setDriveLetterCasing(path, forceBreakpointDriveLetterCasing);
   }
 
   /// Sets the exception pause mode to [pauseMode] and expects to pause after
@@ -1092,6 +1085,7 @@ extension DapTestClientExtension on DapTestClient {
     required String expectedVariables,
     int? start,
     int? count,
+    ValueFormat? format,
     bool ignorePrivate = true,
     Set<String>? ignore,
   }) async {
@@ -1108,6 +1102,7 @@ extension DapTestClientExtension on DapTestClient {
       start: start,
       count: count,
       ignorePrivate: ignorePrivate,
+      format: format,
       ignore: ignore,
     );
   }
@@ -1164,6 +1159,17 @@ extension DapTestClientExtension on DapTestClient {
         response.body as Map<String, Object?>);
   }
 
+  /// A helper that calls the private `_collectAllGarbage` custom request to
+  /// force a GC.
+  Future<void> forceGc(int threadId) async {
+    await sendRequest(
+      {
+        'threadId': threadId,
+      },
+      overrideCommand: '_collectAllGarbage',
+    );
+  }
+
   /// A helper that verifies the variables list matches [expectedVariables].
   ///
   /// [expectedVariables] is a simple text format of `name: value` for each
