@@ -15,8 +15,7 @@ import 'package:dwds/src/connections/app_connection.dart';
 import 'package:dwds/src/connections/debug_connection.dart';
 import 'package:dwds/src/debugging/webkit_debugger.dart';
 import 'package:dwds/src/loaders/build_runner_require.dart';
-import 'package:dwds/src/loaders/frontend_server_ddc.dart';
-import 'package:dwds/src/loaders/frontend_server_require.dart';
+import 'package:dwds/src/loaders/frontend_server_strategy_provider.dart';
 import 'package:dwds/src/loaders/strategy.dart';
 import 'package:dwds/src/readers/proxy_server_asset_reader.dart';
 import 'package:dwds/src/services/chrome_proxy_service.dart';
@@ -37,6 +36,7 @@ import 'package:test_common/logging.dart';
 import 'package:test_common/test_sdk_configuration.dart';
 import 'package:test_common/utilities.dart';
 import 'package:vm_service/vm_service.dart';
+import 'package:vm_service/vm_service_io.dart';
 import 'package:webdriver/async_io.dart';
 import 'package:webkit_inspection_protocol/webkit_inspection_protocol.dart';
 
@@ -113,6 +113,8 @@ class TestContext {
 
   final _logger = logging.Logger('Context');
 
+  final _serviceNameToMethod = <String, String?>{};
+
   /// Internal VM service.
   ///
   /// Prefer using [vmService] instead in tests when possible, to include testing
@@ -172,26 +174,30 @@ class TestContext {
       final chromeDriverPort = await findUnusedPort();
       final chromeDriverUrlBase = 'wd/hub';
       try {
-        _chromeDriver = await Process.start(
-          'chromedriver$_exeExt',
-          ['--port=$chromeDriverPort', '--url-base=$chromeDriverUrlBase'],
-        );
+        _chromeDriver = await Process.start('chromedriver$_exeExt', [
+          '--port=$chromeDriverPort',
+          '--url-base=$chromeDriverUrlBase',
+        ]);
         // On windows this takes a while to boot up, wait for the first line
         // of stdout as a signal that it is ready.
-        final stdOutLines = chromeDriver.stdout
-            .transform(utf8.decoder)
-            .transform(const LineSplitter())
-            .asBroadcastStream();
+        final stdOutLines =
+            chromeDriver.stdout
+                .transform(utf8.decoder)
+                .transform(const LineSplitter())
+                .asBroadcastStream();
 
-        final stdErrLines = chromeDriver.stderr
-            .transform(utf8.decoder)
-            .transform(const LineSplitter())
-            .asBroadcastStream();
+        final stdErrLines =
+            chromeDriver.stderr
+                .transform(utf8.decoder)
+                .transform(const LineSplitter())
+                .asBroadcastStream();
 
-        stdOutLines
-            .listen((line) => _logger.finest('ChromeDriver stdout: $line'));
-        stdErrLines
-            .listen((line) => _logger.warning('ChromeDriver stderr: $line'));
+        stdOutLines.listen(
+          (line) => _logger.finest('ChromeDriver stdout: $line'),
+        );
+        stdErrLines.listen(
+          (line) => _logger.warning('ChromeDriver stderr: $line'),
+        );
 
         await stdOutLines.first;
       } catch (e) {
@@ -200,18 +206,17 @@ class TestContext {
         );
       }
 
-      await Process.run(
-        sdkLayout.dartPath,
-        ['pub', 'upgrade'],
-        workingDirectory: project.absolutePackageDirectory,
-      );
+      await Process.run(sdkLayout.dartPath, [
+        'pub',
+        'upgrade',
+      ], workingDirectory: project.absolutePackageDirectory);
 
       ExpressionCompiler? expressionCompiler;
       AssetReader assetReader;
       Stream<BuildResults> buildResults;
       LoadStrategy loadStrategy;
-      String basePath = '';
-      String filePathToServe = project.filePathToServe;
+      var basePath = '';
+      var filePathToServe = project.filePathToServe;
 
       _port = await findUnusedPort();
       switch (testSettings.compilationMode) {
@@ -233,18 +238,21 @@ class TestContext {
               '--verbose',
             ];
             _daemonClient = await connectClient(
-                sdkLayout.dartPath, project.absolutePackageDirectory, options,
-                (log) {
-              final record = log.toLogRecord();
-              final name =
-                  record.loggerName == '' ? '' : '${record.loggerName}: ';
-              _logger.log(
-                record.level,
-                '$name${record.message}',
-                record.error,
-                record.stackTrace,
-              );
-            });
+              sdkLayout.dartPath,
+              project.absolutePackageDirectory,
+              options,
+              (log) {
+                final record = log.toLogRecord();
+                final name =
+                    record.loggerName == '' ? '' : '${record.loggerName}: ';
+                _logger.log(
+                  record.level,
+                  '$name${record.message}',
+                  record.error,
+                  record.stackTrace,
+                );
+              },
+            );
             daemonClient.registerBuildTarget(
               DefaultBuildTarget((b) => b..target = project.directoryToServe),
             );
@@ -252,8 +260,9 @@ class TestContext {
 
             await waitForSuccessfulBuild();
 
-            final assetServerPort =
-                daemonPort(project.absolutePackageDirectory);
+            final assetServerPort = daemonPort(
+              project.absolutePackageDirectory,
+            );
             _assetHandler = proxyHandler(
               'http://localhost:$assetServerPort/${project.directoryToServe}/',
               client: client,
@@ -273,12 +282,13 @@ class TestContext {
               expressionCompiler = ddcService;
             }
 
-            loadStrategy = BuildRunnerRequireStrategyProvider(
-              assetHandler,
-              testSettings.reloadConfiguration,
-              assetReader,
-              buildSettings,
-            ).strategy;
+            loadStrategy =
+                BuildRunnerRequireStrategyProvider(
+                  assetHandler,
+                  testSettings.reloadConfiguration,
+                  assetReader,
+                  buildSettings,
+                ).strategy;
 
             buildResults = daemonClient.buildResults;
           }
@@ -303,7 +313,6 @@ class TestContext {
             );
 
             final compilerOptions = TestCompilerOptions(
-              nullSafety: project.nullSafety,
               experiments: buildSettings.experiments,
               canaryFeatures: buildSettings.canaryFeatures,
               moduleFormat: testSettings.moduleFormat,
@@ -339,56 +348,67 @@ class TestContext {
             assetReader = webRunner.devFS.assetServer;
             _assetHandler = webRunner.devFS.assetServer.handleRequest;
             loadStrategy = switch (testSettings.moduleFormat) {
-              ModuleFormat.amd => FrontendServerRequireStrategyProvider(
+              ModuleFormat.amd =>
+                FrontendServerRequireStrategyProvider(
                   testSettings.reloadConfiguration,
                   assetReader,
                   packageUriMapper,
                   () async => {},
                   buildSettings,
                 ).strategy,
-              ModuleFormat.ddc => FrontendServerDdcStrategyProvider(
-                  testSettings.reloadConfiguration,
-                  assetReader,
-                  packageUriMapper,
-                  () async => {},
-                  buildSettings,
-                ).strategy,
-              _ => throw Exception(
+              ModuleFormat.ddc =>
+                buildSettings.canaryFeatures
+                    ? FrontendServerDdcLibraryBundleStrategyProvider(
+                      testSettings.reloadConfiguration,
+                      assetReader,
+                      packageUriMapper,
+                      () async => {},
+                      buildSettings,
+                    ).strategy
+                    : FrontendServerDdcStrategyProvider(
+                      testSettings.reloadConfiguration,
+                      assetReader,
+                      packageUriMapper,
+                      () async => {},
+                      buildSettings,
+                    ).strategy,
+              _ =>
+                throw Exception(
                   'Unsupported DDC module format ${testSettings.moduleFormat.name}.',
-                )
+                ),
             };
             buildResults = const Stream<BuildResults>.empty();
           }
           break;
-        default:
-          throw Exception(
-            'Unsupported compilation mode: ${testSettings.compilationMode}',
-          );
       }
 
       final debugPort = await findUnusedPort();
       if (testSettings.launchChrome) {
-        // If the environment variable DWDS_DEBUG_CHROME is set to the string true
-        // then Chrome will be launched with a UI rather than headless.
+        // If the environment variable DWDS_DEBUG_CHROME is set to the string
+        // true then Chrome will be launched with a UI rather than headless.
         // If the extension is enabled, then Chrome will be launched with a UI
         // since headless Chrome does not support extensions.
         final enableDebugExtension = debugSettings.enableDebugExtension;
-        final headless = Platform.environment['DWDS_DEBUG_CHROME'] != 'true' &&
+        final headless =
+            Platform.environment['DWDS_DEBUG_CHROME'] != 'true' &&
             !enableDebugExtension;
         if (enableDebugExtension) {
           await _buildDebugExtension();
         }
-        final capabilities = Capabilities.chrome
-          ..addAll({
-            Capabilities.chromeOptions: {
-              'args': [
-                'remote-debugging-port=$debugPort',
-                if (enableDebugExtension)
-                  '--load-extension=debug_extension/prod_build',
-                if (headless) '--headless',
-              ],
-            },
-          });
+        final capabilities =
+            Capabilities.chrome..addAll({
+              Capabilities.chromeOptions: {
+                'args': [
+                  // --disable-gpu speeds up the tests that use ChromeDriver when
+                  // they are run on GitHub Actions.
+                  '--disable-gpu',
+                  'remote-debugging-port=$debugPort',
+                  if (enableDebugExtension)
+                    '--load-extension=debug_extension/prod_build',
+                  if (headless) '--headless',
+                ],
+              },
+            });
         _webDriver = await createDriver(
           spec: WebDriverSpec.JsonWire,
           desired: capabilities,
@@ -405,8 +425,9 @@ class TestContext {
       final connection = ChromeConnection('localhost', debugPort);
 
       _testServer = await TestServer.start(
-        debugSettings:
-            debugSettings.copyWith(expressionCompiler: expressionCompiler),
+        debugSettings: debugSettings.copyWith(
+          expressionCompiler: expressionCompiler,
+        ),
         appMetadata: appMetadata,
         port: port,
         assetHandler: assetHandler,
@@ -432,9 +453,10 @@ class TestContext {
         }
       });
 
-      _appUrl = basePath.isEmpty
-          ? 'http://localhost:$port/$filePathToServe'
-          : 'http://localhost:$port/$basePath/$filePathToServe';
+      _appUrl =
+          basePath.isEmpty
+              ? 'http://localhost:$port/$filePathToServe'
+              : 'http://localhost:$port/$basePath/$filePathToServe';
 
       if (testSettings.launchChrome) {
         await _webDriver?.get(appUrl);
@@ -442,9 +464,9 @@ class TestContext {
         if (tab != null) {
           _tabConnection = await tab.connect();
           await tabConnection.runtime.enable();
-          await tabConnection.debugger
-              .enable()
-              .then((_) => tabConnectionCompleter.complete());
+          await tabConnection.debugger.enable().then(
+            (_) => tabConnectionCompleter.complete(),
+          );
         } else {
           throw StateError('Unable to connect to tab.');
         }
@@ -470,6 +492,39 @@ class TestContext {
     }
   }
 
+  /// Creates a VM service connection connected to the debug URI.
+  ///
+  /// This can be used to test behavior that should be available to a client
+  /// connected to DWDS.
+  Future<VmService> connectFakeClient() async {
+    final fakeClient = await vmServiceConnectUri(debugConnection.uri);
+
+    fakeClient.onEvent(EventStreams.kService).listen(_handleServiceEvent);
+    await fakeClient.streamListen(EventStreams.kService);
+
+    return fakeClient;
+  }
+
+  /// Returns the service extension method given the [extensionName].
+  ///
+  /// The extension be called by a client created with [connectFakeClient].
+  String? getRegisteredServiceExtension(String extensionName) {
+    if (_serviceNameToMethod.isEmpty) {
+      throw StateError('''
+        No registered service extensions. Did you call connectFakeClient?
+      ''');
+    }
+
+    return _serviceNameToMethod[extensionName];
+  }
+
+  void _handleServiceEvent(Event e) {
+    if (e.kind == EventKind.kServiceRegistered) {
+      final serviceName = e.service!;
+      _serviceNameToMethod[serviceName] = e.method;
+    }
+  }
+
   Future<void> startDebugging() async {
     debugConnection = await testServer.dwds.debugConnection(appConnection);
     _webkitDebugger = WebkitDebugger(WipDebugger(tabConnection));
@@ -524,17 +579,19 @@ class TestContext {
     // Wait for the build until the timeout is reached:
     await daemonClient.buildResults
         .firstWhere(
-          (results) => results.results
-              .any((result) => result.status == BuildStatus.succeeded),
+          (results) => results.results.any(
+            (result) => result.status == BuildStatus.succeeded,
+          ),
         )
         .timeout(timeout ?? const Duration(seconds: 60));
 
     if (propagateToBrowser) {
       // Allow change to propagate to the browser.
       // Windows, or at least Travis on Windows, seems to need more time.
-      final delay = Platform.isWindows
-          ? const Duration(seconds: 5)
-          : const Duration(seconds: 2);
+      final delay =
+          Platform.isWindows
+              ? const Duration(seconds: 5)
+              : const Duration(seconds: 2);
       await Future.delayed(delay);
     }
   }
@@ -554,10 +611,11 @@ class TestContext {
     final extensionTabs = (await connection.getTabs()).where((tab) {
       return tab.isChromeExtension;
     });
-    for (var tab in extensionTabs) {
+    for (final tab in extensionTabs) {
       final tabConnection = await tab.connect();
-      final response =
-          await tabConnection.runtime.evaluate('window.isDartDebugExtension');
+      final response = await tabConnection.runtime.evaluate(
+        'window.isDartDebugExtension',
+      );
       if (response.value == true) {
         return tab;
       }
@@ -576,14 +634,18 @@ class TestContext {
     String isolateId,
     ScriptRef scriptRef,
   ) async {
-    final script = await debugConnection.vmService
-        .getObject(isolateId, scriptRef.id!) as Script;
+    final script =
+        await debugConnection.vmService.getObject(isolateId, scriptRef.id!)
+            as Script;
     final lines = LineSplitter.split(script.source!).toList();
-    final lineNumber =
-        lines.indexWhere((l) => l.endsWith('// Breakpoint: $breakpointId'));
+    final lineNumber = lines.indexWhere(
+      (l) => l.endsWith('// Breakpoint: $breakpointId'),
+    );
     if (lineNumber == -1) {
-      throw StateError('Unable to find breakpoint in ${scriptRef.uri} with id '
-          '$breakpointId');
+      throw StateError(
+        'Unable to find breakpoint in ${scriptRef.uri} with id '
+        '$breakpointId',
+      );
     }
     return lineNumber + 1;
   }
