@@ -22,16 +22,20 @@ class TestInspector {
   ) async {
     Breakpoint? bp;
     try {
-      final line =
-          await context.findBreakpointLine(breakPointId, isolateId, script);
+      final line = await context.findBreakpointLine(
+        breakPointId,
+        isolateId,
+        script,
+      );
       bp = await service.addBreakpointWithScriptUri(
         isolateId,
         script.uri!,
         line,
       );
 
-      final event =
-          await stream.firstWhere((e) => e.kind == EventKind.kPauseBreakpoint);
+      final event = await stream.firstWhere(
+        (e) => e.kind == EventKind.kPauseBreakpoint,
+      );
 
       await body(event);
     } finally {
@@ -64,7 +68,8 @@ class TestInspector {
     expect(
       instance.kind,
       instanceRef.kind,
-      reason: 'object $instanceId with ref kind ${instanceRef.kind} '
+      reason:
+          'object $instanceId with ref kind ${instanceRef.kind} '
           'has an instance kind ${instance.kind}',
     );
 
@@ -91,13 +96,10 @@ class TestInspector {
     }
 
     final fieldValues = <dynamic, Object?>{};
-    for (var p in fieldRefs.entries) {
-      fieldValues[p.key] = _getValue(p.value) ??
-          await getFields(
-            isolateId,
-            p.value,
-            depth: depth,
-          );
+    for (final p in fieldRefs.entries) {
+      fieldValues[p.key] =
+          _getValue(p.value) ??
+          await getFields(isolateId, p.value, depth: depth);
     }
     return fieldValues;
   }
@@ -112,7 +114,7 @@ class TestInspector {
         cls.functions?.where((f) => f.isGetter ?? false).toList() ?? [];
 
     final results = await Future.wait([
-      for (var getter in getters)
+      for (final getter in getters)
         service.evaluate(isolateId, instanceRef.id!, getter.name!),
     ]);
 
@@ -127,11 +129,7 @@ class TestInspector {
     int frame,
     String expression,
   ) async {
-    final result = await service.evaluateInFrame(
-      isolateId,
-      frame,
-      expression,
-    );
+    final result = await service.evaluateInFrame(isolateId, frame, expression);
     expect(result, isA<InstanceRef>());
     return result as InstanceRef;
   }
@@ -141,17 +139,10 @@ class TestInspector {
     int frame,
     String expression,
   ) async {
-    final instanceRef = await getInstanceRef(
-      isolateId,
-      frame,
-      expression,
-    );
+    final instanceRef = await getInstanceRef(isolateId, frame, expression);
 
     expect(instanceRef.id, isNotNull);
-    final result = await service.getObject(
-      isolateId,
-      instanceRef.id!,
-    );
+    final result = await service.getObject(isolateId, instanceRef.id!);
 
     expect(result, isA<Instance>());
     return result as Instance;
@@ -162,7 +153,7 @@ class TestInspector {
     Frame frame,
   ) async {
     final refs = <String, InstanceRef>{
-      for (var variable in frame.vars!)
+      for (final variable in frame.vars!)
         variable.name!: variable.value as InstanceRef,
     };
     final instances = <String, Instance>{};
@@ -217,10 +208,9 @@ class TestInspector {
     final instance = await service.getObject(isolateId, instanceId) as Instance;
     return Future.wait(
       instance.fields!.map(
-        (e) async => await service.getObject(
-          isolateId,
-          (e.value as InstanceRef).id!,
-        ) as Instance,
+        (e) async =>
+            await service.getObject(isolateId, (e.value as InstanceRef).id!)
+                as Instance,
       ),
     );
   }
@@ -228,10 +218,9 @@ class TestInspector {
 
 Map<String, InstanceRef> _associationsToMap(
   Iterable<MapAssociation> associations,
-) =>
-    Map.fromEntries(
-      associations.map((e) => MapEntry(e.key.valueAsString, e.value)),
-    );
+) => Map.fromEntries(
+  associations.map((e) => MapEntry(e.key.valueAsString, e.value)),
+);
 
 Map<dynamic, InstanceRef> _boundFieldsToMap(Iterable<BoundField> fields) =>
     Map.fromEntries(
@@ -251,11 +240,7 @@ Matcher matchRecordInstanceRef({required int length}) => isA<InstanceRef>()
     .having((e) => e.classRef!, 'classRef', matchRecordClassRef);
 
 Matcher matchRecordTypeInstanceRef({required int length}) => isA<InstanceRef>()
-    .having(
-      (e) => e.kind,
-      'kind',
-      InstanceKind.kRecordType,
-    )
+    .having((e) => e.kind, 'kind', InstanceKind.kRecordType)
     .having((e) => e.length, 'length', length)
     .having((e) => e.classRef!, 'classRef', matchRecordTypeClassRef);
 
@@ -264,18 +249,15 @@ Matcher matchTypeInstanceRef(dynamic name) => isA<InstanceRef>()
     .having((e) => e.name, 'type ref name', name)
     .having((e) => e.classRef, 'classRef', matchTypeClassRef);
 
-Matcher matchPrimitiveInstanceRef({
-  required String kind,
-}) =>
+Matcher matchPrimitiveInstanceRef({required String kind}) =>
     isA<InstanceRef>().having((e) => e.kind, 'kind', kind);
 
 Matcher matchPrimitiveInstance({
   required String kind,
   required dynamic value,
-}) =>
-    isA<Instance>()
-        .having((e) => e.kind, 'kind', kind)
-        .having(_getValue, 'value', value);
+}) => isA<Instance>()
+    .having((e) => e.kind, 'kind', kind)
+    .having(_getValue, 'value', value);
 
 Matcher matchPlainInstance({required libraryId, required String type}) =>
     isA<Instance>()
@@ -316,10 +298,14 @@ Matcher matchTypeInstance(dynamic name) => isA<Instance>()
     .having((e) => e.name, 'type name', name)
     .having((e) => e.classRef, 'classRef', matchTypeClassRef);
 
-Matcher matchRecordClass =
-    matchClass(name: matchRecordClassName, libraryId: _dartCoreLibrary);
-Matcher matchTypeClass =
-    matchClass(name: matchTypeClassName, libraryId: _dartCoreLibrary);
+Matcher matchRecordClass = matchClass(
+  name: matchRecordClassName,
+  libraryId: _dartCoreLibrary,
+);
+Matcher matchTypeClass = matchClass(
+  name: matchTypeClassName,
+  libraryId: _dartCoreLibrary,
+);
 
 /// TODO(annagrin): record type class is reported incorrectly
 /// in ddc https://github.com/dart-lang/sdk/issues/54609,
@@ -333,8 +319,10 @@ Matcher matchClass({dynamic name, String? libraryId}) => isA<Class>()
     .having((e) => e.name, 'class name', name)
     .having((e) => e.library, 'library', matchLibraryRef(libraryId));
 
-Matcher matchRecordClassRef =
-    matchClassRef(name: matchRecordClassName, libraryId: _dartCoreLibrary);
+Matcher matchRecordClassRef = matchClassRef(
+  name: matchRecordClassName,
+  libraryId: _dartCoreLibrary,
+);
 
 /// TODO(annagrin): record type class is reported incorrectly
 /// in ddc https://github.com/dart-lang/sdk/issues/54609,
@@ -348,13 +336,13 @@ Matcher matchTypeClassRef = matchClassRef(
   libraryId: _dartCoreLibrary,
 );
 Matcher matchListClassRef(String type) => matchClassRef(
-      name: matchListClassName(type),
-      libraryId: _matchListLibraryName,
-    );
+  name: matchListClassName(type),
+  libraryId: _matchListLibraryName,
+);
 Matcher matchMapClassRef(String type) =>
     matchClassRef(name: type, libraryId: _dartJsHelperLibrary);
 Matcher matchSetClassRef(String type) =>
-    matchClassRef(name: type, libraryId: _dartCollectionLibrary);
+    matchClassRef(name: type, libraryId: _dartJsHelperLibrary);
 
 Matcher matchClassRef({dynamic name, dynamic libraryId}) => isA<ClassRef>()
     .having((e) => e.name, 'class ref name', name)
@@ -382,7 +370,6 @@ Object? _getValue(InstanceRef instanceRef) {
 final _dartCoreLibrary = 'dart:core';
 final _dartInterceptorsLibrary = 'dart:_interceptors';
 final _dartJsHelperLibrary = 'dart:_js_helper';
-final _dartCollectionLibrary = 'dart:collection';
 final _dartRuntimeLibrary = 'dart:_runtime';
 
 final matchRecordClassName = 'Record';
@@ -403,5 +390,7 @@ final matchRecordTypeClassName = 'RecordType';
 Matcher matchListClassName(String elementType) =>
     anyOf(['JSArray<$elementType>', 'List<$elementType>']);
 
-final _matchListLibraryName =
-    anyOf([_dartInterceptorsLibrary, _dartCoreLibrary]);
+final _matchListLibraryName = anyOf([
+  _dartInterceptorsLibrary,
+  _dartCoreLibrary,
+]);
