@@ -24,6 +24,12 @@ typedef struct {
 -(Vec4)twiddleVec4Components:(Vec4)v;
 -(float)addFloats:(float)x Y:(float) y;
 -(double)addDoubles:(double)x Y:(double) y;
+-(Vec4)Vec4;
+
+// An instance method and a static method with the same name.
+// https://github.com/dart-lang/native/issues/1136
+- (int32_t)instStaticSameName;
++ (int32_t)instStaticSameName;
 
 @end
 
@@ -78,4 +84,21 @@ typedef struct {
     return x + y;
 }
 
+-(Vec4)Vec4 {
+    Vec4 u;
+    u.x = 1;
+    u.y = 2;
+    u.z = 3;
+    u.w = 4;
+    return u;
+}
+
+- (int32_t)instStaticSameName {
+  return 123;
+}
+
++ (int32_t)instStaticSameName {
+  return 456;
+}
+
 @end
