@@ -3,6 +3,7 @@
 // BSD-style license that can be found in the LICENSE file.
 
 @Timeout(Duration(minutes: 2))
+library;
 
 import 'package:dwds/src/debugging/location.dart';
 import 'package:dwds/src/debugging/skip_list.dart';
@@ -92,7 +93,7 @@ void main() {
     test('contains the provided id', () {
       final id = '123';
       final skipList = skipLists.compute(id, {});
-      for (var range in skipList) {
+      for (final range in skipList) {
         expect(range['scriptId'], id);
       }
     });
