@@ -17,7 +17,7 @@ main() {
 class AugmentedInvocationResolutionTest extends PubPackageResolutionTest {
   test_class_constructor_named() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {
   A.named(int a);
@@ -25,7 +25,7 @@ class A {
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment class A {
   augment A.named(int a) {
@@ -43,17 +43,18 @@ AugmentedInvocation
     arguments
       IntegerLiteral
         literal: 0
-        parameter: self::@class::A::@constructor::named::@parameter::a
+        parameter: package:test/a.dart::<fragment>::@class::A::@constructor::named::@parameter::a
         staticType: int
     rightParenthesis: )
-  element: self::@class::A::@constructor::named
+  element: package:test/a.dart::<fragment>::@class::A::@constructor::named
+  element2: package:test/a.dart::<fragment>::@class::A::@constructor::named#element
   staticType: A
 ''');
   }
 
   test_class_constructor_unnamed() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {
   A(int a);
@@ -61,7 +62,7 @@ class A {
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment class A {
   augment A(int a) {
@@ -79,17 +80,18 @@ AugmentedInvocation
     arguments
       IntegerLiteral
         literal: 0
-        parameter: self::@class::A::@constructor::new::@parameter::a
+        parameter: package:test/a.dart::<fragment>::@class::A::@constructor::new::@parameter::a
         staticType: int
     rightParenthesis: )
-  element: self::@class::A::@constructor::new
+  element: package:test/a.dart::<fragment>::@class::A::@constructor::new
+  element2: package:test/a.dart::<fragment>::@class::A::@constructor::new#element
   staticType: A
 ''');
   }
 
   test_class_getter_functionTyped() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {
   int Function(int a) get foo => throw 0;
@@ -97,7 +99,7 @@ class A {
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment class A {
   augment int Function(int a) get foo {
@@ -113,7 +115,8 @@ ExpressionStatement
   expression: FunctionExpressionInvocation
     function: AugmentedExpression
       augmentedKeyword: augmented
-      element: self::@class::A::@getter::foo
+      element: package:test/a.dart::<fragment>::@class::A::@getter::foo
+      fragment: package:test/a.dart::<fragment>::@class::A::@getter::foo
       staticType: int Function(int)
     argumentList: ArgumentList
       leftParenthesis: (
@@ -124,6 +127,7 @@ ExpressionStatement
           staticType: int
       rightParenthesis: )
     staticElement: <null>
+    element: <null>
     staticInvokeType: int Function(int)
     staticType: int
   semicolon: ;
@@ -132,7 +136,7 @@ ExpressionStatement
 
   test_class_method() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {
   void foo(int a) {}
@@ -140,7 +144,7 @@ class A {
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment class A {
   augment void foo(int a) {
@@ -158,23 +162,24 @@ AugmentedInvocation
     arguments
       IntegerLiteral
         literal: 0
-        parameter: self::@class::A::@method::foo::@parameter::a
+        parameter: package:test/a.dart::<fragment>::@class::A::@method::foo::@parameter::a
         staticType: int
     rightParenthesis: )
-  element: self::@class::A::@method::foo
+  element: package:test/a.dart::<fragment>::@class::A::@method::foo
+  element2: package:test/a.dart::<fragment>::@class::A::@method::foo#element
   staticType: void
 ''');
   }
 
   test_topLevel_function() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 void foo(int a) {}
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo(int a) {
   augmented(0);
@@ -190,29 +195,30 @@ AugmentedInvocation
     arguments
       IntegerLiteral
         literal: 0
-        parameter: self::@function::foo::@parameter::a
+        parameter: package:test/a.dart::<fragment>::@function::foo::@parameter::a
         staticType: int
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: void
 ''');
   }
 
   test_topLevel_function_augments_class() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class foo {}
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo() {
   augmented(0);
 }
 ''', [
-      error(CompileTimeErrorCode.AUGMENTATION_OF_DIFFERENT_DECLARATION_KIND, 27,
+      error(CompileTimeErrorCode.AUGMENTATION_OF_DIFFERENT_DECLARATION_KIND, 19,
           7),
     ]);
 
@@ -229,19 +235,20 @@ AugmentedInvocation
         staticType: int
     rightParenthesis: )
   element: <null>
+  element2: <null>
   staticType: InvalidType
 ''');
   }
 
   test_topLevel_function_generic_fromArgument() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T>(T a) => a;
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo<T2>(T2 a) {
   augmented(0);
@@ -258,31 +265,30 @@ AugmentedInvocation
       IntegerLiteral
         literal: 0
         parameter: ParameterMember
-          base: self::@function::foo::@parameter::a
+          base: package:test/a.dart::<fragment>::@function::foo::@parameter::a
           substitution: {T: int}
         staticType: int
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: int
 ''');
   }
 
   test_topLevel_function_generic_fromArguments_couldNotInfer() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T extends num>(T a) => throw 0;
 ''');
 
-    await assertErrorsInCode('''
-augment library 'a.dart';
+    await assertNoErrorsInCode('''
+part of 'a.dart';
 
 augment void foo<T2 extends num>(T2 a) {
   augmented('');
 }
-''', [
-      error(CompileTimeErrorCode.COULD_NOT_INFER, 70, 9),
-    ]);
+''');
 
     var node = findNode.singleAugmentedInvocation;
     assertResolvedNodeText(node, r'''
@@ -294,20 +300,21 @@ AugmentedInvocation
       SimpleStringLiteral
         literal: ''
     rightParenthesis: )
-  element: self::@function::foo
-  staticType: String
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
+  staticType: num
 ''');
   }
 
   test_topLevel_function_generic_fromClosure() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 U foo<T, U>(T t, U Function(T) f) => throw 0;
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment U2 foo<T2, U2>(T2 t, U2 Function(T2) f) {
   augmented(0, (_) => '');
@@ -325,7 +332,7 @@ AugmentedInvocation
       IntegerLiteral
         literal: 0
         parameter: ParameterMember
-          base: self::@function::foo::@parameter::t
+          base: package:test/a.dart::<fragment>::@function::foo::@parameter::t
           substitution: {T: int, U: String}
         staticType: int
       FunctionExpression
@@ -333,40 +340,41 @@ AugmentedInvocation
           leftParenthesis: (
           parameter: SimpleFormalParameter
             name: _
-            declaredElement: @92::@parameter::_
+            declaredElement: @84::@parameter::_
               type: int
           rightParenthesis: )
         body: ExpressionFunctionBody
           functionDefinition: =>
           expression: SimpleStringLiteral
             literal: ''
-        declaredElement: @92
+        declaredElement: @84
           type: String Function(int)
         parameter: ParameterMember
-          base: self::@function::foo::@parameter::f
+          base: package:test/a.dart::<fragment>::@function::foo::@parameter::f
           substitution: {T: int, U: String}
         staticType: String Function(int)
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: String
 ''');
   }
 
   test_topLevel_function_generic_fromContextType() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T>() => throw 0;
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo<T2>() {
   int a = augmented();
 }
 ''', [
-      error(WarningCode.UNUSED_LOCAL_VARIABLE, 58, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 50, 1),
     ]);
 
     var node = findNode.singleAugmentedInvocation;
@@ -376,20 +384,21 @@ AugmentedInvocation
   arguments: ArgumentList
     leftParenthesis: (
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: int
 ''');
   }
 
   test_topLevel_function_generic_typeArguments() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T>() => throw 0;
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo<T2>() {
   augmented<int>();
@@ -405,32 +414,34 @@ AugmentedInvocation
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
     rightBracket: >
   arguments: ArgumentList
     leftParenthesis: (
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: int
 ''');
   }
 
   test_topLevel_function_generic_typeArguments_notMatchingBounds() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T extends num>() => throw 0;
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo<T2 extends num>() {
   augmented<String>();
 }
 ''', [
-      error(CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS, 76, 6),
+      error(CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS, 68, 6),
     ]);
 
     var node = findNode.singleAugmentedInvocation;
@@ -442,32 +453,34 @@ AugmentedInvocation
     arguments
       NamedType
         name: String
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String
     rightBracket: >
   arguments: ArgumentList
     leftParenthesis: (
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: String
 ''');
   }
 
   test_topLevel_function_generic_typeArguments_wrongNumber() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 T foo<T>() => throw 0;
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment void foo<T2>() {
   augmented<int, String>();
 }
 ''', [
-      error(CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS, 63, 13),
+      error(CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS, 55, 13),
     ]);
 
     var node = findNode.singleAugmentedInvocation;
@@ -479,30 +492,33 @@ AugmentedInvocation
     arguments
       NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       NamedType
         name: String
-        element: dart:core::@class::String
+        element: dart:core::<fragment>::@class::String
+        element2: dart:core::@class::String
         type: String
     rightBracket: >
   arguments: ArgumentList
     leftParenthesis: (
     rightParenthesis: )
-  element: self::@function::foo
+  element: package:test/a.dart::<fragment>::@function::foo
+  element2: package:test/a.dart::@function::foo
   staticType: dynamic
 ''');
   }
 
   test_topLevel_getter_functionTyped() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 int Function(int a) get foo => throw 0;
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment int Function(int a) get foo {
   augmented(42);
@@ -516,7 +532,8 @@ ExpressionStatement
   expression: FunctionExpressionInvocation
     function: AugmentedExpression
       augmentedKeyword: augmented
-      element: self::@getter::foo
+      element: package:test/a.dart::<fragment>::@getter::foo
+      fragment: package:test/a.dart::<fragment>::@getter::foo
       staticType: int Function(int)
     argumentList: ArgumentList
       leftParenthesis: (
@@ -527,6 +544,7 @@ ExpressionStatement
           staticType: int
       rightParenthesis: )
     staticElement: <null>
+    element: <null>
     staticInvokeType: int Function(int)
     staticType: int
   semicolon: ;
@@ -535,20 +553,20 @@ ExpressionStatement
 
   test_topLevel_getter_notFunctionTyped() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 int get foo => 0;
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment int get foo {
   augmented();
   return 0;
 }
 ''', [
-      error(CompileTimeErrorCode.INVOCATION_OF_NON_FUNCTION_EXPRESSION, 51, 9),
+      error(CompileTimeErrorCode.INVOCATION_OF_NON_FUNCTION_EXPRESSION, 43, 9),
     ]);
 
     var node = findNode.expressionStatement('augmented(');
@@ -559,7 +577,8 @@ ExpressionStatement
     arguments: ArgumentList
       leftParenthesis: (
       rightParenthesis: )
-    element: self::@getter::foo
+    element: package:test/a.dart::<fragment>::@getter::foo
+    element2: package:test/a.dart::<fragment>::@getter::foo#element
     staticType: InvalidType
   semicolon: ;
 ''');
@@ -567,7 +586,7 @@ ExpressionStatement
 
   test_topLevel_getter_notFunctionTyped_implicitCall() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {
   int call() => 0;
@@ -577,7 +596,7 @@ A get foo => A();
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment A get foo {
   augmented();
@@ -591,12 +610,14 @@ ExpressionStatement
   expression: FunctionExpressionInvocation
     function: AugmentedExpression
       augmentedKeyword: augmented
-      element: self::@getter::foo
+      element: package:test/a.dart::<fragment>::@getter::foo
+      fragment: package:test/a.dart::<fragment>::@getter::foo
       staticType: int Function()
     argumentList: ArgumentList
       leftParenthesis: (
       rightParenthesis: )
-    staticElement: self::@class::A::@method::call
+    staticElement: package:test/a.dart::<fragment>::@class::A::@method::call
+    element: package:test/a.dart::<fragment>::@class::A::@method::call#element
     staticInvokeType: int Function()
     staticType: int
   semicolon: ;
@@ -605,7 +626,7 @@ ExpressionStatement
 
   test_topLevel_getter_notFunctionTyped_implicitCall_fromExtension() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 class A {}
 
@@ -617,7 +638,7 @@ A get foo => A();
 ''');
 
     await assertNoErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment A get foo {
   augmented();
@@ -631,12 +652,14 @@ ExpressionStatement
   expression: FunctionExpressionInvocation
     function: AugmentedExpression
       augmentedKeyword: augmented
-      element: self::@getter::foo
+      element: package:test/a.dart::<fragment>::@getter::foo
+      fragment: package:test/a.dart::<fragment>::@getter::foo
       staticType: int Function()
     argumentList: ArgumentList
       leftParenthesis: (
       rightParenthesis: )
-    staticElement: self::@extension::E::@method::call
+    staticElement: package:test/a.dart::<fragment>::@extension::E::@method::call
+    element: package:test/a.dart::<fragment>::@extension::E::@method::call#element
     staticInvokeType: int Function()
     staticType: int
   semicolon: ;
@@ -645,13 +668,13 @@ ExpressionStatement
 
   test_topLevel_getter_notFunctionTyped_variableClosure() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 int get foo => 0;
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment int get foo {
   var v = () {
@@ -660,8 +683,8 @@ augment int get foo {
   return 0;
 }
 ''', [
-      error(WarningCode.UNUSED_LOCAL_VARIABLE, 55, 1),
-      error(CompileTimeErrorCode.INVOCATION_OF_NON_FUNCTION_EXPRESSION, 68, 9),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 47, 1),
+      error(CompileTimeErrorCode.INVOCATION_OF_NON_FUNCTION_EXPRESSION, 60, 9),
     ]);
 
     var node = findNode.expressionStatement('augmented(');
@@ -672,7 +695,8 @@ ExpressionStatement
     arguments: ArgumentList
       leftParenthesis: (
       rightParenthesis: )
-    element: self::@getter::foo
+    element: package:test/a.dart::<fragment>::@getter::foo
+    element2: package:test/a.dart::<fragment>::@getter::foo#element
     staticType: InvalidType
   semicolon: ;
 ''');
@@ -680,19 +704,19 @@ ExpressionStatement
 
   test_topLevel_setter() async {
     newFile('$testPackageLibPath/a.dart', r'''
-import augment 'test.dart';
+part 'test.dart';
 
 set foo(int _) {}
 ''');
 
     await assertErrorsInCode('''
-augment library 'a.dart';
+part of 'a.dart';
 
 augment set foo(int _) {
   augmented(0, 1);
 }
 ''', [
-      error(CompileTimeErrorCode.AUGMENTED_EXPRESSION_IS_SETTER, 54, 9),
+      error(CompileTimeErrorCode.AUGMENTED_EXPRESSION_IS_SETTER, 46, 9),
     ]);
 
     var node = findNode.expressionStatement('augmented(');
@@ -712,7 +736,8 @@ ExpressionStatement
           parameter: <null>
           staticType: int
       rightParenthesis: )
-    element: self::@setter::foo
+    element: package:test/a.dart::<fragment>::@setter::foo
+    element2: package:test/a.dart::<fragment>::@setter::foo#element
     staticType: InvalidType
   semicolon: ;
 ''');
