@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// ignore_for_file: analyzer_use_new_elements
+
 import 'package:analyzer/src/dart/constant/value.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/error/codes.dart';
@@ -67,6 +69,48 @@ main() {}
     expect(value.getField('(super)')!.getField('f')!.toIntValue(), 42);
   }
 
+  test_constList_withNullAwareElement() async {
+    await assertErrorsInCode(r'''
+class A {
+  const A();
+  foo() {
+    return const [?A()];
+  }
+}
+''', [
+      error(StaticWarningCode.INVALID_NULL_AWARE_ELEMENT, 51, 1),
+    ]);
+    assertType(findNode.listLiteral('const ['), 'List<A>');
+  }
+
+  test_constMap_withNullAwareKey() async {
+    await assertErrorsInCode(r'''
+class A {
+  const A();
+  foo() {
+    return const {?A(): 0};
+  }
+}
+''', [
+      error(StaticWarningCode.INVALID_NULL_AWARE_MAP_ENTRY_KEY, 51, 1),
+    ]);
+    assertType(findNode.setOrMapLiteral('const {'), 'Map<A, int>');
+  }
+
+  test_constMap_withNullAwareValue() async {
+    await assertErrorsInCode(r'''
+class A {
+  const A();
+  foo() {
+    return const {0: ?A()};
+  }
+}
+''', [
+      error(StaticWarningCode.INVALID_NULL_AWARE_MAP_ENTRY_VALUE, 54, 1),
+    ]);
+    assertType(findNode.setOrMapLiteral('const {'), 'Map<int, A>');
+  }
+
   test_constNotInitialized() async {
     await assertErrorsInCode(r'''
 class B {
@@ -82,6 +126,20 @@ class C extends B {
     ]);
   }
 
+  test_constSet_withNullAwareElement() async {
+    await assertErrorsInCode(r'''
+class A {
+  const A();
+  foo() {
+    return const {?A()};
+  }
+}
+''', [
+      error(StaticWarningCode.INVALID_NULL_AWARE_ELEMENT, 51, 1),
+    ]);
+    assertType(findNode.setOrMapLiteral('const {'), 'Set<A>');
+  }
+
   test_context_eliminateTypeVariables() async {
     await assertNoErrorsInCode(r'''
 class A<T> {
@@ -127,10 +185,10 @@ const v = a;
 C<double Function(int)>
   typeArguments
     double Function(int)
-      alias: package:test/a.dart::@typeAlias::F
+      alias: package:test/a.dart::<fragment>::@typeAlias::F
         typeArguments
           double
-  variable: self::@variable::v
+  variable: <testLibraryFragment>::@topLevelVariable::v
 ''');
   }
 
