@@ -30,15 +30,38 @@ ImplementsClause
   interfaces
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
 ''');
   }
 
+  test_class_implements_2times_augmentation() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part 'b.dart';
+
+class A {}
+class B implements A {}
+''');
+
+    var b = newFile('$testPackageLibPath/b.dart', r'''
+part of 'a.dart';
+
+augment class B implements A {}
+''');
+
+    await assertErrorsInFile2(a, []);
+
+    await assertErrorsInFile2(b, [
+      error(CompileTimeErrorCode.IMPLEMENTS_REPEATED, 46, 1),
+    ]);
+  }
+
   test_class_implements_2times_viaTypeAlias() async {
     await assertErrorsInCode(r'''
 class A {}
@@ -55,13 +78,15 @@ ImplementsClause
   interfaces
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
     NamedType
       name: B
-      element: self::@typeAlias::B
+      element: <testLibraryFragment>::@typeAlias::B
+      element2: <testLibrary>::@typeAlias::B
       type: A
-        alias: self::@typeAlias::B
+        alias: <testLibraryFragment>::@typeAlias::B
 ''');
   }
 
@@ -93,15 +118,38 @@ ImplementsClause
   interfaces
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
 ''');
   }
 
+  test_enum_implements_2times_augmentation() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part 'b.dart';
+
+class A {}
+enum E implements A {v}
+''');
+
+    var b = newFile('$testPackageLibPath/b.dart', r'''
+part of 'a.dart';
+
+augment enum E implements A {}
+''');
+
+    await assertErrorsInFile2(a, []);
+
+    await assertErrorsInFile2(b, [
+      error(CompileTimeErrorCode.IMPLEMENTS_REPEATED, 45, 1),
+    ]);
+  }
+
   test_enum_implements_2times_viaTypeAlias() async {
     await assertErrorsInCode(r'''
 class A {}
@@ -120,13 +168,15 @@ ImplementsClause
   interfaces
     NamedType
       name: A
-      element: self::@class::A
+      element: <testLibraryFragment>::@class::A
+      element2: <testLibrary>::@class::A
       type: A
     NamedType
       name: B
-      element: self::@typeAlias::B
+      element: <testLibraryFragment>::@typeAlias::B
+      element2: <testLibrary>::@typeAlias::B
       type: A
-        alias: self::@typeAlias::B
+        alias: <testLibraryFragment>::@typeAlias::B
 ''');
   }
 
@@ -157,15 +207,37 @@ ImplementsClause
   interfaces
     NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
     NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
 ''');
   }
 
+  test_extensionType_implements_2times_augmentation() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part 'b.dart';
+
+extension type A(int it) implements int {}
+''');
+
+    var b = newFile('$testPackageLibPath/b.dart', r'''
+part of 'a.dart';
+
+augment extension type A(int it) implements int {}
+''');
+
+    await assertErrorsInFile2(a, []);
+
+    await assertErrorsInFile2(b, [
+      error(CompileTimeErrorCode.IMPLEMENTS_REPEATED, 63, 3),
+    ]);
+  }
+
   test_extensionType_implements_2times_viaTypeAlias() async {
     await assertErrorsInCode(r'''
 typedef A = int;
@@ -181,13 +253,15 @@ ImplementsClause
   interfaces
     NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
     NamedType
       name: A
-      element: self::@typeAlias::A
+      element: <testLibraryFragment>::@typeAlias::A
+      element2: <testLibrary>::@typeAlias::A
       type: int
-        alias: self::@typeAlias::A
+        alias: <testLibraryFragment>::@typeAlias::A
 ''');
   }
 
@@ -210,6 +284,27 @@ mixin M implements A, A {}
     ]);
   }
 
+  test_mixin_implements_2times_augmentation() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part 'b.dart';
+
+class A {}
+mixin M implements A {}
+''');
+
+    var b = newFile('$testPackageLibPath/b.dart', r'''
+part of 'a.dart';
+
+augment mixin M implements A {}
+''');
+
+    await assertErrorsInFile2(a, []);
+
+    await assertErrorsInFile2(b, [
+      error(CompileTimeErrorCode.IMPLEMENTS_REPEATED, 46, 1),
+    ]);
+  }
+
   test_mixin_implements_4times() async {
     await assertErrorsInCode(r'''
 class A {}
