@@ -31,6 +31,14 @@ class A {
 ''');
   }
 
+  test_extensionType() async {
+    await assertNoErrorsInCode(r'''
+import 'package:meta/meta.dart';
+@immutable
+extension type E(int i) {}
+''');
+  }
+
   test_method() async {
     await assertErrorsInCode(r'''
 import 'package:meta/meta.dart';
@@ -39,7 +47,7 @@ class A {
   void m() {}
 }
 ''', [
-      error(WarningCode.INVALID_IMMUTABLE_ANNOTATION, 45, 10),
+      error(WarningCode.INVALID_ANNOTATION_TARGET, 46, 9),
     ]);
   }
 }
