@@ -23,11 +23,11 @@ void f(int x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 35, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 61, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 35, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 61, 1),
     ]);
 
-    final node1 = findNode.caseClause('case final a').guardedPattern;
+    var node1 = findNode.caseClause('case final a').guardedPattern;
     assertResolvedNodeText(node1, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -38,7 +38,7 @@ GuardedPattern
     matchedValueType: int
 ''');
 
-    final node2 = findNode.caseClause('case final b').guardedPattern;
+    var node2 = findNode.caseClause('case final b').guardedPattern;
     assertResolvedNodeText(node2, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -57,11 +57,11 @@ void f(int x) {
   if (x case final b) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 35, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 60, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 35, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 60, 1),
     ]);
 
-    final node1 = findNode.caseClause('case final a').guardedPattern;
+    var node1 = findNode.caseClause('case final a').guardedPattern;
     assertResolvedNodeText(node1, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -72,7 +72,7 @@ GuardedPattern
     matchedValueType: int
 ''');
 
-    final node2 = findNode.caseClause('case final b').guardedPattern;
+    var node2 = findNode.caseClause('case final b').guardedPattern;
     assertResolvedNodeText(node2, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -90,11 +90,11 @@ void f(int x) {
   if (x case final a || final a) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 35, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 35, 1),
       error(WarningCode.DEAD_CODE, 37, 10),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 46, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 46, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: DeclaredVariablePattern
@@ -120,10 +120,10 @@ void f(int x) {
   if (x case 0 && final a || final a) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 40, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 51, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 40, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 51, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalAndPattern
@@ -157,17 +157,18 @@ void f(num x) {
   if (x case final int a || 2) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 39, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 39, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 44, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: DeclaredVariablePattern
     keyword: final
     type: NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
     name: a
     declaredElement: isFinal a@39
@@ -190,9 +191,9 @@ void f(int x) {
 }
 ''', [
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 29, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 40, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 40, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: ConstantPattern
@@ -217,11 +218,11 @@ void f(num x) {
   if (x case final int a || 2 || 3) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 39, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 39, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 44, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 49, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -229,7 +230,8 @@ LogicalOrPattern
       keyword: final
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       name: a
       declaredElement: isFinal a@39
@@ -258,11 +260,11 @@ void f(num x) {
   if (x case final int a || final int a || 3) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 39, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 54, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 39, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 54, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 59, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -270,7 +272,8 @@ LogicalOrPattern
       keyword: final
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       name: a
       declaredElement: isFinal a@39
@@ -281,7 +284,8 @@ LogicalOrPattern
       keyword: final
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       name: a
       declaredElement: isFinal a@54
@@ -304,13 +308,13 @@ void f(int x) {
   if (x case final a || final a || final a) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 35, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 35, 1),
       error(WarningCode.DEAD_CODE, 37, 10),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 46, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 46, 1),
       error(WarningCode.DEAD_CODE, 48, 10),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 57, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 57, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -345,11 +349,11 @@ void f(num x) {
   if (x case final int a || 2 || final int a) {}
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 39, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 39, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 44, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 59, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 59, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -357,7 +361,8 @@ LogicalOrPattern
       keyword: final
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       name: a
       declaredElement: isFinal a@39
@@ -375,7 +380,8 @@ LogicalOrPattern
     keyword: final
     type: NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
     name: a
     declaredElement: isFinal a@59
@@ -392,10 +398,10 @@ void f(num x) {
 }
 ''', [
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 29, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 44, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 44, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 49, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -409,7 +415,8 @@ LogicalOrPattern
       keyword: final
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element: dart:core::<fragment>::@class::int
+        element2: dart:core::@class::int
         type: int
       name: a
       declaredElement: isFinal a@44
@@ -433,11 +440,11 @@ void f(int x) {
 }
 ''', [
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 29, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 40, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 40, 1),
       error(WarningCode.DEAD_CODE, 42, 10),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 51, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 51, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -472,9 +479,9 @@ void f(int x) {
 }
 ''', [
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 29, 6),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 45, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 45, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: LogicalOrPattern
@@ -510,11 +517,11 @@ void f(int x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 46, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 46, 1),
       error(WarningCode.DEAD_CODE, 48, 10),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 57, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 57, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: DeclaredVariablePattern
@@ -545,17 +552,18 @@ void f(num x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 50, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 50, 1),
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 55, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: DeclaredVariablePattern
     keyword: final
     type: NamedType
       name: int
-      element: dart:core::@class::int
+      element: dart:core::<fragment>::@class::int
+      element2: dart:core::@class::int
       type: int
     name: a
     declaredElement: isFinal a@50
@@ -581,9 +589,9 @@ void f(int x) {
 }
 ''', [
       error(CompileTimeErrorCode.MISSING_VARIABLE_PATTERN, 40, 1),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 51, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 51, 1),
     ]);
-    final node = findNode.singleGuardedPattern.pattern;
+    var node = findNode.singleGuardedPattern.pattern;
     assertResolvedNodeText(node, r'''
 LogicalOrPattern
   leftOperand: ConstantPattern
@@ -612,13 +620,13 @@ void f(int x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 52, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 52, 1),
       error(WarningCode.DEAD_CODE, 59, 4),
       error(WarningCode.UNREACHABLE_SWITCH_CASE, 59, 4),
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 76, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 76, 1),
     ]);
 
-    final node1 = findNode.switchPatternCase('case /*1*/').guardedPattern;
+    var node1 = findNode.switchPatternCase('case /*1*/').guardedPattern;
     assertResolvedNodeText(node1, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -629,7 +637,7 @@ GuardedPattern
     matchedValueType: int
 ''');
 
-    final node2 = findNode.switchPatternCase('case /*2*/').guardedPattern;
+    var node2 = findNode.switchPatternCase('case /*2*/').guardedPattern;
     assertResolvedNodeText(node2, r'''
 GuardedPattern
   pattern: DeclaredVariablePattern
@@ -653,7 +661,7 @@ void f(num x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 53, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 53, 1),
     ]);
   }
 
@@ -667,7 +675,7 @@ void f(int x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 58, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 58, 1),
     ]);
   }
 
@@ -684,7 +692,7 @@ void f(int x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 46, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 46, 1),
     ]);
   }
 
@@ -701,7 +709,7 @@ void f(num x) {
   }
 }
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 53, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 53, 1),
     ]);
   }
 }
