@@ -47,6 +47,18 @@ class C extends Object with M {}
     ]);
   }
 
+  test_class_noMatchingInterface_fromAugmentation() async {
+    await assertErrorsInCode('''
+class B with M {}
+mixin M {}
+class A {}
+augment mixin M on A {}
+''', [
+      error(CompileTimeErrorCode.MIXIN_APPLICATION_NOT_IMPLEMENTED_INTERFACE,
+          13, 1),
+    ]);
+  }
+
   test_class_noMatchingInterface_withTypeArguments() async {
     await assertErrorsInCode('''
 abstract class A<T> {}
@@ -119,11 +131,12 @@ abstract class Directory implements FileSystemEntity, ioDirectory {}
 
 mixin DirectoryAddOnsMixin implements Directory {}
 ''', [
+      error(CompileTimeErrorCode.CONFLICTING_GENERIC_INTERFACES, 96, 15),
       error(WarningCode.UNUSED_ELEMENT, 96, 15),
     ]);
-    var mixins =
-        result.unit.declaredElement!.getClass('_LocalDirectory')!.mixins;
-    assertType(mixins[0], 'ForwardingDirectory<_LocalDirectory>');
+
+    var mixins = findElement2.class_('_LocalDirectory').mixins;
+    assertType(mixins[0], 'ForwardingDirectory<Directory>');
   }
 
   test_classTypeAlias_generic() async {
@@ -262,13 +275,13 @@ enum E with M {
 
   test_enum_noSuperclassConstraint_augmented() async {
     newFile(testFile.path, r'''
-import augment 'a.dart';
+part 'a.dart';
 mixin M {}
 enum E {v}
 ''');
 
     var a = newFile('$testPackageLibPath/a.dart', r'''
-augment library 'test.dart';
+part of 'test.dart';
 augment enum E with M {}
 ''');
 
