@@ -29,6 +29,24 @@ class B extends A {}
     ]);
   }
 
+  test_class_extends_inAugmentation() async {
+    newFile('$testPackageLibPath/a.dart', r'''
+part of 'test.dart';
+augment class B extend A {}
+''');
+
+    await assertErrorsInCode(r'''
+part 'a.dart';
+final class A {}
+class B {}
+''', [
+      error(CompileTimeErrorCode.SUBTYPE_OF_FINAL_IS_NOT_BASE_FINAL_OR_SEALED,
+          38, 1,
+          text:
+              "The type 'B' must be 'base', 'final' or 'sealed' because the supertype 'A' is 'final'."),
+    ]);
+  }
+
   test_class_extends_outside() async {
     // No [SUBTYPE_OF_FINAL_IS_NOT_BASE_FINAL_OR_SEALED] reported outside of
     // library.
