@@ -5,7 +5,6 @@
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
 import 'config_test.dart' as config;
-import 'io_test.dart' as io;
 import 'lint_rule_test.dart' as lint_rule;
 import 'linter/test_all.dart' as linter;
 import 'pub_test.dart' as pub;
@@ -13,7 +12,6 @@ import 'pub_test.dart' as pub;
 main() {
   defineReflectiveSuite(() {
     config.main();
-    io.main();
     lint_rule.main();
     linter.main();
     pub.main();
