@@ -4,8 +4,6 @@
 
 import 'dart:async';
 import 'dart:io';
-import 'dart:math' as math;
-import 'dart:typed_data';
 
 import 'package:flutter/foundation.dart' show kIsWeb;
 import 'package:flutter/material.dart';
@@ -14,6 +12,9 @@ import 'package:flutter_test/flutter_test.dart';
 import 'package:video_player/video_player.dart';
 import 'package:video_player_platform_interface/video_player_platform_interface.dart';
 
+// TODO(FirentisTFW): Remove the ignore and rename parameters when adding support for platform views.
+// ignore_for_file: avoid_renaming_method_parameters
+
 const String _localhost = 'https://127.0.0.1';
 final Uri _localhostUri = Uri.parse(_localhost);
 
@@ -131,6 +132,7 @@ void main() {
 
   testWidgets('update texture', (WidgetTester tester) async {
     final FakeController controller = FakeController();
+    addTearDown(controller.dispose);
     await tester.pumpWidget(VideoPlayer(controller));
     expect(find.byType(Texture), findsNothing);
 
@@ -146,6 +148,7 @@ void main() {
 
   testWidgets('update controller', (WidgetTester tester) async {
     final FakeController controller1 = FakeController();
+    addTearDown(controller1.dispose);
     controller1.textureId = 101;
     await tester.pumpWidget(VideoPlayer(controller1));
     expect(
@@ -155,6 +158,7 @@ void main() {
         findsOneWidget);
 
     final FakeController controller2 = FakeController();
+    addTearDown(controller2.dispose);
     controller2.textureId = 102;
     await tester.pumpWidget(VideoPlayer(controller2));
     expect(
@@ -169,29 +173,23 @@ void main() {
     final FakeController controller = FakeController.value(
         const VideoPlayerValue(
             duration: Duration.zero, rotationCorrection: 180));
+    addTearDown(controller.dispose);
     controller.textureId = 1;
     await tester.pumpWidget(VideoPlayer(controller));
-    final Transform actualRotationCorrection =
-        find.byType(Transform).evaluate().single.widget as Transform;
-    final Float64List actualRotationCorrectionStorage =
-        actualRotationCorrection.transform.storage;
-    final Float64List expectedMatrixStorage =
-        Matrix4.rotationZ(math.pi).storage;
-    expect(actualRotationCorrectionStorage.length,
-        equals(expectedMatrixStorage.length));
-    for (int i = 0; i < actualRotationCorrectionStorage.length; i++) {
-      expect(actualRotationCorrectionStorage[i],
-          moreOrLessEquals(expectedMatrixStorage[i]));
-    }
+    final RotatedBox actualRotationCorrection =
+        find.byType(RotatedBox).evaluate().single.widget as RotatedBox;
+    final int actualQuarterTurns = actualRotationCorrection.quarterTurns;
+    expect(actualQuarterTurns, equals(2));
   });
 
-  testWidgets('no transform when rotationCorrection is zero',
+  testWidgets('no RotatedBox when rotationCorrection is zero',
       (WidgetTester tester) async {
     final FakeController controller =
         FakeController.value(const VideoPlayerValue(duration: Duration.zero));
+    addTearDown(controller.dispose);
     controller.textureId = 1;
     await tester.pumpWidget(VideoPlayer(controller));
-    expect(find.byType(Transform), findsNothing);
+    expect(find.byType(RotatedBox), findsNothing);
   });
 
   group('ClosedCaption widget', () {
@@ -315,6 +313,7 @@ void main() {
             VideoPlayerController.networkUrl(
           Uri.parse('https://127.0.0.1'),
         );
+        addTearDown(controller.dispose);
         await controller.initialize();
         await controller.play();
         verifyPlayStateRespondsToLifecycle(controller,
@@ -334,6 +333,7 @@ void main() {
       test('network url', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(Uri.parse('https://127.0.0.1'));
+        addTearDown(controller.dispose);
         await controller.initialize();
 
         expect(
@@ -356,6 +356,7 @@ void main() {
           Uri.parse('https://127.0.0.1'),
           formatHint: VideoFormat.dash,
         );
+        addTearDown(controller.dispose);
         await controller.initialize();
 
         expect(
@@ -378,6 +379,7 @@ void main() {
           Uri.parse('https://127.0.0.1'),
           httpHeaders: <String, String>{'Authorization': 'Bearer token'},
         );
+        addTearDown(controller.dispose);
         await controller.initialize();
 
         expect(
@@ -401,6 +403,7 @@ void main() {
 
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(invalidUrl);
+        addTearDown(controller.dispose);
 
         late Object error;
         fakeVideoPlayerPlatform.forceInitError = true;
@@ -464,6 +467,7 @@ void main() {
           () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         fakeVideoPlayerPlatform.forceInitError = true;
         await controller.initialize().catchError((dynamic e) {});
@@ -485,6 +489,7 @@ void main() {
     test('dispose', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       expect(
           controller.textureId, VideoPlayerController.kUninitializedTextureId);
@@ -500,6 +505,7 @@ void main() {
     test('calling dispose() on disposed controller does not throw', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       await controller.dispose();
@@ -510,6 +516,7 @@ void main() {
     test('play', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(Uri.parse('https://127.0.0.1'));
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       expect(controller.value.isPlaying, isFalse);
@@ -529,6 +536,7 @@ void main() {
     test('play before initialized does not call platform', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       expect(controller.value.isInitialized, isFalse);
 
@@ -540,6 +548,7 @@ void main() {
     test('play restarts from beginning if video is at end', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       const Duration nonzeroDuration = Duration(milliseconds: 100);
@@ -557,6 +566,7 @@ void main() {
     test('setLooping', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       expect(controller.value.isLooping, isFalse);
@@ -568,6 +578,7 @@ void main() {
     test('pause', () async {
       final VideoPlayerController controller =
           VideoPlayerController.networkUrl(_localhostUri);
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       await controller.play();
@@ -583,6 +594,7 @@ void main() {
       test('works', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(await controller.position, Duration.zero);
@@ -595,6 +607,7 @@ void main() {
       test('before initialized does not call platform', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         expect(controller.value.isInitialized, isFalse);
 
@@ -606,6 +619,7 @@ void main() {
       test('clamps values that are too high or low', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(await controller.position, Duration.zero);
@@ -622,6 +636,7 @@ void main() {
       test('works', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.value.volume, 1.0);
@@ -635,6 +650,7 @@ void main() {
       test('clamps values that are too high or low', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.value.volume, 1.0);
@@ -651,6 +667,7 @@ void main() {
       test('works', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.value.playbackSpeed, 1.0);
@@ -664,6 +681,7 @@ void main() {
       test('rejects negative values', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(_localhostUri);
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.value.playbackSpeed, 1.0);
@@ -698,6 +716,7 @@ void main() {
         expect(controller.value.isPlaying, isTrue);
 
         await controller.pause();
+        await tester.runAsync(controller.dispose);
       });
 
       testWidgets('does not restart when dragging to end',
@@ -723,16 +742,57 @@ void main() {
 
         expect(controller.value.position, controller.value.duration);
         expect(controller.value.isPlaying, isFalse);
+        await tester.runAsync(controller.dispose);
       });
     });
 
     group('caption', () {
+      test('works when position updates', () async {
+        final VideoPlayerController controller =
+            VideoPlayerController.networkUrl(
+          _localhostUri,
+          closedCaptionFile: _loadClosedCaption(),
+        );
+
+        await controller.initialize();
+        await controller.play();
+
+        // Optionally record caption changes for later verification.
+        final Map<int, String> recordedCaptions = <int, String>{};
+
+        controller.addListener(() {
+          // Record the caption for the current position (in milliseconds).
+          final int ms = controller.value.position.inMilliseconds;
+          recordedCaptions[ms] = controller.value.caption.text;
+        });
+
+        const Duration updateInterval = Duration(milliseconds: 100);
+        const int totalDurationMs = 350;
+
+        // Simulate continuous playback by incrementing in 50ms steps.
+        for (int ms = 0; ms <= totalDurationMs; ms += 50) {
+          fakeVideoPlayerPlatform._positions[controller.textureId] =
+              Duration(milliseconds: ms);
+          await Future<void>.delayed(updateInterval);
+        }
+
+        // Now, given your closed caption file and the 100ms update interval,
+        // you expect:
+        //   • at 100ms: caption should be 'one'
+        //   • at 250ms: no caption (i.e. '')
+        //   • at 300ms: caption should be 'two'
+        expect(recordedCaptions[100], 'one');
+        expect(recordedCaptions[250], '');
+        expect(recordedCaptions[300], 'two');
+      });
+
       test('works when seeking', () async {
         final VideoPlayerController controller =
             VideoPlayerController.networkUrl(
           _localhostUri,
           closedCaptionFile: _loadClosedCaption(),
         );
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.value.position, Duration.zero);
@@ -766,6 +826,7 @@ void main() {
           _localhostUri,
           closedCaptionFile: _loadClosedCaption(),
         );
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         controller.setCaptionOffset(const Duration(milliseconds: 100));
@@ -803,6 +864,7 @@ void main() {
           _localhostUri,
           closedCaptionFile: _loadClosedCaption(),
         );
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         controller.setCaptionOffset(const Duration(milliseconds: -100));
@@ -842,6 +904,7 @@ void main() {
             VideoPlayerController.networkUrl(
           _localhostUri,
         );
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(controller.closedCaptionFile, null);
@@ -859,6 +922,7 @@ void main() {
           _localhostUri,
           closedCaptionFile: _loadClosedCaption(),
         );
+        addTearDown(controller.dispose);
 
         await controller.initialize();
         expect(
@@ -893,6 +957,7 @@ void main() {
 
         expect(controller.value.isPlaying, isFalse);
         expect(controller.value.position, nonzeroDuration);
+        await tester.runAsync(controller.dispose);
       });
 
       testWidgets('playback status', (WidgetTester tester) async {
@@ -917,6 +982,7 @@ void main() {
         ));
         await tester.pumpAndSettle();
         expect(controller.value.isPlaying, isFalse);
+        await tester.runAsync(controller.dispose);
       });
 
       testWidgets('buffering status', (WidgetTester tester) async {
@@ -953,10 +1019,46 @@ void main() {
             .add(VideoEvent(eventType: VideoEventType.bufferingEnd));
         await tester.pumpAndSettle();
         expect(controller.value.isBuffering, isFalse);
+        await tester.runAsync(controller.dispose);
       });
     });
   });
 
+  test('updates position', () async {
+    final VideoPlayerController controller = VideoPlayerController.networkUrl(
+      _localhostUri,
+      videoPlayerOptions: VideoPlayerOptions(),
+    );
+
+    await controller.initialize();
+
+    const Duration updatesInterval = Duration(milliseconds: 100);
+
+    final List<Duration> positions = <Duration>[];
+    final Completer<void> intervalUpdateCompleter = Completer<void>();
+
+    // Listen for position updates
+    controller.addListener(() {
+      positions.add(controller.value.position);
+      if (positions.length >= 3 && !intervalUpdateCompleter.isCompleted) {
+        intervalUpdateCompleter.complete();
+      }
+    });
+    await controller.play();
+    for (int i = 0; i < 3; i++) {
+      await Future<void>.delayed(updatesInterval);
+      fakeVideoPlayerPlatform._positions[controller.textureId] =
+          Duration(milliseconds: i * updatesInterval.inMilliseconds);
+    }
+
+    // Wait for at least 3 position updates
+    await intervalUpdateCompleter.future;
+
+    // Verify that the intervals between updates are approximately correct
+    expect(positions[1] - positions[0], greaterThanOrEqualTo(updatesInterval));
+    expect(positions[2] - positions[1], greaterThanOrEqualTo(updatesInterval));
+  });
+
   group('DurationRange', () {
     test('uses given values', () {
       const Duration start = Duration(seconds: 2);
@@ -1155,6 +1257,7 @@ void main() {
         _localhostUri,
         videoPlayerOptions: VideoPlayerOptions(mixWithOthers: true),
       );
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       expect(controller.videoPlayerOptions!.mixWithOthers, true);
@@ -1167,6 +1270,7 @@ void main() {
           allowBackgroundPlayback: true,
         ),
       );
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       await controller.play();
@@ -1181,6 +1285,7 @@ void main() {
         _localhostUri,
         videoPlayerOptions: VideoPlayerOptions(),
       );
+      addTearDown(controller.dispose);
 
       await controller.initialize();
       await controller.play();
@@ -1211,6 +1316,7 @@ void main() {
       _localhostUri,
       videoPlayerOptions: VideoPlayerOptions(),
     );
+    addTearDown(controller.dispose);
 
     await controller.initialize();
 
@@ -1238,6 +1344,7 @@ void main() {
       _localhostUri,
       videoPlayerOptions: VideoPlayerOptions(),
     );
+    addTearDown(controller.dispose);
 
     await controller.initialize();
 
@@ -1275,6 +1382,7 @@ void main() {
       _localhostUri,
       videoPlayerOptions: VideoPlayerOptions(),
     );
+    addTearDown(controller.dispose);
 
     await controller.initialize();
 
